@@ -2,7 +2,7 @@
 /**
  *  @brief Design matrix cached evaluation
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -43,7 +43,7 @@ DesignProxy::DesignProxy ()
 
 /* Parameters constructor */
 DesignProxy::DesignProxy(const Sample & x,
-                         const Basis & basis)
+                         const FunctionCollection & basis)
   : Object()
   , x_(x)
   , basis_(basis)
@@ -67,6 +67,7 @@ void DesignProxy::initialize() const
   UnsignedInteger nbCols = cacheSize / nbRows;
   // The cache stores at least the first function values
   if (nbCols <= 0) nbCols = 1;
+  if (nbCols > basis_.getSize()) nbCols = basis_.getSize();
   designCache_ = Matrix(nbRows, nbCols);
   alreadyComputed_ = Indices(nbCols, 0);
 }
@@ -167,7 +168,7 @@ Sample DesignProxy::getInputSample() const
 }
 
 /* Basis accessor */
-Basis DesignProxy::getBasis() const
+DesignProxy::FunctionCollection DesignProxy::getBasis() const
 {
   return basis_;
 }
