@@ -2,7 +2,7 @@
 /**
  *  @brief Basis selection algorithm
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -46,7 +46,7 @@ LeastSquaresMetaModelSelection::LeastSquaresMetaModelSelection()
 /* Default constructor */
 LeastSquaresMetaModelSelection::LeastSquaresMetaModelSelection(const Sample & x,
     const Sample & y,
-    const Basis & psi,
+    const FunctionCollection & psi,
     const Indices & indices,
     const BasisSequenceFactory & basisSequenceFactory,
     const FittingAlgorithm & fittingAlgorithm)
@@ -62,7 +62,7 @@ LeastSquaresMetaModelSelection::LeastSquaresMetaModelSelection(const Sample & x,
 LeastSquaresMetaModelSelection::LeastSquaresMetaModelSelection(const Sample & x,
     const Sample & y,
     const Point & weight,
-    const Basis & psi,
+    const FunctionCollection & psi,
     const Indices & indices,
     const BasisSequenceFactory & basisSequenceFactory,
     const FittingAlgorithm & fittingAlgorithm)
