@@ -2,7 +2,7 @@
 /**
  *  @brief A factory for building PenalizedLeastSquaresAlgorithm objects
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -55,11 +55,10 @@ String PenalizedLeastSquaresAlgorithmFactory::__repr__() const
 PenalizedLeastSquaresAlgorithm * PenalizedLeastSquaresAlgorithmFactory::build(const Sample & x,
     const Sample & y,
     const Point & weight,
-    const Basis & psi,
+    const FunctionCollection & psi,
     const Indices & indices) const
 {
-  const PenalizedLeastSquaresAlgorithm algo( x, y, weight, psi, indices, false, useNormal_ );
-  return algo.clone();
+  return new PenalizedLeastSquaresAlgorithm( x, y, weight, psi, indices, false, useNormal_ );
 }
 
 /* Method save() stores the object through the StorageManager */
