@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  AtomicFunctions.cxx
  *  @brief This file supplies some atomic functions to support multithreading
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,22 +14,20 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2007-05-10 16:43:31 +0200 (Thu, 10 May 2007)
  */
 
-#include "AtomicFunctions.hxx"
+#include "openturns/AtomicFunctions.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
-#if !defined(HAVE_SYNC_PRIMITIVES)
+#if !defined(OPENTURNS_HAVE_SYNC_BUILTINS)
 pthread_mutex_t Atomic::Atomic_Mutex_ = PTHREAD_MUTEX_INITIALIZER;
 #endif
 
-#if !defined(HAVE_SYNC_PRIMITIVES) && !defined(WIN32) && !defined(__i386__)
+#if !defined(OPENTURNS_HAVE_SYNC_BUILTINS) && !defined(_WIN32) && !defined(__i386__)
 #warning "Using slow implementation for synchronization functions."
 #endif
 
