@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  Catalog.cxx
  *  @brief Catalog records all user information to a file or tty
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,45 +14,51 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
 #include <iostream>
 #include <cstdlib>
 #include <assert.h>
 #include <errno.h>
-#include "OSS.hxx"
-#include "Catalog.hxx"
-#include "Exception.hxx"
-#include "Log.hxx"
-#include "MutexLock.hxx"
-#include "PersistentObjectFactory.hxx"
+#include "openturns/OSS.hxx"
+#include "openturns/Catalog.hxx"
+#include "openturns/Exception.hxx"
+#include "openturns/Log.hxx"
+#include "openturns/MutexLock.hxx"
+#include "openturns/PersistentObjectFactory.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
 
-
-
 static pthread_mutex_t Catalog_InstanceMutex_;
 static Catalog * Catalog_P_instance_ = 0;
-static pthread_once_t Catalog_InstanceMutex_once = PTHREAD_ONCE_INIT;
+static const Catalog_init static_initializer_Catalog;
 
 Catalog_init::Catalog_init()
 {
-  int rc = pthread_once( &Catalog_InstanceMutex_once, Catalog::Initialize );
-  if (rc != 0)
+  if (!Catalog_P_instance_)
   {
-    perror("Catalog_init::Log_init once Initialization failed");
-    exit(1);
+#ifndef OT_MUTEXINIT_NOCHECK
+    pthread_mutexattr_t attr;
+    pthread_mutexattr_init( &attr );
+    pthread_mutexattr_settype( &attr, PTHREAD_MUTEX_ERRORCHECK );
+    pthread_mutex_init( &Catalog_InstanceMutex_, &attr );
+#else
+    pthread_mutex_init( &Catalog_InstanceMutex_, NULL );
+#endif
+    Catalog_P_instance_ = new Catalog;
   }
+  assert(Catalog_P_instance_);
 }
 
 Catalog_init::~Catalog_init()
 {
-  Catalog::Release();
+  if (Catalog_P_instance_)
+    pthread_mutex_destroy(&Catalog_InstanceMutex_);
+  delete Catalog_P_instance_;
+  Catalog_P_instance_ = 0;
 }
 
 
@@ -61,8 +66,7 @@ Catalog_init::~Catalog_init()
 Catalog::Catalog()
   : catalog_()
 {
-  // Registration of destructor at exit
-  // std::atexit( Catalog::Release );
+  // Do nothing
 }
 
 
@@ -77,53 +81,30 @@ Catalog::~Catalog()
 }
 
 
-/* Return the catalog as a singleton */
-Catalog & Catalog::GetInstance()
+template<>
+MutexLockSingleton<Catalog>::MutexLockSingleton( Catalog & singleton )  throw()
+  : singleton_(singleton)
+  , lock_(Catalog_InstanceMutex_) {}
+
+
+MutexLockSingleton<Catalog> Catalog::GetInstance()
 {
-  if (!Catalog_P_instance_)
-  {
-    Catalog_P_instance_ = new Catalog;
-    assert(Catalog_P_instance_);
-  }
+  static const Catalog_init force_instantiation;
+  // Catalog_InstanceMutex_ is always initialized
   return *Catalog_P_instance_;
 }
 
-
-void Catalog::Initialize()
+/* Get the list of keys */
+std::vector<String> Catalog::GetKeys()
 {
-#ifndef OT_MUTEXINIT_NOCHECK
-  pthread_mutexattr_t attr;
-  pthread_mutexattr_init( &attr );
-  //pthread_mutexattr_settype( &attr, PTHREAD_MUTEX_NORMAL );
-  pthread_mutexattr_settype( &attr, PTHREAD_MUTEX_ERRORCHECK );
-  //pthread_mutexattr_settype( &attr, PTHREAD_MUTEX_RECURSIVE );
-  int rc = pthread_mutex_init( &Catalog_InstanceMutex_, &attr );
-  if (rc != 0)
-  {
-    perror("Catalog::Initialize mutex initialization failed");
-    exit(1);
-  }
-#else
-  pthread_mutex_init( &Catalog_InstanceMutex_, NULL );
-#endif
-  Catalog_P_instance_ = new Catalog;
-  assert(Catalog_P_instance_);
-}
-
-
-
-void Catalog::Release()
-{
-  delete Catalog_P_instance_;
-  Catalog_P_instance_ = 0;
+  return GetInstance().lock().getKeys();
 }
 
 
 /* Get the factory from its name */
 const PersistentObjectFactory & Catalog::Get(const String & factoryName)
 {
-  MutexLock lock( Catalog_InstanceMutex_ );
-  return GetInstance().get( factoryName );
+  return GetInstance().lock().get( factoryName );
 }
 
 /* Get the factory from its name */
@@ -137,11 +118,21 @@ const PersistentObjectFactory & Catalog::get(const String & factoryName) const
 }
 
 
+/* Get the list of keys */
+std::vector<String> Catalog::getKeys() const
+{
+  std::vector<String> keys;
+  for(CatalogType::const_iterator it = catalog_.begin(); it != catalog_.end(); ++it)
+  {
+    keys.push_back(it->first);
+  }
+  return keys;
+}
+
 /* Add a new factory to the catalog */
 void Catalog::Add(const String & factoryName, const PersistentObjectFactory * p_factory)
 {
-  MutexLock lock( Catalog_InstanceMutex_ );
-  GetInstance().add( factoryName, p_factory );
+  GetInstance().lock().add( factoryName, p_factory );
 }
 
 /* Add a new factory to the catalog */
