@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  Exception.cxx
  *  @brief Exception defines top-most exception strategies
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,31 +14,26 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-04-18 17:56:46 +0200 (Wed, 18 Apr 2012)
  */
 #include <cstdlib>
 #include <assert.h>
 //#include <typeinfo>
-#include "OSS.hxx"
-#include "Exception.hxx"
-#include "Log.hxx"
+#include "openturns/OSS.hxx"
+#include "openturns/Exception.hxx"
+#include "openturns/Log.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
 
-
-
-
 /* Default constructor */
 Exception::Exception(const PointInSourceFile & point)
-  : std::exception(),
-    point_(point),
-    reason_(),
-    className_("Exception")
+  : std::exception()
+  , point_(point)
+  , reason_()
+  , className_("Exception")
 {
   // Nothing to do
   //LOGDEBUG(OSS() << className_  << " typeid = " << typeid(*this).name() );
@@ -47,18 +41,21 @@ Exception::Exception(const PointInSourceFile & point)
 
 /* Copy constructor */
 Exception::Exception(const Exception & other)
-  : std::exception(other), point_(other.point_), reason_(other.reason_), className_(other.className_)
+  : std::exception(other)
+  , point_(other.point_)
+  , reason_(other.reason_)
+  , className_(other.className_)
 {
   //LOGDEBUG(OSS() << className_  << " emited at " << point_.str() << ": " << String(reason_) );
 }
 
 /* Inheritance constructor */
 Exception::Exception(const PointInSourceFile & point,
-                     const char * type)
-  : std::exception(),
-    point_(point),
-    reason_(),
-    className_(type)
+                     const char * className)
+  : std::exception()
+  , point_(point)
+  , reason_()
+  , className_(className)
 {
   // Nothing to do
 }
@@ -130,11 +127,8 @@ DEFINE_EXCEPTION( FileNotFoundException )
 DEFINE_EXCEPTION( InternalException )
 DEFINE_EXCEPTION( InvalidArgumentException )
 DEFINE_EXCEPTION( InvalidDimensionException )
-DEFINE_EXCEPTION( NoWrapperFileFoundException )
 DEFINE_EXCEPTION( NotYetImplementedException )
 DEFINE_EXCEPTION( OutOfBoundException )
-DEFINE_EXCEPTION( WrapperFileParsingException )
-DEFINE_EXCEPTION( WrapperInternalException )
 DEFINE_EXCEPTION( XMLException )
 DEFINE_EXCEPTION( XMLParserException )
 DEFINE_EXCEPTION( DynamicLibraryException )
