@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  Lockable.cxx
  *  @brief The class Lockable defines an interface for the lock functionality
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,13 +14,11 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "Lockable.hxx"
+#include "openturns/Lockable.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
