@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  Log.cxx
  *  @brief Log records all user information to a file or tty
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,25 +14,25 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @author schueller
- *  @date   2012-07-16 10:12:54 +0200 (Mon, 16 Jul 2012)
  */
 #include <iostream>
 #include <cstdlib>
 #include <cassert>
 #include <errno.h>
 
-#include "OTthread.hxx"
-#include "Log.hxx"
-#include "OTconfig.hxx"
-#include "MutexLock.hxx"
+#include "openturns/OTthread.hxx"
+#include "openturns/Log.hxx"
+#include "openturns/OTconfig.hxx"
+#include "openturns/MutexLock.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
+static pthread_mutex_t Log_InstanceMutex_;
+static Log * Log_P_instance_ = 0;
+static const Log_init static_initializer_Log;
 
 
 static inline
@@ -48,23 +47,33 @@ std::ostream & operator << ( std::ostream & os, const _Prefix & pfx )
 }
 
 
-static pthread_mutex_t Log_InstanceMutex_;
-static Log * Log_P_instance_ = 0;
-static pthread_once_t Log_InstanceMutex_once = PTHREAD_ONCE_INIT;
-
 Log_init::Log_init()
 {
-  int rc = pthread_once( &Log_InstanceMutex_once, Log::Initialization );
-  if (rc != 0)
+  if (!Log_P_instance_)
   {
-    perror("Log_init::Log_init once Initialization failed");
-    exit(1);
+#ifndef OT_MUTEXINIT_NOCHECK
+    pthread_mutexattr_t attr;
+    pthread_mutexattr_init( &attr );
+    pthread_mutexattr_settype( &attr, PTHREAD_MUTEX_RECURSIVE );
+    pthread_mutex_init( &Log_InstanceMutex_, &attr );
+#else
+    pthread_mutex_init( &Log_InstanceMutex_, NULL );
+#endif
+    Log_P_instance_ = new Log;
+    Log_P_instance_->push(Log::Entry(Log::INFO, "*** Log Beginning ***"));
   }
+  assert(Log_P_instance_);
 }
 
 Log_init::~Log_init()
 {
-  Log::Release();
+  if (Log_P_instance_)
+  {
+    Log_P_instance_->push(Log::Entry(Log::INFO, "*** Log End ***"));
+    pthread_mutex_destroy(&Log_InstanceMutex_);
+  }
+  delete Log_P_instance_;
+  Log_P_instance_ = 0;
 }
 
 
@@ -72,7 +81,6 @@ const Log::Severity Log::NONE    =  0;
 const Log::Severity Log::ALL     = ~0;
 
 const Log::Severity Log::DBG     = 1 << 0;
-const Log::Severity Log::WRAPPER = 1 << 1;
 const Log::Severity Log::INFO    = 1 << 2;
 const Log::Severity Log::USER    = 1 << 3;
 const Log::Severity Log::WARN    = 1 << 4;
@@ -96,17 +104,14 @@ Log::Log()
   logName_[NONE]    = make_prefix( String(TTY::GetColor(TTY::DEFAULT))                                    , "", "   " );
   logName_[ALL]     = make_prefix( String(TTY::GetColor(TTY::DEFAULT))                                    , "", "ALL" );
   logName_[DBG]     = make_prefix( String(TTY::GetColor(TTY::DEFAULT))                                    , "", "DBG" );
-  logName_[WRAPPER] = make_prefix( String(TTY::GetColor(TTY::BLUEFG))                                     , "", "WRP" );
-  logName_[INFO]    = make_prefix( String(TTY::GetColor(TTY::BLUEFG))                                     , "", "INF" );
-  logName_[USER]    = make_prefix( String(TTY::GetColor(TTY::BLUEFG))                                     , "", "USR" );
-  logName_[WARN]    = make_prefix( String(TTY::GetColor(TTY::PURPLEFG)) + String(TTY::GetColor(TTY::BOLD)), "", "WRN" );
-  logName_[ERROR]   = make_prefix( String(TTY::GetColor(TTY::REDFG))    + String(TTY::GetColor(TTY::BOLD)), "", "ERR" );
+  logName_[INFO]    = make_prefix( String(TTY::GetColor(TTY::GREENFG))                                     , "", "INF" );
+  logName_[USER]    = make_prefix( String(TTY::GetColor(TTY::CYANFG))                                     , "", "USR" );
+  logName_[WARN]    = make_prefix( String(TTY::GetColor(TTY::BLUEFG)) + String(TTY::GetColor(TTY::BOLD)), "", "WRN" );
+  logName_[ERROR]   = make_prefix( String(TTY::GetColor(TTY::REDFG))  + String(TTY::GetColor(TTY::BOLD)), "", "ERR" );
   logName_[TRACE]   = make_prefix( String(TTY::GetColor(TTY::YELLOWFG))                                   , "", "TRA" );
 
   initSeverityFromEnvironment();
 
-  // Registration of destructor at exit
-  //std::atexit(Log::Release);
 }
 
 
@@ -153,79 +158,36 @@ void Log::initSeverityFromEnvironment()
 }
 
 
-Log & Log::GetInstance()
+template<>
+MutexLockSingleton<Log>::MutexLockSingleton( Log & singleton )  throw()
+  : singleton_(singleton)
+  , lock_(Log_InstanceMutex_) {}
+
+
+/* GetInstance gives a locked access to the singleton */
+MutexLockSingleton<Log> Log::GetInstance()
 {
-  if (!Log_P_instance_)
-  {
-    Log_P_instance_ = new Log;
-    assert(Log_P_instance_);
-    Log_P_instance_->push(Entry(INFO, "*** Log Beginning ***"));
-  }
+  static const Log_init force_instantiation;
+  // Log_InstanceMutex_ is always initialized
   return *Log_P_instance_;
 }
 
-
-void Log::Initialization()
-{
-#ifndef OT_MUTEXINIT_NOCHECK
-  pthread_mutexattr_t attr;
-  pthread_mutexattr_init( &attr );
-  //pthread_mutexattr_settype( &attr, PTHREAD_MUTEX_NORMAL );
-  pthread_mutexattr_settype( &attr, PTHREAD_MUTEX_ERRORCHECK );
-  //pthread_mutexattr_settype( &attr, PTHREAD_MUTEX_RECURSIVE );
-  int rc = pthread_mutex_init( &Log_InstanceMutex_, &attr );
-  if (rc != 0)
-  {
-    perror("Log::Initialization mutex initialization failed");
-    exit(1);
-  }
-#else
-  pthread_mutex_init( &Log_InstanceMutex_, NULL );
-#endif
-  Log_P_instance_ = 0;
-}
-
-
-
-void Log::Release()
-{
-  if (Log_P_instance_) Log_P_instance_->push(Entry(INFO, "*** Log End ***"));
-  delete Log_P_instance_;
-  Log_P_instance_ = 0;
-}
-
-
-
 void Log::Reset()
 {
-  //Release();
-  //Initialization();
 }
 
 
 /* Log messages according to its relative severity */
 void Log::Debug(const String & msg)
 {
-  MutexLock lock( Log_InstanceMutex_ );
-  Log::GetInstance().push(Entry(DBG, msg));
+  GetInstance().lock().push(Entry(DBG, msg));
 }
 
 
-
-/* Log messages according to its relative severity */
-void Log::Wrapper(const String & msg)
-{
-  MutexLock lock( Log_InstanceMutex_ );
-  Log::GetInstance().push(Entry(WRAPPER, msg));
-}
-
-
-
 /*  Log messages according to its relative severity */
 void Log::Info(const String & msg)
 {
-  MutexLock lock( Log_InstanceMutex_ );
-  Log::GetInstance().push(Entry(INFO, msg));
+  GetInstance().lock().push(Entry(INFO, msg));
 }
 
 
@@ -233,8 +195,7 @@ void Log::Info(const String & msg)
 /*  Log messages according to its relative severity */
 void Log::User(const String & msg)
 {
-  MutexLock lock( Log_InstanceMutex_ );
-  Log::GetInstance().push(Entry(USER, msg));
+  GetInstance().lock().push(Entry(USER, msg));
 }
 
 
@@ -242,8 +203,7 @@ void Log::User(const String & msg)
 /* Log messages according to its relative severity */
 void Log::Warn(const String & msg)
 {
-  MutexLock lock( Log_InstanceMutex_ );
-  Log::GetInstance().push(Entry(WARN, msg));
+  GetInstance().lock().push(Entry(WARN, msg));
 }
 
 
@@ -251,16 +211,14 @@ void Log::Warn(const String & msg)
 /* Log messages according to its relative severity */
 void Log::Error(const String & msg)
 {
-  MutexLock lock( Log_InstanceMutex_ );
-  Log::GetInstance().push(Entry(ERROR, msg));
+  GetInstance().lock().push(Entry(ERROR, msg));
 }
 
 
 /* Log messages according to its relative severity */
 void Log::Trace(const String & msg)
 {
-  MutexLock lock( Log_InstanceMutex_ );
-  Log::GetInstance().push(Entry(TRACE, msg));
+  GetInstance().lock().push(Entry(TRACE, msg));
 }
 
 
@@ -279,8 +237,7 @@ Log::Severity Log::Flags()
 /* Flush pending messages */
 void Log::Flush()
 {
-  MutexLock lock( Log_InstanceMutex_ );
-  Log::GetInstance().flush();
+  GetInstance().lock().flush();
 }
 
 
@@ -293,8 +250,7 @@ void Log::Flush()
  */
 void Log::Repeat( Bool r )
 {
-  MutexLock lock( Log_InstanceMutex_ );
-  Log::GetInstance().repeat( r );
+  GetInstance().lock().repeat( r );
 }
 
 void Log::repeat( Bool r )
@@ -337,8 +293,7 @@ void Log::printRepeatedMessage(const Entry & entry)
 /* Set the name of the log file */
 void Log::SetFile(const FileName & file)
 {
-  MutexLock lock( Log_InstanceMutex_ );
-  Log::GetInstance().setFile(file);
+  GetInstance().lock().setFile(file);
 }
 
 
@@ -358,15 +313,13 @@ void Log::setFile(const FileName & file)
 void Log::SetColor(const Log::Severity severity,
                    const TTY::Color color)
 {
-  MutexLock lock( Log_InstanceMutex_ );
-  Log::GetInstance().setColor(severity, String(TTY::GetColor(color)));
+  GetInstance().lock().setColor(severity, String(TTY::GetColor(color)));
 }
 
 void Log::SetColor(const Log::Severity severity,
                    const String & color)
 {
-  MutexLock lock( Log_InstanceMutex_ );
-  Log::GetInstance().setColor(severity, color);
+  GetInstance().lock().setColor(severity, color);
 }
 
 
@@ -379,8 +332,7 @@ void Log::setColor(const Log::Severity severity,
 /* Get the color */
 String Log::GetColor(const Log::Severity severity)
 {
-  MutexLock lock( Log_InstanceMutex_ );
-  return Log::GetInstance().getColor(severity);
+  return GetInstance().lock().getColor(severity);
 }
 
 String Log::getColor(const Log::Severity severity) const
