@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  Memory.cxx
  *  @brief This file declares memory debugging functions
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,16 +14,14 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2008-05-21 17:44:02 +0200 (Wed, 21 May 2008)
  */
 #include <cstdio>
 #include <algorithm>
 #include <cassert>
-#include "Memory.hxx"
+#include "openturns/Memory.hxx"
 
 #ifdef DEBUG_MEMORY
 
