@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  Os.cxx
  *  @brief This class provides operating system specific variables
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,26 +14,34 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2009-04-30 12:04:13 +0200 (jeu 30 avr 2009)
  */
 
-#include "OTwindows.h" // For CreateProcess
-#include "Os.hxx"
-#include "Log.hxx"
-#include "OSS.hxx"
-#include "ResourceMap.hxx" // For ResourceMap
+#include "openturns/OTwindows.h" // For CreateProcess
+#include "openturns/Os.hxx"
+#include "openturns/Log.hxx"
+#include "openturns/OSS.hxx"
+#include "openturns/ResourceMap.hxx" // For ResourceMap
+
+// include OTConfig that defines OPENTURNS_HAVE_XXX
+#include "openturns/OTconfig.hxx"
 
 #ifdef OPENTURNS_HAVE_UNISTD_H
 # include <unistd.h>  // for rmdir, unlink
 #endif
 
 #include <cstdlib>   // for system(3)
-#include <sys/types.h>            // for stat
-#include <sys/stat.h>             // for stat
+
+#ifdef OPENTURNS_HAVE_SYS_TYPES_H
+# include <sys/types.h>            // for stat
+#endif
+
+#ifdef OPENTURNS_HAVE_SYS_STAT_H
+# include <sys/stat.h>             // for stat
+#endif
+
 #include <fcntl.h>
 #ifndef WIN32
 #include <ftw.h>       // for stat(2)
@@ -46,6 +53,9 @@
 # if !defined(S_ISDIR)
 #  define S_ISDIR(mode) (((mode) & S_IFDIR) != 0)
 # endif
+# if !defined(S_ISREG)
+#  define S_ISREG(mode) (((mode) & S_IFREG) != 0)
+# endif
 #elif defined(WIN32)
 # define MKDIR(p, mode)  mkdir(p)
 #else
@@ -112,7 +122,7 @@ int Os::ExecuteCommand(const String & command)
     // Create the process
     DWORD dwProcessFlags = 0;
     char * cmd = strdup(command.c_str());
-    const Bool processOk = CreateProcess(NULL, cmd, NULL, NULL, true, dwProcessFlags, NULL, NULL, &si, &pi);
+    const Bool processOk = CreateProcess(NULL, cmd, NULL, NULL, true, dwProcessFlags, NULL, NULL, &si, &pi) != 0;
     free(cmd);
     if ( processOk )
     {
@@ -121,7 +131,7 @@ int Os::ExecuteCommand(const String & command)
       if ( waitRc != WAIT_FAILED )
       {
         DWORD exit_code = 0;
-        const Bool codeOk = GetExitCodeProcess(pi.hProcess, &exit_code);
+        const Bool codeOk = GetExitCodeProcess(pi.hProcess, &exit_code) != 0;
         if (codeOk)
         {
           rc = exit_code;
@@ -180,20 +190,25 @@ convert_backslashes(String & path)
 #endif
 }
 
-// Function helper for Os::MakeDirectory
-static bool
-is_directory(const char * name)
+Bool Os::IsDirectory(const String & fileName)
 {
   struct stat dir_stat;
-  if(stat(name, &dir_stat) != 0) return false;
+  if(stat(fileName.c_str(), &dir_stat) != 0) return false;
   return S_ISDIR(dir_stat.st_mode);
 }
 
+Bool Os::IsFile(const String & fileName)
+{
+  struct stat dir_stat;
+  if(stat(fileName.c_str(), &dir_stat) != 0) return false;
+  return S_ISREG(dir_stat.st_mode);
+}
+
 // Returns 0 if no error
 int Os::MakeDirectory(const String & path)
 {
   if (path.empty()) return 1;
-  if (is_directory(path.c_str())) return 0;
+  if (IsDirectory(path)) return 0;
 
   String slashPath(path);
   convert_backslashes(slashPath);
@@ -203,7 +218,7 @@ int Os::MakeDirectory(const String & path)
   {
     String current_dir(path.substr(0, pos));
     const char * cpath = current_dir.c_str();
-    if (!is_directory(cpath) && (0 != MKDIR(cpath, 0777))) return 1;
+    if (!IsDirectory(current_dir) && (0 != MKDIR(cpath, 0777))) return 1;
     pos++;
   }
 
@@ -244,7 +259,7 @@ static int deleteRegularFileOrDirectory(const char * path,
 int Os::DeleteDirectory(const String & path)
 {
   if (path.empty()) return 1;
-  if (!is_directory(path.c_str())) return 1;
+  if (!IsDirectory(path)) return 1;
 
   // Refuse to delete root directory (/) and current directory (.)
   if (path == "/" || path == ".") return 1;
@@ -259,49 +274,36 @@ int Os::DeleteDirectory(const String & path)
   }
 #endif
 
-  struct stat file_stat;
   int rc = 0;
-  rc = stat( directory, &file_stat );
-  if (rc == 0)
-  {
-    if (! S_ISDIR(file_stat.st_mode))
-    {
-      // Not a directory
-      return 1;
-    }
-  }
 
 #ifndef WIN32
 
-  rc = nftw( directory, deleteRegularFileOrDirectory, 20, FTW_DEPTH );
-  if ( rc != 0 ) return 1;
+  rc = nftw(directory, deleteRegularFileOrDirectory, 20, FTW_DEPTH);
 
 #else /* WIN32 */
 
-  size_t timeout = ResourceMap::GetAsUnsignedInteger("output-files-timeout");
-  size_t countdown = timeout;
-  OT::String rmdirCmd = OT::String("rmdir /Q /S \"") + directory + "\"";
-  int directoryExists;
+  UnsignedInteger countdown = ResourceMap::GetAsUnsignedInteger("output-files-timeout");
+  String rmdirCmd("rmdir /Q /S \"" + path + "\"");
+  Bool directoryExists = true;
 
   do
   {
-    rc = system( (rmdirCmd + " > NUL 2>&1").c_str() );
+    rc = system((rmdirCmd + " > NUL 2>&1").c_str());
 
     // check if directory still there (rmdir dos command always return 0)
-    struct stat dir_stat;
-    directoryExists = stat( directory, &dir_stat );
-    if( directoryExists == 0 )
+    directoryExists = IsDirectory(path);
+    if (directoryExists)
     {
-      if  ( countdown <= 0 ) return 1;
-      --countdown;
+      if (countdown == 0) return 1;
+      -- countdown;
     }
-    Sleep( 1000 );
+    Sleep(1000);
   }
-  while( directoryExists == 0 );
+  while (directoryExists);
 
 #endif /* WIN32 */
 
-  return 0;
+  return rc;
 }
 
 
