@@ -2,7 +2,7 @@
 /**
  *  @brief ResourceMap defines top-most resourceMap strategies
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -106,12 +106,6 @@ Scalar ResourceMap::GetAsScalar(String key)
   return GetInstance().lock().getAsScalar( key );
 }
 
-Scalar ResourceMap::GetAsNumericalScalar(String key)
-{
-  return GetAsScalar(key);
-}
-
-/* Get the size of the map */
 UnsignedInteger ResourceMap::GetSize()
 {
   return GetInstance().lock().getSize();
@@ -138,11 +132,6 @@ void ResourceMap::SetAsScalar(String key, Scalar value)
   GetInstance().lock().setAsScalar( key, value );
 }
 
-void ResourceMap::SetAsNumericalScalar(String key, Scalar value)
-{
-  SetAsScalar(key, value);
-}
-
 /* Default constructor */
 ResourceMap::ResourceMap()
   : map_()
@@ -310,6 +299,10 @@ void ResourceMap::loadDefaultConfiguration()
   setAsUnsignedInteger( "SpecFunc-MaximumIteration", 1000 );
   setAsScalar( "SpecFunc-Precision", 2.0e-16 );
 
+  // SymbolicParser parameters
+  set( "SymbolicParser-Backend", SYMBOLICPARSER_DEFAULT_BACKEND );
+  setAsBool( "SymbolicParser-CheckResult", true );
+
   // GramProxy parameters
   setAsUnsignedInteger( "DesignProxy-DefaultCacheSize", 16777216 );// 2^24=16777216=128 Mio
 
@@ -375,6 +368,7 @@ void ResourceMap::loadDefaultConfiguration()
   setAsScalar( "SQP-DefaultTau", 0.5 );
   setAsScalar( "SQP-DefaultOmega", 1.0e-4 );
   setAsScalar( "SQP-DefaultSmooth", 1.2 );
+  setAsUnsignedInteger ("SQP-DefaultMaximumEvaluationNumber", 100000);
 
   // TNC parameters //
   setAsUnsignedInteger( "TNC-DefaultMaxCGit", 50 );
@@ -388,11 +382,12 @@ void ResourceMap::loadDefaultConfiguration()
   setAsScalar( "AbdoRackwitz-DefaultTau", 0.5 );
   setAsScalar( "AbdoRackwitz-DefaultOmega", 1.0e-4 );
   setAsScalar( "AbdoRackwitz-DefaultSmooth", 1.2 );
+  setAsUnsignedInteger ("AbdoRackwitz-DefaultMaximumEvaluationNumber", 100000);
 
   // OptimizationAlgorithm parameters //
   setAsScalar( "OptimizationAlgorithm-DefaultLevelValue", 0.0 );
-  setAsUnsignedInteger( "OptimizationAlgorithm-DefaultMaximumIteration", 100 );
-  setAsUnsignedInteger( "OptimizationAlgorithm-DefaultMaximumEvaluationNumber", 100000);
+  setAsUnsignedInteger( "OptimizationAlgorithm-DefaultMaximumIterationNumber", 100 );
+  setAsUnsignedInteger( "OptimizationAlgorithm-DefaultMaximumEvaluationNumber", 100);
   setAsScalar( "OptimizationAlgorithm-DefaultMaximumAbsoluteError", 1.0e-5 );
   setAsScalar( "OptimizationAlgorithm-DefaultMaximumRelativeError", 1.0e-5 );
   setAsScalar( "OptimizationAlgorithm-DefaultMaximumResidualError", 1.0e-5 );
@@ -426,6 +421,11 @@ void ResourceMap::loadDefaultConfiguration()
   setAsUnsignedInteger( "IteratedQuadrature-MaximumSubIntervals", 32 );
   setAsScalar( "IteratedQuadrature-MaximumError",    1.0e-7 );
 
+  // Fehlberg parameters //
+  setAsScalar("Fehlberg-LocalPrecision", 1.0e-10);
+  setAsScalar("Fehlberg-InitialStep", 1.0e-7);
+  setAsUnsignedInteger("Fehlberg-DefaultOrder", 4);
+
   // KarhunenLoeveQuadratureAlgorithm parameters //
   setAsScalar( "KarhunenLoeveQuadratureAlgorithm-RegularizationFactor", 0.0);
 
@@ -467,7 +467,7 @@ void ResourceMap::loadDefaultConfiguration()
   setAsUnsignedInteger( "SobolSequence-InitialSeed", 1 );
 
   // SensitivityAlgorithm parameters //
-  setAsBool( "MartinezSensitivityAlgorithm-UseAsymptoticInterval", false );
+  setAsBool( "SobolIndicesAlgorithm-DefaultUseAsymptoticDistribution", false );
   setAsUnsignedInteger( "SobolIndicesAlgorithm-DefaultBlockSize", 1 );
   setAsUnsignedInteger( "SobolIndicesAlgorithm-DefaultBootstrapSize", 100 );
   setAsScalar( "SobolIndicesAlgorithm-DefaultBootstrapConfidenceLevel", 0.95 );
@@ -507,7 +507,18 @@ void ResourceMap::loadDefaultConfiguration()
   // Mesh parameters
   setAsScalar( "Mesh-VertexEpsilon", 1.0e-12 );
   setAsUnsignedInteger( "Mesh-LargeSize", 5000 );
-  setAsUnsignedInteger( "Mesh-UseKDTree", 1 );
+  setAsBool( "Mesh-BackfaceCulling", false );
+  setAsScalar( "Mesh-DiffuseFactor", 0.7 );
+  setAsScalar( "Mesh-AmbientFactor", 0.1 );
+  setAsScalar( "Mesh-SpecularFactor", 0.2 );
+  setAsScalar( "Mesh-Shininess", 100.0 );
+
+  // BoundingVolumeHierarchy parameters
+  setAsUnsignedInteger( "BoundingVolumeHierarchy-BinNumber", 50 );
+  set( "BoundingVolumeHierarchy-Strategy", "Mean" );
+
+  // EnclosingSimplexAlgorithm parameters
+  setAsUnsignedInteger( "EnclosingSimplexAlgorithm-LargeDimension", 5);
 
   // Matrix parameters
   setAsUnsignedInteger( "Matrix-size-visible-in-str-from", 5 );
@@ -523,7 +534,12 @@ void ResourceMap::loadDefaultConfiguration()
   setAsScalar( "Matrix-SymmetryThreshold", 1.0e-12 );
 
   // BernsteinCopulaFactory parameters //
-  setAsBool( "BernsteinCopulaFactory-Parallel", false );
+  setAsUnsignedInteger( "BernsteinCopulaFactory-kFraction", 2 );
+  setAsScalar( "BernsteinCopulaFactory-alpha", 1.0 );
+  set( "BernsteinCopulaFactory-BinNumberSelectionMethod", "LogLikelihood" );
+  setAsUnsignedInteger( "BernsteinCopulaFactory-MinM", 2 );
+  setAsUnsignedInteger( "BernsteinCopulaFactory-MaxM", 1 );
+  setAsUnsignedInteger( "BernsteinCopulaFactory-SamplingSize", 10000 );
 
   // BurrFactory parameters //
   setAsScalar( "BurrFactory-AbsolutePrecision", 1.0e-12 );
@@ -554,6 +570,9 @@ void ResourceMap::loadDefaultConfiguration()
   setAsScalar( "FisherSnedecorFactory-D1LowerBound", 1.0e-2 );
   setAsScalar( "FisherSnedecorFactory-D2LowerBound", 1.0e-2 );
 
+  // FrechetFactory parameters //
+  setAsScalar( "FrechetFactory-BoundMargin", 10.0 );
+
   // GeneralizedExtremeValue parameters //
   setAsScalar( "GeneralizedExtremeValue-XiThreshold", 1.0e-6 );
 
@@ -637,7 +656,7 @@ void ResourceMap::loadDefaultConfiguration()
   // TrapezoidalFactory parameters //
   setAsScalar( "TrapezoidalFactory-RhoBeg", 0.1 );
   setAsScalar( "TrapezoidalFactory-RhoEnd", 1.0e-5 );
-  setAsUnsignedInteger( "TrapezoidalFactory-MaximumIteration", 10000 );
+  setAsUnsignedInteger( "TrapezoidalFactory-MaximumIteration", 2000 );
 
   // TruncatedDistribution parameters //
   setAsScalar( "TruncatedDistribution-DefaultThresholdRealization", 0.5 );
@@ -646,6 +665,7 @@ void ResourceMap::loadDefaultConfiguration()
   setAsScalar( "TruncatedNormalFactory-SigmaLowerBound", 1.0e-4 );
 
   // MaximumLikelihoodFactory parameters //
+  set( "MaximumLikelihoodFactory-DefaultOptimizationAlgorithm", "TNC" );
   setAsUnsignedInteger( "MaximumLikelihoodFactory-MaximumEvaluationNumber", 1000 );
   setAsScalar( "MaximumLikelihoodFactory-MaximumAbsoluteError", 1.0e-10 );
   setAsScalar( "MaximumLikelihoodFactory-MaximumRelativeError", 1.0e-10 );
@@ -768,6 +788,9 @@ void ResourceMap::loadDefaultConfiguration()
   setAsUnsignedInteger( "FunctionalChaosAlgorithm-LargeSampleSize", 10000);
   setAsUnsignedInteger( "FunctionalChaosAlgorithm-MaximumTotalDegree", 10 );
 
+  // FunctionalChaosSobolIndices parameters //
+  setAsScalar( "FunctionalChaosSobolIndices-VariancePartThreshold", 1.0e-2);
+
   // GeneralLinearModelAlgorithm parameters //
   set("GeneralLinearModelAlgorithm-LinearAlgebra", "LAPACK");
   setAsBool("GeneralLinearModelAlgorithm-NormalizeData", false);
@@ -780,6 +803,7 @@ void ResourceMap::loadDefaultConfiguration()
   setAsScalar( "GeneralLinearModelAlgorithm-MaximalScaling", 1.0e5 );
   setAsScalar( "GeneralLinearModelAlgorithm-DefaultOptimizationLowerBound", 1.0e-2 );
   setAsScalar( "GeneralLinearModelAlgorithm-DefaultOptimizationUpperBound", 1.0e2 );
+  setAsScalar( "GeneralLinearModelAlgorithm-DefaultOptimizationScaleFactor", 2.0 );
   set("GeneralLinearModelAlgorithm-DefaultOptimizationAlgorithm", "TNC");
 
   // KrigingAlgorithm parameters //
@@ -828,9 +852,11 @@ void ResourceMap::loadDefaultConfiguration()
   setAsBool("Distribution-Parallel", true);
   setAsUnsignedInteger( "Distribution-CharacteristicFunctionBlockMax", 20 );
   setAsUnsignedInteger( "Distribution-CharacteristicFunctionNMax", 1000000 );
-  setAsUnsignedInteger( "Distribution-MinimumVolumeLevelSetSamplingSize", 1000000 );
+  setAsUnsignedInteger( "Distribution-MinimumVolumeLevelSetSamplingSize", 1048576 );
   setAsBool( "Distribution-MinimumVolumeLevelSetBySampling", false );
   setAsBool( "Distribution-UseCovarianceAdaptiveAlgorithm", true );
+  setAsUnsignedInteger( "Distribution-SmallDimensionEntropy", 3 );
+  setAsUnsignedInteger( "Distribution-EntropySamplingSize", 1048576 );
 
   // ContinuousDistribution parameters //
   setAsUnsignedInteger( "ContinuousDistribution-DefaultIntegrationNodesNumber", 256 );
@@ -840,6 +866,7 @@ void ResourceMap::loadDefaultConfiguration()
 
   // DistributionFactoryImplementation parameters //
   setAsUnsignedInteger( "DistributionFactory-DefaultBootstrapSize", 100 );
+  setAsScalar( "DistributionFactory-BootstrapErrorTolerance", 0.1 );
 
   // OrderStatisticsMarginalChecker //
   setAsUnsignedInteger( "OrderStatisticsMarginalChecker-QuantileIteration", 100 );
@@ -940,6 +967,9 @@ void ResourceMap::loadDefaultConfiguration()
   setAsUnsignedInteger("TensorApproximationAlgorithm-DefaultMaximumAlternatingLeastSquaresIteration", 100);
   setAsScalar("TensorApproximationAlgorithm-DefaultMaximumRadiusError", 1.0e-5);
   setAsScalar("TensorApproximationAlgorithm-DefaultMaximumResidualError", 1.0e-5);
+
+  // viewer.View parameters //
+  set("View-ImageFormat", "png");
 }
 
 /* String converter */
