@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- * @file  TTY.cxx
  * @brief This file provides definitions for tty control sequences
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @author dutka
- * @date   2011-04-08 17:04:10 +0200 (Fri, 08 Apr 2011)
  */
 
-#include "TTY.hxx"
+#include "openturns/TTY.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
