@@ -2,7 +2,7 @@
 /**
  *  @brief XMLStorageManager provides an interface for different storage classes
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,11 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 #include <iomanip>
+#include <limits>
 #include "openturns/XMLStorageManager.hxx"
 #include "openturns/PersistentObject.hxx"
 #include "openturns/InterfaceObject.hxx"
@@ -31,6 +32,7 @@
 #include "openturns/XMLToolbox.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/OTconfig.hxx"
+#include "openturns/SpecFunc.hxx"
 
 #ifndef WIN32
 #ifndef SWIG
@@ -389,6 +391,15 @@ void toStringConverter(const _Tp & value, String & st)
   PlatformInfo::SetNumericalPrecision(XMLStorageManager::Precision_);
   st = ( OSS() << value );
   PlatformInfo::SetNumericalPrecision(oldPrecision);
+
+  if (SpecFunc::IsNaN(value))
+  {
+    st = "nan";
+  }
+  else if (SpecFunc::IsInf(value))
+  {
+    st = value < 0.0 ? "-inf" : "inf";
+  }
 }
 
 
@@ -407,12 +418,26 @@ void fromStringConverter(const String & st, String & value)
   value = st;
 }
 
+
 template <typename _Tp>
 static inline
 void fromStringConverter(const String & st, _Tp & value)
 {
   std::istringstream iss (st);
   iss >> value;
+
+  if (st == "nan")
+  {
+    value = std::numeric_limits<_Tp>::quiet_NaN();
+  }
+  else if (st == "inf")
+  {
+    value = std::numeric_limits<_Tp>::infinity();
+  }
+  else if (st == "-inf")
+  {
+    value = -std::numeric_limits<_Tp>::infinity();
+  }
 }
 
 
