@@ -4,7 +4,7 @@
  *         form a numerical math evaluation implementation by using centered
  *         finite difference formula.
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -16,7 +16,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -40,23 +40,23 @@ CenteredFiniteDifferenceGradient::CenteredFiniteDifferenceGradient() :
 
 /* Parameter constructor */
 CenteredFiniteDifferenceGradient::CenteredFiniteDifferenceGradient(const Point & epsilon,
-    const EvaluationPointer & p_evaluation)
-  : FiniteDifferenceGradient(epsilon, p_evaluation)
+    const Evaluation & evaluation)
+  : FiniteDifferenceGradient(epsilon, evaluation)
 
 {
 }
 
 /* Parameter constructor */
 CenteredFiniteDifferenceGradient::CenteredFiniteDifferenceGradient(const Scalar epsilon,
-    const EvaluationPointer & p_evaluation)
-  : FiniteDifferenceGradient(epsilon, p_evaluation)
+    const Evaluation & evaluation)
+  : FiniteDifferenceGradient(epsilon, evaluation)
 {
 }
 
 /* Parameter constructor */
 CenteredFiniteDifferenceGradient::CenteredFiniteDifferenceGradient(const FiniteDifferenceStep & step,
-    const EvaluationPointer & p_evaluation)
-  : FiniteDifferenceGradient(step, p_evaluation)
+    const Evaluation & evaluation)
+  : FiniteDifferenceGradient(step, evaluation)
 {
   // Nothing to do
 }
@@ -75,7 +75,7 @@ String CenteredFiniteDifferenceGradient::__repr__() const
   oss << "class=" << CenteredFiniteDifferenceGradient::GetClassName()
       << " name=" << getName()
       << " epsilon=" << getEpsilon().__repr__()
-      << " evaluation=" << p_evaluation_->__repr__();
+      << " evaluation=" << evaluation_.getImplementation()->__repr__();
   return oss;
 }
 
@@ -97,17 +97,17 @@ Matrix CenteredFiniteDifferenceGradient::gradient(const Point & inP) const
   Sample gridPoints(2 * inputDimension, inP);
   for(UnsignedInteger i = 0; i < inputDimension; ++i)
   {
-    gridPoints[2 * i][i] += step[i];
-    gridPoints[2 * i + 1][i] -= step[i];
+    gridPoints(2 * i, i) += step[i];
+    gridPoints(2 * i + 1, i) -= step[i];
   } // For i
   /* Evaluate the evaluation */
-  Sample gridValues(p_evaluation_->operator()(gridPoints));
+  Sample gridValues(evaluation_.operator()(gridPoints));
   /* Compute the gradient */
-  Matrix result(p_evaluation_->getInputDimension(), p_evaluation_->getOutputDimension());
+  Matrix result(evaluation_.getInputDimension(), evaluation_.getOutputDimension());
   for (UnsignedInteger i = 0; i < result.getNbRows(); ++i)
     for (UnsignedInteger j = 0; j < result.getNbColumns(); ++j)
       /* result(i, j) = (f_j(x + e_i) - f_j(x - e_i)) / (2 * e_i) ~ df_j / dx_i */
-      result(i, j) = (gridValues[2 * i][j] - gridValues[2 * i + 1][j]) / (2.0 * step[i]);
+      result(i, j) = (gridValues(2 * i, j) - gridValues(2 * i + 1, j)) / (2.0 * step[i]);
   return result;
 }
 
