@@ -2,7 +2,7 @@
 /**
  *  @brief Implementation of the box experiment plane
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -86,12 +86,12 @@ Sample Box::generate() const
   const UnsignedInteger dimension = levels_.getDimension();
   Indices bounds(dimension);
   for (UnsignedInteger i = 0; i < dimension; ++i) bounds[i] = static_cast< UnsignedInteger > (round(levels_[i] + 2.0));
-  Tuples::IndicesCollection tuples(Tuples(bounds).generate());
+  IndicesCollection tuples(Tuples(bounds).generate());
   const UnsignedInteger size = tuples.getSize();
   Sample boxPlane(size, dimension);
   for (UnsignedInteger i = 0; i < size; ++i)
     for (UnsignedInteger j = 0; j < dimension; ++j)
-      boxPlane[i][j] = tuples[i][j] / (levels_[j] + 1.0);
+      boxPlane(i, j) = tuples(i, j) / (levels_[j] + 1.0);
 
   // scale sample
   if (bounds_ != Interval(dimension))
