@@ -2,7 +2,7 @@
 /**
  *  @brief A collection of numerical math function
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -131,9 +131,9 @@ Bool Basis::isOrthogonal() const
   return getImplementation()->isOrthogonal();
 }
 
-Bool Basis::isFunctional() const
+Bool Basis::isFinite() const
 {
-  return getImplementation()->isFunctional();
+  return getImplementation()->isFinite();
 }
 
 END_NAMESPACE_OPENTURNS
