@@ -2,7 +2,7 @@
 /**
  *  @brief A sequence of numerical math function collection
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -29,21 +29,21 @@ CLASSNAMEINIT(BasisSequence)
 
 /* Default constructor */
 BasisSequence::BasisSequence()
-  : TypedCollectionInterfaceObject<BasisSequenceImplementation>( new BasisSequenceImplementation )
+  : TypedInterfaceObject<BasisSequenceImplementation>( new BasisSequenceImplementation )
 {
   // Nothing to do
 }
 
 /* Default constructor */
 BasisSequence::BasisSequence(const Basis & psi)
-  : TypedCollectionInterfaceObject<BasisSequenceImplementation>( new BasisSequenceImplementation(psi) )
+  : TypedInterfaceObject<BasisSequenceImplementation>( new BasisSequenceImplementation(psi) )
 {
   // Nothing to do
 }
 
 /* Constructor from implementation */
 BasisSequence::BasisSequence(const BasisSequenceImplementation & implementation)
-  : TypedCollectionInterfaceObject<BasisSequenceImplementation>( implementation.clone() )
+  : TypedInterfaceObject<BasisSequenceImplementation>( implementation.clone() )
 {
   // Nothing to do
 }
@@ -72,10 +72,22 @@ Indices BasisSequence::getIndices(const UnsignedInteger index) const
   return getImplementation()->getIndices( index );
 }
 
-/* Converter to Basis collection */
-BasisSequence::operator PersistentCollection<Indices> () const
+/* Size accessor */
+UnsignedInteger BasisSequence::getSize() const
 {
-  return *getImplementation();
+  return getImplementation()->getSize();
+}
+
+/** Extend basis */
+void BasisSequence::add(const Indices & indices)
+{
+  getImplementation()->add( indices );
+}
+
+/* Converter to Basis collection */
+BasisSequence::operator IndicesCollection () const
+{
+  return getImplementation()->getIndicesCollection();
 }
 
 /* String converter */
