@@ -2,7 +2,7 @@
 /**
  * @brief Abstract top-level class for all evaluation implementations
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -24,35 +24,21 @@
 #include "openturns/EvaluationImplementation.hxx"
 #include "openturns/ComposedEvaluation.hxx"
 #include "openturns/OTconfig.hxx"
-#ifdef OPENTURNS_HAVE_MUPARSER
+#ifdef OPENTURNS_HAVE_ANALYTICAL_PARSER
 #include "openturns/SymbolicEvaluation.hxx"
-#endif
+#else
 #include "openturns/LinearEvaluation.hxx"
+#endif
 #include "openturns/Exception.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
-#include "openturns/Full.hxx"
 #include "openturns/Contour.hxx"
 #include "openturns/Curve.hxx"
 #include "openturns/Indices.hxx"
 #include "openturns/Box.hxx"
+#include "openturns/Evaluation.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
-typedef EvaluationImplementation::CacheType EvaluationImplementationCache;
-
-static const Factory<EvaluationImplementationCache> Factory_EvaluationImplementationCache;
-
-/* These methods are implemented here for the needs of Cache */
-/* We should be careful because they may interfere with other definitions placed elsewhere */
-static const Factory<PersistentCollection<UnsignedInteger> > Factory_PersistentCollection_UnsignedInteger;
-#ifndef OPENTURNS_UNSIGNEDLONG_SAME_AS_UINT64
-static const Factory<PersistentCollection<Unsigned64BitsInteger> > Factory_PersistentCollection_Unsigned64BitsInteger;
-#endif
-
-TEMPLATE_CLASSNAMEINIT(PersistentCollection<PersistentCollection<Scalar> >)
-static const Factory<PersistentCollection<PersistentCollection<Scalar> > > Factory_PersistentCollection_PersistentCollection_Scalar;
-
-
 CLASSNAMEINIT(EvaluationImplementation)
 
 static const Factory<EvaluationImplementation> Factory_EvaluationImplementation;
@@ -62,16 +48,11 @@ static const Factory<EvaluationImplementation> Factory_EvaluationImplementation;
 EvaluationImplementation::EvaluationImplementation()
   : PersistentObject()
   , callsNumber_(0)
-  , p_cache_(new CacheType)
-  , inputStrategy_(Full())
-  , outputStrategy_(Full())
-  , isHistoryEnabled_(false)
   , parameter_(0)
   , inputDescription_(0)
   , outputDescription_(0)
 {
-  // We disable the cache by default
-  p_cache_->disable();
+  // Nothing to do
 }
 
 /* Virtual constructor */
@@ -182,119 +163,11 @@ Sample EvaluationImplementation::operator() (const Sample & inSample) const
 Field EvaluationImplementation::operator() (const Field & inField) const
 {
   const UnsignedInteger inputDimension = getInputDimension();
-  if (inField.getDimension() != inputDimension) throw InvalidArgumentException(HERE) << "Error: the given time series has an invalid dimension. Expect a dimension " << inputDimension << ", got " << inField.getDimension();
+  if (inField.getOutputDimension() != inputDimension) throw InvalidArgumentException(HERE) << "Error: the given time series has an invalid dimension. Expect a dimension " << inputDimension << ", got " << inField.getOutputDimension();
   return Field(inField.getMesh(), operator()(inField.getValues()));
 }
 
 
-/* Enable or disable the internal cache */
-void EvaluationImplementation::enableCache() const
-{
-  p_cache_->enable();
-}
-
-void EvaluationImplementation::disableCache() const
-{
-  p_cache_->disable();
-}
-
-Bool EvaluationImplementation::isCacheEnabled() const
-{
-  return p_cache_->isEnabled();
-}
-
-UnsignedInteger EvaluationImplementation::getCacheHits() const
-{
-  return p_cache_->getHits();
-}
-
-void EvaluationImplementation::addCacheContent(const Sample& inSample, const Sample& outSample)
-{
-  p_cache_->enable();
-  const UnsignedInteger size = inSample.getSize();
-  for ( UnsignedInteger i = 0; i < size; ++ i )
-  {
-    p_cache_->add( inSample[i], outSample[i] );
-  }
-}
-
-Sample EvaluationImplementation::getCacheInput() const
-{
-  Bool cacheEnabled = isCacheEnabled();
-  enableCache();
-  PersistentCollection<CacheKeyType> keyColl( p_cache_->getKeys() );
-  if ( ! cacheEnabled )
-    disableCache();
-  Sample inSample(0, getInputDimension());
-  for ( UnsignedInteger i = 0; i < keyColl.getSize(); ++ i ) inSample.add( keyColl[i] );
-  return inSample;
-}
-
-Sample EvaluationImplementation::getCacheOutput() const
-{
-  Bool cacheEnabled = isCacheEnabled();
-  enableCache();
-  PersistentCollection<CacheValueType> valuesColl( p_cache_->getValues() );
-  if ( ! cacheEnabled )
-    disableCache();
-  Sample outSample(0, getOutputDimension());
-  for ( UnsignedInteger i = 0; i < valuesColl.getSize(); ++ i )
-  {
-    outSample.add( valuesColl[i] );
-  }
-  return outSample;
-}
-
-void EvaluationImplementation::clearCache() const
-{
-  p_cache_->clear();
-}
-
-/* Enable or disable the input/output history */
-void EvaluationImplementation::enableHistory() const
-{
-  isHistoryEnabled_ = true;
-}
-
-void EvaluationImplementation::disableHistory() const
-{
-  isHistoryEnabled_ = false;
-}
-
-Bool EvaluationImplementation::isHistoryEnabled() const
-{
-  return isHistoryEnabled_;
-}
-
-void EvaluationImplementation::clearHistory() const
-{
-  inputStrategy_ = Full();
-  outputStrategy_ = Full();
-}
-
-HistoryStrategy EvaluationImplementation::getHistoryInput() const
-{
-  return inputStrategy_;
-}
-
-HistoryStrategy EvaluationImplementation::getHistoryOutput() const
-{
-  return outputStrategy_;
-}
-
-/* Input point / parameter history accessor */
-Sample EvaluationImplementation::getInputPointHistory() const
-{
-  if (getParameterDimension() == 0) return inputStrategy_.getSample();
-  throw NotYetImplementedException(HERE) << "in EvaluationImplementation::getInputPointHistory";
-}
-
-Sample EvaluationImplementation::getInputParameterHistory() const
-{
-  throw NotYetImplementedException(HERE) << "in EvaluationImplementation::getInputParameterHistory";
-}
-
-
 /* Gradient according to the marginal parameters */
 Matrix EvaluationImplementation::parameterGradient(const Point & inP) const
 {
@@ -307,18 +180,22 @@ Matrix EvaluationImplementation::parameterGradient(const Point & inP) const
   Sample inS(parameterDimension + 1, parameter);
   for (UnsignedInteger i = 0; i < parameterDimension; ++ i)
   {
-    inS[1 + i][i] += epsilon;
+    inS(1 + i, i) += epsilon;
   }
-  // operator()(x, theta) is non-const as it sets the parameter
+  Sample outS(parameterDimension + 1, getOutputDimension());
   Pointer<EvaluationImplementation> p_evaluation(clone());
-  Sample outS(p_evaluation->operator()(inP, inS));
+  for (UnsignedInteger i = 0; i < parameterDimension + 1; ++ i)
+  {
+    p_evaluation->setParameter(inS[i]);
+    outS[i] = p_evaluation->operator()(inP);
+  }
 
   Matrix grad(parameterDimension, outputDimension);
   for (UnsignedInteger i = 0; i < parameterDimension; ++ i)
   {
     for (UnsignedInteger j = 0; j < outputDimension; ++ j)
     {
-      grad(i, j) = (outS[1 + i][j] - outS[0][j]) / epsilon;
+      grad(i, j) = (outS(1 + i, j) - outS(0, j)) / epsilon;
     }
   }
   return grad;
@@ -356,6 +233,7 @@ Point EvaluationImplementation::operator() (const Point & inP) const
 Point EvaluationImplementation::operator() (const Point & inP,
     const Point & parameter)
 {
+  LOGWARN("EvaluationImplementation::operator()(inP,parameter) is deprecated, use setParameter(parameter) and operator()(inP)");
   setParameter(parameter);
   return (*this)(inP);
 }
@@ -363,6 +241,7 @@ Point EvaluationImplementation::operator() (const Point & inP,
 Sample EvaluationImplementation::operator() (const Point & inP,
     const Sample & parameters)
 {
+  LOGWARN("EvaluationImplementation::operator()(inP,parameters) is deprecated, use setParameter(parameter) and operator()(inP)");
   const UnsignedInteger size = parameters.getSize();
   Sample outS(size, getOutputDimension());
   for (UnsignedInteger i = 0; i < size; ++ i)
@@ -392,14 +271,14 @@ UnsignedInteger EvaluationImplementation::getParameterDimension() const
 }
 
 /* Get the i-th marginal function */
-EvaluationImplementation::Implementation EvaluationImplementation::getMarginal(const UnsignedInteger i) const
+Evaluation EvaluationImplementation::getMarginal(const UnsignedInteger i) const
 {
   if (i >= getOutputDimension()) throw InvalidArgumentException(HERE) << "Error: the index of a marginal function must be in the range [0, outputDimension-1]";
   return getMarginal(Indices(1, i));
 }
 
 /* Get the function corresponding to indices components */
-EvaluationImplementation::Implementation EvaluationImplementation::getMarginal(const Indices & indices) const
+Evaluation EvaluationImplementation::getMarginal(const Indices & indices) const
 {
   if (!indices.check(getOutputDimension())) throw InvalidArgumentException(HERE) << "Error: the indices of a marginal function must be in the range [0, outputDimension-1] and must be different";
   // We build an analytical function that extract the needed component
@@ -408,7 +287,7 @@ EvaluationImplementation::Implementation EvaluationImplementation::getMarginal(c
   // Build non-ambigous names for the inputs. We cannot simply use the output description, as it must be valid muParser identifiers
   const UnsignedInteger inputDimension = getOutputDimension();
   const UnsignedInteger outputDimension = indices.getSize();
-#ifdef OPENTURNS_HAVE_MUPARSER
+#ifdef OPENTURNS_HAVE_ANALYTICAL_PARSER
   Description input(inputDimension);
   for (UnsignedInteger index = 0; index < inputDimension; ++index)
     input[index] = OSS() << "x" << index;
@@ -430,18 +309,13 @@ EvaluationImplementation::Implementation EvaluationImplementation::getMarginal(c
   Point constant(outputDimension);
   const LinearEvaluation left(center, constant, linear);
 #endif
-  ComposedEvaluation marginal(left.clone(), clone());
-  if (isHistoryEnabled())
-  {
-    marginal.enableHistory();
-  }
-  return marginal.clone();
+  return new ComposedEvaluation(left.clone(), clone());
 }
 
 /* Get the number of calls to operator() */
 UnsignedInteger EvaluationImplementation::getCallsNumber() const
 {
-  return callsNumber_;
+  return callsNumber_.get();
 }
 
 
@@ -464,7 +338,7 @@ Graph EvaluationImplementation::draw(const UnsignedInteger inputMarginal,
   {
     const Scalar dx = (xMax - xMin) / (pointNumber - 1.0);
     for (UnsignedInteger i = 0; i < pointNumber; ++i)
-      inputData[i][inputMarginal] = xMin + i * dx;
+      inputData(i, inputMarginal) = xMin + i * dx;
   }
   else
   {
@@ -472,7 +346,7 @@ Graph EvaluationImplementation::draw(const UnsignedInteger inputMarginal,
     const Scalar b = std::log(xMax);
     const Scalar dLogX = (b - a) / (pointNumber - 1.0);
     for (UnsignedInteger i = 0; i < pointNumber; ++i)
-      inputData[i][inputMarginal] = std::exp(a + i * dLogX);
+      inputData(i, inputMarginal) = std::exp(a + i * dLogX);
   }
   // Evaluate the function over all its input in one call in order to benefit from potential parallelism
   const Sample outputData((*this)(inputData));
@@ -525,7 +399,7 @@ Graph EvaluationImplementation::draw(const UnsignedInteger firstInputMarginal,
   x += Point(1, origin[0]);
   // Recover the original scale if the discretization has been done in the logarithmic scale
   if ((scale == GraphImplementation::LOGY) || (scale == GraphImplementation::LOGXY))
-    for (UnsignedInteger i = 0; i < x.getDimension(); ++i) x[i][0] = std::exp(x[i][0]);
+    for (UnsignedInteger i = 0; i < x.getDimension(); ++i) x(i, 0) = std::exp(x(i, 0));
   const Scalar nY = pointNumber[1] - 2;
   discretization[1] = nY;
   // Discretization of the second component
@@ -545,19 +419,19 @@ Graph EvaluationImplementation::draw(const UnsignedInteger firstInputMarginal,
   y += Point(1, origin[1]);
   // Recover the original scale if the discretization has been done in the logarithmic scale
   if ((scale == GraphImplementation::LOGY) || (scale == GraphImplementation::LOGXY))
-    for (UnsignedInteger i = 0; i < y.getDimension(); ++i) y[i][0] = std::exp(y[i][0]);
+    for (UnsignedInteger i = 0; i < y.getDimension(); ++i) y(i, 0) = std::exp(y(i, 0));
   // Discretization of the XY plane
   Sample inputSample((nX + 2) * (nY + 2), centralPoint);
   // Prepare the input sample
   UnsignedInteger index = 0;
   for (UnsignedInteger j = 0; j < nY + 2; ++j)
   {
-    const Scalar yJ = (scale == GraphImplementation::LOGY) || (scale == GraphImplementation::LOGXY) ? exp(y[j][0]) : y[j][0];
+    const Scalar yJ = (scale == GraphImplementation::LOGY) || (scale == GraphImplementation::LOGXY) ? exp(y(j, 0)) : y(j, 0);
     for (UnsignedInteger i = 0; i < nX + 2; ++i)
     {
-      const Scalar xI = (scale == GraphImplementation::LOGX) || (scale == GraphImplementation::LOGXY) ? exp(x[i][0]) : x[i][0];
-      inputSample[index][firstInputMarginal]  = xI;
-      inputSample[index][secondInputMarginal]  = yJ;
+      const Scalar xI = (scale == GraphImplementation::LOGX) || (scale == GraphImplementation::LOGXY) ? exp(x(i, 0)) : x(i, 0);
+      inputSample(index, firstInputMarginal)  = xI;
+      inputSample(index, secondInputMarginal)  = yJ;
       ++index;
     } // i
   } // j
@@ -614,8 +488,7 @@ Graph EvaluationImplementation::draw(const Point & xMin,
 void EvaluationImplementation::save(Advocate & adv) const
 {
   PersistentObject::save(adv);
-  adv.saveAttribute( "callsNumber_", callsNumber_ );
-  adv.saveAttribute( "cache_", *p_cache_ );
+  adv.saveAttribute( "callsNumber_", static_cast<UnsignedInteger>(callsNumber_.get()) );
   adv.saveAttribute( "inputDescription_", inputDescription_ );
   adv.saveAttribute( "outputDescription_", outputDescription_ );
   adv.saveAttribute( "parameter_", parameter_ );
@@ -625,11 +498,10 @@ void EvaluationImplementation::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void EvaluationImplementation::load(Advocate & adv)
 {
-  TypedInterfaceObject<CacheType> cache;
   PersistentObject::load(adv);
-  adv.loadAttribute( "callsNumber_", callsNumber_ );
-  adv.loadAttribute( "cache_", cache );
-  p_cache_ = cache.getImplementation();
+  UnsignedInteger callsNumber;
+  adv.loadAttribute( "callsNumber_", callsNumber );
+  callsNumber_ = callsNumber;
   adv.loadAttribute( "inputDescription_", inputDescription_ );
   adv.loadAttribute( "outputDescription_", outputDescription_ );
   adv.loadAttribute( "parameter_", parameter_ );
