@@ -1,10 +1,9 @@
 //                                               -*- C++ -*-
 /**
- *  @file  GammaFunctions.cxx
  *  @brief Efficient implementation of the computation of the incomplete
  *         regularized gamma function and related functions
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -16,19 +15,17 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 12:24:33 +0200 (Mon, 16 Jul 2012)
  */
 #include <cmath>
 
-#include "GammaFunctions.hxx"
-#include "Exception.hxx"
-#include "Log.hxx"
-#include "SpecFunc.hxx"
-#include "incgam.hxx"
+#include "openturns/GammaFunctions.hxx"
+#include "openturns/Exception.hxx"
+#include "openturns/Log.hxx"
+#include "openturns/SpecFunc.hxx"
+#include "openturns/incgam.hxx"
 #ifdef OPENTURNS_HAVE_BOOST
 #include <boost/math/special_functions/gamma.hpp>
 #endif
@@ -38,53 +35,53 @@ BEGIN_NAMESPACE_OPENTURNS
 namespace GammaFunctions
 {
 
-NumericalScalar IncompleteGamma(const NumericalScalar a,
-                                const NumericalScalar x,
-                                const Bool tail)
+Scalar IncompleteGamma(const Scalar a,
+                       const Scalar x,
+                       const Bool tail)
 {
-  if (a <= 0.0) throw InvalidArgumentException(HERE) << "Error: a must be positive, here a=" << a;
+  if (!(a > 0.0)) throw InvalidArgumentException(HERE) << "Error: a must be positive, here a=" << a;
   return RegularizedIncompleteGamma(a, x, tail) * SpecFunc::Gamma(a);
 }
 
-NumericalScalar IncompleteGammaInverse(const NumericalScalar a,
-                                       const NumericalScalar x,
-                                       const Bool tail)
+Scalar IncompleteGammaInverse(const Scalar a,
+                              const Scalar x,
+                              const Bool tail)
 {
-  if (a <= 0.0) throw InvalidArgumentException(HERE) << "Error: a must be positive, here a=" << a;
+  if (!(a > 0.0)) throw InvalidArgumentException(HERE) << "Error: a must be positive, here a=" << a;
   return RegularizedIncompleteGammaInverse(a, x / SpecFunc::Gamma(a), tail);
 }
 
-NumericalScalar RegularizedIncompleteGamma(const NumericalScalar a,
-    const NumericalScalar x,
-    const Bool tail)
+Scalar RegularizedIncompleteGamma(const Scalar a,
+                                  const Scalar x,
+                                  const Bool tail)
 {
-  if (a <= 0.0) throw InvalidArgumentException(HERE) << "Error: a must be positive, here a=" << a;
+  if (!(a > 0.0)) throw InvalidArgumentException(HERE) << "Error: a must be positive, here a=" << a;
   if (x <= 0.0) return (tail ? 1.0 : 0.0);
 #ifdef OPENTURNS_HAVE_BOOST
   return (tail ? boost::math::gamma_q(a, x) : boost::math::gamma_p(a, x));
 #else
-  NumericalScalar p;
-  NumericalScalar q;
+  Scalar p = -1.0;
+  Scalar q = -1.0;
   SignedInteger ierr;
   incgam(a, x, p, q, ierr);
-  if (ierr == 1) throw InternalException(HERE) << "Error: underflow or overflow in RegularizedIncompleteGamma for a=" << a << ", x=" << x;
+  if (ierr == 1) LOGWARN(OSS() << "underflow or overflow in RegularizedIncompleteGamma for a=" << a << ", x=" << x);
   return (tail ? q : p);
 #endif
 }
 
-NumericalScalar RegularizedIncompleteGammaInverse(const NumericalScalar a,
-    const NumericalScalar x,
+Scalar RegularizedIncompleteGammaInverse(const Scalar a,
+    const Scalar x,
     const Bool tail)
 {
-  if (a <= 0.0) throw InvalidArgumentException(HERE) << "Error: a must be positive, here a=" << a;
+  if (!(a > 0.0)) throw InvalidArgumentException(HERE) << "Error: a must be positive, here a=" << a;
 #ifdef OPENTURNS_HAVE_BOOST
   return (tail ? boost::math::gamma_q_inv(a, x) : boost::math::gamma_p_inv(a, x));
 #else
-  const NumericalScalar y(0.5 + (0.5 - x));
-  NumericalScalar xr;
+  const Scalar y = 0.5 + (0.5 - x);
+  Scalar xr = -1.0;
   SignedInteger ierr;
   invincgam(a, (tail ? y : x), (tail ? x : y), xr, ierr);
-  if (ierr == -1) throw InternalException(HERE) << "Error: cannot compute the RegularizedIncompleteGammaInverse funtion for a=" << a << ", x=" << x << ", tail=" << tail << " because of an overflow.";
+  if (ierr == -1) LOGWARN(OSS() << "cannot compute the RegularizedIncompleteGammaInverse funtion to full precision for a=" << a << ", x=" << x << ", tail=" << tail << " because of an overflow.");
   if (ierr == -2) LOGWARN(OSS() << "up to 15 Newton iterations have been made to compute the RegularizedIncompleteGammaInverse funtion for a=" << a << ", x=" << x << ", tail=" << tail << ". The accuracy may be reduced.");
   return xr;
 #endif
