@@ -2,7 +2,7 @@
 /**
  *  @brief OpenTURNS wrapper to a library of special functions
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -49,7 +49,7 @@
 #else
 
 #include "openturns/GaussKronrod.hxx"
-#include "openturns/Function.hxx"
+#include "openturns/SymbolicFunction.hxx"
 #include "openturns/Interval.hxx"
 
 #endif
@@ -88,13 +88,6 @@ const Scalar SpecFunc::ScalarEpsilon = std::numeric_limits<Scalar>::epsilon();
 const UnsignedInteger SpecFunc::MaximumIteration = ResourceMap::GetAsUnsignedInteger("SpecFunc-MaximumIteration");
 const Scalar SpecFunc::Precision = ResourceMap::GetAsScalar("SpecFunc-Precision");
 
-// @deprecated
-const Scalar SpecFunc::MinNumericalScalar    = MinScalar;
-const Scalar SpecFunc::LogMinNumericalScalar = LogMinScalar;
-const Scalar SpecFunc::MaxNumericalScalar    = MaxScalar;
-const Scalar SpecFunc::LogMaxNumericalScalar = LogMaxScalar;
-const Scalar SpecFunc::NumericalScalarEpsilon = ScalarEpsilon;
-
 // Some facilities for NaN and inf
 Bool SpecFunc::IsNaN(const Scalar value)
 {
@@ -305,13 +298,13 @@ Scalar SpecFunc::LogBesselK(const Scalar nu,
   Scalar upper = -1.0;
   if (nu == 0.0)
   {
-    integrand = Function("t", String(OSS() << "exp(-" << x << "*cosh(t))"));
+    integrand = SymbolicFunction("t", String(OSS() << "exp(-" << x << "*cosh(t))"));
     upper = std::log(-2.0 * std::log(ScalarEpsilon) / x);
   }
   else
   {
     logFactor = nu * std::log(0.5 * x) - LogGamma(0.5 + nu) + 0.5 * std::log(M_PI);
-    integrand = Function("t", String(OSS() << "exp(-" << x << "*cosh(t))*(sinh(t))^" << 2.0 * nu));
+    integrand = SymbolicFunction("t", String(OSS() << "exp(-" << x << "*cosh(t))*(sinh(t))^" << 2.0 * nu));
     upper = std::log(ScalarEpsilon) / (2.0 * nu) - LambertW(-0.25 * x * std::exp(0.5 * std::log(ScalarEpsilon) / nu) / nu, false);
   }
   Scalar epsilon = -1.0;
@@ -475,17 +468,26 @@ Scalar SpecFunc::DiLog(const Scalar x)
 {
   // Special case for 0
   if (x == 0.0) return 0.0;
+  // Special case for 1
+  if (x == 1.0) return PI2_6;
   // No real value on (1, \infty)
   if (!(x <= 1.0)) throw InvalidArgumentException(HERE) << "Error: the DiLog function does not take real values for arguments greater than 1.";
+  // Special case for x close to 1
+  if (x >= 0.999997)
+  {
+    const Scalar z = 1.0 - x;
+    const Scalar logZ = std::log(z);
+    return PI2_6 + z * (logZ - 1.0 + z * (logZ - 0.5) * 0.5);
+  }
   // Use DiLog(x) = -DiLog(1 / x) - \pi^2 / 6 - \log^2(-x) / 2
   // to map (-\infty, -1) into (-1, 0) for the argument
-  if (x < -1.0) return -DiLog(1.0 / x) - SpecFunc::PI2_6  - 0.5 * pow(log(-x), 2);
-  // Use DiLog(x) = \pi^2 / 6 - DiLog(1 - x) - \log(x)\log(1-x)
-  // to map (1/2, 1] into [0, 1/2)
-  if (x > 0.5) return SpecFunc::PI2_6 - DiLog(1.0 - x) - log(x) * log1p(-x);
+  if (x < -1.0) return -DiLog(1.0 / x) - PI2_6  - 0.5 * pow(log(-x), 2);
   // Use DiLog(x) = DiLog(x^2) / 2 - DiLog(-x)
   // to map [-1, 0) into (0, 1]
   if (x < 0.0) return 0.5 * DiLog(x * x) - DiLog(-x);
+  // Use DiLog(x) = \pi^2 / 6 - DiLog(1 - x) - \log(x)\log(1-x)
+  // to map (1/2, 1] into [0, 1/2)
+  if (x > 0.5) return PI2_6 - DiLog(1.0 - x) - log(x) * log1p(-x);
   // Use the definition of DiLog in terms of series
   // DiLog(x)=\sum_{k=1}^{\infty} x^k/k^2
   // for (0, 1/2)
