@@ -2,7 +2,7 @@
 /**
  *  @brief DomainImplementation is defined as a domain of \mathbb{R}^d
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -34,8 +34,6 @@ static const Factory<DomainImplementation> Factory_DomainImplementation;
 DomainImplementation::DomainImplementation(UnsignedInteger dimension)
   : PersistentObject()
   , dimension_(dimension)
-  , volume_(0.0)
-  , isAlreadyComputedVolume_(false)
 {
   // Nothing to do
 }
@@ -66,52 +64,68 @@ Bool DomainImplementation::contains(const Point & point) const
   throw NotYetImplementedException(HERE) << "In DomainImplementation::contains(const Point & point) const";
 }
 
+/* Check if the given points are inside of the domain */
+DomainImplementation::BoolCollection DomainImplementation::contains(const Sample & sample) const
+{
+  BoolCollection result(sample.getSize());
+  for(UnsignedInteger i = 0; i < sample.getSize(); ++i)
+    result[i] = contains(sample[i]);
+  return result;
+}
+
 /* Check if the given point is inside of the discretization of the domain */
 Bool DomainImplementation::numericallyContains(const Point & point) const
 {
+  LOGWARN(OSS() << "DomainImplementation::numericallyContains is deprecated in favor of derived classes.");
   return contains(point);
 }
 
 /* Check if the domain is empty, i.e if its numerical volume is zero */
 Bool DomainImplementation::isEmpty() const
 {
+  LOGWARN(OSS() << "DomainImplementation::isEmpty is deprecated in favor of derived classes.");
   return isNumericallyEmpty();
 }
 
 /* Check if the domain is numerically empty, i.e if its numerical volume is zero */
 Bool DomainImplementation::isNumericallyEmpty() const
 {
+  LOGWARN(OSS() << "DomainImplementation::isNumericallyEmpty is deprecated in favor of derived classes.");
   return getNumericalVolume() <= ResourceMap::GetAsScalar("Domain-SmallVolume");
 }
 
 /* Get the volume of the domain */
 Scalar DomainImplementation::getVolume() const
 {
-  return getNumericalVolume();
+  LOGWARN(OSS() << "DomainImplementation::getVolume is deprecated in favor of derived classes.");
+  throw NotYetImplementedException(HERE);
 }
 
 /* Get the numerical volume of the domain */
 Scalar DomainImplementation::getNumericalVolume() const
 {
-  if (!isAlreadyComputedVolume_) computeVolume();
-  return volume_;
+  LOGWARN(OSS() << "DomainImplementation::getNumericalVolume is deprecated in favor of getVolume method in derived classes.");
+  return getVolume();
 }
 
 /* Compute the volume of the mesh */
-void DomainImplementation::computeVolume() const
+Scalar DomainImplementation::computeVolume() const
 {
-  throw NotYetImplementedException(HERE);
+  LOGWARN(OSS() << "DomainImplementation::computeVolume is deprecated in favor of getVolume method in derived classes.");
+  return getVolume();
 }
 
 /* Lower bound of the bounding box */
 Point DomainImplementation::getLowerBound() const
 {
+  LOGWARN(OSS() << "DomainImplementation::getLowerBound is deprecated in favor of derived classes.");
   throw NotYetImplementedException(HERE) << "In DomainImplementation::getLowerBound()";
 }
 
 /* Upper bound of the bounding box */
 Point DomainImplementation::getUpperBound() const
 {
+  LOGWARN(OSS() << "DomainImplementation::getUpperBound is deprecated in favor of derived classes.");
   throw NotYetImplementedException(HERE) << "In DomainImplementation::getUpperBound()";
 }
 
