@@ -2,7 +2,7 @@
 /**
  *  @brief Interval is defined as the cartesian product of n 1D intervalls ]low_1, up_1]x...x]low_n,up_n]
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -148,6 +148,12 @@ Bool Interval::isEmpty() const
   return false;
 }
 
+/* Check if the interval is numerically empty, i.e. its volume is zero */
+Bool Interval::isNumericallyEmpty() const
+{
+  return getVolume() <= ResourceMap::GetAsScalar("Domain-SmallVolume");
+}
+
 /* Check if the given point is inside of the closed interval */
 Bool Interval::contains(const Point & point) const
 {
@@ -164,24 +170,30 @@ Bool Interval::contains(const Point & point) const
 }
 
 /* Compute the numerical volume of the interval */
-void Interval::computeVolume() const
+Scalar Interval::getVolume() const
 {
   const UnsignedInteger dimension = getDimension();
   if (dimension == 0)
   {
-    volume_ = 0.0;
-    return;
+    return 0.0;
   }
-  volume_ = 1.0;
+  Scalar volume = 1.0;
   for (UnsignedInteger i = 0; i < dimension; ++i)
   {
-    volume_ *= upperBound_[i] - lowerBound_[i];
-    if (volume_ <= 0.0)
+    volume *= upperBound_[i] - lowerBound_[i];
+    if (volume <= 0.0)
     {
-      volume_ = 0.0;
-      return;
+      return 0.0;
     }
   }
+  return volume;
+}
+
+/* Get the numerical volume of the domain */
+Scalar Interval::computeVolume() const
+{
+  LOGWARN(OSS() << "Interval::computeVolume is deprecated in favor of getVolume.");
+  return getVolume();
 }
 
 /* Check if the given point is numerically inside of the closed interval, i.e. using only the bounds part of the interval */
@@ -216,6 +228,34 @@ Interval Interval::operator +(const Interval & rhs) const
 }
 
 
+Interval Interval::getMarginal(const Indices & indices) const
+{
+  if (!indices.check(getDimension())) throw InvalidArgumentException(HERE) << "Marginal indices cannot exceed dimension";
+  const UnsignedInteger size = indices.getSize();
+  Point lowerBound(size);
+  Point upperBound(size);
+  Interval::BoolCollection finiteLowerBound(size);
+  Interval::BoolCollection finiteUpperBound(size);
+  for(UnsignedInteger i = 0; i < size; ++ i)
+  {
+    lowerBound[i] = lowerBound_[indices[i]];
+    upperBound[i] = upperBound_[indices[i]];
+    finiteLowerBound[i] = finiteLowerBound_[indices[i]];
+    finiteUpperBound[i] = finiteUpperBound_[indices[i]];
+  }
+  return Interval(lowerBound, upperBound, finiteLowerBound, finiteUpperBound);
+}
+
+
+Interval Interval::getMarginal(const UnsignedInteger index) const
+{
+  if (index >= getDimension()) throw InvalidArgumentException(HERE) << "Marginal index cannot exceed dimension";
+  return Interval(Point(1, lowerBound_[index]),
+                  Point(1, upperBound_[index]),
+                  Interval::BoolCollection(1, finiteLowerBound_[index]),
+                  Interval::BoolCollection(1, finiteUpperBound_[index]));
+}
+
 
 /* In-place addition operator */
 Interval & Interval::operator +=(const Interval & other)
@@ -240,7 +280,7 @@ Interval & Interval::operator +=(const Interval & other)
 }
 
 
-/* Substraction operator */
+/* Subtraction operator */
 Interval Interval::operator -(const Interval & rhs) const
 {
   if (getDimension() != rhs.getDimension())
@@ -263,12 +303,12 @@ Interval Interval::operator -(const Interval & rhs) const
 
 
 
-/* In-place substraction operator */
+/* In-place subtraction operator */
 Interval & Interval::operator -=(const Interval & other)
 {
   if (getDimension() != other.getDimension())
     throw InvalidArgumentException(HERE)
-        << "Intervals of different dimensions cannot be substracted (LHS dimension = "
+        << "Intervals of different dimensions cannot be subtracted (LHS dimension = "
         << getDimension()
         << "; RHS dimension = " <<
         other.getDimension();
