@@ -2,7 +2,7 @@
 /**
  *  @brief LevelSet is defined as the set of points such that f(x_1,...,x_n) <= level
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -127,6 +127,38 @@ Bool LevelSet::contains(const Point & point) const
   return function_(point)[0] <= level_;
 }
 
+/* Check if the given points are inside of the closed levelSet */
+LevelSet::BoolCollection LevelSet::contains(const Sample & sample) const
+{
+  if (sample.getDimension() != dimension_) throw InvalidArgumentException(HERE) << "Error: expected a sample of dimension=" << dimension_ << ", got dimension=" << sample.getDimension();
+  const UnsignedInteger size(sample.getSize());
+  BoolCollection result(size);
+  // If a bounding box has been computed/provided, only check points inside this bounding box
+  if ((lowerBound_.getDimension() == dimension_) && (upperBound_.getDimension() == dimension_))
+  {
+    Indices insideIndices(0);
+    const DomainImplementation::BoolCollection isInsideBoundingBox(Interval(lowerBound_, upperBound_).contains(sample));
+    for(UnsignedInteger i = 0; i < size; ++i)
+    {
+      if (isInsideBoundingBox[i])
+      {
+        insideIndices.add(i);
+      }
+    }
+    const Sample insidePoints(sample.select(insideIndices));
+    const Sample values(function_(insidePoints));
+    for(UnsignedInteger i = 0; i < insideIndices.getSize(); ++i)
+      result[insideIndices[i]] = values(i, 0) <= level_;
+  }
+  else
+  {
+    const Sample values(function_(sample));
+    for(UnsignedInteger i = 0; i < size; ++i)
+      result[i] = values(i, 0) <= level_;
+  }
+  return result;
+}
+
 /* Comparison operator */
 Bool LevelSet::operator == (const LevelSet & other) const
 {
@@ -166,29 +198,9 @@ void LevelSet::setLowerBound(const Point & bound)
 
 Point LevelSet::getLowerBound() const
 {
-  if (lowerBound_.getDimension() != dimension_) computeLowerBound();
   return lowerBound_;
 }
 
-void LevelSet::computeLowerBound() const
-{
-  lowerBound_ = Point(dimension_);
-  LinearFunction translate(Point(1, level_), Point(1), IdentityMatrix(1));
-  ComposedFunction equality(translate, function_);
-  for (UnsignedInteger i = 0; i < dimension_; ++i)
-  {
-    Matrix m(1, dimension_);
-    m(0, i) = 1.0;
-    LinearFunction coordinate(Point(dimension_), Point(1), m);
-    OptimizationProblem problem(coordinate, equality, Function(), Interval());
-    problem.setMinimization(true);
-    Cobyla solver(problem);
-    solver.setStartingPoint(Point(dimension_));
-    solver.run();
-    lowerBound_[i] = solver.getResult().getOptimalPoint()[i];
-  }
-}
-
 /* Upper bound of the bounding box */
 void LevelSet::setUpperBound(const Point & bound)
 {
@@ -198,29 +210,9 @@ void LevelSet::setUpperBound(const Point & bound)
 
 Point LevelSet::getUpperBound() const
 {
-  if (upperBound_.getDimension() != dimension_) computeUpperBound();
   return upperBound_;
 }
 
-void LevelSet::computeUpperBound() const
-{
-  upperBound_ = Point(dimension_);
-  LinearFunction translate(Point(1, level_), Point(1), IdentityMatrix(1));
-  ComposedFunction equality(translate, function_);
-  for (UnsignedInteger i = 0; i < dimension_; ++i)
-  {
-    Matrix m(1, dimension_);
-    m(0, i) = 1.0;
-    LinearFunction coordinate(Point(dimension_), Point(1), m);
-    OptimizationProblem problem(coordinate, equality, Function(), Interval());
-    problem.setMinimization(false);
-    Cobyla solver(problem);
-    solver.setStartingPoint(Point(dimension_));
-    solver.run();
-    upperBound_[i] = solver.getResult().getOptimalPoint()[i];
-  }
-}
-
 /* String converter */
 String LevelSet::__repr__() const
 {
