@@ -2,7 +2,7 @@
 /**
  *  @brief Cloud class for cloud plots
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -52,8 +52,8 @@ Cloud::Cloud(const ComplexCollection & data,
   Sample sample(size, 2);
   for (UnsignedInteger i = 0; i < size; ++i)
   {
-    sample[i][0] = data[i].real();
-    sample[i][1] = data[i].imag();
+    sample(i, 0) = data[i].real();
+    sample(i, 1) = data[i].imag();
   }
   // Check data validity
   setData(sample);
@@ -71,8 +71,8 @@ Cloud::Cloud(const Sample & dataX,
   Sample dataFull(size, 2);
   for (UnsignedInteger i = 0; i < size; ++i)
   {
-    dataFull[i][0] = dataX[i][0];
-    dataFull[i][1] = dataY[i][0];
+    dataFull(i, 0) = dataX(i, 0);
+    dataFull(i, 1) = dataY(i, 0);
   }
   // Check data validity
   setData(dataFull);
@@ -88,8 +88,8 @@ Cloud::Cloud(const Point & dataX,
   Sample dataFull(size, 2);
   for (UnsignedInteger i = 0; i < size; ++i)
   {
-    dataFull[i][0] = dataX[i];
-    dataFull[i][1] = dataY[i];
+    dataFull(i, 0) = dataX[i];
+    dataFull(i, 1) = dataY[i];
   }
   // Check data validity
   setData(dataFull);
