@@ -2,7 +2,7 @@
 /**
  *  @brief Contour class for contourchart plots
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -56,9 +56,9 @@ Contour::Contour(const UnsignedInteger dimX,
   // Check data validity
   setData(data);
   // By default, x is assumed to be equally spaced in [0, 1]
-  for (UnsignedInteger i = 0; i < dimX; ++i) x_[i][0] = Scalar(i) / (dimX - 1.0);
+  for (UnsignedInteger i = 0; i < dimX; ++i) x_(i, 0) = Scalar(i) / (dimX - 1.0);
   // By default, y is assumed to be equally spaced in [0, 1]
-  for (UnsignedInteger i = 0; i < dimY; ++i) y_[i][0] = Scalar(i) / (dimY - 1.0);
+  for (UnsignedInteger i = 0; i < dimY; ++i) y_(i, 0) = Scalar(i) / (dimY - 1.0);
   // Build the levels
   buildDefaultLevels();
   // Build the labels
@@ -251,7 +251,7 @@ void Contour::buildDefaultLevels(const UnsignedInteger number)
   const Sample sortedData(data_.sort(0));
   const UnsignedInteger size = data_.getSize();
   levels_ = Point(number);
-  for (UnsignedInteger i = 0; i < number; ++i) levels_[i] = sortedData[static_cast<UnsignedInteger>(size * (i + 0.5) / number)][0];
+  for (UnsignedInteger i = 0; i < number; ++i) levels_[i] = sortedData(static_cast<UnsignedInteger>(size * (i + 0.5) / number), 0);
   levels_.erase(std::unique(levels_.begin(), levels_.end()), levels_.end());
 }
 
