@@ -2,7 +2,7 @@
 /**
  *  @brief PolygonArray class for polygonArray plots
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -112,7 +112,7 @@ String PolygonArray::draw() const
   {
     for (UnsignedInteger j = 0; j < verticesNumber_; ++j)
     {
-      dataFile << std::setprecision(16) << data_[index][0] << " " << data_[index][1] << "\n";
+      dataFile << std::setprecision(16) << data_(index, 0) << " " << data_(index, 1) << "\n";
       ++index;
     }
     // Insert NaNs in order to tell R to go to the next polygon
