@@ -2,7 +2,7 @@
 /**
  *  @brief NLopt solver
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -49,8 +49,9 @@ void NLopt::InitializeAlgorithmNames()
   AlgorithmNames_["GN_DIRECT_L_RAND_NOSCAL"] = nlopt::GN_DIRECT_L_RAND_NOSCAL;
   AlgorithmNames_["GN_ORIG_DIRECT"] = nlopt::GN_ORIG_DIRECT;
   AlgorithmNames_["GN_ORIG_DIRECT_L"] = nlopt::GN_ORIG_DIRECT_L;
-  AlgorithmNames_["GD_STOGO"] = nlopt::GD_STOGO;
-  AlgorithmNames_["GD_STOGO_RAND"] = nlopt::GD_STOGO_RAND;
+  // stogo is optional
+//   AlgorithmNames_["GD_STOGO"] = nlopt::GD_STOGO;
+//   AlgorithmNames_["GD_STOGO_RAND"] = nlopt::GD_STOGO_RAND;
   AlgorithmNames_["LD_LBFGS_NOCEDAL"] = nlopt::LD_LBFGS_NOCEDAL;
   AlgorithmNames_["LD_LBFGS"] = nlopt::LD_LBFGS;
   AlgorithmNames_["LN_PRAXIS"] = nlopt::LN_PRAXIS;
@@ -160,7 +161,7 @@ void NLopt::checkProblem(const OptimizationProblem & problem) const
     {
       opt.add_inequality_constraint(NLopt::ComputeInequalityConstraint, 0);
     }
-    catch (std::invalid_argument)
+    catch (std::invalid_argument &)
     {
       throw InvalidArgumentException(HERE) << "Error: " << getAlgorithmName() << " does not support inequality constraints";
     }
@@ -172,7 +173,7 @@ void NLopt::checkProblem(const OptimizationProblem & problem) const
     {
       opt.add_equality_constraint(NLopt::ComputeEqualityConstraint, 0);
     }
-    catch (std::invalid_argument)
+    catch (std::invalid_argument &)
     {
       throw InvalidArgumentException(HERE) << "Error: " << getAlgorithmName() << " does not support equality constraints";
     }
@@ -226,6 +227,8 @@ void NLopt::run()
   if (getProblem().hasBounds())
   {
     Interval bounds(getProblem().getBounds());
+    if (!bounds.contains(startingPoint))
+      throw InvalidArgumentException(HERE) << "Starting point is not inside bounds x=" << startingPoint.__str__() << " bounds=" << bounds;
     Interval::BoolCollection finiteLowerBound(bounds.getFiniteLowerBound());
     Interval::BoolCollection finiteUpperBound(bounds.getFiniteUpperBound());
     Point lowerBound(bounds.getLowerBound());
@@ -275,8 +278,21 @@ void NLopt::run()
     opt.set_default_initial_step(dx);
   }
 
-  if (!p_localSolver_.isNull())
+  // some algorithms require a local solver (AUGLAG, MLSL)
+  if (p_localSolver_.isNull())
   {
+    // use a default local solver
+    const nlopt::algorithm local_algo = static_cast<nlopt::algorithm>(GetAlgorithmCode("LD_MMA"));
+    nlopt::opt local_opt(local_algo, dimension);
+    local_opt.set_xtol_abs(getMaximumAbsoluteError());
+    local_opt.set_xtol_rel(getMaximumRelativeError());
+    local_opt.set_ftol_abs(getMaximumResidualError());
+    local_opt.set_maxeval(getMaximumEvaluationNumber());
+    opt.set_local_optimizer(local_opt);
+  }
+  else
+  {
+    // use the specified local solver
     const nlopt::algorithm local_algo = static_cast<nlopt::algorithm>(GetAlgorithmCode(p_localSolver_->getAlgorithmName()));
     nlopt::opt local_opt(local_algo, dimension);
     local_opt.set_xtol_abs(p_localSolver_->getMaximumAbsoluteError());
@@ -305,15 +321,15 @@ void NLopt::run()
     p_opt_ = &opt;
     opt.optimize(x, optimalValue);
   }
-  catch (nlopt::roundoff_limited)
+  catch (nlopt::roundoff_limited &)
   {
     // Here we catch the roundoff_limited exception as the result
     // of the optimization may be useful even if not at the requested precision
-    LOGWARN(OSS() << "NLopt raised a roundoff-limited exception");
+    LOGWARN("NLopt raised a roundoff-limited exception");
   }
-  catch (nlopt::forced_stop)
+  catch (nlopt::forced_stop &)
   {
-    LOGWARN(OSS() << "NLopt was stopped by user");
+    LOGWARN("NLopt was stopped by user");
   }
   catch (std::exception & exc)
   {
@@ -323,7 +339,7 @@ void NLopt::run()
 
   Point optimizer(dimension);
   std::copy(x.begin(), x.end(), optimizer.begin());
-  OptimizationResult result;
+  OptimizationResult result(dimension, 1);
   result.setProblem(getProblem());
 
   UnsignedInteger size = evaluationInputHistory_.getSize();
@@ -348,6 +364,7 @@ void NLopt::run()
     result.store(inP, outP, absoluteError, relativeError, residualError, constraintError);
   }
 
+  result.setEvaluationNumber(size);
   result.setOptimalPoint(optimizer);
   result.setOptimalValue(Point(1, optimalValue));
   result.setLagrangeMultipliers(computeLagrangeMultipliers(optimizer));
@@ -451,10 +468,14 @@ double NLopt::ComputeObjective(const std::vector<double> & x, std::vector<double
   if (!grad.empty())
   {
     Matrix gradient(algorithm->getProblem().getObjective().gradient(inP));
+    Scalar norm = 0;
     for (UnsignedInteger i = 0; i < dimension; ++ i)
     {
-      grad[i] = gradient(i, 0);
+      const Scalar gradI = gradient(i, 0);
+      grad[i] = gradI;
+      norm += gradI * gradI;
     }
+    LOGINFO(OSS() << "Gradient norm: " << sqrt(norm));
   }
 
 #ifdef OPENTURNS_HAVE_NLOPT
