@@ -2,7 +2,7 @@
 /**
  *  @brief NearestPointChecker checks wether the nearest point found is really the nearestpoint
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -130,7 +130,7 @@ void  NearestPointChecker::run()
     /* While some points remain to be classified */
     while (toBeClassified < notClassified)
     {
-      if (getComparisonOperator().compare(levelValuesSample[toBeClassified][0], getThreshold())) // the point verifies the constraint
+      if (getComparisonOperator().compare(levelValuesSample(toBeClassified, 0), getThreshold())) // the point verifies the constraint
       {
         /* Leave it in place and go to the next point */
         toBeClassified++;
@@ -148,7 +148,7 @@ void  NearestPointChecker::run()
       }
     }
     /* At the end, we still have to check the point at the position toBeClassified but without updating notClassified, which should be already equals to 0 and then could try to become < 0 */
-    if (getComparisonOperator().compare(levelValuesSample[toBeClassified][0], getThreshold())) toBeClassified++;
+    if (getComparisonOperator().compare(levelValuesSample(toBeClassified, 0), getThreshold())) toBeClassified++;
 
     /* we split the sample_ in 2 Sample : one with the left side (points verifying the constraint) and the other with the right side (points not verifying the constraint) */
     if (toBeClassified < pointNumber)
