@@ -2,7 +2,7 @@
 /**
  *  @brief ODE solver base class
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -57,6 +57,14 @@ Sample ODESolverImplementation::solve(const Point & initialState,
   throw NotYetImplementedException(HERE) << "In ODESolverImplementation::solve(const Point & initialState, const Point & timeGrid) const";
 }
 
+Sample ODESolverImplementation::solve(const Point & initialState,
+                                      const Mesh & timeGrid) const
+{
+  if (timeGrid.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: expected a mesh of dimension=1, here dimension=" << timeGrid.getDimension();
+  const Sample vertices(timeGrid.getVertices());
+  return solve(initialState, vertices.getImplementation()->getData());
+}
+
 /* String converter */
 String ODESolverImplementation::__repr__() const
 {
