@@ -2,7 +2,7 @@
 /**
  *  @brief
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -28,6 +28,8 @@
 #include "openturns/HMatrixFactory.hxx"
 #include "openturns/Contour.hxx"
 #include "openturns/Curve.hxx"
+#include "openturns/CovarianceModel.hxx"
+#include "openturns/TBB.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -43,19 +45,19 @@ static const Factory<CovarianceModelImplementation> Factory_CovarianceModelImple
 CovarianceModelImplementation::CovarianceModelImplementation(const UnsignedInteger spatialDimension)
   : PersistentObject()
   , scale_(spatialDimension, 1.0)
-  , spatialDimension_(spatialDimension)
+  , inputDimension_(spatialDimension)
   , amplitude_(1, 1.0)
-  , dimension_(1)
-  , spatialCorrelation_(0)
-  , spatialCovariance_(0)
-  , spatialCovarianceCholeskyFactor_(0)
+  , outputDimension_(1)
+  , outputCorrelation_(0)
+  , outputCovariance_(0)
+  , outputCovarianceCholeskyFactor_(0)
   , definesComputeStandardRepresentative_(false)
   , isDiagonal_(true)
   , nuggetFactor_(ResourceMap::GetAsScalar("CovarianceModel-DefaultNuggetFactor"))
-  , activeParameter_(spatialDimension_ + dimension_)
+  , activeParameter_(inputDimension_ + outputDimension_)
 {
   activeParameter_.fill();
-  updateSpatialCovariance();
+  updateOutputCovariance();
 }
 
 /* Standard constructor with scale and amplitude scale parameter parameter */
@@ -63,21 +65,21 @@ CovarianceModelImplementation::CovarianceModelImplementation(const Point & scale
     const Point & amplitude)
   : PersistentObject()
   , scale_(0)
-  , spatialDimension_(scale.getDimension())
+  , inputDimension_(scale.getDimension())
   , amplitude_(0)
-  , dimension_(amplitude.getDimension())
-  , spatialCorrelation_(0)
-  , spatialCovariance_(0)
-  , spatialCovarianceCholeskyFactor_(0)
+  , outputDimension_(amplitude.getDimension())
+  , outputCorrelation_(0)
+  , outputCovariance_(0)
+  , outputCovarianceCholeskyFactor_(0)
   , definesComputeStandardRepresentative_(false)
   , isDiagonal_(true)
   , nuggetFactor_(ResourceMap::GetAsScalar("CovarianceModel-DefaultNuggetFactor"))
-  , activeParameter_(spatialDimension_ + (dimension_ * (dimension_ + 1)) / 2)
+  , activeParameter_(inputDimension_ + outputDimension_)
 {
   setAmplitude(amplitude);
   setScale(scale);
   activeParameter_.fill();
-  updateSpatialCovariance();
+  updateOutputCovariance();
 }
 
 /* Standard constructor with scale, amplitude and spatial correlation parameter parameter */
@@ -86,21 +88,21 @@ CovarianceModelImplementation::CovarianceModelImplementation(const Point & scale
     const CorrelationMatrix & spatialCorrelation)
   : PersistentObject()
   , scale_(0)
-  , spatialDimension_(scale.getDimension())
+  , inputDimension_(scale.getDimension())
   , amplitude_(0)
-  , dimension_(amplitude.getDimension())
-  , spatialCorrelation_(0)
-  , spatialCovariance_(0)
-  , spatialCovarianceCholeskyFactor_(0)
+  , outputDimension_(amplitude.getDimension())
+  , outputCorrelation_(0)
+  , outputCovariance_(0)
+  , outputCovarianceCholeskyFactor_(0)
   , definesComputeStandardRepresentative_(false)
   , isDiagonal_(true)
   , nuggetFactor_(ResourceMap::GetAsScalar("CovarianceModel-DefaultNuggetFactor"))
-  , activeParameter_(spatialDimension_ + (dimension_ * (dimension_ + 1)) / 2)
+  , activeParameter_(inputDimension_ + outputDimension_)
 {
   setAmplitude(amplitude);
   setScale(scale);
   activeParameter_.fill();
-  setSpatialCorrelation(spatialCorrelation);
+  setOutputCorrelation(spatialCorrelation);
 }
 
 /* Standard constructor with scale and spatial covariance parameter parameter */
@@ -108,30 +110,28 @@ CovarianceModelImplementation::CovarianceModelImplementation(const Point & scale
     const CovarianceMatrix & spatialCovariance)
   : PersistentObject()
   , scale_(0)
-  , spatialDimension_(scale.getDimension())
+  , inputDimension_(scale.getDimension())
   , amplitude_(0)
-  , dimension_(spatialCovariance.getDimension())
-  , spatialCorrelation_(0)
-  , spatialCovariance_(0)
-  , spatialCovarianceCholeskyFactor_(0)
+  , outputDimension_(spatialCovariance.getDimension())
+  , outputCorrelation_(0)
+  , outputCovariance_(spatialCovariance)
+  , outputCovarianceCholeskyFactor_(0)
   , definesComputeStandardRepresentative_(false)
   , isDiagonal_(true)
   , nuggetFactor_(ResourceMap::GetAsScalar("CovarianceModel-DefaultNuggetFactor"))
-  , activeParameter_(spatialDimension_ + (dimension_ * (dimension_ + 1)) / 2)
+  , activeParameter_(inputDimension_ + outputDimension_)
 {
-  // spatialCovariance
-  spatialCovariance_ = spatialCovariance;
-  Point amplitude(dimension_);
-  for (UnsignedInteger i = 0; i < dimension_; ++i) amplitude[i] = sqrt(spatialCovariance(i, i));
+  Point amplitude(outputDimension_);
+  for (UnsignedInteger i = 0; i < outputDimension_; ++i) amplitude[i] = sqrt(spatialCovariance(i, i));
   // Check that the amplitudes are valid
   setAmplitude(amplitude);
   // Convert the spatial covariance into a spatial correlation
   if (!spatialCovariance.isDiagonal())
   {
-    spatialCorrelation_ = CorrelationMatrix(dimension_);
-    for (UnsignedInteger i = 0; i < dimension_; ++i)
+    outputCorrelation_ = CorrelationMatrix(outputDimension_);
+    for (UnsignedInteger i = 0; i < outputDimension_; ++i)
       for (UnsignedInteger j = 0; j < i; ++j)
-        spatialCorrelation_(i, j) = spatialCovariance(i, j) / (amplitude[i] * amplitude[j]);
+        outputCorrelation_(i, j) = spatialCovariance(i, j) / (amplitude[i] * amplitude[j]);
   } // !isDiagonal
   setScale(scale);
   activeParameter_.fill();
@@ -144,14 +144,26 @@ CovarianceModelImplementation * CovarianceModelImplementation::clone() const
 }
 
 /* Dimension accessors */
+UnsignedInteger CovarianceModelImplementation::getOutputDimension() const
+{
+  return outputDimension_;
+}
+
+UnsignedInteger CovarianceModelImplementation::getInputDimension() const
+{
+  return inputDimension_;
+}
+
 UnsignedInteger CovarianceModelImplementation::getDimension() const
 {
-  return dimension_;
+  LOGWARN(OSS() << "CovarianceModel::getDimension is deprecated in favor of getOutputDimension.");
+  return getOutputDimension();
 }
 
 UnsignedInteger CovarianceModelImplementation::getSpatialDimension() const
 {
-  return spatialDimension_;
+  LOGWARN(OSS() << "CovarianceModel::getSpatialDimension is deprecated in favor of getInputDimension.");
+  return getInputDimension();
 }
 
 CovarianceMatrix CovarianceModelImplementation::operator() (const Scalar s,
@@ -164,7 +176,7 @@ CovarianceMatrix CovarianceModelImplementation::operator() (const Point & s,
     const Point & t) const
 {
   const Scalar rho = computeStandardRepresentative(s, t);
-  return CovarianceMatrix((spatialCovariance_ * rho).getImplementation());
+  return CovarianceMatrix((outputCovariance_ * rho).getImplementation());
 }
 
 // compute standard representative computes the term \rho(s, t)
@@ -174,11 +186,17 @@ Scalar CovarianceModelImplementation::computeStandardRepresentative(const Point
   throw NotYetImplementedException(HERE) << "In CovarianceModelImplementation::computeStandardRepresentative(const Point & s, const Point & t) const";
 }
 
+Scalar CovarianceModelImplementation::computeStandardRepresentative(const Collection<Scalar>::const_iterator & s_begin,
+    const Collection<Scalar>::const_iterator & t_begin) const
+{
+  throw NotYetImplementedException(HERE) << "In CovarianceModelImplementation::computeStandardRepresentative(const Collection<Scalar>::const_iterator & s_begin, const Collection<Scalar>::const_iterator & t_begin) const";
+}
+
 Scalar CovarianceModelImplementation::computeAsScalar (const Point & s,
     const Point & t) const
 {
-  if (dimension_ != 1) throw NotDefinedException(HERE) << "Error: the covariance model is of dimension=" << dimension_ << ", expected dimension=1.";
-  return spatialCovariance_(0, 0) * computeStandardRepresentative(s, t);
+  if (outputDimension_ != 1) throw NotDefinedException(HERE) << "Error: the covariance model is of dimension=" << outputDimension_ << ", expected dimension=1.";
+  return outputCovariance_(0, 0) * computeStandardRepresentative(s, t);
 }
 
 /* Computation of the covariance function */
@@ -196,9 +214,9 @@ CovarianceMatrix CovarianceModelImplementation::operator() (const Point & tau) c
 Matrix CovarianceModelImplementation::partialGradient (const Point & s,
     const Point & t) const
 {
-  if (s.getDimension() != spatialDimension_) throw InvalidArgumentException(HERE) << "Error: the point s has dimension=" << s.getDimension() << ", expected dimension=" << spatialDimension_;
-  if (t.getDimension() != spatialDimension_) throw InvalidArgumentException(HERE) << "Error: the point t has dimension=" << t.getDimension() << ", expected dimension=" << spatialDimension_;
-  Matrix gradient(spatialDimension_, dimension_ * dimension_);
+  if (s.getDimension() != inputDimension_) throw InvalidArgumentException(HERE) << "Error: the point s has dimension=" << s.getDimension() << ", expected dimension=" << inputDimension_;
+  if (t.getDimension() != inputDimension_) throw InvalidArgumentException(HERE) << "Error: the point t has dimension=" << t.getDimension() << ", expected dimension=" << inputDimension_;
+  Matrix gradient(inputDimension_, outputDimension_ * outputDimension_);
   CovarianceMatrix covarianceST(operator()(s, t));
   // Convert result into MatrixImplementation to symmetrize & get the collection
   MatrixImplementation covarianceSTImplementation(*covarianceST.getImplementation());
@@ -206,7 +224,7 @@ Matrix CovarianceModelImplementation::partialGradient (const Point & s,
   const Point centralValue(covarianceSTImplementation);
   const Scalar epsilon = std::sqrt(SpecFunc::ScalarEpsilon);
   // Loop over the shifted points
-  for (UnsignedInteger i = 0; i < spatialDimension_; ++i)
+  for (UnsignedInteger i = 0; i < inputDimension_; ++i)
   {
     Point currentPoint(s);
     currentPoint[i] += epsilon;
@@ -227,7 +245,7 @@ Matrix CovarianceModelImplementation::parameterGradient(const Point & s,
   const Point parameter(getParameter());
   const UnsignedInteger size = parameter.getSize();
   const Scalar epsilon = std::sqrt(SpecFunc::ScalarEpsilon);
-  Matrix gradient(size, (dimension_ * (dimension_ + 1)) / 2);
+  Matrix gradient(size, (outputDimension_ * (outputDimension_ + 1)) / 2);
   CovarianceMatrix covRef = operator()(s, t);
   Pointer<CovarianceModelImplementation> p_implementation(clone());
   for (UnsignedInteger k = 0; k < size; ++ k)
@@ -237,7 +255,7 @@ Matrix CovarianceModelImplementation::parameterGradient(const Point & s,
     p_implementation->setParameter(parameterP);
     CovarianceMatrix covP = p_implementation->operator()(s, t);
     UnsignedInteger index = 0;
-    for (UnsignedInteger j = 0; j < dimension_; ++ j)
+    for (UnsignedInteger j = 0; j < outputDimension_; ++ j)
     {
       for (UnsignedInteger i = 0; i <= j; ++ i)
       {
@@ -257,18 +275,18 @@ CovarianceMatrix CovarianceModelImplementation::discretize(const RegularGrid & t
 
 struct CovarianceModelDiscretizePolicy
 {
-  const Sample & input_;
+  const SampleImplementation & input_;
   CovarianceMatrix & output_;
   const CovarianceModelImplementation & model_;
-  const UnsignedInteger dimension_;
+  const UnsignedInteger outputDimension_;
 
   CovarianceModelDiscretizePolicy(const Sample & input,
                                   CovarianceMatrix & output,
                                   const CovarianceModelImplementation & model)
-    : input_(input)
+    : input_(*input.getImplementation())
     , output_(output)
     , model_(model)
-    , dimension_(model.getDimension())
+    , outputDimension_(model.getOutputDimension())
   {}
 
   inline void operator()( const TBB::BlockedRange<UnsignedInteger> & r ) const
@@ -276,12 +294,12 @@ struct CovarianceModelDiscretizePolicy
     for (UnsignedInteger i = r.begin(); i != r.end(); ++i)
     {
       const UnsignedInteger jLocal = static_cast< UnsignedInteger >(sqrt(2.0 * i + 0.25) - 0.5);
-      const UnsignedInteger jBase = jLocal * dimension_;
+      const UnsignedInteger jBase = jLocal * outputDimension_;
       const UnsignedInteger iLocal = i - (jLocal * (jLocal + 1)) / 2;
-      const UnsignedInteger iBase = iLocal * dimension_;
+      const UnsignedInteger iBase = iLocal * outputDimension_;
       const CovarianceMatrix localCovariance(model_(input_[iLocal], input_[jLocal]));
-      for (UnsignedInteger ii = 0; ii < dimension_; ++ii)
-        for (UnsignedInteger jj = 0; jj < dimension_; ++jj)
+      for (UnsignedInteger jj = 0; jj < outputDimension_; ++jj)
+        for (UnsignedInteger ii = 0; ii < outputDimension_; ++ii)
           output_(iBase + ii, jBase + jj) = localCovariance(ii, jj);
     }
   }
@@ -290,16 +308,21 @@ struct CovarianceModelDiscretizePolicy
 
 struct CovarianceModelDiscretizeKroneckerPolicy
 {
-  const Sample & input_;
-  CovarianceMatrix & output_;
+  const SampleImplementation & input_;
+  // output_ is a CovarianceMatrix, but since we fill only its half part,
+  // we can directly store results in the underlying MatrixImplementation.
+  // This avoids comparing row and column numbers.
+  MatrixImplementation & output_;
   const CovarianceModelImplementation & model_;
+  const UnsignedInteger inputDimension_;
 
   CovarianceModelDiscretizeKroneckerPolicy(const Sample & input,
       CovarianceMatrix & output,
       const CovarianceModelImplementation & model)
-    : input_(input)
-    , output_(output)
+    : input_(*input.getImplementation())
+    , output_(*output.getImplementation())
     , model_(model)
+    , inputDimension_(input_.getDimension())
   {}
 
   inline void operator()( const TBB::BlockedRange<UnsignedInteger> & r ) const
@@ -308,7 +331,8 @@ struct CovarianceModelDiscretizeKroneckerPolicy
     {
       const UnsignedInteger jLocal = static_cast< UnsignedInteger >(sqrt(2.0 * i + 0.25) - 0.5);
       const UnsignedInteger iLocal = i - (jLocal * (jLocal + 1)) / 2;
-      output_(iLocal, jLocal) = model_.computeStandardRepresentative(input_[iLocal], input_[jLocal]);
+      // By construction, iLocal <= jLocal
+      output_(jLocal, iLocal) = model_.computeStandardRepresentative(input_.data_begin() + iLocal * inputDimension_, input_.data_begin() + jLocal * inputDimension_);
     }
   }
   static void genericKroneckerProduct(const SquareMatrix & leftMatrix, const SquareMatrix & rightMatrix, SquareMatrix & productMatrix)
@@ -350,7 +374,7 @@ struct CovarianceModelDiscretizeKroneckerPolicy
 
 CovarianceMatrix CovarianceModelImplementation::discretize(const Sample & vertices) const
 {
-  if (vertices.getDimension() != spatialDimension_) throw InvalidArgumentException(HERE) << "Error: the given sample has a dimension=" << vertices.getDimension() << " different from the input dimension=" << spatialDimension_;
+  if (vertices.getDimension() != inputDimension_) throw InvalidArgumentException(HERE) << "Error: the given sample has a dimension=" << vertices.getDimension() << " different from the input dimension=" << inputDimension_;
   const UnsignedInteger size = vertices.getSize();
   if (definesComputeStandardRepresentative_)
   {
@@ -359,13 +383,13 @@ CovarianceMatrix CovarianceModelImplementation::discretize(const Sample & vertic
     // The loop is over the lower block-triangular part
     TBB::ParallelFor( 0, size * (size + 1) / 2, policy );
     rhoMatrix.checkSymmetry();
-    spatialCovariance_.checkSymmetry();
-    // Compute the Kronecker product of rhoMatrix by spatialCovariance_
-    return policy.kroneckerProduct(spatialCovariance_);;
+    outputCovariance_.checkSymmetry();
+    // Compute the Kronecker product of rhoMatrix by outputCovariance_
+    return policy.kroneckerProduct(outputCovariance_);
   }
   else
   {
-    const UnsignedInteger fullSize = size * dimension_;
+    const UnsignedInteger fullSize = size * outputDimension_;
     CovarianceMatrix covarianceMatrix(fullSize);
     const CovarianceModelDiscretizePolicy policy( vertices, covarianceMatrix, *this );
     // The loop is over the lower block-triangular part
@@ -400,11 +424,11 @@ TriangularMatrix CovarianceModelImplementation::discretizeAndFactorize(const Sam
     const CovarianceModelDiscretizeKroneckerPolicy policy( vertices, rhoMatrix, *this );
     // The loop is over the lower block-triangular part
     TBB::ParallelFor( 0, size * (size + 1) / 2, policy );
-    // Compute the Cholesky factor of spatialCovariance_
-    if (spatialCovarianceCholeskyFactor_.getDimension() == 0)
-      spatialCovarianceCholeskyFactor_ = spatialCovariance_.computeCholesky();
-    // Compute the Kronecker product of rhoCholeskyFactor by spatialCovarianceCholeskyFactor_
-    return policy.kroneckerProductCholeskyFactor(spatialCovarianceCholeskyFactor_);
+    // Compute the Cholesky factor of outputCovariance_
+    if (outputCovarianceCholeskyFactor_.getDimension() == 0)
+      outputCovarianceCholeskyFactor_ = outputCovariance_.computeCholesky();
+    // Compute the Kronecker product of rhoCholeskyFactor by outputCovarianceCholeskyFactor_
+    return policy.kroneckerProductCholeskyFactor(outputCovarianceCholeskyFactor_);
   }
   else
   {
@@ -434,7 +458,7 @@ struct CovarianceModelScalarDiscretizeRowPolicy
 
   inline void operator()( const TBB::BlockedRange<UnsignedInteger> & r ) const
   {
-    for (UnsignedInteger i = r.begin(); i != r.end(); ++i) output_[i][0] = model_.computeAsScalar(p_, input_[i]);
+    for (UnsignedInteger i = r.begin(); i != r.end(); ++i) output_(i, 0) = model_.computeAsScalar(p_, input_[i]);
   }
 
 }; /* end struct CovarianceModelScalarDiscretizeRowPolicy */
@@ -445,7 +469,7 @@ struct CovarianceModelDiscretizeRowPolicy
   const Point p_;
   Sample & output_;
   const CovarianceModelImplementation & model_;
-  const UnsignedInteger dimension_;
+  const UnsignedInteger outputDimension_;
 
   CovarianceModelDiscretizeRowPolicy(const Sample & input,
                                      const UnsignedInteger p,
@@ -455,7 +479,7 @@ struct CovarianceModelDiscretizeRowPolicy
     , p_(input[p])
     , output_(output)
     , model_(model)
-    , dimension_(model.getDimension())
+    , outputDimension_(model.getOutputDimension())
   {}
 
   inline void operator()( const TBB::BlockedRange<UnsignedInteger> & r ) const
@@ -463,9 +487,9 @@ struct CovarianceModelDiscretizeRowPolicy
     for (UnsignedInteger i = r.begin(); i != r.end(); ++i)
     {
       const MatrixImplementation localCovariance(*(model_(p_, input_[i]).getImplementation()));
-      const UnsignedInteger base = i * dimension_;
-      for (UnsignedInteger ii = 0; ii < dimension_; ++ii)
-        for (UnsignedInteger jj = 0; jj < dimension_; ++jj)
+      const UnsignedInteger base = i * outputDimension_;
+      for (UnsignedInteger ii = 0; ii < outputDimension_; ++ii)
+        for (UnsignedInteger jj = 0; jj < outputDimension_; ++jj)
           output_[base + ii][jj] = localCovariance(ii, jj);
     }
   }
@@ -475,10 +499,10 @@ struct CovarianceModelDiscretizeRowPolicy
 Sample CovarianceModelImplementation::discretizeRow(const Sample & vertices,
     const UnsignedInteger p) const
 {
-  if (vertices.getDimension() != spatialDimension_) throw InvalidArgumentException(HERE) << "Error: the given sample has a dimension=" << vertices.getDimension() << " different from the input dimension=" << spatialDimension_;
+  if (vertices.getDimension() != inputDimension_) throw InvalidArgumentException(HERE) << "Error: the given sample has a dimension=" << vertices.getDimension() << " different from the input dimension=" << inputDimension_;
   const UnsignedInteger size = vertices.getSize();
-  Sample result(size * dimension_, dimension_);
-  if (dimension_ == 1)
+  Sample result(size * outputDimension_, outputDimension_);
+  if (outputDimension_ == 1)
   {
     const CovarianceModelScalarDiscretizeRowPolicy policy( vertices, p, result, *this );
     TBB::ParallelFor( 0, size, policy );
@@ -512,8 +536,8 @@ HMatrix CovarianceModelImplementation::discretizeHMatrix(const Sample & vertices
 {
 #ifdef OPENTURNS_HAVE_HMAT
   HMatrixFactory hmatrixFactory;
-  HMatrix covarianceHMatrix = hmatrixFactory.build(vertices, dimension_, true, parameters);
-  if (dimension_ == 1)
+  HMatrix covarianceHMatrix = hmatrixFactory.build(vertices, outputDimension_, true, parameters);
+  if (outputDimension_ == 1)
   {
     CovarianceAssemblyFunction simple(*this, vertices, nuggetFactor);
     covarianceHMatrix.assemble(simple, 'L');
@@ -565,12 +589,12 @@ Point CovarianceModelImplementation::getAmplitude() const
 
 void CovarianceModelImplementation::setAmplitude(const Point & amplitude)
 {
-  if (amplitude.getDimension() != dimension_) throw InvalidArgumentException(HERE) << "In CovarianceModelImplementation::setAmplitude: the given amplitude has a dimension=" << amplitude.getDimension() << " different from the dimension=" << dimension_;
-  for (UnsignedInteger index = 0; index < dimension_; ++index)
+  if (amplitude.getDimension() != outputDimension_) throw InvalidArgumentException(HERE) << "In CovarianceModelImplementation::setAmplitude: the given amplitude has a dimension=" << amplitude.getDimension() << " different from the dimension=" << outputDimension_;
+  for (UnsignedInteger index = 0; index < outputDimension_; ++index)
     if (!(amplitude[index] > 0.0))
       throw InvalidArgumentException(HERE) << "In CovarianceModelImplementation::setAmplitude, the component " << index << " of amplitude is non positive" ;
   amplitude_ = amplitude;
-  updateSpatialCovariance();
+  updateOutputCovariance();
 }
 
 /* Scale accessor */
@@ -581,42 +605,54 @@ Point CovarianceModelImplementation::getScale() const
 
 void CovarianceModelImplementation::setScale(const Point & scale)
 {
-  if (scale.getDimension() != spatialDimension_) throw InvalidArgumentException(HERE) << "In CovarianceModelImplementation::setScale: the given scale has a dimension=" << scale.getDimension() << " different from the input dimension=" << spatialDimension_;
-  for (UnsignedInteger index = 0; index < spatialDimension_; ++index)
+  if (scale.getDimension() != inputDimension_) throw InvalidArgumentException(HERE) << "In CovarianceModelImplementation::setScale: the given scale has a dimension=" << scale.getDimension() << " different from the input dimension=" << inputDimension_;
+  for (UnsignedInteger index = 0; index < inputDimension_; ++index)
     if (!(scale[index] > 0.0))
       throw InvalidArgumentException(HERE) << "In CovarianceModelImplementation::setScale: the component " << index << " of scale is non positive" ;
   scale_ = scale;
 }
 
-/* Spatial correlation accessor */
+/* Output correlation accessor */
+CorrelationMatrix CovarianceModelImplementation::getOutputCorrelation() const
+{
+  if (!isDiagonal_) return outputCorrelation_;
+  return CorrelationMatrix(outputDimension_);
+}
+
+void CovarianceModelImplementation::setOutputCorrelation(const CorrelationMatrix & outputCorrelation)
+{
+  if (outputCorrelation.getDimension() != outputDimension_)
+    throw InvalidArgumentException(HERE) << "The given spatial correlation has a dimension different from the amplitudes.";
+  isDiagonal_ = outputCorrelation.isDiagonal();
+  outputCorrelation_ = isDiagonal_ ? CorrelationMatrix() : outputCorrelation;
+  updateOutputCovariance();
+}
+
 CorrelationMatrix CovarianceModelImplementation::getSpatialCorrelation() const
 {
-  if (!isDiagonal_) return spatialCorrelation_;
-  return CorrelationMatrix(dimension_);
+  LOGWARN(OSS() << "CovarianceModel::getSpatialCorrelation is deprecated in favor of getOutputCorrelation.");
+  return getOutputCorrelation();
 }
 
 void CovarianceModelImplementation::setSpatialCorrelation(const CorrelationMatrix & spatialCorrelation)
 {
-  if (spatialCorrelation.getDimension() != dimension_)
-    throw InvalidArgumentException(HERE) << "The given spatial correlation has a dimension different from the amplitudes.";
-  isDiagonal_ = spatialCorrelation.isDiagonal();
-  spatialCorrelation_ = isDiagonal_ ? CorrelationMatrix() : spatialCorrelation;
-  updateSpatialCovariance();
+  LOGWARN(OSS() << "CovarianceModel::setSpatialCorrelation is deprecated in favor of setOutputCorrelation.");
+  setOutputCorrelation(spatialCorrelation);
 }
 
-void CovarianceModelImplementation::updateSpatialCovariance()
+void CovarianceModelImplementation::updateOutputCovariance()
 {
-  spatialCovariance_ = CovarianceMatrix(dimension_);
-  for (UnsignedInteger j = 0; j < dimension_; ++j)
+  outputCovariance_ = CovarianceMatrix(outputDimension_);
+  for (UnsignedInteger j = 0; j < outputDimension_; ++j)
   {
-    spatialCovariance_(j, j) = amplitude_[j] * amplitude_[j];
+    outputCovariance_(j, j) = amplitude_[j] * amplitude_[j];
     if (!isDiagonal_)
     {
-      for (UnsignedInteger i = j + 1; i < dimension_; ++i)
-        spatialCovariance_(i, j) = spatialCorrelation_(i , j) * amplitude_[i] * amplitude_[j];
+      for (UnsignedInteger i = j + 1; i < outputDimension_; ++i)
+        outputCovariance_(i, j) = outputCorrelation_(i , j) * amplitude_[i] * amplitude_[j];
     }
   }
-  spatialCovarianceCholeskyFactor_.getImplementation().reset(new MatrixImplementation);
+  outputCovarianceCholeskyFactor_.getImplementation().reset(new MatrixImplementation);
 }
 
 /* Nugget factor accessor */
@@ -637,12 +673,12 @@ void CovarianceModelImplementation::setFullParameter(const Point & parameter)
   // First the scale parameter
   UnsignedInteger index = 0;
   // Check the size
-  const UnsignedInteger totalSize = spatialDimension_ + dimension_ * (dimension_ + 1) / 2;
+  const UnsignedInteger totalSize = inputDimension_ + outputDimension_ * (outputDimension_ + 1) / 2;
   if (parameter.getSize() < totalSize)
     throw InvalidArgumentException(HERE) << "In CovarianceModelImplementation::setFullParameter, points have incompatible size. Point size = " << parameter.getSize()
                                          << " whereas expected size = " << totalSize ;
 
-  for (UnsignedInteger i = 0; i < spatialDimension_; ++ i)
+  for (UnsignedInteger i = 0; i < inputDimension_; ++ i)
   {
     if (!(parameter[index] > 0.0))
       throw InvalidArgumentException(HERE) << "In CovarianceModelImplementation::setParameter, the component " << index << " of scale is non positive" ;
@@ -650,22 +686,22 @@ void CovarianceModelImplementation::setFullParameter(const Point & parameter)
     ++ index;
   }
   // Second the amplitude parameter
-  for (UnsignedInteger i = 0; i < dimension_; ++ i)
+  for (UnsignedInteger i = 0; i < outputDimension_; ++ i)
   {
     if (!(parameter[index] > 0.0))
       throw InvalidArgumentException(HERE) << "In CovarianceModelImplementation::setParameter, the component " << index << " of amplitude is non positive" ;
     amplitude_[i] = parameter[index];
     ++ index;
   }
-  CorrelationMatrix spatialCorrelation(dimension_);
+  CorrelationMatrix spatialCorrelation(outputDimension_);
   // Third the spatial correation parameter, only the lower triangle
-  for (UnsignedInteger i = 0; i < dimension_; ++ i)
+  for (UnsignedInteger i = 0; i < outputDimension_; ++ i)
     for (UnsignedInteger j = 0; j < i; ++ j)
     {
       spatialCorrelation(i, j) = parameter[index];
       ++ index;
     }
-  setSpatialCorrelation(spatialCorrelation);
+  setOutputCorrelation(spatialCorrelation);
 }
 
 
@@ -679,13 +715,13 @@ Point CovarianceModelImplementation::getFullParameter() const
   // Third the spatial correation parameter, only the lower triangle
   if (isDiagonal_)
   {
-    if (dimension_ > 1)
-      parameter.add(Point((dimension_ * (dimension_ - 1)) / 2));
+    if (outputDimension_ > 1)
+      parameter.add(Point((outputDimension_ * (outputDimension_ - 1)) / 2));
   }
   else
-    for (UnsignedInteger i = 0; i < dimension_; ++ i)
+    for (UnsignedInteger i = 0; i < outputDimension_; ++ i)
       for (UnsignedInteger j = 0; j < i; ++ j)
-        parameter.add(spatialCorrelation_(i, j));
+        parameter.add(outputCorrelation_(i, j));
   return parameter;
 }
 
@@ -695,13 +731,13 @@ Description CovarianceModelImplementation::getFullParameterDescription() const
   // First the scale parameter
   Description description(0);
   // First the scale parameter
-  for (UnsignedInteger j = 0; j < spatialDimension_; ++j)
+  for (UnsignedInteger j = 0; j < inputDimension_; ++j)
     description.add(OSS() << "scale_" << j);
   // Second the amplitude parameter
-  for (UnsignedInteger j = 0; j < dimension_; ++j)
+  for (UnsignedInteger j = 0; j < outputDimension_; ++j)
     description.add(OSS() << "amplitude_" << j);
   // Third the spatial correlation parameter, only the lower triangle
-  for (UnsignedInteger i = 0; i < dimension_; ++i)
+  for (UnsignedInteger i = 0; i < outputDimension_; ++i)
     for (UnsignedInteger j = 0; j < i; ++j)
       description.add(OSS() << "R_" << i << "_" << j);
 
@@ -777,10 +813,10 @@ Bool CovarianceModelImplementation::isDiagonal() const
 }
 
 /* Marginal accessor */
-CovarianceModelImplementation::Implementation CovarianceModelImplementation::getMarginal(const UnsignedInteger index) const
+CovarianceModel CovarianceModelImplementation::getMarginal(const UnsignedInteger index) const
 {
-  if (index >= dimension_) throw InvalidArgumentException(HERE) << "Error: index=" << index << " must be less than output dimension=" << dimension_;
-  if (dimension_ != 1) throw NotYetImplementedException(HERE) << "In CovarianceModelImplementation::getMarginal(const UnsignedInteger index) const";
+  if (index >= outputDimension_) throw InvalidArgumentException(HERE) << "Error: index=" << index << " must be less than output dimension=" << outputDimension_;
+  if (outputDimension_ != 1) throw NotYetImplementedException(HERE) << "In CovarianceModelImplementation::getMarginal(const UnsignedInteger index) const";
   return clone();
 }
 
@@ -793,9 +829,9 @@ Graph CovarianceModelImplementation::draw(const UnsignedInteger rowIndex,
     const Bool asStationary,
     const Bool correlationFlag) const
 {
-  if (spatialDimension_ != 1) throw NotDefinedException(HERE) << "Error: can draw covariance models only if spatial dimension=1, here spatial dimension=" << spatialDimension_;
-  if (rowIndex >= dimension_) throw InvalidArgumentException(HERE) << "Error: the given row index must be less than " << dimension_ << ", here rowIndex=" << rowIndex;
-  if (columnIndex >= dimension_) throw InvalidArgumentException(HERE) << "Error: the given column index must be less than " << dimension_ << ", here columnIndex=" << columnIndex;
+  if (inputDimension_ != 1) throw NotDefinedException(HERE) << "Error: can draw covariance models only if spatial dimension=1, here spatial dimension=" << inputDimension_;
+  if (rowIndex >= outputDimension_) throw InvalidArgumentException(HERE) << "Error: the given row index must be less than " << outputDimension_ << ", here rowIndex=" << rowIndex;
+  if (columnIndex >= outputDimension_) throw InvalidArgumentException(HERE) << "Error: the given column index must be less than " << outputDimension_ << ", here columnIndex=" << columnIndex;
   if (pointNumber < 2) throw InvalidArgumentException(HERE) << "Error: cannot draw the model with pointNumber<2, here pointNumber=" << pointNumber;
   // Check if the model is stationary and if we want to draw it this way
   if (asStationary && isStationary())
@@ -814,8 +850,8 @@ Graph CovarianceModelImplementation::draw(const UnsignedInteger rowIndex,
     {
       const Scalar tau = (i * tMin + (pointNumber - i - 1.0) * tMax) / (pointNumber - 1.0);
       const Scalar value((*this)(tau)(rowIndex, columnIndex) / ratio);
-      data[i][0] = tau;
-      data[i][1] = value;
+      data(i, 0) = tau;
+      data(i, 1) = value;
     }
     Graph graph(getName(), "tau", (correlationFlag ? "correlation" : "covariance"), true, "topright");
     Curve curve(data);
@@ -890,10 +926,10 @@ void CovarianceModelImplementation::save(Advocate & adv) const
 {
   PersistentObject::save(adv);
   adv.saveAttribute("scale_", scale_);
-  adv.saveAttribute("spatialDimension_", spatialDimension_);
+  adv.saveAttribute("inputDimension_", inputDimension_);
   adv.saveAttribute("amplitude_", amplitude_);
-  adv.saveAttribute("dimension_", dimension_);
-  adv.saveAttribute("spatialCorrelation_", spatialCorrelation_);
+  adv.saveAttribute("outputDimension_", outputDimension_);
+  adv.saveAttribute("outputCorrelation_", outputCorrelation_);
   adv.saveAttribute("definesComputeStandardRepresentative_", definesComputeStandardRepresentative_);
   adv.saveAttribute("isDiagonal_", isDiagonal_);
   adv.saveAttribute("nuggetFactor_", nuggetFactor_);
@@ -905,15 +941,15 @@ void CovarianceModelImplementation::load(Advocate & adv)
 {
   PersistentObject::load(adv);
   adv.loadAttribute("scale_", scale_);
-  adv.loadAttribute("spatialDimension_", spatialDimension_);
+  adv.loadAttribute("inputDimension_", inputDimension_);
   adv.loadAttribute("amplitude_", amplitude_);
-  adv.loadAttribute("dimension_", dimension_);
-  adv.loadAttribute("spatialCorrelation_", spatialCorrelation_);
+  adv.loadAttribute("outputDimension_", outputDimension_);
+  adv.loadAttribute("outputCorrelation_", outputCorrelation_);
   adv.loadAttribute("definesComputeStandardRepresentative_", definesComputeStandardRepresentative_);
   adv.loadAttribute("isDiagonal_", isDiagonal_);
   adv.loadAttribute("nuggetFactor_", nuggetFactor_);
   adv.loadAttribute("activeParameter_", activeParameter_);
-  updateSpatialCovariance();
+  updateOutputCovariance();
 }
 
 END_NAMESPACE_OPENTURNS
