@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  LinearModelFactory.cxx
  *  @brief Factory for linear model
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,22 +14,20 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-04-18 17:56:46 +0200 (Wed, 18 Apr 2012)
  */
 #include <fstream>
 #include <cstdlib>
 
-#include "LinearModelFactory.hxx"
-#include "LinearModel.hxx"
-#include "Path.hxx"
-#include "Exception.hxx"
-#include "OTconfig.hxx"
-#include "Log.hxx"
-#include "Os.hxx"
+#include "openturns/LinearModelFactory.hxx"
+#include "openturns/LinearModel.hxx"
+#include "openturns/Path.hxx"
+#include "openturns/Exception.hxx"
+#include "openturns/OTconfig.hxx"
+#include "openturns/Log.hxx"
+#include "openturns/Os.hxx"
 
 
 BEGIN_NAMESPACE_OPENTURNS
@@ -42,9 +39,9 @@ LinearModelFactory::LinearModelFactory()
 }
 
 /* LinearModel creation */
-LinearModel LinearModelFactory::build(const NumericalSample & samplePred,
-                                      const NumericalSample & sampleLab,
-                                      const NumericalScalar levelValue) const
+LinearModel LinearModelFactory::build(const Sample & samplePred,
+                                      const Sample & sampleLab,
+                                      const Scalar levelValue) const
 {
   if (samplePred.getSize() != sampleLab.getSize()) throw InvalidArgumentException(HERE) << "Error: predictors sample must have the same size than the laboratory sample";
   String predictorFileName(samplePred.storeToTemporaryFile());
@@ -67,38 +64,34 @@ LinearModel LinearModelFactory::build(const NumericalSample & samplePred,
   const String RExecutable(ResourceMap::Get("R-executable-command"));
   OSS systemCommand;
   if (RExecutable != "") systemCommand << RExecutable << " --no-save --silent < \"" << commandFileName << "\"" << Os::GetDeleteCommandOutput();
-  else throw NotYetImplementedException(HERE) << "In LinearModelFactory::build(const NumericalSample & samplePred, const NumericalSample & sampleLab, const NumericalScalar levelValue) const: needs R. Please install it and set the absolute path of the R executable in ResourceMap.";
+  else throw NotYetImplementedException(HERE) << "In LinearModelFactory::build(const Sample & samplePred, const Sample & sampleLab, const Scalar levelValue) const: needs R. Please install it and set the absolute path of the R executable in ResourceMap.";
   int returnCode(Os::ExecuteCommand(systemCommand));
   if (returnCode != 0) throw InternalException(HERE) << "Error: unable to execute the system command " << String(systemCommand) << " returned code is " << returnCode;
   // Parse result file
   std::ifstream resultFile(resultFileName.c_str(), std::ios::in);
-  UnsignedInteger dimension(samplePred.getDimension() + 1);
-  NumericalPoint regression(dimension);
+  UnsignedInteger dimension = samplePred.getDimension() + 1;
+  Point regression(dimension);
   // Read the regression parameters
   for (UnsignedInteger i = 0; i < dimension; i++)
   {
     resultFile >> regression[i];
   }
   // Read the lower bounds of the intervals
-  NumericalPoint lowerBounds(dimension);
+  Point lowerBounds(dimension);
   for (UnsignedInteger i = 0; i < dimension; i++)
   {
     resultFile >> lowerBounds[i];
   }
   // Read the upper bounds of the intervals
-  NumericalPoint upperBounds(dimension);
+  Point upperBounds(dimension);
   for (UnsignedInteger i = 0; i < dimension; i++)
   {
     resultFile >> upperBounds[i];
   }
-  // Convert the bounds to an interval collection
-  ConfidenceIntervalPersistentCollection confidenceIntervals(dimension, ConfidenceInterval(0.0, 1.0));
-  for (UnsignedInteger i = 0; i < dimension; i++)
-  {
-    confidenceIntervals[i].setValues(lowerBounds[i], upperBounds[i]);
-  }
+  Interval confidenceIntervals(lowerBounds, upperBounds);
+
   // Read the p-values of the coefficients
-  NumericalScalarPersistentCollection pValues(dimension);
+  ScalarPersistentCollection pValues(dimension);
   for (UnsignedInteger i = 0; i < dimension; i++)
   {
     resultFile >> pValues[i];
