@@ -2,7 +2,7 @@
 /**
  *  @brief Top-level class for all spectral model factories
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -62,14 +62,14 @@ String NonStationaryCovarianceModelFactory::__str__(const String & offset) const
 }
 
 
-CovarianceModelImplementation::Implementation NonStationaryCovarianceModelFactory::build(const ProcessSample & sample) const
+CovarianceModel NonStationaryCovarianceModelFactory::build(const ProcessSample & sample) const
 {
   return buildAsUserDefinedCovarianceModel(sample, false).clone();
 }
 
 
 
-CovarianceModelImplementation::Implementation NonStationaryCovarianceModelFactory::build(const ProcessSample & sample, const Bool isCentered) const
+CovarianceModel NonStationaryCovarianceModelFactory::build(const ProcessSample & sample, const Bool isCentered) const
 {
   return buildAsUserDefinedCovarianceModel(sample, isCentered).clone();
 }
@@ -119,7 +119,7 @@ struct ComputeCovariancePolicy
           Scalar coef = 0.0;
           for (UnsignedInteger sampleIndex = 0; sampleIndex < size_; ++sampleIndex)
           {
-            coef += input_[sampleIndex][i][k] * input_[sampleIndex][j][l];
+            coef += input_[sampleIndex](i, k) * input_[sampleIndex](j, l);
           } // sampleIndex
           matrix(k, l) = coef * alpha_;
         } // l
@@ -145,7 +145,7 @@ struct ComputeCovariancePolicy
           Scalar coef = 0.0;
           for (UnsignedInteger sampleIndex = 0; sampleIndex < size_; ++sampleIndex)
           {
-            coef += (input_[sampleIndex][i][k] - muIK) * (input_[sampleIndex][j][l] - muJL);
+            coef += (input_[sampleIndex](i, k) - muIK) * (input_[sampleIndex](j, l) - muJL);
           } // sampleIndex
           matrix(k, l) = coef * alpha_;
         } // l
