@@ -2,7 +2,7 @@
 /**
  *  @brief
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -32,7 +32,8 @@ BEGIN_NAMESPACE_OPENTURNS
 CLASSNAMEINIT(Null)
 
 static const Factory<Null> Factory_Null;
-/* Constructor with parameters */
+
+/* Default constructor */
 Null::Null()
   : HistoryStrategyImplementation()
 {
@@ -48,21 +49,13 @@ Null * Null::clone() const
 /* Store the point according to the strategy */
 void Null::store(const Point & point)
 {
-  if (!isInitialized_)
-  {
-    sample_ = Sample(0, point.getDimension());
-    isInitialized_ = true;
-  }
+  // Nothing to do
 }
 
 /* Store the sample according to the strategy */
 void Null::store(const Sample & sample)
 {
-  if (!isInitialized_)
-  {
-    sample_ = Sample(0, sample.getDimension());
-    isInitialized_ = true;
-  }
+  // Nothing to do
 }
 
 /* String converter */
@@ -70,7 +63,6 @@ String Null::__repr__() const
 {
   OSS oss;
   oss << "class=" << Null::GetClassName();
-  oss << " sample_= " << sample_;
   return oss;
 }
 
