@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  RandomGenerator.cxx
  *  @brief RandomGenerator implements methods to control the random generator
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,17 +14,15 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
 #include <cstdlib>
 #include "dsfmt.h"
-#include "RandomGenerator.hxx"
-#include "RandomGeneratorState.hxx"
-#include "ResourceMap.hxx"
+#include "openturns/RandomGenerator.hxx"
+#include "openturns/RandomGeneratorState.hxx"
+#include "openturns/ResourceMap.hxx"
 
 
 BEGIN_NAMESPACE_OPENTURNS
@@ -65,8 +62,8 @@ void RandomGenerator::SetSeed(const UnsignedInteger seed)
 /* State accessor */
 void RandomGenerator::SetState(const RandomGeneratorState & state)
 {
-  UnsignedInteger size(state.buffer_.getSize());
-  UnsignedInteger stateSize(Generator.get_state_length_32());
+  UnsignedInteger size = state.buffer_.getSize();
+  UnsignedInteger stateSize = Generator.get_state_length_32();
   /* The unusual case, the given seed is too small. It is completed with 0 */
   Indices stateArray(state.buffer_);
   for (UnsignedInteger i = size; i < stateSize; i++) stateArray.add(0);
@@ -81,7 +78,7 @@ void RandomGenerator::SetState(const RandomGeneratorState & state)
 /* Seed accessor */
 RandomGeneratorState RandomGenerator::GetState()
 {
-  UnsignedInteger size((UnsignedInteger)(Generator.get_state_length_32()));
+  UnsignedInteger size = (UnsignedInteger)(Generator.get_state_length_32());
   // Create the state and get the index at the same time
   RandomGeneratorState state(Indices(size, 0), (UnsignedInteger)(Generator.get_index()));
   // Get the state array
@@ -90,7 +87,7 @@ RandomGeneratorState RandomGenerator::GetState()
 }
 
 /* Generate a pseudo-random number uniformly distributed over ]0, 1[ */
-NumericalScalar RandomGenerator::Generate()
+Scalar RandomGenerator::Generate()
 {
   if (!IsInitialized)
   {
@@ -112,9 +109,9 @@ UnsignedInteger RandomGenerator::IntegerGenerate(const UnsignedInteger n)
 }
 
 /* Generate a pseudo-random vector of numbers uniformly distributed over ]0, 1[ */
-NumericalPoint RandomGenerator::Generate(const UnsignedInteger size)
+Point RandomGenerator::Generate(const UnsignedInteger size)
 {
-  NumericalPoint result(size);
+  Point result(size);
   if (!IsInitialized)
   {
     SetSeed(ResourceMap::GetAsUnsignedInteger( "RandomGenerator-InitialSeed" ));
