@@ -2,7 +2,7 @@
 /**
  *  @brief The class Sample implements blank free samples
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -37,9 +37,10 @@ Sample Sample::ImportFromCSVFile(const FileName & fileName,
 
 /* Factory of Sample from Text file */
 Sample Sample::ImportFromTextFile(const FileName & fileName,
-                                  const String & separator)
+                                  const String & separator,
+                                  const UnsignedInteger skippedLines)
 {
-  Sample sample(SampleImplementation::BuildFromTextFile(fileName, separator));
+  Sample sample(SampleImplementation::BuildFromTextFile(fileName, separator, skippedLines));
   return sample;
 }
 
@@ -101,7 +102,7 @@ Sample::Sample(const UnsignedInteger size,
 }
 
 /* Partial copy constructor */
-Sample::Sample(const Sample other,
+Sample::Sample(const Sample & other,
                const UnsignedInteger first,
                const UnsignedInteger last)
   : TypedInterfaceObject<SampleImplementation>(new SampleImplementation(*other.getImplementation(), other.getImplementation()->begin() + first, other.getImplementation()->begin() + last))
@@ -199,7 +200,7 @@ Scalar & Sample::at (const UnsignedInteger i,
   if (i >= getSize()) throw OutOfBoundException(HERE) << "i (" << i << ") must be less than size (" << getSize() << ")";
   if (j >= getDimension()) throw OutOfBoundException(HERE) << "j (" << j << ") must be less than dimension (" << getDimension() << ")";
   copyOnWrite();
-  return (*getImplementation())[i][j];
+  return (*getImplementation())(i, j);
 }
 
 const Scalar & Sample::at (const UnsignedInteger i,
@@ -207,7 +208,7 @@ const Scalar & Sample::at (const UnsignedInteger i,
 {
   if (i >= getSize()) throw OutOfBoundException(HERE) << "i (" << i << ") must be less than size (" << getSize() << ")";
   if (j >= getDimension()) throw OutOfBoundException(HERE) << "j (" << j << ") must be less than dimension (" << getDimension() << ")";
-  return (*getImplementation())[i][j];
+  return (*getImplementation())(i, j);
 }
 
 const Scalar * Sample::__baseaddress__ () const
@@ -315,6 +316,12 @@ void Sample::stack(const Sample & sample)
   getImplementation()->stack(*sample.getImplementation());
 }
 
+/* Return the internal linear storage */
+Point Sample::asPoint() const
+{
+  if (getDimension() != 1) throw NotDefinedException(HERE) << "Error: the conversion to Point is defined only for a sample of dimension=1, here dimension=" << getDimension();
+  return getImplementation()->getData();
+}
 
 void Sample::erase(const UnsignedInteger first,
                    const UnsignedInteger last)
@@ -759,6 +766,12 @@ Sample Sample::getMarginal(const Indices & indices) const
   return getImplementation()->getMarginal(indices);
 }
 
+/* Select points as a sample */
+Sample Sample::select(const UnsignedIntegerCollection & indices) const
+{
+  return getImplementation()->select(indices);
+}
+
 /* Returns a pointer to the underlying implementation object */
 Sample::ImplementationAsPersistentObject Sample::getImplementationAsPersistentObject() const
 {
