@@ -2,7 +2,7 @@
 /**
  *  @brief The class SampleImplementation implements blank free samples
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,12 +14,11 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 #include <sstream>
-#include <limits>        // std::numeric_limits
 #include <cmath>
 #include <fstream>
 #include <iomanip>
@@ -39,6 +38,8 @@
 #include "openturns/TBB.hxx"
 #include "kendall.h"
 #include "openturns/IdentityMatrix.hxx"
+#include "openturns/SpecFunc.hxx"
+#include "openturns/Lapack.hxx"
 
 #include <locale.h>
 #ifdef OPENTURNS_HAVE_XLOCALE_H
@@ -52,7 +53,8 @@
 int csvparse (OT::CSVParserState & theState, yyscan_t yyscanner, FILE * theFile, OT::SampleImplementation &impl, OT::UnsignedInteger & theDimension, const char * separator);
 #endif
 
-namespace {
+namespace
+{
 
 // wraps std::getline to handle EOLs across systems
 OT::Bool GetLine(std::ifstream & file, OT::String & line)
@@ -137,7 +139,7 @@ NSI_point & NSI_point::operator -= (const NSI_point & other)
 {
   if (getDimension() != other.getDimension())
     throw InvalidArgumentException(HERE)
-        << "Points of different dimensions cannot be substracted (LHS dimension = "
+        << "Points of different dimensions cannot be subtracted (LHS dimension = "
         << getDimension()
         << "; RHS dimension = "
         << other.getDimension();
@@ -163,7 +165,7 @@ NSI_point & NSI_point::operator -= (const Point & other)
 {
   if (getDimension() != other.getDimension())
     throw InvalidArgumentException(HERE)
-        << "Points of different dimensions cannot be substracted (LHS dimension = "
+        << "Points of different dimensions cannot be subtracted (LHS dimension = "
         << getDimension()
         << "; RHS dimension = "
         << other.getDimension();
@@ -414,45 +416,38 @@ Bool SampleImplementation::ParseStringAsValues(const String & line,
   return true;
 }
 
+
 Bool SampleImplementation::ParseStringAsDescription(const String & line,
     const char separator,
     Description & description)
 {
   // Here the speed is not critical at all
-  String workingLine(line);
 
-  // replace non escaped separators by spaces
-  if (!(separator == ' '))
+  description = Description();
+  UnsignedInteger start = 0;
+  UnsignedInteger len = 0;
+  Bool escaped = false;
+
+  for (UnsignedInteger i = 0; i < line.size(); ++ i)
   {
-    Bool escaped = false;
-    for (UnsignedInteger i = 0; i < workingLine.size(); ++ i)
+    if (line[i] == '\"')
     {
-      if (workingLine[i] == '\"')
-        escaped = !escaped;
-      else if (workingLine[i] == separator)
-        if (!escaped)
-          workingLine[i] = ' ';
+      if (!escaped)
+        ++ start;
+      escaped = !escaped;
     }
+    else if ((line[i] == separator) && !escaped)
+    {
+      description.add(line.substr(start, len));
+      start = i + 1;
+      len = 0;
+    }
+    else
+      ++ len;
   }
+  if (len > 0)
+    description.add(line.substr(start, len));
 
-  // Store every fields of the current line in a vector
-  std::stringstream strstr(workingLine);
-  std::vector<std::string> words;
-  std::copy(std::istream_iterator<std::string>(strstr),
-            std::istream_iterator<std::string>(), back_inserter(words));
-
-  // Check and store the fields in a Point
-  description = Description(words.size());
-  for(UnsignedInteger i = 0; i < words.size(); ++ i)
-  {
-    String word(words[i]);
-    // trim double quote delimiters
-    if ((word.size() >= 2) && (word[0] == '\"') && (word[word.size() - 1] == '\"'))
-    {
-      word = word.substr(1, word.size() - 2);
-    }
-    description[i] = word;
-  } // for i
   return true;
 }
 
@@ -477,7 +472,8 @@ Bool SampleImplementation::ParseComment(const String & line, const String & mark
 
 
 SampleImplementation SampleImplementation::BuildFromTextFile(const FileName & fileName,
-    const String & separator)
+    const String & separator,
+    const UnsignedInteger skippedLines)
 {
   if (separator.size() != 1) throw InvalidArgumentException(HERE) << "Expected a separator with one character, got separator=" << separator;
   const char theSeparator = separator[0];
@@ -506,10 +502,14 @@ SampleImplementation SampleImplementation::BuildFromTextFile(const FileName & fi
   setlocale(LC_NUMERIC, "C");
 #endif
 
+  String line;
   UnsignedInteger index = 1;
 
+  // skip N lines
+  for ( ; index <= skippedLines; ++ index)
+    GetLine(theFile, line);
+
   // Go to the first line containing data
-  String line;
   Point data;
   Description description(0);
   while (!impl.dimension_ && GetLine(theFile, line))
@@ -1060,8 +1060,8 @@ SampleImplementation & SampleImplementation::stack(const SampleImplementation &
   // First, the values
   for (UnsignedInteger i = 0; i < size_; ++i)
   {
-    for (UnsignedInteger j = 0; j < dimension_; ++j) result[i][j] = (*this)[i][j];
-    for (UnsignedInteger j = 0; j < otherDimension; ++j) result[i][dimension_ + j] = sample[i][j];
+    for (UnsignedInteger j = 0; j < dimension_; ++j) result(i, j) = operator()(i, j);
+    for (UnsignedInteger j = 0; j < otherDimension; ++j) result(i, dimension_ + j) = sample(i, j);
   }
   // Second, the description
   if (!p_description_.isNull() || !sample.p_description_.isNull())
@@ -1128,8 +1128,8 @@ Point SampleImplementation::computeMean() const
   if (size_ == 0) throw InternalException(HERE) << "Error: cannot compute the mean of an empty sample.";
   Point accumulated(dimension_);
 
-  const_data_iterator it(data_begin());
-  const const_data_iterator guard(data_end());
+  data_const_iterator it(data_begin());
+  const data_const_iterator guard(data_end());
   while (it != guard)
   {
     for (UnsignedInteger i = 0; i < dimension_; ++i, ++it)
@@ -1158,8 +1158,8 @@ CovarianceMatrix SampleImplementation::computeCovariance() const
   const UnsignedInteger squaredDim(dimension_ * dimension_);
   Point accumulated(squaredDim);
 
-  const_data_iterator it(data_begin());
-  const const_data_iterator guard(data_end());
+  data_const_iterator it(data_begin());
+  const data_const_iterator guard(data_end());
   while (it != guard)
   {
     UnsignedInteger baseIndex = 0;
@@ -1207,8 +1207,8 @@ Point SampleImplementation::computeVariance() const
   const Point mean( computeMean() );
   Point accumulated(dimension_);
 
-  const_data_iterator it(data_begin());
-  const const_data_iterator guard(data_end());
+  data_const_iterator it(data_begin());
+  const data_const_iterator guard(data_end());
   while (it != guard)
   {
     for (UnsignedInteger i = 0; i < dimension_; ++i, ++it)
@@ -1307,10 +1307,10 @@ struct Comparison
 
   Bool operator() (const UnsignedInteger i, const UnsignedInteger j) const
   {
-    const Scalar xI = nsi_[ permutation_[i] ][ first_  ];
-    const Scalar xJ = nsi_[ permutation_[j] ][ first_  ];
-    const Scalar yI = nsi_[ permutation_[i] ][ second_ ];
-    const Scalar yJ = nsi_[ permutation_[j] ][ second_ ];
+    const Scalar xI = nsi_( permutation_[i], first_  );
+    const Scalar xJ = nsi_( permutation_[j], first_  );
+    const Scalar yI = nsi_( permutation_[i], second_ );
+    const Scalar yJ = nsi_( permutation_[j], second_ );
     hasTies_ |= (xI == xJ);
     return ( (xI < xJ) || ((xI == xJ) && (yI < yJ)) );
   }
@@ -1331,7 +1331,7 @@ SampleImplementation SampleImplementation::rank() const
     Collection<Pair> sortedMarginalSamples(size_);
     for (UnsignedInteger j = 0; j < size_; ++j)
     {
-      sortedMarginalSamples[j].value_ = (*this)[j][i];
+      sortedMarginalSamples[j].value_ = operator()(j, i);
       sortedMarginalSamples[j].index_ = j;
     }
     // sort
@@ -1346,7 +1346,7 @@ SampleImplementation SampleImplementation::rank() const
       if (currentValue > lastValue)
       {
         const Scalar rankValue = 0.5 * (lastIndex + j - 1);
-        for (UnsignedInteger k = lastIndex; k < j; ++k) rankedSample[ sortedMarginalSamples[k].index_ ][i] = rankValue;
+        for (UnsignedInteger k = lastIndex; k < j; ++k) rankedSample(sortedMarginalSamples[k].index_, i) = rankValue;
         lastIndex = j;
         lastValue = currentValue;
       }
@@ -1355,7 +1355,7 @@ SampleImplementation SampleImplementation::rank() const
     if (currentValue == lastValue)
     {
       const Scalar rankValue = 0.5 * (lastIndex + size_ - 1);
-      for (UnsignedInteger k = lastIndex; k < size_; ++k) rankedSample[ sortedMarginalSamples[k].index_ ][i] = rankValue;
+      for (UnsignedInteger k = lastIndex; k < size_; ++k) rankedSample(sortedMarginalSamples[k].index_, i) = rankValue;
     }
   }
   if (!p_description_.isNull()) rankedSample.setDescription(getDescription());
@@ -1395,7 +1395,7 @@ struct NSI_Sortable
   }
   inline NSI_const_point::const_iterator end()
   {
-    return &NSI_const_point(p_nsi_, index_).operator[](getDimension());
+    return &NSI_const_point(p_nsi_, index_).operator[](0) + getDimension();
   }
 
 };
@@ -1517,17 +1517,17 @@ struct ComputeKendallPolicy
 
   inline void operator()( const TBB::BlockedRange<UnsignedInteger> & r ) const
   {
+    const UnsignedInteger size = input_.getSize();
+    Point x(size);
+    Point y(size);
     for (UnsignedInteger i = r.begin(); i != r.end(); ++i)
     {
-      const UnsignedInteger size = input_.getSize();
       const UnsignedInteger indX = indicesX_[i];
       const UnsignedInteger indY = indicesY_[i];
-      Point x(size);
-      Point y(size);
       for (UnsignedInteger k = 0; k < size; ++k)
       {
-        x[k] = input_[k][indX];
-        y[k] = input_[k][indY];
+        x[k] = input_(k, indX);
+        y[k] = input_(k, indY);
       }
       if (smallCase_) output_[i] = kendallSmallN(&x[0], &y[0], size);
       else output_[i] = kendallNlogN(&x[0], &y[0], size);
@@ -1593,40 +1593,6 @@ Point SampleImplementation::computeMedian() const
   return computeQuantilePerComponent(0.5);
 }
 
-struct SkewnessPerComponentPolicy
-{
-  typedef Point value_type;
-
-  const value_type & mean_;
-  const UnsignedInteger dimension_;
-
-  SkewnessPerComponentPolicy( const value_type & mean)
-    : mean_(mean), dimension_(mean_.getDimension()) {}
-
-  static inline value_type GetInvariant(const SampleImplementation & nsi)
-  {
-    return value_type(2 * nsi.getDimension(), 0.0);
-  }
-
-  inline value_type & inplace_op( value_type & var, NSI_const_point point ) const
-  {
-    for (UnsignedInteger i = 0; i < dimension_; ++i)
-    {
-      const Scalar val = point[i] - mean_[i];
-      const Scalar val2 = val * val;
-      var[i] += val2;
-      var[i + dimension_] += val2 * val;
-    }
-    return var;
-  }
-
-  static inline value_type & inplace_op( value_type & var, const value_type & point )
-  {
-    return var += point;
-  }
-
-}; /* end struct SkewnessPerComponentPolicy */
-
 /*
  * Gives the skewness of the sample (by component)
  */
@@ -1637,53 +1603,27 @@ Point SampleImplementation::computeSkewness() const
   if (size_ == 2) return Point(dimension_, 0.0);
 
   const Point mean(computeMean());
-  const SkewnessPerComponentPolicy policy ( mean );
-  ReductionFunctor<SkewnessPerComponentPolicy> functor( *this, policy );
-  TBB::ParallelReduce( 0, size_, functor );
+  Point centeredMoments(2 * dimension_);
+  for(UnsignedInteger i = 0; i < size_; ++i)
+  {
+    for (UnsignedInteger j = 0; j < dimension_; ++j)
+    {
+      const Scalar val = operator()(i, j) - mean[j];
+      const Scalar val2 = val * val;
+      centeredMoments[j] += val2;
+      centeredMoments[j + dimension_] += val2 * val;
+    }
+  }
   Point skewness(dimension_);
   const Scalar factor = size_ * sqrt(size_ - 1.0) / (size_ - 2);
   for (UnsignedInteger i = 0; i < dimension_; ++i)
   {
-    if (functor.accumulator_[i] == 0.0) throw NotDefinedException(HERE) << "Error: the sample has component " << i << " constant. The skewness is not defined.";
-    skewness[i] = factor * functor.accumulator_[i + dimension_] / pow(functor.accumulator_[i], 1.5);
+    if (centeredMoments[i] == 0.0) throw NotDefinedException(HERE) << "Error: the sample has component " << i << " constant. The skewness is not defined.";
+    skewness[i] = factor * centeredMoments[i + dimension_] / pow(centeredMoments[i], 1.5);
   }
   return skewness;
 }
 
-struct KurtosisPerComponentPolicy
-{
-  typedef Point value_type;
-
-  const value_type & mean_;
-  const UnsignedInteger dimension_;
-
-  KurtosisPerComponentPolicy( const value_type & mean)
-    : mean_(mean), dimension_(mean_.getDimension()) {}
-
-  static inline value_type GetInvariant(const SampleImplementation & nsi)
-  {
-    return value_type(2 * nsi.getDimension(), 0.0);
-  }
-
-  inline value_type & inplace_op( value_type & var, NSI_const_point point ) const
-  {
-    for (UnsignedInteger i = 0; i < dimension_; ++i)
-    {
-      const Scalar val = point[i] - mean_[i];
-      const Scalar val2 = val * val;
-      var[i] += val2;
-      var[i + dimension_] += val2 * val2;
-    }
-    return var;
-  }
-
-  static inline value_type & inplace_op( value_type & var, const value_type & point )
-  {
-    return var += point;
-  }
-
-}; /* end struct KurtosisPerComponentPolicy */
-
 /*
  * Gives the kurtosis of the sample (by component)
  */
@@ -1694,53 +1634,28 @@ Point SampleImplementation::computeKurtosis() const
   if (size_ == 3) return Point(dimension_, 0.0);
 
   const Point mean(computeMean());
-  const KurtosisPerComponentPolicy policy ( mean );
-  ReductionFunctor<KurtosisPerComponentPolicy> functor( *this, policy );
-  TBB::ParallelReduce( 0, size_, functor );
+  Point centeredMoments(2 * dimension_);
+  for(UnsignedInteger i = 0; i < size_; ++i)
+  {
+    for (UnsignedInteger j = 0; j < dimension_; ++j)
+    {
+      const Scalar val = operator()(i, j) - mean[j];
+      const Scalar val2 = val * val;
+      centeredMoments[j] += val2;
+      centeredMoments[j + dimension_] += val2 * val2;
+    }
+  }
   Point kurtosis(dimension_);
   const Scalar factor1 = (size_ + 1.0) * size_ * (size_ - 1.0) / ((size_ - 2.0) * (size_ - 3.0));
   const Scalar factor2 = -3.0 * (3.0 * size_ - 5.0) / ((size_ - 2.0) * (size_ - 3.0));
   for (UnsignedInteger i = 0; i < dimension_; ++i)
   {
-    if (functor.accumulator_[i] == 0.0) throw NotDefinedException(HERE) << "Error: the sample has component " << i << " constant. The kurtosis is not defined.";
-    kurtosis[i] = factor1 * functor.accumulator_[i + dimension_] / (functor.accumulator_[i] * functor.accumulator_[i]) + factor2;
+    if (centeredMoments[i] == 0.0) throw NotDefinedException(HERE) << "Error: the sample has component " << i << " constant. The kurtosis is not defined.";
+    kurtosis[i] = factor1 * centeredMoments[i + dimension_] / (centeredMoments[i] * centeredMoments[i]) + factor2;
   }
   return kurtosis;
 }
 
-struct CenteredMomentPerComponentPolicy
-{
-  typedef Point value_type;
-
-  const value_type & mean_;
-  const UnsignedInteger k_;
-  const UnsignedInteger dimension_;
-
-  CenteredMomentPerComponentPolicy( const value_type & mean, const UnsignedInteger k)
-    : mean_(mean), k_(k), dimension_(mean_.getDimension()) {}
-
-  static inline value_type GetInvariant(const SampleImplementation & nsi)
-  {
-    return value_type(nsi.getDimension(), 0.0);
-  }
-
-  inline value_type & inplace_op( value_type & var, NSI_const_point point ) const
-  {
-    for (UnsignedInteger i = 0; i < dimension_; ++i)
-    {
-      const Scalar val = point[i] - mean_[i];
-      var[i] += pow(val, static_cast<int>(k_));
-    }
-    return var;
-  }
-
-  static inline value_type & inplace_op( value_type & var, const value_type & point )
-  {
-    return var += point;
-  }
-
-}; /* end struct CenteredMomentPerComponentPolicy */
-
 /*
  * Gives the centered moment of order k of the sample (by component)
  */
@@ -1757,10 +1672,17 @@ Point SampleImplementation::computeCenteredMoment(const UnsignedInteger k) const
   // General case
   const Point mean(computeMean());
 
-  const CenteredMomentPerComponentPolicy policy ( mean, k );
-  ReductionFunctor<CenteredMomentPerComponentPolicy> functor( *this, policy );
-  TBB::ParallelReduce( 0, size_, functor );
-  return functor.accumulator_ / size_;
+  Point centeredMoment(dimension_);
+  const int intK(static_cast<const int>(k));
+  for(UnsignedInteger i = 0; i < size_; ++i)
+  {
+    for (UnsignedInteger j = 0; j < dimension_; ++j)
+    {
+      const Scalar val = operator()(i, j) - mean[j];
+      centeredMoment[j] += pow(val, intK);
+    }
+  }
+  return centeredMoment / size_;
 }
 
 /*
@@ -1775,11 +1697,16 @@ Point SampleImplementation::computeRawMoment(const UnsignedInteger k) const
   // Special case: order 0, return (size,...,size)
   if (k == 0) return Point(dimension_, 1.0);
 
-  const Point zero(dimension_);
-  const CenteredMomentPerComponentPolicy policy ( zero, k );
-  ReductionFunctor<CenteredMomentPerComponentPolicy> functor( *this, policy );
-  TBB::ParallelReduce( 0, size_, functor );
-  return functor.accumulator_ / size_;
+  Point moment(dimension_);
+  const int intK(static_cast<const int>(k));
+  for(UnsignedInteger i = 0; i < size_; ++i)
+  {
+    for (UnsignedInteger j = 0; j < dimension_; ++j)
+    {
+      moment[j] += pow(operator()(i, j), intK);
+    }
+  }
+  return moment / size_;
 }
 
 /*
@@ -1804,7 +1731,7 @@ Point SampleImplementation::computeQuantilePerComponent(const Scalar prob) const
   for (UnsignedInteger j = 0; j < dimension_; ++j)
   {
     for (UnsignedInteger i = 0; i < size_; ++i)
-      component[i] = operator[](i)[j];
+      component[i] = operator()(i, j);
 
     TBB::ParallelSort(component.begin(), component.end());
 
@@ -1878,52 +1805,23 @@ Scalar SampleImplementation::computeEmpiricalCDF(const Point & point,
   return static_cast < Scalar > (functor.accumulator_) / size_;
 }
 
-struct MaxPerComponentPolicy
-{
-  typedef Point value_type;
-
-  static inline value_type GetInvariant(const SampleImplementation & nsi)
-  {
-    return value_type(nsi.getDimension(), - std::numeric_limits<Scalar>::max());
-  }
-
-  template <typename T>
-  static inline value_type & inplace_op( value_type & a, const T & b)
-  {
-    const UnsignedInteger dim = a.getDimension();
-    for (UnsignedInteger j = 0; j < dim; ++j) a[j] = std::max( a[j], b[j] );
-    return a;
-  }
-}; /* end struct MaxPerComponentPolicy */
-
-struct MinPerComponentPolicy
-{
-  typedef Point value_type;
-
-  static inline value_type GetInvariant(const SampleImplementation & nsi)
-  {
-    return value_type(nsi.getDimension(), std::numeric_limits<Scalar>::max());
-  }
-
-  template <typename T>
-  static inline value_type & inplace_op( value_type & a, const T & b)
-  {
-    const UnsignedInteger dim = a.getDimension();
-    for (UnsignedInteger j = 0; j < dim; ++j) a[j] = std::min( a[j], b[j] );
-    return a;
-  }
-}; /* end struct MinPerComponentPolicy */
-
 
 /* Maximum accessor */
 Point SampleImplementation::getMax() const
 {
   if (size_ == 0) throw InternalException(HERE) << "Impossible to get the maximum of an empty Sample";
 
-  ReductionFunctor<MaxPerComponentPolicy> functor( *this, MaxPerComponentPolicy() );
-  functor.accumulator_ = operator[](0);
-  TBB::ParallelReduce( 1, size_, functor );
-  return functor.accumulator_;
+  Point maxPoint(dimension_, - SpecFunc::MaxScalar);
+  for(UnsignedInteger i = 0; i < size_; ++i)
+  {
+    for (UnsignedInteger j = 0; j < dimension_; ++j)
+    {
+      const Scalar val = operator()(i, j);
+      if (val > maxPoint[j])
+        maxPoint[j] = val;
+    }
+  }
+  return maxPoint;
 }
 
 /* Minimum accessor */
@@ -1931,28 +1829,20 @@ Point SampleImplementation::getMin() const
 {
   if (size_ == 0) throw InternalException(HERE) << "Impossible to get the minimum of an empty Sample";
 
-  ReductionFunctor<MinPerComponentPolicy> functor( *this, MinPerComponentPolicy() );
-  functor.accumulator_ = operator[](0);
-  TBB::ParallelReduce( 1, size_, functor );
-  return functor.accumulator_;
+  Point minPoint(dimension_, SpecFunc::MaxScalar);
+  for(UnsignedInteger i = 0; i < size_; ++i)
+  {
+    for (UnsignedInteger j = 0; j < dimension_; ++j)
+    {
+      const Scalar val = operator()(i, j);
+      if (val < minPoint[j])
+        minPoint[j] = val;
+    }
+  }
+  return minPoint;
 }
 
 
-struct TranslationPolicy
-{
-  const Point & translation_;
-  const UnsignedInteger dimension_;
-
-  TranslationPolicy( const Point & translation)
-    : translation_(translation), dimension_(translation_.getDimension()) {}
-
-  inline void inplace_op( NSI_point point ) const
-  {
-    for (UnsignedInteger j = 0; j < dimension_; ++j) point[j] += translation_[j];
-  }
-
-}; /* end struct TranslationPolicy */
-
 /*
  * Translate realizations in-place
  */
@@ -1964,9 +1854,9 @@ void SampleImplementation::translate(const Point & translation)
 
   if (size_ == 0) return;
 
-  const TranslationPolicy policy( translation );
-  ParallelFunctor<TranslationPolicy> functor( *this, policy );
-  TBB::ParallelFor( 0, size_, functor );
+  for(UnsignedInteger i = 0; i < size_; ++i)
+    for (UnsignedInteger j = 0; j < dimension_; ++j)
+      operator()(i, j) += translation[j];
 }
 
 SampleImplementation & SampleImplementation::operator += (const Scalar translation)
@@ -1981,44 +1871,14 @@ SampleImplementation & SampleImplementation::operator += (const Point & translat
   return *this;
 }
 
-struct PositiveTranslationSamplePolicy
-{
-  const SampleImplementation & translation_;
-  SampleImplementation & output_;
-
-  PositiveTranslationSamplePolicy( const SampleImplementation & translation,
-                                   SampleImplementation & output)
-    : translation_(translation), output_(output) {}
-
-  inline void operator()( const TBB::BlockedRange<UnsignedInteger> & r ) const
-  {
-    for (UnsignedInteger i = r.begin(); i != r.end(); ++i) output_[i] += translation_[i];
-  }
-
-}; /* end struct TranslationSamplePolicy */
-
-struct NegativeTranslationSamplePolicy
-{
-  const SampleImplementation & translation_;
-  SampleImplementation & output_;
-
-  NegativeTranslationSamplePolicy( const SampleImplementation & translation,
-                                   SampleImplementation & output)
-    : translation_(translation), output_(output) {}
-
-  inline void operator()( const TBB::BlockedRange<UnsignedInteger> & r ) const
-  {
-    for (UnsignedInteger i = r.begin(); i != r.end(); ++i) output_[i] -= translation_[i];
-  }
-
-}; /* end struct TranslationSamplePolicy */
-
 SampleImplementation & SampleImplementation::operator += (const SampleImplementation & translation)
 {
   if (translation.getDimension() != dimension_) throw InvalidArgumentException(HERE) << "Error: the dimension of the given translation=" << translation.getDimension() << " does not match the dimension of the sample=" << dimension_;
   if (translation.getSize() != size_) throw InvalidArgumentException(HERE) << "Error: the size of the given translation=" << translation.getSize() << " does not match the size of the sample=" << size_;
-  const PositiveTranslationSamplePolicy policy( translation, *this );
-  TBB::ParallelFor( 0, size_, policy );
+  int size(size_ * dimension_);
+  double alpha(1.0);
+  int one(1);
+  daxpy_(&size, &alpha, const_cast<double*>(&((translation)(0, 0))), &one, &((*this)(0, 0)), &one);
   return *this;
 }
 
@@ -2036,8 +1896,9 @@ SampleImplementation & SampleImplementation::operator -= (const SampleImplementa
 {
   if (translation.getDimension() != dimension_) throw InvalidArgumentException(HERE) << "Error: the dimension of the given translation=" << translation.getDimension() << " does not match the dimension of the sample=" << dimension_;
   if (translation.getSize() != size_) throw InvalidArgumentException(HERE) << "Error: the size of the given translation=" << translation.getSize() << " does not match the size of the sample=" << size_;
-  const NegativeTranslationSamplePolicy policy( translation, *this );
-  TBB::ParallelFor( 0, size_, policy );
+  for(UnsignedInteger i = 0; i < size_; ++i)
+    for (UnsignedInteger j = 0; j < dimension_; ++j)
+      operator()(i, j) -= translation(i, j);
   return *this;
 }
 
@@ -2083,20 +1944,6 @@ SampleImplementation SampleImplementation::operator - (const SampleImplementatio
   return sample;
 }
 
-struct ScalingPolicy
-{
-  const Point & scale_;
-  const UnsignedInteger dimension_;
-
-  ScalingPolicy( const Point & scale) : scale_(scale), dimension_(scale_.getDimension()) {}
-
-  inline void inplace_op( NSI_point point ) const
-  {
-    for (UnsignedInteger j = 0; j < dimension_; ++j) point[j] *= scale_[j];
-  }
-
-}; /* end struct ScalingPolicy */
-
 struct MatrixMultiplyPolicy
 {
   const SquareMatrix & scale_;
@@ -2134,9 +1981,9 @@ void SampleImplementation::scale(const Point & scaling)
 
   if (size_ == 0) return;
 
-  const ScalingPolicy policy( scaling );
-  ParallelFunctor<ScalingPolicy> functor( *this, policy );
-  TBB::ParallelFor( 0, size_, functor );
+  for(UnsignedInteger i = 0; i < size_; ++i)
+    for (UnsignedInteger j = 0; j < dimension_; ++j)
+      operator()(i, j) *= scaling[j];
 }
 
 SampleImplementation & SampleImplementation::operator *= (const Scalar scaling)
@@ -2239,7 +2086,7 @@ SampleImplementation SampleImplementation::getMarginal(const UnsignedInteger ind
   if (!p_description_.isNull())
     marginalSample.setDescription(Description(1, getDescription()[index]));
   for (UnsignedInteger i = 0; i < size_; ++i)
-    marginalSample[i][0] = operator[](i)[index];
+    marginalSample(i, 0) = operator()(i, index);
 
   return marginalSample;
 }
@@ -2271,13 +2118,28 @@ SampleImplementation SampleImplementation::getMarginal(const Indices & indices)
     for (UnsignedInteger j = 0; j < outputDimension; ++j)
     {
       // We access directly to the component of the Point for performance reason
-      marginalSample[i][j] = operator[](i)[indices[j]];
+      marginalSample(i, j) = operator()(i, indices[j]);
     }
   }
 
   return marginalSample;
 }
 
+/* Select points as a sample */
+SampleImplementation SampleImplementation::select(const UnsignedIntegerCollection & indices) const
+{
+  const UnsignedInteger size = indices.getSize();
+  SampleImplementation result(size, dimension_);
+  for (UnsignedInteger i = 0; i < size; ++i)
+  {
+    const UnsignedInteger index = indices[i];
+    if (index >= size_) throw InvalidArgumentException(HERE) << "Error: expected indices less than " << size_ << ", here indices[" << i << "]=" << index;
+    std::copy(data_.begin() + index * dimension_, data_.begin() + (index + 1) * dimension_, result.data_.begin() + i * dimension_);
+  }
+  result.setDescription(getDescription());
+  return result;
+}
+
 /* Save to CSV file */
 void SampleImplementation::exportToCSVFile(const FileName & filename,
     const String & csvSeparator) const
