@@ -2,7 +2,7 @@
 /**
  *  @brief
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -58,14 +58,26 @@ SecondOrderModelImplementation * SecondOrderModelImplementation::clone() const
 }
 
 /* Dimension accessor */
+UnsignedInteger SecondOrderModelImplementation::getInputDimension() const
+{
+  return covarianceModel_.getInputDimension();
+}
+
+UnsignedInteger SecondOrderModelImplementation::getOutputDimension() const
+{
+  return covarianceModel_.getOutputDimension();
+}
+
 UnsignedInteger SecondOrderModelImplementation::getSpatialDimension() const
 {
-  return covarianceModel_.getSpatialDimension();
+  LOGWARN(OSS() << "SecondOrder::getSpatialDimension is deprecated in favor of getInputDimension.");
+  return covarianceModel_.getInputDimension();
 }
 
 UnsignedInteger SecondOrderModelImplementation::getDimension() const
 {
-  return covarianceModel_.getDimension();
+  LOGWARN(OSS() << "SecondOrder::getDimension is deprecated in favor of getOutputDimension.");
+  return covarianceModel_.getOutputDimension();
 }
 
 /* Computation of the covariance function */
@@ -129,14 +141,14 @@ void SecondOrderModelImplementation::setModels(const CovarianceModel & covarianc
     const SpectralModel & spectralModel)
 {
   if (!covarianceModel.isStationary()) throw InvalidArgumentException(HERE) << "Error: the covariance model is not stationary.";
-  if (covarianceModel.getDimension() != spectralModel.getDimension())
+  if (covarianceModel.getOutputDimension() != spectralModel.getOutputDimension())
     throw InvalidDimensionException(HERE) << "Error: the spectral model and the covariance model have different dimensions"
-                                          << " spectral dimension = " << spectralModel.getDimension()
-                                          << " covariance dimension = " << covarianceModel.getDimension();
-  if (covarianceModel.getSpatialDimension() != spectralModel.getSpatialDimension())
+                                          << " spectral dimension = " << spectralModel.getOutputDimension()
+                                          << " covariance dimension = " << covarianceModel.getOutputDimension();
+  if (covarianceModel.getInputDimension() != spectralModel.getInputDimension())
     throw InvalidDimensionException(HERE) << "Error: the spectral model and the covariance model have different spatial dimensions"
-                                          << " spectral spatial dimension = " << spectralModel.getSpatialDimension()
-                                          << " covariance spatial dimension = " << covarianceModel.getSpatialDimension();
+                                          << " spectral spatial dimension = " << spectralModel.getInputDimension()
+                                          << " covariance spatial dimension = " << covarianceModel.getInputDimension();
   covarianceModel_ = covarianceModel;
   spectralModel_ = spectralModel;
 }
