@@ -2,7 +2,7 @@
 /**
  *  @brief Top-level class for all spectral model factories
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -83,7 +83,7 @@ UserDefinedStationaryCovarianceModel StationaryCovarianceModelFactory::buildAsUs
     const RegularGrid & frequencyGrid) const
 {
   // We get the dimension of the model
-  const UnsignedInteger dimension = mySpectralModel.getDimension();
+  const UnsignedInteger dimension = mySpectralModel.getOutputDimension();
   // From the spectral model, we want to evaluate the autocovariance function
   const UnsignedInteger N = frequencyGrid.getN();
   const Scalar df = frequencyGrid.getStep();
@@ -166,7 +166,7 @@ UserDefinedStationaryCovarianceModel StationaryCovarianceModelFactory::buildAsUs
 }
 
 /* Build a covariance model based on a process sample */
-CovarianceModelImplementation::Implementation StationaryCovarianceModelFactory::build(const ProcessSample & sample) const
+CovarianceModel StationaryCovarianceModelFactory::build(const ProcessSample & sample) const
 {
   return buildAsUserDefinedStationaryCovarianceModel(sample).clone();
 }
@@ -178,7 +178,7 @@ UserDefinedStationaryCovarianceModel StationaryCovarianceModelFactory::buildAsUs
 }
 
 /* Build a covariance model based on a field */
-CovarianceModelImplementation::Implementation StationaryCovarianceModelFactory::build(const Field & timeSeries) const
+CovarianceModel StationaryCovarianceModelFactory::build(const Field & timeSeries) const
 {
   return buildAsUserDefinedStationaryCovarianceModel(timeSeries).clone();
 }
