@@ -3,7 +3,7 @@
  * @brief This class builds a spectral model using a frequency grid and a spectral function
  *  given as a collection of Covariance Matrix
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,13 +15,14 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 #include "openturns/UserDefinedCovarianceModel.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/Exception.hxx"
+#include "openturns/NearestNeighbourAlgorithm.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -38,8 +39,9 @@ UserDefinedCovarianceModel::UserDefinedCovarianceModel()
   : CovarianceModelImplementation()
   , covarianceCollection_(0)
   , p_mesh_(RegularGrid().clone())
+  , nearestNeighbour_()
 {
-  dimension_ = 0;
+  outputDimension_ = 0;
 }
 
 // For a non stationary model, we need N x N covariance functions with N the number of vertices in the mesh
@@ -48,6 +50,7 @@ UserDefinedCovarianceModel::UserDefinedCovarianceModel(const Mesh & mesh,
   : CovarianceModelImplementation()
   , covarianceCollection_(0)
   , p_mesh_(0)
+  , nearestNeighbour_()
 {
   const UnsignedInteger N = mesh.getVerticesNumber();
   const UnsignedInteger size = (N * (N + 1)) / 2;
@@ -56,15 +59,16 @@ UserDefinedCovarianceModel::UserDefinedCovarianceModel(const Mesh & mesh,
     throw InvalidArgumentException(HERE) << "Error: for a non stationary covariance model, sizes are incoherent:"
                                          << " mesh size=" << N << " and covariance function size=" << covarianceFunction.getSize() << " instead of " << size;
   p_mesh_ = mesh.clone();
-  spatialDimension_ = mesh.getDimension();
+  nearestNeighbour_.setSample(p_mesh_->getVertices());
+  inputDimension_ = mesh.getDimension();
   covarianceCollection_ = CovarianceMatrixCollection(size);
   // put the first element
   covarianceCollection_[0] = covarianceFunction[0];
-  dimension_ = covarianceCollection_[0].getDimension();
+  outputDimension_ = covarianceCollection_[0].getDimension();
   // put the next elements if dimension is ok
   for (UnsignedInteger k = 1; k < size; ++k)
   {
-    if (covarianceFunction[k].getDimension() != dimension_)
+    if (covarianceFunction[k].getDimension() != outputDimension_)
       throw InvalidArgumentException(HERE) << " Error with dimension; all the covariance matrices must have the same dimension";
     covarianceCollection_[k] = covarianceFunction[k];
   }
@@ -81,15 +85,15 @@ UserDefinedCovarianceModel * UserDefinedCovarianceModel::clone() const
 CovarianceMatrix UserDefinedCovarianceModel::operator() (const Point & s,
     const Point & t) const
 {
-  if (s.getDimension() != spatialDimension_) throw InvalidArgumentException(HERE) << "Error: the point s has dimension=" << s.getDimension() << ", expected dimension=" << spatialDimension_;
-  if (t.getDimension() != spatialDimension_) throw InvalidArgumentException(HERE) << "Error: the point t has dimension=" << t.getDimension() << ", expected dimension=" << spatialDimension_;
+  if (s.getDimension() != inputDimension_) throw InvalidArgumentException(HERE) << "Error: the point s has dimension=" << s.getDimension() << ", expected dimension=" << inputDimension_;
+  if (t.getDimension() != inputDimension_) throw InvalidArgumentException(HERE) << "Error: the point t has dimension=" << t.getDimension() << ", expected dimension=" << inputDimension_;
   // If the grid size is one, return the covariance function
   // else find in the grid the nearest instant values
   const UnsignedInteger N = p_mesh_->getVerticesNumber();
   if (N == 1) return covarianceCollection_[0];
 
   // Use the evaluation based on indices
-  return operator()(p_mesh_->getNearestVertexIndex(s), p_mesh_->getNearestVertexIndex(t));
+  return operator()(nearestNeighbour_.query(s), nearestNeighbour_.query(t));
 }
 
 CovarianceMatrix UserDefinedCovarianceModel::operator() (const UnsignedInteger i,
@@ -115,7 +119,7 @@ CovarianceMatrix UserDefinedCovarianceModel::operator() (const UnsignedInteger i
 CovarianceMatrix UserDefinedCovarianceModel::discretize(const Sample & vertices) const
 {
   const UnsignedInteger size = vertices.getSize();
-  CovarianceMatrix covariance(size * dimension_);
+  CovarianceMatrix covariance(size * outputDimension_);
   // It is better to check vertices as the simplices don't play a role in the discretization
   if (vertices == p_mesh_->getVertices())
   {
@@ -124,37 +128,33 @@ CovarianceMatrix UserDefinedCovarianceModel::discretize(const Sample & vertices)
     {
       const UnsignedInteger jBase = static_cast< UnsignedInteger >(sqrt(2 * i + 0.25) - 0.5);
       const UnsignedInteger kBase = i - (jBase * (jBase + 1)) / 2;
-      for (UnsignedInteger k = 0; k < dimension_; ++k)
-        for (UnsignedInteger j = 0; j < dimension_; ++j)
+      for (UnsignedInteger k = 0; k < outputDimension_; ++k)
+        for (UnsignedInteger j = 0; j < outputDimension_; ++j)
           covariance(jBase + j, kBase + k) = covarianceCollection_[i](j, k);
     }
     return covariance;
   }
   // Here we have to project the given vertices on the underlying mesh
-  // We try to call the getNearestVertexIndex() method a minimum number
-  // of time as it is the most costly part of the discretization
-  Indices nearestIndex(size);
-  for (UnsignedInteger i = 0; i < size; ++i)
-  {
-    nearestIndex[i] = p_mesh_->getNearestVertexIndex(vertices[i]);
-    LOGINFO(OSS() << "The vertex " << i << " over " << size - 1 << " in the given sample corresponds to the vertex " << nearestIndex[i] << " in the underlying mesh (" << Point(vertices[i]).__str__() << "->" << p_mesh_->getVertex(nearestIndex[i]).__str__() << ")");
-  }
+  // We try to call the query() method a minimum number of time as it
+  // is the most costly part of the discretization
+  const Indices nearestIndex(nearestNeighbour_.query(vertices));
+
   // Now, we use a set of loops similar to the default algorithm
   // Fill-in the matrix by blocks
   for (UnsignedInteger rowIndex = 0; rowIndex < size; ++rowIndex)
   {
-    const UnsignedInteger rowBase = rowIndex * dimension_;
+    const UnsignedInteger rowBase = rowIndex * outputDimension_;
     // Only the lower part has to be filled-in
     for (UnsignedInteger columnIndex = 0; columnIndex <= rowIndex; ++columnIndex)
     {
-      const UnsignedInteger columnBase = columnIndex * dimension_;
+      const UnsignedInteger columnBase = columnIndex * outputDimension_;
       const CovarianceMatrix localCovarianceMatrix(operator()(nearestIndex[rowIndex], nearestIndex[columnIndex]));
       // We fill the covariance matrix using the previous local one
       // The full local covariance matrix has to be copied as it is
       // not copied on a symmetric position
-      for (UnsignedInteger rowIndexLocal = 0; rowIndexLocal < dimension_; ++rowIndexLocal)
+      for (UnsignedInteger rowIndexLocal = 0; rowIndexLocal < outputDimension_; ++rowIndexLocal)
       {
-        for (UnsignedInteger columnIndexLocal = 0; columnIndexLocal < dimension_; ++columnIndexLocal)
+        for (UnsignedInteger columnIndexLocal = 0; columnIndexLocal < outputDimension_; ++columnIndexLocal)
         {
           covariance(rowBase + rowIndexLocal, columnBase + columnIndexLocal) = localCovarianceMatrix(rowIndexLocal, columnIndexLocal) ;
         } // column index within the block
@@ -167,7 +167,7 @@ CovarianceMatrix UserDefinedCovarianceModel::discretize(const Sample & vertices)
 Sample UserDefinedCovarianceModel::discretizeRow(const Sample & vertices,
     const UnsignedInteger p) const
 {
-  if (dimension_ != 1) throw InternalException(HERE) << "Error: the discretizeRow() method is not defined if the output dimension is not 1. Here, dimension=" << dimension_;
+  if (outputDimension_ != 1) throw InternalException(HERE) << "Error: the discretizeRow() method is not defined if the output dimension is not 1. Here, dimension=" << outputDimension_;
   const UnsignedInteger size = vertices.getSize();
   Sample result(size, 1);
   if (vertices == p_mesh_->getVertices())
@@ -175,25 +175,20 @@ Sample UserDefinedCovarianceModel::discretizeRow(const Sample & vertices,
     UnsignedInteger index = (p * (p + 1)) / 2;
     for (UnsignedInteger i = 0; i < p; ++i)
     {
-      result[i][0] = covarianceCollection_[index](0, 0);
+      result(i, 0) = covarianceCollection_[index](0, 0);
       ++index;
     }
     UnsignedInteger shift = p;
     for (UnsignedInteger i = p; i < size; ++i)
     {
-      result[i][0] = covarianceCollection_[index](0, 0);
+      result(i, 0) = covarianceCollection_[index](0, 0);
       ++shift;
       index += shift;
     }
     return result;
   }
-  Indices nearestIndex(size);
-  for (UnsignedInteger i = 0; i < size; ++i)
-  {
-    nearestIndex[i] = p_mesh_->getNearestVertexIndex(vertices[i]);
-    LOGINFO(OSS() << "The vertex " << i << " over " << size - 1 << " in the given sample corresponds to the vertex " << nearestIndex[i] << " in the underlying mesh (" << Point(vertices[i]).__str__() << "->" << p_mesh_->getVertex(nearestIndex[i]).__str__() << ")");
-  }
-  for (UnsignedInteger i = 0; i < size; ++i) result[i][0] = operator()(nearestIndex[p], nearestIndex[i])(0, 0);
+  const Indices nearestIndex(nearestNeighbour_.query(vertices));
+  for (UnsignedInteger i = 0; i < size; ++i) result(i, 0) = operator()(nearestIndex[p], nearestIndex[i])(0, 0);
   return result;
 }
 
@@ -239,6 +234,7 @@ void UserDefinedCovarianceModel::save(Advocate & adv) const
 {
   CovarianceModelImplementation::save(adv);
   adv.saveAttribute( "mesh_", *p_mesh_);
+  adv.saveAttribute("nearestNeighbour_", nearestNeighbour_);
   adv.saveAttribute( "covarianceCollection_", covarianceCollection_);
 }
 
@@ -249,6 +245,7 @@ void UserDefinedCovarianceModel::load(Advocate & adv)
   CovarianceModelImplementation::load(adv);
   adv.loadAttribute( "mesh_", mesh);
   p_mesh_ = mesh.getImplementation();
+  adv.loadAttribute( "nearestNeighbour_", nearestNeighbour_);
   adv.loadAttribute( "covarianceCollection_", covarianceCollection_);
 }
 
