@@ -2,7 +2,7 @@
 /**
  *  @brief This class build a stationary covariance model using a time grid and a collection of covariance matrices
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -36,9 +36,10 @@ UserDefinedStationaryCovarianceModel::UserDefinedStationaryCovarianceModel()
   : StationaryCovarianceModel()
   , covarianceCollection_(0)
   , mesh_()
+  , nearestNeighbour_()
 {
-  spatialDimension_ = 1;
-  dimension_ = 0;
+  inputDimension_ = 1;
+  outputDimension_ = 0;
 }
 
 // Classical constructor
@@ -48,20 +49,21 @@ UserDefinedStationaryCovarianceModel::UserDefinedStationaryCovarianceModel(const
   : StationaryCovarianceModel()
   , covarianceCollection_(0)
   , mesh_(mesh)
+  , nearestNeighbour_(mesh)
 {
   const UnsignedInteger size = mesh.getVerticesNumber();
   if (size != covarianceFunction.getSize())
     throw InvalidArgumentException(HERE) << "Error: for a non stationary covariance model, sizes are incoherents"
                                          << " mesh size = " << size << "covariance function size = " << covarianceFunction.getSize();
-  spatialDimension_ = mesh.getDimension();
+  inputDimension_ = mesh.getDimension();
   covarianceCollection_ = CovarianceMatrixCollection(size);
   // put the first element
   covarianceCollection_[0] = covarianceFunction[0];
-  dimension_ = covarianceCollection_[0].getDimension();
+  outputDimension_ = covarianceCollection_[0].getDimension();
   // put the next elements if dimension is ok
   for (UnsignedInteger k = 1; k < size; ++k)
   {
-    if (covarianceFunction[k].getDimension() != dimension_)
+    if (covarianceFunction[k].getDimension() != outputDimension_)
       throw InvalidArgumentException(HERE) << " Error with dimension; the covariance matrices should be of same dimension";
     covarianceCollection_[k] = covarianceFunction[k];
   }
@@ -76,13 +78,13 @@ UserDefinedStationaryCovarianceModel * UserDefinedStationaryCovarianceModel::clo
 /* Computation of the covariance function */
 CovarianceMatrix UserDefinedStationaryCovarianceModel::operator()(const Point & tau) const
 {
-  if (tau.getDimension() != spatialDimension_) throw InvalidArgumentException(HERE) << "Error: expected a shift of dimension=" << spatialDimension_ << ", got dimension=" << tau.getDimension();
+  if (tau.getDimension() != inputDimension_) throw InvalidArgumentException(HERE) << "Error: expected a shift of dimension=" << inputDimension_ << ", got dimension=" << tau.getDimension();
   // If the grid size is one, return the covariance function
   // else find in the grid the nearest instant values with nonnegative first component
   if (mesh_.getN() == 1) return covarianceCollection_[0];
 
-  if (tau[0] < 0.0) return covarianceCollection_[mesh_.getNearestVertexIndex(tau * (-1.0))];
-  return covarianceCollection_[mesh_.getNearestVertexIndex(tau)];
+  if (tau[0] < 0.0) return covarianceCollection_[nearestNeighbour_.query(tau * (-1.0))];
+  return covarianceCollection_[nearestNeighbour_.query(tau)];
 }
 
 CovarianceMatrix UserDefinedStationaryCovarianceModel::discretize(const Mesh & mesh) const
