@@ -2,7 +2,7 @@
 /**
  *  @brief ComplexMatrixImplementation implements the classical mathematicalComplexMatrixImplementation
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -426,10 +426,10 @@ ComplexMatrixImplementation ComplexMatrixImplementation::operator + (const Matri
   return result;
 }
 
-/* ComplexMatrixImplementation substraction (must have the same dimensions) */
+/* ComplexMatrixImplementation subtraction (must have the same dimensions) */
 ComplexMatrixImplementation ComplexMatrixImplementation::operator - (const ComplexMatrixImplementation & matrix) const
 {
-  if ((nbRows_ != matrix.nbRows_ ) || (nbColumns_ != matrix.nbColumns_ )) throw InvalidDimensionException(HERE) << "Cannot substract matrices with incompatible dimensions";
+  if ((nbRows_ != matrix.nbRows_ ) || (nbColumns_ != matrix.nbColumns_ )) throw InvalidDimensionException(HERE) << "Cannot subtract matrices with incompatible dimensions";
   // Must copy as add will be overwritten by the operation
   ComplexMatrixImplementation result(*this);
   int size(nbRows_ * nbColumns_);
@@ -441,7 +441,7 @@ ComplexMatrixImplementation ComplexMatrixImplementation::operator - (const Compl
   return result;
 }
 
-/* ComplexMatrixImplementation substraction (must have the same dimensions) */
+/* ComplexMatrixImplementation subtraction (must have the same dimensions) */
 ComplexMatrixImplementation ComplexMatrixImplementation::operator - (const MatrixImplementation & matrix) const
 {
   return operator - (ComplexMatrixImplementation(matrix));
