@@ -2,7 +2,7 @@
 /**
  *  @brief Matrix implements the classical mathematical matrix
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -23,6 +23,7 @@
 #include "openturns/SymmetricMatrix.hxx"
 #include "openturns/IdentityMatrix.hxx"
 #include "openturns/ResourceMap.hxx"
+#include "openturns/Sample.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -159,7 +160,7 @@ Matrix Matrix::operator+ (const SymmetricMatrix & m) const
   return Implementation((*getImplementation() + * (m.getImplementation())).clone());
 }
 
-/* Matrix substractions (must have the same dimensions) */
+/* Matrix subtractions (must have the same dimensions) */
 Matrix Matrix::operator- (const Matrix & m) const
 {
   return Implementation((*getImplementation() - * (m.getImplementation())).clone());
@@ -187,6 +188,12 @@ Matrix Matrix::operator* (const IdentityMatrix & m) const
   return *this;
 }
 
+/* Multiplication with a Sample (must have consistent dimensions) */
+Sample Matrix::operator* (const Sample & sample) const
+{
+  return getImplementation()->genSampleProd(sample, false, false, 'L');
+}
+
 /* Multiplication with a Point (must have consistent dimensions) */
 Point Matrix::operator* (const Point & pt) const
 {
