@@ -2,7 +2,7 @@
 /**
  *  @brief Result computes the results of an analytical Algorithm
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -25,7 +25,7 @@
 #include "openturns/Distribution.hxx"
 #include "openturns/Sample.hxx"
 #include "openturns/SobolIndicesAlgorithmImplementation.hxx"
-#include "openturns/Function.hxx"
+#include "openturns/SymbolicFunction.hxx"
 #include "openturns/BarPlot.hxx"
 #include "openturns/Description.hxx"
 #include "openturns/CompositeRandomVector.hxx"
@@ -76,7 +76,7 @@ AnalyticalResult::AnalyticalResult():
   standardSpaceDesignPoint_(0),
   physicalSpaceDesignPoint_(0),
   // Fake event based on a fake 1D composite random vector, which requires a fake 1D Function
-  limitStateVariable_(RandomVector(CompositeRandomVector(Function(Description(0), Description(1), Description(1)),
+  limitStateVariable_(RandomVector(CompositeRandomVector(SymbolicFunction(Description(0), Description(1)),
                                    ConstantRandomVector(Point(0)))),
                       Less(), 0.0),
   isStandardPointOriginInFailureSpace_(false),
@@ -117,9 +117,9 @@ void AnalyticalResult::setStandardSpaceDesignPoint(const Point & standardSpaceDe
 void AnalyticalResult::computePhysicalSpaceDesignPoint() const
 {
   /* Compute the physical design point */
-  physicalSpaceDesignPoint_ = limitStateVariable_.getImplementation()->getAntecedent()->getDistribution().getInverseIsoProbabilisticTransformation().operator()(standardSpaceDesignPoint_);
+  physicalSpaceDesignPoint_ = limitStateVariable_.getImplementation()->getAntecedent().getDistribution().getInverseIsoProbabilisticTransformation().operator()(standardSpaceDesignPoint_);
   /* we give to the physical space design point the description of the input random vector */
-  //physicalSpaceDesignPoint_.setDescription(limitStateVariable_.getImplementation()->getAntecedent()->getDescription());
+  //physicalSpaceDesignPoint_.setDescription(limitStateVariable_.getImplementation()->getAntecedent().getDescription());
 
   /* we give to the physical space design point the name Physical Design Point */
   physicalSpaceDesignPoint_.setName("Physical Space Design Point");
@@ -164,7 +164,7 @@ void AnalyticalResult::computeImportanceFactors() const
   if (standardSpaceDesignPoint_.norm() > 0.0)
   {
     /* get the input distribution */
-    const Distribution inputDistribution(limitStateVariable_.getImplementation()->getAntecedent()->getDistribution());
+    const Distribution inputDistribution(limitStateVariable_.getImplementation()->getAntecedent().getDistribution());
     /* get the input standard distribution */
     const Distribution standardDistribution(inputDistribution.getStandardDistribution());
     /* get the marginal 1D from in the standard space where all marginals are identical */
@@ -184,7 +184,7 @@ void AnalyticalResult::computeImportanceFactors() const
   importanceFactors_.setName("Importance Factors");
 
   /* we give to the importance factors vector the description of the input random vector */
-  importanceFactors_.setDescription(limitStateVariable_.getImplementation()->getAntecedent()->getDescription());
+  importanceFactors_.setDescription(limitStateVariable_.getImplementation()->getAntecedent().getDescription());
   isAlreadyComputedImportanceFactors_ = true;
 }
 
@@ -200,7 +200,7 @@ void AnalyticalResult::computeClassicalImportanceFactors() const
   classicalImportanceFactors_.setName("Classical Importance Factors");
 
   /* we give to the importance factors vector the description of the input random vector */
-  classicalImportanceFactors_.setDescription(limitStateVariable_.getImplementation()->getAntecedent()->getDescription());
+  classicalImportanceFactors_.setDescription(limitStateVariable_.getImplementation()->getAntecedent().getDescription());
 
   isAlreadyComputedClassicalImportanceFactors_ = true;
 }
@@ -213,14 +213,14 @@ void AnalyticalResult::computePhysicalImportanceFactors() const
   const Scalar sign = myEvent.getOperator().compare(0., 1.) ? 1.0 : -1.0;
   const Point currentStandardGradient(mystandardEvent.getImplementation()->getFunction().gradient(getStandardSpaceDesignPoint()) * Point(1, 1.0));
   const Point alpha(sign / currentStandardGradient.norm() * currentStandardGradient);
-  const Distribution physicalDistribution(myEvent.getImplementation()->getAntecedent()->getDistribution());
+  const Distribution physicalDistribution(myEvent.getImplementation()->getAntecedent().getDistribution());
   const InverseIsoProbabilisticTransformation inverseIsoProbabilisticTransformation(physicalDistribution.getInverseIsoProbabilisticTransformation());
   const Matrix isoGradient(inverseIsoProbabilisticTransformation.gradient(standardSpaceDesignPoint_));
   physicalImportanceFactors_ = (isoGradient * alpha).normalizeSquare();
   const Point currentPhysicalGradient(limitStateVariable_.getImplementation()->getFunction().gradient(getPhysicalSpaceDesignPoint()) * Point(1, 1.0));
   physicalImportanceFactors_ = currentPhysicalGradient.normalizeSquare();
   physicalImportanceFactors_.setName("Physical importance factors");
-  physicalImportanceFactors_.setDescription(myEvent.getImplementation()->getAntecedent()->getDescription());
+  physicalImportanceFactors_.setDescription(myEvent.getImplementation()->getAntecedent().getDescription());
   isAlreadyComputedPhysicalImportanceFactors_ = true;
 }
 
@@ -229,7 +229,7 @@ void AnalyticalResult::computePhysicalImportanceFactors() const
 void AnalyticalResult::computeMeanPointInStandardEventDomain() const
 {
   // We use the implementation here in order to have access to the computeRadialDistributionCDF() method
-  Distribution::Implementation p_standardDistribution(limitStateVariable_.getImplementation()->getAntecedent()->getDistribution().getStandardDistribution().getImplementation());
+  Distribution::Implementation p_standardDistribution(limitStateVariable_.getImplementation()->getAntecedent().getDistribution().getStandardDistribution().getImplementation());
   // Perform the integration along the ray going from the origin to the infinity
   Scalar scaling = hasoferReliabilityIndex_ * p_standardDistribution->computeRadialDistributionCDF(hasoferReliabilityIndex_, true);
   Scalar a = hasoferReliabilityIndex_;
@@ -319,7 +319,7 @@ void AnalyticalResult::setHasoferReliabilityIndex(const Scalar & hasoferReliabil
 void AnalyticalResult::computeHasoferReliabilityIndexSensitivity() const
 {
   /* get Set1 : parameters of the physical distribution */
-  const Distribution physicalDistribution(limitStateVariable_.getImplementation()->getAntecedent()->getDistribution());
+  const Distribution physicalDistribution(limitStateVariable_.getImplementation()->getAntecedent().getDistribution());
   const PointWithDescriptionCollection set1(physicalDistribution.getParametersCollection());
   /* get Set2 : parameters of the physical model */
   const Function physicalModel(limitStateVariable_.getImplementation()->getFunction());
