@@ -2,7 +2,7 @@
 /**
  *  @brief The class builds generalized linear models
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -31,10 +31,15 @@
 #include "openturns/NonCenteredFiniteDifferenceGradient.hxx"
 #include "openturns/TNC.hxx"
 #include "openturns/NLopt.hxx"
+#ifdef OPENTURNS_HAVE_ANALYTICAL_PARSER
 #include "openturns/SymbolicFunction.hxx"
+#else
+#include "openturns/DatabaseFunction.hxx"
+#endif
 #include "openturns/IdentityFunction.hxx"
 #include "openturns/ComposedFunction.hxx"
 #include "openturns/DualLinearCombinationFunction.hxx"
+#include "openturns/MemoizeFunction.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -103,12 +108,8 @@ GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm(const Sample & inputSam
   , analyticalAmplitude_(false)
   , lastReducedLogLikelihood_(SpecFunc::LogMinScalar)
 {
-  // set data & covariance model
+  // Set data
   setData(inputSample, outputSample);
-  // If no basis then we suppose output sample centered
-  checkYCentered(outputSample);
-  setCovarianceModel(covarianceModel);
-
   // Build a normalization function if needed
   if (normalize_)
   {
@@ -124,6 +125,15 @@ GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm(const Sample & inputSam
     const Point zero(dimension);
     setInputTransformation(LinearFunction(mean, zero, linear));
   }
+
+  // Normalize input sample
+  normalizeInputSample();
+
+  // If no basis then we suppose output sample centered
+  checkYCentered(outputSample);
+  // Set covariance model
+  setCovarianceModel(covarianceModel);
+
   initializeMethod();
   initializeDefaultOptimizationAlgorithm();
 }
@@ -158,23 +168,8 @@ GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm(const Sample & inputSam
   , analyticalAmplitude_(false)
   , lastReducedLogLikelihood_(SpecFunc::LogMinScalar)
 {
-  // set data & covariance model
+  // Set data
   setData(inputSample, outputSample);
-  setCovarianceModel(covarianceModel);
-
-  if (basis.getSize() > 0)
-  {
-    if (basis[0].getOutputDimension() > 1) LOGWARN(OSS() << "Expected a basis of scalar functions, but first function has dimension " << basis[0].getOutputDimension() << ". Only the first output component will be taken into account.");
-    if (outputSample.getDimension() > 1) LOGWARN(OSS() << "The basis of functions will be applied to all output marginals" );
-    // Set basis
-    basisCollection_ = BasisCollection(outputSample.getDimension(), basis);
-  }
-  else
-  {
-    // If no basis then we suppose output sample centered
-    checkYCentered(outputSample);
-  }
-
   // Build a normalization function if needed
   if (normalize_)
   {
@@ -190,49 +185,16 @@ GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm(const Sample & inputSam
     const Point zero(dimension);
     setInputTransformation(LinearFunction(mean, zero, linear));
   }
-  initializeMethod();
-  initializeDefaultOptimizationAlgorithm();
-}
 
-/* Parameters constructor */
-GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm(const Sample & inputSample,
-    const Function & inputTransformation,
-    const Sample & outputSample,
-    const CovarianceModel & covarianceModel,
-    const Basis & basis,
-    const Bool keepCholeskyFactor)
-  : MetaModelAlgorithm()
-  , inputSample_()
-  , normalizedInputSample_(0, inputSample.getDimension())
-  , inputTransformation_()
-  , normalize_(true)
-  , outputSample_()
-  , covarianceModel_()
-  , reducedCovarianceModel_()
-  , solver_()
-  , optimizationBounds_()
-  , beta_(0)
-  , rho_(0)
-  , F_(0, 0)
-  , result_()
-  , basisCollection_()
-  , covarianceCholeskyFactor_()
-  , covarianceCholeskyFactorHMatrix_()
-  , keepCholeskyFactor_(keepCholeskyFactor)
-  , method_(0)
-  , hasRun_(false)
-  , optimizeParameters_(ResourceMap::GetAsBool("GeneralLinearModelAlgorithm-OptimizeParameters"))
-  , analyticalAmplitude_(false)
-  , lastReducedLogLikelihood_(SpecFunc::LogMinScalar)
-{
-  // set data & covariance model
-  setData(inputSample, outputSample);
+  // Normalize input sample
+  normalizeInputSample();
+
+  // Set covariance model
   setCovarianceModel(covarianceModel);
 
-  // basis setter
   if (basis.getSize() > 0)
   {
-    if (basis[0].getOutputDimension() > 1) LOGWARN(OSS() << "Expected a basis of scalar functions, but first function has dimension" << basis[0].getOutputDimension() << ". Only the first output component will be taken into account.");
+    if (basis[0].getOutputDimension() > 1) LOGWARN(OSS() << "Expected a basis of scalar functions, but first function has dimension " << basis[0].getOutputDimension() << ". Only the first output component will be taken into account.");
     if (outputSample.getDimension() > 1) LOGWARN(OSS() << "The basis of functions will be applied to all output marginals" );
     // Set basis
     basisCollection_ = BasisCollection(outputSample.getDimension(), basis);
@@ -243,12 +205,11 @@ GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm(const Sample & inputSam
     checkYCentered(outputSample);
   }
 
-  // Set the isoprobabilistic transformation
-  setInputTransformation(inputTransformation);
   initializeMethod();
   initializeDefaultOptimizationAlgorithm();
 }
 
+
 /* Parameters constructor */
 GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm(const Sample & inputSample,
     const Sample & outputSample,
@@ -280,13 +241,8 @@ GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm(const Sample & inputSam
   , analyticalAmplitude_(false)
   , lastReducedLogLikelihood_(SpecFunc::LogMinScalar)
 {
-  // set data & covariance model
+  // Set data
   setData(inputSample, outputSample);
-  setCovarianceModel(covarianceModel);
-
-  // Set basis collection
-  if (basisCollection.getSize() > 0) setBasisCollection(basisCollection);
-
   // Build a normalization function if needed
   if (normalize_)
   {
@@ -302,50 +258,17 @@ GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm(const Sample & inputSam
     const Point zero(dimension);
     setInputTransformation(LinearFunction(mean, zero, linear));
   }
-  initializeMethod();
-  initializeDefaultOptimizationAlgorithm();
-}
 
-/* Parameters constructor */
-GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm(const Sample & inputSample,
-    const Function & inputTransformation,
-    const Sample & outputSample,
-    const CovarianceModel & covarianceModel,
-    const BasisCollection & basisCollection,
-    const Bool keepCholeskyFactor)
-  : MetaModelAlgorithm()
-  , inputSample_()
-  , normalizedInputSample_(0, inputSample.getDimension())
-  , inputTransformation_()
-  , normalize_(true)
-  , outputSample_()
-  , covarianceModel_()
-  , reducedCovarianceModel_()
-  , solver_()
-  , optimizationBounds_()
-  , beta_(0)
-  , rho_(0)
-  , F_(0, 0)
-  , result_()
-  , basisCollection_()
-  , covarianceCholeskyFactor_()
-  , covarianceCholeskyFactorHMatrix_()
-  , keepCholeskyFactor_(keepCholeskyFactor)
-  , method_(0)
-  , hasRun_(false)
-  , optimizeParameters_(ResourceMap::GetAsBool("GeneralLinearModelAlgorithm-OptimizeParameters"))
-  , analyticalAmplitude_(false)
-  , lastReducedLogLikelihood_(SpecFunc::LogMinScalar)
-{
-  // set data & covariance model
-  setData(inputSample, outputSample);
+  // Normalize input sample
+  normalizeInputSample();
+
+
+  // Set covariance model
   setCovarianceModel(covarianceModel);
 
   // Set basis collection
-  if (basisCollection.getSize() > 0)  setBasisCollection(basisCollection);
+  if (basisCollection.getSize() > 0) setBasisCollection(basisCollection);
 
-  // Set the isoprobabilistic transformation
-  setInputTransformation(inputTransformation);
   initializeMethod();
   initializeDefaultOptimizationAlgorithm();
 }
@@ -377,10 +300,10 @@ void GeneralLinearModelAlgorithm::setCovarianceModel(const CovarianceModel & cov
   // 4) The spatial dimension of the model is 1 and different from the spatial dimension of the problem, and the dimension of the model is 1 and different from the dimension of the problem. The actual model is a tensorization of products of the given model.
   // The other situations are invalid.
 
-  const Bool sameDimension = dimension == covarianceModel.getDimension();
-  const Bool unitModelDimension = covarianceModel.getDimension() == 1;
-  const Bool sameSpatialDimension = inputDimension == covarianceModel.getSpatialDimension();
-  const Bool unitModelSpatialDimension = covarianceModel.getSpatialDimension() == 1;
+  const Bool sameDimension = dimension == covarianceModel.getOutputDimension();
+  const Bool unitModelDimension = covarianceModel.getOutputDimension() == 1;
+  const Bool sameSpatialDimension = inputDimension == covarianceModel.getInputDimension();
+  const Bool unitModelSpatialDimension = covarianceModel.getInputDimension() == 1;
   // Case 1
   if (sameSpatialDimension && sameDimension)
     covarianceModel_ = covarianceModel;
@@ -393,7 +316,7 @@ void GeneralLinearModelAlgorithm::setCovarianceModel(const CovarianceModel & cov
   // Case 4
   else if (unitModelSpatialDimension && unitModelDimension)
     covarianceModel_ = TensorizedCovarianceModel(TensorizedCovarianceModel::CovarianceModelCollection(dimension, ProductCovarianceModel(ProductCovarianceModel::CovarianceModelCollection(inputDimension, covarianceModel))));
-  else throw InvalidArgumentException(HERE) << "In GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm, invalid dimension=" << covarianceModel.getDimension() << " or spatial dimension=" << covarianceModel.getSpatialDimension() << " for the given covariance model. A model of both spatial dimension=" << inputDimension << " and dimension=" << dimension << " is expected, or a model of spatial dimension=" << inputDimension << " and unit dimension, or a model of unit spatial dimension and dimension=" << dimension << ", or a model of unit spatial dimension and unit dimension.";
+  else throw InvalidArgumentException(HERE) << "In GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm, invalid dimension=" << covarianceModel.getOutputDimension() << " or spatial dimension=" << covarianceModel.getInputDimension() << " for the given covariance model. A model of both spatial dimension=" << inputDimension << " and dimension=" << dimension << " is expected, or a model of spatial dimension=" << inputDimension << " and unit dimension, or a model of unit spatial dimension and dimension=" << dimension << ", or a model of unit spatial dimension and unit dimension.";
   // All the computation will be done on the reduced covariance model. We keep the initial covariance model (ie the one we just built) in order to reinitialize the reduced covariance model if some flags are changed after the creation of the algorithm.
   reducedCovarianceModel_ = covarianceModel_;
   // Now, adapt the model parameters.
@@ -404,7 +327,7 @@ void GeneralLinearModelAlgorithm::setCovarianceModel(const CovarianceModel & cov
   else if (ResourceMap::GetAsBool("GeneralLinearModelAlgorithm-UseAnalyticalAmplitudeEstimate"))
   {
     // The model has to be of dimension 1
-    if (reducedCovarianceModel_.getDimension() == 1)
+    if (reducedCovarianceModel_.getOutputDimension() == 1)
     {
       const Description activeParametersDescription(reducedCovarianceModel_.getParameterDescription());
       // And one of the active parameters must be called amplitude_0
@@ -430,8 +353,27 @@ void GeneralLinearModelAlgorithm::setCovarianceModel(const CovarianceModel & cov
   const UnsignedInteger optimizationDimension = reducedCovarianceModel_.getParameter().getSize();
   if (optimizationDimension > 0)
   {
+    const Scalar scaleFactor(ResourceMap::GetAsScalar( "GeneralLinearModelAlgorithm-DefaultOptimizationScaleFactor"));
+    if (!(scaleFactor > 0))
+      throw InvalidArgumentException(HERE) << "Scale factor set in ResourceMap is invalid. It should be a positive value. Here, scale = " << scaleFactor ;
     const Point lowerBound(optimizationDimension, ResourceMap::GetAsScalar( "GeneralLinearModelAlgorithm-DefaultOptimizationLowerBound"));
-    const Point upperBound(optimizationDimension, ResourceMap::GetAsScalar( "GeneralLinearModelAlgorithm-DefaultOptimizationUpperBound"));
+    Point upperBound(optimizationDimension, ResourceMap::GetAsScalar( "GeneralLinearModelAlgorithm-DefaultOptimizationUpperBound"));
+    // We could set scale parameter if these parameters are enabled.
+    // check if scale is active
+    const Indices activeParameters(reducedCovarianceModel_.getActiveParameter());
+    Bool isScaleActive(true);
+    for (UnsignedInteger k = 0; k < reducedCovarianceModel_.getScale().getSize(); ++k)
+    {
+      if (!activeParameters.contains(k))
+        isScaleActive = false;
+    }
+    if (isScaleActive)
+    {
+      const Point inputSampleRange(normalizedInputSample_.getMax() - normalizedInputSample_.getMin());
+      for (UnsignedInteger k = 0; k < reducedCovarianceModel_.getScale().getSize(); ++k) upperBound[k] = inputSampleRange[k] * scaleFactor;
+    }
+    LOGWARN(OSS() <<  "Warning! For coherency we set scale upper bounds = " << upperBound.__str__());
+
     optimizationBounds_ = Interval(lowerBound, upperBound);
   }
   else optimizationBounds_ = Interval();
@@ -465,7 +407,7 @@ void GeneralLinearModelAlgorithm::setBasisCollection(const BasisCollection & bas
       outputDimension =  basis[index][0].getOutputDimension();
       continuationCondition = false;
     }
-    catch (InvalidArgumentException)
+    catch (InvalidArgumentException &)
     {
       ++index;
       continuationCondition = continuationCondition && index < basis.getSize();
@@ -519,7 +461,7 @@ void GeneralLinearModelAlgorithm::normalizeInputSample()
     normalizedInputSample_ = inputSample_;
     return;
   }
-  LOGINFO("Data are normalized");
+  LOGINFO("Normalize input data");
   normalizedInputSample_ = inputTransformation_(inputSample_);
 }
 
@@ -528,6 +470,7 @@ void GeneralLinearModelAlgorithm::computeF()
 {
   // Nothing to do if the design matrix has already been computed
   if (F_.getNbRows() != 0) return;
+  LOGINFO("Compute the design matrix");
   // No early exit based on the sample/basis size as F_ must be initialized with the correct dimensions
   // With a multivariate basis of size similar to output dimension, each ith-basis should be applied to elements
   // of corresponding marginal
@@ -550,7 +493,7 @@ void GeneralLinearModelAlgorithm::computeF()
     {
       // Here we use potential parallelism in the evaluation of the basis functions
       const Sample basisSample = localBasis[j](normalizedInputSample_);
-      for (UnsignedInteger i = 0; i < sampleSize; ++i) F_(outputMarginal + i * outputDimension, index) = basisSample[i][0];
+      for (UnsignedInteger i = 0; i < sampleSize; ++i) F_(outputMarginal + i * outputDimension, index) = basisSample(i, 0);
     }
   }
 }
@@ -578,13 +521,10 @@ void GeneralLinearModelAlgorithm::run()
 {
   // Do not run again if already computed
   if (hasRun_) return;
-  LOGINFO("Normalize the data");
   normalizeInputSample();
-  LOGINFO("Compute the design matrix");
   computeF();
   const UnsignedInteger outputDimension = outputSample_.getDimension();
   // optimization of likelihood function if provided
-  LOGINFO("Optimize the parameter of the covariance model if needed");
   // Here we call the optimizeReducedLogLikelihood() method even if the covariance
   // model has no active parameter, because:
   // + it can be due to the fact that the amplitude is obtained through an
@@ -600,7 +540,7 @@ void GeneralLinearModelAlgorithm::run()
   // 1) To get a collection of Point for the result class
   // 2) To get same results as Sample for the trend NMF
   Collection<Point> trendCoefficients(basisCollection_.getSize());
-  Sample trendCoefficientsSample(beta_.getSize(), reducedCovarianceModel_.getDimension());
+  Sample trendCoefficientsSample(beta_.getSize(), reducedCovarianceModel_.getOutputDimension());
 
   UnsignedInteger cumulatedSize = 0;
   for (UnsignedInteger outputIndex = 0; outputIndex < basisCollection_.getSize(); ++ outputIndex)
@@ -610,7 +550,7 @@ void GeneralLinearModelAlgorithm::run()
     for(UnsignedInteger basisElement = 0; basisElement < localBasisSize; ++ basisElement)
     {
       beta_i[basisElement] = beta_[cumulatedSize];
-      trendCoefficientsSample[cumulatedSize][outputIndex] =  beta_[cumulatedSize];
+      trendCoefficientsSample(cumulatedSize, outputIndex) =  beta_[cumulatedSize];
       ++cumulatedSize;
     }
     trendCoefficients[outputIndex] = beta_i;
@@ -633,10 +573,10 @@ void GeneralLinearModelAlgorithm::run()
   else
   {
     // If no basis ==> zero function
-#ifdef OPENTURNS_HAVE_MUPARSER
-    metaModel = SymbolicFunction(Description::BuildDefault(covarianceModel_.getSpatialDimension(), "x"), Description(covarianceModel_.getDimension(), "0.0"));
+#ifdef OPENTURNS_HAVE_ANALYTICAL_PARSER
+    metaModel = SymbolicFunction(Description::BuildDefault(covarianceModel_.getInputDimension(), "x"), Description(covarianceModel_.getOutputDimension(), "0.0"));
 #else
-    metaModel = Function(Sample(1, reducedCovarianceModel_.getSpatialDimension()), Sample(1, reducedCovarianceModel_.getDimension()));
+    metaModel = DatabaseFunction(Sample(1, reducedCovarianceModel_.getInputDimension()), Sample(1, reducedCovarianceModel_.getOutputDimension()));
 #endif
   }
 
@@ -715,18 +655,20 @@ Scalar GeneralLinearModelAlgorithm::maximizeReducedLogLikelihood()
   solver_.setProblem(problem);
   LOGINFO(OSS(false) << "Solve problem=" << problem << " using solver=" << solver_);
   solver_.run();
-  const Scalar optimalLogLikelihood = solver_.getResult().getOptimalValue()[0];
-  const Point optimalParameters = solver_.getResult().getOptimalPoint();
+  const OptimizationAlgorithm::Result result(solver_.getResult());
+  const Scalar optimalLogLikelihood = result.getOptimalValue()[0];
+  const Point optimalParameters = result.getOptimalPoint();
+  const UnsignedInteger evaluationNumber = result.getEvaluationNumber();
   // Check if the optimal value corresponds to the last computed value, in order to
   // see if the by-products (Cholesky factor etc) are correct
   if (lastReducedLogLikelihood_ != optimalLogLikelihood)
   {
-    LOGINFO(OSS(false) << "Need to evaluate the objective function one more time because the last computed reduced log-likelihood value=" << lastReducedLogLikelihood_ << " is different from the optimal one=" << optimalLogLikelihood);
+    LOGDEBUG(OSS(false) << "Need to evaluate the objective function one more time because the last computed reduced log-likelihood value=" << lastReducedLogLikelihood_ << " is different from the optimal one=" << optimalLogLikelihood);
     (void) computeReducedLogLikelihood(optimalParameters);
   }
   // Final call to reducedLogLikelihoodFunction() in order to update the amplitude
   // No additional cost since the cache mechanism is activated
-  LOGDEBUG(OSS() << "Optimized parameters=" << optimalParameters << ", log-likelihood=" << optimalLogLikelihood);
+  LOGINFO(OSS() << evaluationNumber << " evaluations, optimized parameters=" << optimalParameters << ", log-likelihood=" << optimalLogLikelihood);
   return optimalLogLikelihood;
 }
 
@@ -737,7 +679,8 @@ Point GeneralLinearModelAlgorithm::computeReducedLogLikelihood(const Point & par
     throw InvalidArgumentException(HERE) << "In GeneralLinearModelAlgorithm::computeReducedLogLikelihood, could not compute likelihood,"
                                          << " covariance model requires an argument of size " << reducedCovarianceModel_.getParameter().getSize()
                                          << " but here we got " << parameters.getSize();
-  LOGINFO(OSS(false) << "Compute reduced log-likelihood for parameters=" << parameters);
+  LOGDEBUG(OSS(false) << "Compute reduced log-likelihood for parameters=" << parameters);
+  const Scalar constant = - SpecFunc::LOGSQRT2PI * static_cast<Scalar>(inputSample_.getSize()) * static_cast<Scalar>(outputSample_.getDimension());
   Scalar logDeterminant = 0.0;
   // If the amplitude is deduced from the other parameters, work with
   // the correlation function
@@ -753,7 +696,7 @@ Point GeneralLinearModelAlgorithm::computeReducedLogLikelihood(const Point & par
   // and update the reduced log-likelihood.
   if (analyticalAmplitude_)
   {
-    LOGINFO("Analytical amplitude");
+    LOGDEBUG("Analytical amplitude");
     // J(\sigma)=-\log(\sqrt{\sigma^{2N}\det{R}})-(Y-M)^tR^{-1}(Y-M)/(2\sigma^2)
     //          =-N\log(\sigma)-\log(\det{R})/2-(Y-M)^tR^{-1}(Y-M)/(2\sigma^2)
     // dJ/d\sigma=-N/\sigma+(Y-M)^tR^{-1}(Y-M)/\sigma^3=0
@@ -772,7 +715,7 @@ Point GeneralLinearModelAlgorithm::computeReducedLogLikelihood(const Point & par
   LOGDEBUG(OSS(false) << "epsilon=||rho||^2=" << epsilon);
   if (epsilon <= 0) lastReducedLogLikelihood_ = SpecFunc::LogMinScalar;
   // For the general multidimensional case, we have to compute the general log-likelihood (ie including marginal variances)
-  else lastReducedLogLikelihood_ = -0.5 * (logDeterminant + epsilon);
+  else lastReducedLogLikelihood_ = constant - 0.5 * (logDeterminant + epsilon);
   LOGINFO(OSS(false) << "Reduced log-likelihood=" << lastReducedLogLikelihood_);
   return Point(1, lastReducedLogLikelihood_);
 }
@@ -781,17 +724,17 @@ Point GeneralLinearModelAlgorithm::computeReducedLogLikelihood(const Point & par
 Scalar GeneralLinearModelAlgorithm::computeLapackLogDeterminantCholesky() const
 {
   // Using the hypothesis that parameters = scale & model writes : C(s,t) = diag(sigma) * R(s,t) * diag(sigma) with R a correlation function
-  LOGINFO(OSS(false) << "Compute the LAPACK log-determinant of the Cholesky factor for covariance=" << reducedCovarianceModel_);
+  LOGDEBUG(OSS(false) << "Compute the LAPACK log-determinant of the Cholesky factor for covariance=" << reducedCovarianceModel_);
 
-  LOGINFO("Discretize the covariance model");
+  LOGDEBUG("Discretize the covariance model");
   CovarianceMatrix C(reducedCovarianceModel_.discretize(normalizedInputSample_));
   if (noise_.getDimension() > 0)
   {
-    LOGINFO("Add noise to the covariance matrix");
+    LOGDEBUG("Add noise to the covariance matrix");
     for (UnsignedInteger i = 0; i < C.getDimension(); ++ i) C(i, i) += noise_[i];
   }
   LOGDEBUG(OSS(false) << "C=\n" << C);
-  LOGINFO("Compute the Cholesky factor of the covariance matrix");
+  LOGDEBUG("Compute the Cholesky factor of the covariance matrix");
   Bool continuationCondition = true;
   const Scalar startingScaling = ResourceMap::GetAsScalar("GeneralLinearModelAlgorithm-StartingScaling");
   const Scalar maximalScaling = ResourceMap::GetAsScalar("GeneralLinearModelAlgorithm-MaximalScaling");
@@ -824,25 +767,25 @@ Scalar GeneralLinearModelAlgorithm::computeLapackLogDeterminantCholesky() const
   const Point y(outputSample_.getImplementation()->getData());
   LOGDEBUG(OSS(false) << "y=" << y);
   // rho = L^{-1}y
-  LOGINFO("Solve L.rho = y");
+  LOGDEBUG("Solve L.rho = y");
   rho_ = covarianceCholeskyFactor_.solveLinearSystem(y);
   LOGDEBUG(OSS(false) << "rho_=L^{-1}y=" << rho_);
   // If trend to estimate
   if (basisCollection_.getSize() > 0)
   {
     // Phi = L^{-1}F
-    LOGINFO("Solve L.Phi = F");
+    LOGDEBUG("Solve L.Phi = F");
     LOGDEBUG(OSS(false) << "F_=\n" << F_);
     Matrix Phi(covarianceCholeskyFactor_.solveLinearSystem(F_));
     LOGDEBUG(OSS(false) << "Phi=\n" << Phi);
-    LOGINFO("Solve min_beta||Phi.beta - rho||^2");
+    LOGDEBUG("Solve min_beta||Phi.beta - rho||^2");
     beta_ = Phi.solveLinearSystem(rho_);
     LOGDEBUG(OSS(false) << "beta_=" << beta_);
-    LOGINFO("Update rho");
+    LOGDEBUG("Update rho");
     rho_ -= Phi * beta_;
     LOGDEBUG(OSS(false) << "rho_=L^{-1}y-L^{-1}F.beta=" << rho_);
   }
-  LOGINFO("Compute log(|det(L)|)=log(sqrt(|det(C)|))");
+  LOGDEBUG("Compute log(|det(L)|)=log(sqrt(|det(C)|))");
   Scalar logDetL = 0.0;
   for (UnsignedInteger i = 0; i < covarianceCholeskyFactor_.getDimension(); ++i )
   {
@@ -857,14 +800,14 @@ Scalar GeneralLinearModelAlgorithm::computeLapackLogDeterminantCholesky() const
 Scalar GeneralLinearModelAlgorithm::computeHMatLogDeterminantCholesky() const
 {
   // Using the hypothesis that parameters = scale & model writes : C(s,t) = \sigma^2 * R(s,t) with R a correlation function
-  LOGINFO(OSS(false) << "Compute the HMAT log-determinant of the Cholesky factor for covariance=" << reducedCovarianceModel_);
+  LOGDEBUG(OSS(false) << "Compute the HMAT log-determinant of the Cholesky factor for covariance=" << reducedCovarianceModel_);
 
   Bool continuationCondition = true;
   const Scalar startingScaling = ResourceMap::GetAsScalar("GeneralLinearModelAlgorithm-StartingScaling");
   const Scalar maximalScaling = ResourceMap::GetAsScalar("GeneralLinearModelAlgorithm-MaximalScaling");
   Scalar cumulatedScaling = 0.0;
   Scalar scaling = startingScaling;
-  const UnsignedInteger covarianceDimension = reducedCovarianceModel_.getDimension();
+  const UnsignedInteger covarianceDimension = reducedCovarianceModel_.getOutputDimension();
 
   HMatrixFactory hmatrixFactory;
   HMatrixParameters hmatrixParameters;
@@ -912,7 +855,7 @@ Scalar GeneralLinearModelAlgorithm::computeHMatLogDeterminantCholesky() const
   // The PersistentCollection is returned as Point with the right memory map
   Point y(outputSample_.getImplementation()->getData());
   // rho = L^{-1}y
-  LOGINFO("Solve L.rho = y");
+  LOGDEBUG("Solve L.rho = y");
   rho_ = covarianceCholeskyFactorHMatrix_.solveLower(y);
   // If trend to estimate
   if (basisCollection_.getSize() > 0)
@@ -920,11 +863,11 @@ Scalar GeneralLinearModelAlgorithm::computeHMatLogDeterminantCholesky() const
     // Phi = L^{-1}F
     LOGDEBUG("Solve L.Phi = F");
     Matrix Phi(covarianceCholeskyFactorHMatrix_.solveLower(F_));
-    LOGINFO("Solve min_beta||Phi.beta - rho||^2");
+    LOGDEBUG("Solve min_beta||Phi.beta - rho||^2");
     beta_ = Phi.solveLinearSystem(rho_);
     rho_ -= Phi * beta_;
   }
-  LOGINFO("Compute log(sqrt(|det(C)|)) = log(|det(L)|)");
+  LOGDEBUG("Compute log(sqrt(|det(C)|)) = log(|det(L)|)");
   Scalar logDetL = 0.0;
   Point diagonal(covarianceCholeskyFactorHMatrix_.getDiagonal());
   for (UnsignedInteger i = 0; i < rho_.getSize(); ++i )
@@ -1055,11 +998,9 @@ GeneralLinearModelResult GeneralLinearModelAlgorithm::getResult()
 
 Function GeneralLinearModelAlgorithm::getObjectiveFunction()
 {
-  LOGINFO("Normalizing the data (if needed)...");
   normalizeInputSample();
-  LOGINFO("Compute the design matrix");
   computeF();
-  Function logLikelihood(ReducedLogLikelihoodEvaluation(*this));
+  MemoizeFunction logLikelihood(ReducedLogLikelihoodEvaluation(*this));
   // Here we change the finite difference gradient for a non centered one in order to reduce the computational cost
   logLikelihood.setGradient(NonCenteredFiniteDifferenceGradient(ResourceMap::GetAsScalar( "NonCenteredFiniteDifferenceGradient-DefaultEpsilon" ), logLikelihood.getEvaluation()).clone());
   logLikelihood.enableCache();
