@@ -2,7 +2,7 @@
 /**
  *  @brief Tensor approximation algorithm
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -66,7 +66,7 @@ TensorApproximationAlgorithm::TensorApproximationAlgorithm(const Sample & inputS
     const OrthogonalProductFunctionFactory & basisFactory,
     const Indices & degrees,
     const UnsignedInteger maxRank)
-  : MetaModelAlgorithm(distribution, Function(FunctionImplementation(DatabaseEvaluation(inputSample, outputSample, false).clone())))
+  : MetaModelAlgorithm(distribution, Function(FunctionImplementation(new DatabaseEvaluation(inputSample, outputSample))))
   , inputSample_(inputSample)
   , outputSample_(outputSample)
   , maxRank_(maxRank)
@@ -209,8 +209,7 @@ void TensorApproximationAlgorithm::greedyRankOne (const Sample & x,
       prodColl[i2] = Function(tensor.getMarginalRank(i2).clone());
     }
 
-    const Basis basis(prodColl);
-    DesignProxy proxy(x, basis);
+    DesignProxy proxy(x, prodColl);
     Indices full(prodColl.getSize());
     full.fill();
 
@@ -311,7 +310,7 @@ void TensorApproximationAlgorithm::rankOne(const Sample & x,
     {
       for (UnsignedInteger p = 0; p < size; ++ p)
       {
-        f[p] *= V[j][p];
+        f[p] *= V(j, p);
       }
     }
     Scalar currentRadius = dot(f, yFlat) / f.normSquare();
@@ -338,9 +337,9 @@ void TensorApproximationAlgorithm::rankOne(const Sample & x,
       Scalar prod = currentRadius;
       for (UnsignedInteger j = 0; j < dimension; ++ j)
       {
-        prod *= V[j][p];
+        prod *= V(j, p);
       }
-      const Scalar slack = y[p][0] - prod;
+      const Scalar slack = y(p, 0) - prod;
       marginalResidual += slack * slack / size;
     }
     marginalRelativeError = marginalResidual / y.computeVariance()[0];
@@ -410,8 +409,7 @@ void TensorApproximationAlgorithm::rankM (const Sample & x,
       prodColl[i] = Function(tensor.getMarginalRank(i).clone());
     }
 
-    const Basis basis(prodColl);
-    DesignProxy proxy(x, basis);
+    DesignProxy proxy(x, prodColl);
     Indices full(prodColl.getSize());
     full.fill();
 
@@ -434,7 +432,7 @@ void TensorApproximationAlgorithm::rankM (const Sample & x,
     marginalResidual = 0.0;
     for (UnsignedInteger p = 0; p < size; ++ p)
     {
-      const Scalar slack = y[p][0] - tensor(x[p])[0];
+      const Scalar slack = y(p, 0) - tensor(x[p])[0];
       marginalResidual += slack * slack / size;
     }
     marginalRelativeError = marginalResidual / y.computeVariance()[0];
@@ -489,16 +487,16 @@ void TensorApproximationAlgorithm::rankMComponent (const Sample & x,
     }
   }
 
-  Basis basis;
+  FunctionCollection functions;
   const Basis basisj(tensor.getBasis(j));
   for (UnsignedInteger i = 0; i < m; ++ i)
   {
     for (UnsignedInteger k = 0; k < nj; ++ k)
     {
-      basis.add(basisj[k]);
+      functions.add(basisj[k]);
     }
   }
-  DesignProxy proxy(transformedInputSample_.getMarginal(j), basis);
+  DesignProxy proxy(transformedInputSample_.getMarginal(j), functions);
   proxy.setWeight(w);
   Indices full(nj * m);
   full.fill();
