@@ -2,7 +2,7 @@
 /**
  *  @brief EfficientGlobalOptimization or EGO algorithm
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -157,7 +157,7 @@ void EfficientGlobalOptimization::run()
     Sample noiseSample(model.getMarginal(1)(inputSample));
     for (UnsignedInteger i = 0; i < size; ++ i)
     {
-      noise[i] = noiseSample[i][0];
+      noise[i] = noiseSample(i, 0);
       if (!(noise[i] >= 0.0)) throw InvalidArgumentException(HERE) << "Noise model must be positive";
     }
 
@@ -165,7 +165,7 @@ void EfficientGlobalOptimization::run()
     if (noiseModel_.getOutputDimension() != 1)
       noiseModel_ = model.getMarginal(1);
   }
-  UnsignedInteger iterationNumber = 0;
+  UnsignedInteger evaluationNumber = 0;
   Bool exitLoop = false;
 
   // select the best feasible point
@@ -176,8 +176,8 @@ void EfficientGlobalOptimization::run()
   for (UnsignedInteger index = 0; index < size; ++ index)
   {
     if (!problem.hasBounds() || (problem.hasBounds() && problem.getBounds().contains(inputSample[index])))
-      if ((problem.isMinimization() && (outputSample[index][0] < optimalValue))
-          || (!problem.isMinimization() && (outputSample[index][0] > optimalValue)))
+      if ((problem.isMinimization() && (outputSample(index, 0) < optimalValue))
+          || (!problem.isMinimization() && (outputSample(index, 0) > optimalValue)))
       {
         optimizerPrev = optimizer;
         optimalValuePrev = optimalValue;
@@ -196,11 +196,11 @@ void EfficientGlobalOptimization::run()
     for (UnsignedInteger index = 1; index < size; ++ index)
     {
       if (!problem.hasBounds() || (problem.hasBounds() && problem.getBounds().contains(inputSample[index])))
-        if ((problem.isMinimization() && (outputSample[index][0] < optimalValuePrev))
-            || (!problem.isMinimization() && (outputSample[index][0] > optimalValuePrev)))
+        if ((problem.isMinimization() && (outputSample(index, 0) < optimalValuePrev))
+            || (!problem.isMinimization() && (outputSample(index, 0) > optimalValuePrev)))
         {
           optimizerPrev = inputSample[index];
-          optimalValuePrev = outputSample[index][0];
+          optimalValuePrev = outputSample(index, 0);
         }
     }
   }
@@ -215,7 +215,7 @@ void EfficientGlobalOptimization::run()
       {
         for (UnsignedInteger j = 0; j < dimension; ++ j)
         {
-          Scalar distance = std::abs(inputSample[i1][j] - inputSample[i2][j]);
+          Scalar distance = std::abs(inputSample(i1, j) - inputSample(i2, j));
           if (distance < minimumDistance[j])
           {
             minimumDistance[j] = distance;
@@ -225,18 +225,18 @@ void EfficientGlobalOptimization::run()
     }
   }
 
-  OptimizationResult result;
+  OptimizationResult result(dimension, 1);
   result.setProblem(getProblem());
 
-  while ((!exitLoop) && (iterationNumber < getMaximumIterationNumber()))
+  while ((!exitLoop) && (evaluationNumber < getMaximumEvaluationNumber()))
   {
     // use the provided kriging result at first iteration
     KrigingResult metaModelResult(krigingResult_);
-    if (iterationNumber > 0)
+    if (evaluationNumber > 0)
     {
       KrigingAlgorithm algo(inputSample, outputSample, krigingResult_.getCovarianceModel(), krigingResult_.getBasisCollection());
       LOGINFO(OSS() << "Rebuilding kriging ...");
-      algo.setOptimizeParameters((parameterEstimationPeriod_ > 0) && ((iterationNumber % parameterEstimationPeriod_) == 0));
+      algo.setOptimizeParameters((parameterEstimationPeriod_ > 0) && ((evaluationNumber % parameterEstimationPeriod_) == 0));
       if (hasNoise)
         algo.setNoise(noise);
       algo.run();
@@ -312,9 +312,10 @@ void EfficientGlobalOptimization::run()
 
     const Point newPoint(improvementResult.getOptimalPoint());
     const Point newOutput(model(newPoint));
+    ++ evaluationNumber;
     const Point newValue(Point(1, newOutput[0]));// noise can be provided on the 2nd marginal
 
-    LOGINFO(OSS() << "New point x=" << newPoint << " f(x)=" << newValue << "iteration=" << iterationNumber + 1);
+    LOGINFO(OSS() << "New point x=" << newPoint << " f(x)=" << newValue << " evaluations=" << evaluationNumber);
 
     // is the new point better ?
     if ((problem.isMinimization() && (newValue[0] < optimalValue))
@@ -347,7 +348,7 @@ void EfficientGlobalOptimization::run()
       {
         for (UnsignedInteger j = 0; j < dimension; ++ j)
         {
-          Scalar distance = std::abs(inputSample[i][j] - newPoint[j]);
+          Scalar distance = std::abs(inputSample(i, j) - newPoint[j]);
           if (distance < minimumDistance[j])
           {
             minimumDistance[j] = distance;
@@ -382,12 +383,10 @@ void EfficientGlobalOptimization::run()
       noise.add(newOutput[1]);
     }
 
-    ++ iterationNumber;
-
     // callbacks
     if (progressCallback_.first)
     {
-      progressCallback_.first((100.0 * iterationNumber) / getMaximumIterationNumber(), progressCallback_.second);
+      progressCallback_.first((100.0 * evaluationNumber) / getMaximumEvaluationNumber(), progressCallback_.second);
     }
     if (stopCallback_.first)
     {
@@ -401,7 +400,7 @@ void EfficientGlobalOptimization::run()
   }
   result.setOptimalPoint(optimizer);
   result.setOptimalValue(Point(1, optimalValue));
-  result.setIterationNumber(iterationNumber);
+  result.setEvaluationNumber(evaluationNumber);
   setResult(result);
 }
 
