@@ -2,7 +2,7 @@
 /**
  * @brief ANCOVA implements the sensivity analysis method for correlated data
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -73,7 +73,7 @@ void ANCOVA::run() const
     }
     for (UnsignedInteger marginal_k = 0; marginal_k < nbMarginals; ++marginal_k)
     {
-      const Sample coefficients = allCoefficients.getMarginal(marginal_k);
+      const Sample coefficients(allCoefficients.getMarginal(marginal_k));
 
       // Output sample obtained with correlated inputs
       const Sample Y(functionalChaosResult_.getMetaModel().getMarginal(marginal_k)(correlatedInput_));
@@ -84,17 +84,17 @@ void ANCOVA::run() const
       {
         Scalar temp = 0.;
         for (UnsignedInteger k = 0; k < counter + 1; ++k)
-          temp += coefficients[coefList[k]][0] * B[coefList[k]](T(correlatedInput_[j]))[0];
+          temp += coefficients(coefList[k], 0) * B[coefList[k]](T(correlatedInput_[j]))[0];
 
-        inputOutput[j][0] = temp;
-        inputOutput[j][1] = Y[j][0];
+        inputOutput(j, 0) = temp;
+        inputOutput(j, 1) = Y(j, 0);
       }
       const CovarianceMatrix inputOutputCovariance(inputOutput.computeCovariance());
 
       // Compute total part of variance of the marginal_k output due to input_i
-      indices_[marginal_k][input_i] = inputOutputCovariance(0, 1) / inputOutputCovariance(1, 1);
+      indices_(marginal_k, input_i) = inputOutputCovariance(0, 1) / inputOutputCovariance(1, 1);
       // "uncorrelated" part
-      uncorrelatedIndices_[marginal_k][input_i] = inputOutputCovariance(0, 0) / inputOutputCovariance(1, 1);
+      uncorrelatedIndices_(marginal_k, input_i) = inputOutputCovariance(0, 0) / inputOutputCovariance(1, 1);
     }
   }
   alreadyComputedIndices_ = true;
