@@ -2,7 +2,7 @@
 /**
  *  @brief Implementation for sensitivity algorithms
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -29,6 +29,8 @@
 #include "openturns/Pie.hxx"
 #include "openturns/Text.hxx"
 #include "openturns/SobolIndicesExperiment.hxx"
+#include "openturns/Normal.hxx"
+#include "openturns/KernelSmoothing.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -50,8 +52,10 @@ SobolIndicesAlgorithmImplementation::SobolIndicesAlgorithmImplementation()
   , mergedFirstOrderIndices_()
   , mergedTotalOrderIndices_()
   , secondOrderIndices_()
-  , firstOrderIndiceInterval_()
-  , totalOrderIndiceInterval_()
+  , firstOrderIndiceDistribution_()
+  , totalOrderIndiceDistribution_()
+  , alreadyComputedIndicesDistribution_(false)
+  , useAsymptoticDistribution_(ResourceMap::GetAsBool("SobolIndicesAlgorithm-DefaultUseAsymptoticDistribution"))
 {
   // Nothing to do
 }
@@ -72,8 +76,10 @@ SobolIndicesAlgorithmImplementation::SobolIndicesAlgorithmImplementation(const S
   , mergedFirstOrderIndices_()
   , mergedTotalOrderIndices_()
   , secondOrderIndices_()
-  , firstOrderIndiceInterval_()
-  , totalOrderIndiceInterval_()
+  , firstOrderIndiceDistribution_()
+  , totalOrderIndiceDistribution_()
+  , alreadyComputedIndicesDistribution_(false)
+  , useAsymptoticDistribution_(ResourceMap::GetAsBool("SobolIndicesAlgorithm-DefaultUseAsymptoticDistribution"))
 {
   if (outputDesign.getSize() == 0)
     throw InvalidArgumentException(HERE) << "In SobolIndicesAlgorithmImplementation::SobolIndicesAlgorithmImplementation, output design is empty" ;
@@ -115,21 +121,32 @@ SobolIndicesAlgorithmImplementation::SobolIndicesAlgorithmImplementation(const D
   , mergedFirstOrderIndices_()
   , mergedTotalOrderIndices_()
   , secondOrderIndices_()
-  , firstOrderIndiceInterval_()
-  , totalOrderIndiceInterval_()
+  , firstOrderIndiceDistribution_()
+  , totalOrderIndiceDistribution_()
+  , alreadyComputedIndicesDistribution_(false)
+  , useAsymptoticDistribution_(ResourceMap::GetAsBool("SobolIndicesAlgorithm-DefaultUseAsymptoticDistribution"))
 {
   const UnsignedInteger inputDimension = model.getInputDimension();
   if (inputDimension != distribution.getDimension())
     throw InvalidArgumentException(HERE) << "In SobolIndicesAlgorithmImplementation::SobolIndicesAlgorithmImplementation, incompatible dimension between model and distribution. distribution dimension=" << distribution.getDimension()
                                          << ", model input dimension = " << inputDimension;
-  inputDesign_ = Generate(distribution, size, computeSecondOrder);
+  const SobolIndicesExperiment sobolExperiment(distribution, size, computeSecondOrder);
+  inputDesign_ = sobolExperiment.generate();
   outputDesign_ = model(inputDesign_);
 
+  if (computeSecondOrder && (inputDimension == 2))
+  {
+    // Special case: the experiment does not contain the C=[E_2, E_1] sample
+    Sample E1(outputDesign_, size * 2, size * 3);
+    Sample E2(outputDesign_, size * 3, size * 4);
+    outputDesign_.add(E2);
+    outputDesign_.add(E1);
+  }
+
   // center Y
   Point muY(outputDesign_.computeMean());
   outputDesign_ -= muY;
 
-  size_ = size;
   // Reference sample and its variance
   Sample outReference(size, outputDesign_.getDimension());
   for (UnsignedInteger k = 0; k < size_; ++k) outReference[k] = outputDesign_[k];
@@ -143,7 +160,7 @@ SobolIndicesAlgorithmImplementation::SobolIndicesAlgorithmImplementation(const W
   : PersistentObject()
   , inputDesign_()
   , outputDesign_()
-  , size_()
+  , size_(experiment.getSize())
   , bootstrapSize_(ResourceMap::GetAsUnsignedInteger("SobolIndicesAlgorithm-DefaultBootstrapSize"))
   , confidenceLevel_(ResourceMap::GetAsScalar("SobolIndicesAlgorithm-DefaultBootstrapConfidenceLevel"))
   , referenceVariance_()
@@ -152,43 +169,29 @@ SobolIndicesAlgorithmImplementation::SobolIndicesAlgorithmImplementation(const W
   , mergedFirstOrderIndices_()
   , mergedTotalOrderIndices_()
   , secondOrderIndices_()
-  , firstOrderIndiceInterval_()
-  , totalOrderIndiceInterval_()
+  , firstOrderIndiceDistribution_()
+  , totalOrderIndiceDistribution_()
+  , alreadyComputedIndicesDistribution_(false)
+  , useAsymptoticDistribution_(ResourceMap::GetAsBool("SobolIndicesAlgorithm-DefaultUseAsymptoticDistribution"))
 {
   const UnsignedInteger inputDimension = model.getInputDimension();
   if (inputDimension != experiment.getDistribution().getDimension())
     throw InvalidArgumentException(HERE) << "In SobolIndicesAlgorithmImplementation::SobolIndicesAlgorithmImplementation, incompatible dimension between model and distribution. Experiment dimension=" << experiment.getDistribution().getDimension()
                                          << ", model input dimension = " << inputDimension;
-  inputDesign_ = Generate(experiment, computeSecondOrder);
+  const SobolIndicesExperiment sobolExperiment(experiment, computeSecondOrder);
+  inputDesign_ = sobolExperiment.generate();
   outputDesign_ = model(inputDesign_);
 
   // center Y
   Point muY(outputDesign_.computeMean());
   outputDesign_ -= muY;
 
-  size_ = experiment.getSize();
   // Reference sample and its variance
   Sample outReference(size_, outputDesign_.getDimension());
   for (UnsignedInteger k = 0; k < size_; ++k) outReference[k] = outputDesign_[k];
   referenceVariance_ = outReference.computeVariance();
 }
 
-Sample SobolIndicesAlgorithmImplementation::Generate(const Distribution & distribution,
-    const UnsignedInteger size,
-    const Bool computeSecondOrder)
-{
-  Log::Warn(OSS() << "SobolIndicesAlgorithm::Generate is deprecated: use SobolIndicesExperiment");
-  SobolIndicesExperiment sobolExperiment(distribution, size, computeSecondOrder);
-  return sobolExperiment.generate();
-}
-
-Sample SobolIndicesAlgorithmImplementation::Generate(const WeightedExperiment & experiment,
-    const Bool computeSecondOrder)
-{
-  Log::Warn(OSS() << "SobolIndicesAlgorithm::Generate is deprecated: use SobolIndicesExperiment");
-  SobolIndicesExperiment sobolExperiment(experiment, computeSecondOrder);
-  return sobolExperiment.generate();
-}
 
 /* First order indices accessor */
 Point SobolIndicesAlgorithmImplementation::getFirstOrderIndices(const UnsignedInteger marginalIndex) const
@@ -265,17 +268,12 @@ struct BootstrapPolicy
 }; /* end struct BootstrapPolicy */
 
 /** void method that computes confidence interval */
-void SobolIndicesAlgorithmImplementation::computeIndicesInterval() const
+void SobolIndicesAlgorithmImplementation::computeBootstrapDistribution() const
 {
-  if (0 != totalOrderIndiceInterval_.getDimension()) return;
-
   // Build interval using sample variance
   // Mean reference is the Sensitivity values
   const Point aggregatedFirstOrder(getAggregatedFirstOrderIndices());
   const Point aggregatedTotalOrder(getAggregatedTotalOrderIndices());
-  // Compute confidence interval
-  firstOrderIndiceInterval_ = Interval(aggregatedFirstOrder, aggregatedFirstOrder);
-  totalOrderIndiceInterval_ = Interval(aggregatedTotalOrder, aggregatedTotalOrder);
   if (bootstrapSize_ > 0)
   {
     // Temporary samples that stores the first/total indices
@@ -308,41 +306,57 @@ void SobolIndicesAlgorithmImplementation::computeIndicesInterval() const
       bsTO.add(bsTOpartial);
     }
 
-    // Confidence interval elements
-    // Sample of indices
-    const Scalar lowerQuantileLevel = 0.5 * (1.0 - confidenceLevel_);
-    const Scalar upperQuantileLevel = 0.5 * (1.0 + confidenceLevel_);
-    // Compute empirical quantiles
-    // 1) First order indices
-    const Point lowerQuantileFO(bsFO.computeQuantilePerComponent(lowerQuantileLevel));
-    const Point upperQuantileFO(bsFO.computeQuantilePerComponent(upperQuantileLevel));
-    LOGINFO(OSS() << "First Order from Bootstrap sample:  lowerQuantile=" << lowerQuantileFO << ", upperQuantile=" << upperQuantileFO );
-    // 2) Total order indices
-    const Point lowerQuantileTO(bsTO.computeQuantilePerComponent(lowerQuantileLevel));
-    const Point upperQuantileTO(bsTO.computeQuantilePerComponent(upperQuantileLevel));
-    LOGINFO(OSS() << "Total Order from Bootstrap sample:  lowerQuantile=" << lowerQuantileTO << ", upperQuantile=" << upperQuantileTO );
-
-    // First order interval
-    const Point firstOrderLowerBound(aggregatedFirstOrder * 2.0 - upperQuantileFO);
-    const Point firstOrderUpperBound(aggregatedFirstOrder * 2.0 - lowerQuantileFO);
-    // Total order interval
-    const Point totalOrderLowerBound(aggregatedTotalOrder * 2.0 - upperQuantileTO);
-    const Point totalOrderUpperBound(aggregatedTotalOrder * 2.0 - lowerQuantileTO);
-
-    // Compute confidence interval
-    firstOrderIndiceInterval_ = Interval(firstOrderLowerBound, firstOrderUpperBound);
-    totalOrderIndiceInterval_ = Interval(totalOrderLowerBound, totalOrderUpperBound);
-    LOGINFO(OSS() << "First order interval Bootstrap with Basic method=" );
-    LOGINFO(OSS() << "Total Order from Bootstrap sample:  lowerQuantile=" << lowerQuantileTO << ", upperQuantile=" << upperQuantileTO );
+    KernelSmoothing factory;
+    firstOrderIndiceDistribution_ = factory.build(bsFO);
+    totalOrderIndiceDistribution_ = factory.build(bsTO);
   }
 }
 
+
+void SobolIndicesAlgorithmImplementation::computeAsymptoticDistribution() const
+{
+  throw NotYetImplementedException(HERE) << "SobolIndicesAlgorithmImplementation::computeAsymptoticInterval";
+}
+
+
+Scalar SobolIndicesAlgorithmImplementation::computeVariance(const Sample & u, const Function & psi) const
+{
+  Point gradient(*psi.gradient(u.computeMean()).getImplementation());
+  return dot(gradient, u.computeCovariance() * gradient) / size_;
+}
+
+void SobolIndicesAlgorithmImplementation::setConfidenceInterval(const Point & varianceFO,
+    const Point & varianceTO) const
+{
+  const UnsignedInteger inputDimension = inputDesign_.getDimension();
+  Point stdandardDeviationFO(inputDimension);
+  Point stdandardDeviationTO(inputDimension);
+  for (UnsignedInteger p = 0; p < inputDimension; ++ p)
+  {
+    stdandardDeviationFO[p] = sqrt(varianceFO[p]);
+    stdandardDeviationTO[p] = sqrt(varianceTO[p]);
+  }
+  const Point aggregatedFO(getAggregatedFirstOrderIndices());
+  const Point aggregatedTO(getAggregatedTotalOrderIndices());
+  firstOrderIndiceDistribution_ = Normal(aggregatedFO, stdandardDeviationFO, CorrelationMatrix(inputDimension));
+  totalOrderIndiceDistribution_ = Normal(aggregatedTO, stdandardDeviationTO, CorrelationMatrix(inputDimension));
+}
+
+
 /* Interval for the first order indices accessor */
 Interval SobolIndicesAlgorithmImplementation::getFirstOrderIndicesInterval() const
 {
-  // Interval evaluation using Bootstrap
-  computeIndicesInterval();
-  return firstOrderIndiceInterval_;
+  const Distribution distribution = getFirstOrderIndicesDistribution();
+  const UnsignedInteger inputDimension = distribution.getDimension();
+  Point lowerBound(inputDimension);
+  Point upperBound(inputDimension);
+  for (UnsignedInteger j = 0; j < inputDimension; ++ j)
+  {
+    Distribution marginal(distribution.getMarginal(j));
+    lowerBound[j] = marginal.computeQuantile(0.5 * (1.0 - confidenceLevel_))[0];
+    upperBound[j] = marginal.computeQuantile(0.5 * (1.0 + confidenceLevel_))[0];
+  }
+  return Interval(lowerBound, upperBound);
 }
 
 /* Second order indices accessor */
@@ -411,9 +425,47 @@ Point SobolIndicesAlgorithmImplementation::getTotalOrderIndices(const UnsignedIn
 /* Interval for the total order indices accessor */
 Interval SobolIndicesAlgorithmImplementation::getTotalOrderIndicesInterval() const
 {
-  // Interval evaluation using Bootstrap
-  computeIndicesInterval();
-  return totalOrderIndiceInterval_;
+  const Distribution distribution = getTotalOrderIndicesDistribution();
+  const UnsignedInteger inputDimension = distribution.getDimension();
+  Point lowerBound(inputDimension);
+  Point upperBound(inputDimension);
+  for (UnsignedInteger j = 0; j < inputDimension; ++ j)
+  {
+    Distribution marginal(distribution.getMarginal(j));
+    lowerBound[j] = marginal.computeQuantile(0.5 * (1.0 - confidenceLevel_))[0];
+    upperBound[j] = marginal.computeQuantile(0.5 * (1.0 + confidenceLevel_))[0];
+  }
+  return Interval(lowerBound, upperBound);
+}
+
+void SobolIndicesAlgorithmImplementation::computeIndicesDistribution() const
+{
+  // if not already computed
+  if (!alreadyComputedIndicesDistribution_)
+  {
+    if (useAsymptoticDistribution_)
+    {
+      computeAsymptoticDistribution();
+    }
+    else
+    {
+      computeBootstrapDistribution();
+    }
+    alreadyComputedIndicesDistribution_ = true;
+  }
+}
+
+
+Distribution SobolIndicesAlgorithmImplementation::getFirstOrderIndicesDistribution() const
+{
+  computeIndicesDistribution();
+  return firstOrderIndiceDistribution_;
+}
+
+Distribution SobolIndicesAlgorithmImplementation::getTotalOrderIndicesDistribution() const
+{
+  computeIndicesDistribution();
+  return totalOrderIndiceDistribution_;
 }
 
 /* Aggregated first order indices accessor for multivariate samples */
@@ -459,27 +511,37 @@ UnsignedInteger SobolIndicesAlgorithmImplementation::getBootstrapSize() const
 // Setter for bootstrap size
 void SobolIndicesAlgorithmImplementation::setBootstrapSize(const UnsignedInteger bootstrapSize)
 {
-  if (bootstrapSize <= 0.0)
+  if (bootstrapSize <= 0)
     throw InvalidArgumentException(HERE) << "Bootstrap sampling size should be positive. Here, bootstrapSize=" << bootstrapSize;
   bootstrapSize_ = bootstrapSize;
-  firstOrderIndiceInterval_ = Interval();
-  totalOrderIndiceInterval_ = Interval();
 }
 
 // Getter for bootstrap confidence level
-Scalar SobolIndicesAlgorithmImplementation::getBootstrapConfidenceLevel() const
+Scalar SobolIndicesAlgorithmImplementation::getConfidenceLevel() const
 {
   return confidenceLevel_;
 }
 
 // Setter for bootstrap confidence level
-void SobolIndicesAlgorithmImplementation::setBootstrapConfidenceLevel(const Scalar confidenceLevel)
+void SobolIndicesAlgorithmImplementation::setConfidenceLevel(const Scalar confidenceLevel)
 {
   if ((confidenceLevel < 0.0) || (confidenceLevel >= 1.0))
     throw InvalidArgumentException(HERE) << "Confidence level value should be in ]0,1[. Here, confidence level=" << confidenceLevel;
   confidenceLevel_ = confidenceLevel;
-  firstOrderIndiceInterval_ = Interval();
-  totalOrderIndiceInterval_ = Interval();
+}
+
+// Getter for bootstrap confidence level
+Scalar SobolIndicesAlgorithmImplementation::getBootstrapConfidenceLevel() const
+{
+  LOGWARN("SobolIndicesAlgorithm::getBootstrapConfidenceLevel is deprecated, use getConfidenceLevel.");
+  return getConfidenceLevel();
+}
+
+// Setter for bootstrap confidence level
+void SobolIndicesAlgorithmImplementation::setBootstrapConfidenceLevel(const Scalar confidenceLevel)
+{
+  LOGWARN("SobolIndicesAlgorithm::setBootstrapConfidenceLevel is deprecated, use setConfidenceLevel.");
+  setConfidenceLevel(confidenceLevel);
 }
 
 /* String converter */
@@ -533,6 +595,19 @@ Point SobolIndicesAlgorithmImplementation::computeSumDotSamples(const Sample & s
   return value;
 }
 
+/* Multiplication of two sub-samples */
+Sample SobolIndicesAlgorithmImplementation::ComputeProdSample(const Sample & sample,
+    const UnsignedInteger marginalIndex,
+    const UnsignedInteger size,
+    const UnsignedInteger indexX,
+    const UnsignedInteger indexY)
+{
+  Sample prod(size, 1);
+  for (UnsignedInteger i = 0; i < size; ++ i)
+    prod(i, 0) = sample(i + indexX, marginalIndex) * sample(i + indexY, marginalIndex);
+  return prod;
+}
+
 /* String converter */
 String SobolIndicesAlgorithmImplementation::__str__(const String & offset) const
 {
@@ -627,8 +702,8 @@ Graph SobolIndicesAlgorithmImplementation::draw(UnsignedInteger marginalIndex) c
   Sample data(foIndices.getDimension(), 2);
   for (UnsignedInteger k = 0; k < foIndices.getDimension(); ++k)
   {
-    data[k][0] = k + 1;
-    data[k][1] = foIndices[k];
+    data(k, 0) = k + 1;
+    data(k, 1) = foIndices[k];
   }
   // Define cloud for FO
   Cloud firstOrderIndicesGraph(data, "red", "circle", "Aggregated FO");
@@ -636,8 +711,8 @@ Graph SobolIndicesAlgorithmImplementation::draw(UnsignedInteger marginalIndex) c
   // Total order
   for (UnsignedInteger k = 0; k < foIndices.getDimension(); ++k)
   {
-    data[k][0] = (k + 1) + 0.1;
-    data[k][1] = toIndices[k];
+    data(k, 0) = (k + 1) + 0.1;
+    data(k, 1) = toIndices[k];
   }
   // Define cloud for TO
   Cloud totalOrderIndicesGraph(data, "blue", "square", "Aggregated TO");
@@ -662,9 +737,9 @@ Sample SobolIndicesAlgorithmImplementation::getBootstrapDesign(const Indices & i
   for (UnsignedInteger p = 0; p < 2 + inputDimension; ++p)
   {
     Sample y(size_, outputDimension);
-    Scalar* yPermData = &y[0][0];
+    Scalar* yPermData = &y(0, 0);
 
-    const Scalar* yData = &outputDesign_[p * size_][0];
+    const Scalar* yData = &outputDesign_(p * size_, 0);
     for (UnsignedInteger k = 0; k < size_; ++k, yPermData += outputDimension)
       memcpy(yPermData, &yData[indices[k] * outputDimension], outputDimension * sizeof(Scalar));
     // add samples to the collection
@@ -749,6 +824,19 @@ Graph SobolIndicesAlgorithmImplementation::DrawImportanceFactors(const Point & v
   return importanceFactorsGraph;
 }
 
+void SobolIndicesAlgorithmImplementation::setUseAsymptoticDistribution(Bool useAsymptoticDistribution)
+{
+  if (useAsymptoticDistribution_ != useAsymptoticDistribution)
+  {
+    useAsymptoticDistribution_ = useAsymptoticDistribution;
+    alreadyComputedIndicesDistribution_ = false;
+  }
+}
+
+Bool SobolIndicesAlgorithmImplementation::getUseAsymptoticDistribution() const
+{
+  return useAsymptoticDistribution_;
+}
 
 /* Method save() stores the object through the StorageManager */
 void SobolIndicesAlgorithmImplementation::save(Advocate & adv) const
@@ -765,8 +853,10 @@ void SobolIndicesAlgorithmImplementation::save(Advocate & adv) const
   adv.saveAttribute( "mergedFirstOrderIndices_", mergedFirstOrderIndices_);
   adv.saveAttribute( "mergedTotalOrderIndices_", mergedTotalOrderIndices_);
   adv.saveAttribute( "secondOrderIndices_", secondOrderIndices_);
-  adv.saveAttribute( "firstOrderIndiceInterval_", firstOrderIndiceInterval_);
-  adv.saveAttribute( "totalOrderIndiceInterval_", totalOrderIndiceInterval_);
+  adv.saveAttribute( "firstOrderIndiceDistribution_", firstOrderIndiceDistribution_);
+  adv.saveAttribute( "totalOrderIndiceDistribution_", totalOrderIndiceDistribution_);
+  adv.saveAttribute( "alreadyComputedIndicesDistribution_", alreadyComputedIndicesDistribution_);
+  adv.saveAttribute( "useAsymptoticDistribution_" , useAsymptoticDistribution_);
 }
 
 /* Method load() reloads the object from the StorageManager */
@@ -784,8 +874,10 @@ void SobolIndicesAlgorithmImplementation::load(Advocate & adv)
   adv.loadAttribute( "mergedFirstOrderIndices_", mergedFirstOrderIndices_);
   adv.loadAttribute( "mergedTotalOrderIndices_", mergedTotalOrderIndices_);
   adv.loadAttribute( "secondOrderIndices_", secondOrderIndices_);
-  adv.loadAttribute( "firstOrderIndiceInterval_", firstOrderIndiceInterval_);
-  adv.loadAttribute( "totalOrderIndiceInterval_", totalOrderIndiceInterval_);
+  adv.loadAttribute( "firstOrderIndiceDistribution_", firstOrderIndiceDistribution_);
+  adv.loadAttribute( "totalOrderIndiceDistribution_", totalOrderIndiceDistribution_);
+  adv.loadAttribute( "alreadyComputedIndicesDistribution_", alreadyComputedIndicesDistribution_);
+  adv.loadAttribute( "useAsymptoticDistribution_" , useAsymptoticDistribution_);
 }
 
 END_NAMESPACE_OPENTURNS
