@@ -3,7 +3,7 @@
  *  @brief PostAnalyticalSimulation is a generic view of postAnalyticalSimulation methods for computing
  * probabilities and related quantities by sampling and estimation
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,7 +15,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -46,7 +46,7 @@ PostAnalyticalSimulation::PostAnalyticalSimulation(const AnalyticalResult & anal
   : Simulation(analyticalResult.getLimitStateVariable())
   , analyticalResult_(analyticalResult)
   , standardEvent_(StandardEvent(getEvent()))
-  , standardDistribution_(standardEvent_.getImplementation()->getAntecedent()->getDistribution())
+  , standardDistribution_(standardEvent_.getImplementation()->getAntecedent().getDistribution())
 {
   // Compute the probability associated to the analytical result
   controlProbability_ = standardDistribution_.getMarginal(0).computeCDF(-analyticalResult.getHasoferReliabilityIndex());
@@ -87,7 +87,7 @@ void PostAnalyticalSimulation::load(Advocate & adv)
   Simulation::load(adv);
   adv.loadAttribute("analyticalResult_", analyticalResult_);
   standardEvent_ = StandardEvent(getEvent());
-  standardDistribution_ = standardEvent_.getImplementation()->getAntecedent()->getDistribution();
+  standardDistribution_ = standardEvent_.getImplementation()->getAntecedent().getDistribution();
   controlProbability_ = standardDistribution_.getMarginal(0).computeCDF(-analyticalResult_.getHasoferReliabilityIndex());
 }
 
