@@ -2,7 +2,7 @@
 /**
  *  @brief Implementation of SimulationResult
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,13 +14,14 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 #include "openturns/SimulationSensitivityAnalysis.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/Exception.hxx"
+#include "openturns/MemoizeFunction.hxx"
 #include "openturns/SobolIndicesAlgorithmImplementation.hxx"
 #include "openturns/Curve.hxx"
 #include "openturns/Collection.hxx"
@@ -94,16 +95,15 @@ SimulationSensitivityAnalysis::SimulationSensitivityAnalysis(const Event & event
   // Inspect the event to see if it is a composite random vector based event
   if (!event.isComposite()) throw InvalidArgumentException(HERE) << "Error: cannot perform a sensitivity analysis based on the given event. Check if it is based on a composite random vector.";
   // Get the input/output sample from the model
-  Function model(event.getFunction());
-  if (!model.isHistoryEnabled()) throw InvalidArgumentException(HERE) << "Error: cannot perform analysis if the history of the underlying model is disabled.";
-  inputSample_  = model.getHistoryInput().getSample();
+  MemoizeFunction model(event.getFunction());
+  inputSample_  = model.getInputHistory();
   // Check if the samples are not empty
   if (inputSample_.getSize() == 0) throw InvalidArgumentException(HERE) << "Error: cannot perform analysis based on empty samples.";
   // We are sure that the output sample has the same size as the input sample
-  outputSample_ = model.getHistoryOutput().getSample();
+  outputSample_ = model.getOutputHistory();
   // Get the transformation from the input distribution
-  transformation_ = event.getImplementation()->getAntecedent()->getDistribution().getIsoProbabilisticTransformation();
-  inputSample_.setDescription(event.getImplementation()->getAntecedent()->getDistribution().getDescription());
+  transformation_ = event.getImplementation()->getAntecedent().getDistribution().getIsoProbabilisticTransformation();
+  inputSample_.setDescription(event.getImplementation()->getAntecedent().getDistribution().getDescription());
   // Get the comparison operator
   comparisonOperator_ = event.getOperator();
   // Get the threshold
@@ -123,7 +123,7 @@ Point SimulationSensitivityAnalysis::computeMeanPointInEventDomain(const Scalar
   Sample filteredSample(0, inputSample_.getDimension());
   // Filter the input points with respect to the considered event
   for (UnsignedInteger i = 0; i < inputSize; ++i)
-    if (comparisonOperator_(outputSample_[i][0], threshold)) filteredSample.add(inputSample_[i]);
+    if (comparisonOperator_(outputSample_(i, 0), threshold)) filteredSample.add(inputSample_[i]);
   if (filteredSample.getSize() == 0) throw NotDefinedException(HERE) << "Error: cannont compute the mean point if no point is in the event domain.";
   return filteredSample.computeMean();
 }
@@ -203,9 +203,9 @@ Graph SimulationSensitivityAnalysis::drawImportanceFactorsRange(const Bool proba
   UnsignedInteger good = 0;
   for (UnsignedInteger i = 0; i < size; ++i)
   {
-    for (UnsignedInteger j = 0; j < inputDimension; ++j) mergedSample[i][j] = inputSample_[i][j];
-    mergedSample[i][inputDimension] = outputSample_[i][0];
-    good += comparisonOperator_(outputSample_[i][0], threshold_);
+    for (UnsignedInteger j = 0; j < inputDimension; ++j) mergedSample(i, j) = inputSample_(i, j);
+    mergedSample[i][inputDimension] = outputSample_(i, 0);
+    good += comparisonOperator_(outputSample_(i, 0), threshold_);
   }
   if ((good < sampleMargin) || (good >= size - sampleMargin)) LOGWARN(OSS() << "Warning: the default threshold does not correspond to well-estimated importance factors according to the default sample margin. The number of points defining the event is " << good << " and should be in [" << sampleMargin << ", " << size - sampleMargin - 1 << "] according to the SimulationSensitivityAnalysis-DefaulSampleMargin key value in ResourceMap.");
   // Sort the merged sample according to its last component
@@ -315,10 +315,10 @@ Graph SimulationSensitivityAnalysis::drawImportanceFactorsRange(const Bool proba
   if ((internalX >= lower) && (internalX <= upper) && (good >= sampleMargin) && (good < size - sampleMargin))
   {
     Sample data(2, 2);
-    data[0][0] = internalX;
-    data[0][1] = 0.0;
-    data[1][0] = internalX;
-    data[1][1] = 100.0;
+    data(0, 0) = internalX;
+    data(0, 1) = 0.0;
+    data(1, 0) = internalX;
+    data(1, 1) = 100.0;
     Curve curve(data);
     curve.setLineStyle("dashed");
     curve.setLineWidth(2);
