@@ -1,10 +1,9 @@
 //                                               -*- C++ -*-
 /**
- *  @file  Wilks.cxx
  *  @brief Wilks is a generic view of Wilks methods for computing
  * probabilities and related quantities by sampling and estimation
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -16,18 +15,16 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
 #include <cmath>
-#include "Wilks.hxx"
-#include "Exception.hxx"
-#include "NumericalSample.hxx"
-#include "DistFunc.hxx"
-#include "SpecFunc.hxx"
+#include "openturns/Wilks.hxx"
+#include "openturns/Exception.hxx"
+#include "openturns/Sample.hxx"
+#include "openturns/DistFunc.hxx"
+#include "openturns/SpecFunc.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -40,7 +37,8 @@ BEGIN_NAMESPACE_OPENTURNS
 
 /* Constructor */
 Wilks::Wilks(const RandomVector & vector)
-  : vector_()
+  : Object()
+  , vector_()
 {
   // Check if the given vector is 1D as no theory has been made so far (2011) to define a quantile in higher dimension
   if (vector.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given vector must be 1D.";
@@ -48,23 +46,23 @@ Wilks::Wilks(const RandomVector & vector)
 }
 
 /* Sample size computation */
-UnsignedInteger Wilks::ComputeSampleSize(const NumericalScalar quantileLevel,
-    const NumericalScalar confidenceLevel,
+UnsignedInteger Wilks::ComputeSampleSize(const Scalar quantileLevel,
+    const Scalar confidenceLevel,
     const UnsignedInteger marginIndex)
 {
   if ((quantileLevel <= 0.0) || (quantileLevel >= 1.0)) throw InvalidArgumentException(HERE) << "Error: quantile level must be in ]0, 1[, here quantile level=" << quantileLevel;
   if ((confidenceLevel <= 0.0) || (confidenceLevel >= 1.0)) throw InvalidArgumentException(HERE) << "Error: confidence level must be in ]0, 1[, here confidence level=" << confidenceLevel;
   // Initial guess based on asymptotic normality of the empirical quantile
-  NumericalScalar x(DistFunc::qNormal(confidenceLevel));
-  NumericalScalar x2(x * x);
-  UnsignedInteger n((UnsignedInteger)(ceil((quantileLevel * x2 + 2.0 * marginIndex + sqrt(quantileLevel * x2 * (quantileLevel * x2 + 4.0 * marginIndex))) / (2.0 * (1.0 - quantileLevel)))));
+  Scalar x = DistFunc::qNormal(confidenceLevel);
+  Scalar x2 = x * x;
+  UnsignedInteger n = (UnsignedInteger)(ceil((quantileLevel * x2 + 2.0 * marginIndex + sqrt(quantileLevel * x2 * (quantileLevel * x2 + 4.0 * marginIndex))) / (2.0 * (1.0 - quantileLevel))));
   // Initialize cQuantileLevel to cQuantileLevel[i] = Binomial(n, n - marginIndex + i) * quantileLevel ^ (n - marginIndex + i) * (1 - quantileLevel) ^ (marginIndex - i)
   // For i = marginIndex, cQuantileLevel[i] = quantileLevel ^ n
-  NumericalPoint cQuantileLevel(marginIndex + 1, pow(quantileLevel, static_cast<int>(n)));
+  Point cQuantileLevel(marginIndex + 1, pow(quantileLevel, static_cast<int>(n)));
   // Descending recursion n! / (m - i)! / (n - m + i)! = n! / (m - (i - 1))! / (n - m + (i - 1))! * (m - (i - 1)) / (n - m + i)
   // -> Binomial(n, n - m + i - 1) = Binomial(n, n - m + i) * (n - m + i) / (m - i)
   for (UnsignedInteger i = marginIndex; i > 0; --i) cQuantileLevel[i - 1] = cQuantileLevel[i] * (1.0 - quantileLevel) / quantileLevel * (n - marginIndex + i) / (marginIndex - i + 1.0);
-  NumericalScalar cumulQuantileLevel;
+  Scalar cumulQuantileLevel = -1.0;
   do
   {
     cumulQuantileLevel = 0.0;
@@ -82,14 +80,14 @@ UnsignedInteger Wilks::ComputeSampleSize(const NumericalScalar quantileLevel,
 }
 
 /* Estimate an upper bound of the quantile of the random vector for the given quantile level and confidence level, using the marginIndex upper statistics */
-NumericalPoint Wilks::computeQuantileBound(const NumericalScalar quantileLevel,
-    const NumericalScalar confidenceLevel,
-    const UnsignedInteger marginIndex) const
+Point Wilks::computeQuantileBound(const Scalar quantileLevel,
+                                  const Scalar confidenceLevel,
+                                  const UnsignedInteger marginIndex) const
 {
   // Compute the needed sample size
-  const UnsignedInteger size(ComputeSampleSize(quantileLevel, confidenceLevel, marginIndex));
+  const UnsignedInteger size = ComputeSampleSize(quantileLevel, confidenceLevel, marginIndex);
   // Generate a sorted sample of the needed size
-  const NumericalSample sample(vector_.getSample(size).sort());
+  const Sample sample(vector_.getSample(size).sort(0));
   // The upper bound is the marginIndex upper statistics
   return sample[size - 1 - marginIndex];
 }
