@@ -2,7 +2,7 @@
 /**
  *  @brief Class for the Nataf transformation evaluation for elliptical
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -316,16 +316,12 @@ Point MarginalTransformationEvaluation::operator () (const Point & inP) const
       if (upperTail) inputCDF = inputDistributionCollection_[i].computeComplementaryCDF(inP[i]);
       // The upper tail CDF is defined by CDF(x, upper) = P(X>x)
       // The upper tail quantile is defined by Quantile(CDF(x, upper), upper) = x
-      const Scalar q = outputDistributionCollection_[i].computeQuantile(inputCDF, upperTail)[0];
+      // Avoid to create useless Point
+      const Scalar q = outputDistributionCollection_[i].getImplementation()->computeScalarQuantile(inputCDF, upperTail);
       result[i] = q;
     }
   }
-  ++callsNumber_;
-  if (isHistoryEnabled_)
-  {
-    inputStrategy_.store(inP);
-    outputStrategy_.store(result);
-  }
+  callsNumber_.increment();
   return result;
 }
 
@@ -386,6 +382,8 @@ Matrix MarginalTransformationEvaluation::parameterGradient(const Point & inP) co
           const Point x(1, inP[j]);
           const Distribution inputMarginal(inputDistributionCollection_[j]);
           const Distribution outputMarginal(outputDistributionCollection_[j]);
+          // Here it is useless to call computeScalarQuantile() as the result will
+          // be promoted into a Point in computePDF()
           const Scalar denominator = outputMarginal.computePDF(outputMarginal.computeQuantile(inputMarginal.computeCDF(x)));
           if (denominator > 0.0)
           {
@@ -409,6 +407,8 @@ Matrix MarginalTransformationEvaluation::parameterGradient(const Point & inP) co
           const Point x(1, inP[j]);
           const Distribution inputMarginal(inputDistributionCollection_[j]);
           const Distribution outputMarginal(outputDistributionCollection_[j]);
+          // Here it is useless to call computeScalarQuantile() as the result will
+          // be promoted into a Point in computePDF()
           const Point q(outputMarginal.computeQuantile(inputMarginal.computeCDF(x)));
           const Scalar denominator = outputMarginal.computePDF(q);
           if (denominator > 0.0)
@@ -602,7 +602,7 @@ String MarginalTransformationEvaluation::__str__(const String & offset) const
   {
     oss << offset;
     if (inputDistributionCollection_.getSize() > 1) oss << "| " << std::setw(length) << outputDescription[i] << " = ";
-    if (simplifications_[i]) oss << expressions_[i].getEvaluation()->__str__() << "\n";
+    if (simplifications_[i]) oss << expressions_[i].getEvaluation().__str__() << "\n";
     else oss << inputDistributionCollection_[i] << " -> " << outputDescription[i] << " : " << outputDistributionCollection_[i] << "\n";
   }
   return oss;
