@@ -2,7 +2,7 @@
 /**
  *  @brief Class for the InverseNataf transformation evaluation for independent
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,12 +14,13 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 #include "openturns/InverseNatafIndependentCopulaEvaluation.hxx"
 #include "openturns/DistFunc.hxx"
+#include "openturns/PersistentObjectFactory.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -32,6 +33,8 @@ BEGIN_NAMESPACE_OPENTURNS
 
 CLASSNAMEINIT(InverseNatafIndependentCopulaEvaluation)
 
+static const Factory<InverseNatafIndependentCopulaEvaluation> Factory_InverseNatafIndependentCopulaEvaluation;
+
 /* Parameter constructor */
 InverseNatafIndependentCopulaEvaluation::InverseNatafIndependentCopulaEvaluation(const UnsignedInteger dimension)
   : EvaluationImplementation()
@@ -77,12 +80,7 @@ Point InverseNatafIndependentCopulaEvaluation::operator () (const Point & inP) c
 {
   Point result(dimension_);
   for (UnsignedInteger i = 0; i < dimension_; ++i) result[i] = DistFunc::pNormal(inP[i]);
-  ++callsNumber_;
-  if (isHistoryEnabled_)
-  {
-    inputStrategy_.store(inP);
-    outputStrategy_.store(result);
-  }
+  callsNumber_.increment();
   return result;
 }
 
