@@ -2,7 +2,7 @@
 /**
  *  @brief Class for the Nataf transformation evaluation for independent
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -38,7 +38,7 @@ static const Factory<NatafIndependentCopulaEvaluation> Factory_NatafIndependentC
 /* Default constructor */
 NatafIndependentCopulaEvaluation::NatafIndependentCopulaEvaluation()
   : EvaluationImplementation()
-  , dimension_()
+  , dimension_(1)
 {
   // Nothing to do
 }
@@ -93,12 +93,7 @@ Point NatafIndependentCopulaEvaluation::operator () (const Point & inP) const
     if ((x < 0.0) || (x > 1.0)) throw InvalidArgumentException(HERE) << "Error: cannot evaluate the NatafIndependentCopulaEvaluation if all the components are not in [0, 1], here in=" << inP;
     result[i] = DistFunc::qNormal(x);
   }
-  ++callsNumber_;
-  if (isHistoryEnabled_)
-  {
-    inputStrategy_.store(inP);
-    outputStrategy_.store(result);
-  }
+  callsNumber_.increment();
   return result;
 }
 
