@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level view of an monteCarloExperiment plane
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -34,24 +34,24 @@ static const Factory<LowDiscrepancyExperiment> Factory_LowDiscrepancyExperiment;
 /* Default constructor */
 LowDiscrepancyExperiment::LowDiscrepancyExperiment()
   : WeightedExperimentImplementation()
-  , marginals_(1, distribution_)
   , sequence_(SobolSequence())
   , restart_(true)
   , randomize_(false)
 {
-  // Nothing to do
+  // Build the iso-probabilistic transformation
+  setDistribution(distribution_);
 }
 
 /* Constructor with parameters */
 LowDiscrepancyExperiment::LowDiscrepancyExperiment(const UnsignedInteger size,
     const Bool restart)
   : WeightedExperimentImplementation(size)
-  , marginals_(1, distribution_)
   , sequence_(SobolSequence())
   , restart_(restart)
   , randomize_(false)
 {
-  // Nothing to do
+  // Build the iso-probabilistic transformation
+  setDistribution(distribution_);
 }
 
 /* Constructor with parameters */
@@ -60,7 +60,6 @@ LowDiscrepancyExperiment::LowDiscrepancyExperiment(const LowDiscrepancySequence
     const UnsignedInteger size,
     const Bool restart)
   : WeightedExperimentImplementation(size)
-  , marginals_(0)
   , sequence_(sequence)
   , restart_(restart)
   , randomize_(false)
@@ -76,7 +75,6 @@ LowDiscrepancyExperiment::LowDiscrepancyExperiment(const LowDiscrepancySequence
     const UnsignedInteger size,
     const Bool restart)
   : WeightedExperimentImplementation(size)
-  , marginals_(0)
   , sequence_(sequence)
   , restart_(restart)
   , randomize_(false)
@@ -135,7 +133,7 @@ void LowDiscrepancyExperiment::load(Advocate & adv)
   adv.loadAttribute("sequence_", sequence_);
   adv.loadAttribute("restart_", restart_);
   adv.loadAttribute("randomize_", randomize_);
-  setDistribution(distribution_);// set marginals_
+  setDistribution(distribution_);
 }
 
 /* Distribution accessor */
@@ -143,12 +141,14 @@ void LowDiscrepancyExperiment::setDistribution(const Distribution & distribution
 {
   if (!distribution.hasIndependentCopula()) throw InvalidArgumentException(HERE) << "Error: the LowDiscrepancyExperiment can only be used with distributions having an independent copula.";
   const UnsignedInteger dimension = distribution.getDimension();
-  marginals_ = DistributionCollection(dimension);
+  DistributionCollection marginals(dimension);
   // Get the marginal distributions
-  for (UnsignedInteger i = 0; i < dimension; ++ i) marginals_[i] = distribution.getMarginal(i);
+  for (UnsignedInteger i = 0; i < dimension; ++ i) marginals[i] = distribution.getMarginal(i);
   // restart the low-discrepancy sequence if asked for or mandatory (dimension changed)
   if (restart_ || (dimension != getDistribution().getDimension()))
     sequence_.initialize(dimension);
+  // Build the iso-probabilistic transformation
+  transformation_ = MarginalTransformationEvaluation(marginals, MarginalTransformationEvaluation::TO);
   WeightedExperimentImplementation::setDistribution(distribution);
 }
 
@@ -185,31 +185,27 @@ void LowDiscrepancyExperiment::setRandomize(const Bool randomize)
 /* Sample generation */
 Sample LowDiscrepancyExperiment::generateWithWeights(Point & weights) const
 {
-  // In-place transformation to reduce memory consumption
   Sample sample(sequence_.generate(size_));
   sample.setDescription(distribution_.getDescription());
-  const UnsignedInteger dimension = marginals_.getSize();
+  const UnsignedInteger dimension = distribution_.getDimension();
   Scalar tmp = -1.0;
-  for (UnsignedInteger i = 0; i < size_; ++ i)
+  if (randomize_)
   {
-    for (UnsignedInteger j = 0; j < dimension; ++ j)
+    for (UnsignedInteger i = 0; i < size_; ++ i)
     {
-      Scalar p = sample(i, j);
-      if (randomize_)
+      for (UnsignedInteger j = 0; j < dimension; ++ j)
       {
-        // with a cyclic scrambling of the low discrepancy point as in R. Cranley and T.N.L. Patterson,
-        // "Randomization of number theoretic methods for multiple integration.",
-        // SIAM Journal of Numerical Analysis, 13:904-914, 1976.
+        // with a cyclic scrambling of the low discrepancy point as in
+        // L’Ecuyer P., Lemieux C. (2005) Recent Advances in Randomized Quasi-Monte Carlo Methods. In: Dror M., L’Ecuyer P., Szidarovszky F. (eds) Modeling Uncertainty. International Series in Operations Research & Management Science, vol 46. Springer, Boston, MA
         const Scalar u = RandomGenerator::Generate();
-        p = std::modf(p + u, &tmp);
-      }
-      // use marginal laws to compute quantile from the low-discrepancy value to build the sample
-      sample[i][j] = marginals_[j].computeQuantile(p)[0];
-    }
-  }
+        sample(i, j) = std::modf(sample(i, j) + u, &tmp);
+      } // j
+    } // i
+  } // randomize
+  // In-place transformation to reduce memory consumption
+  sample = transformation_(sample);
   weights = Point(size_, 1.0 / size_);
   return sample;
 }
 
 END_NAMESPACE_OPENTURNS
-
