@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for AliMikhailHaqCopula distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -47,17 +47,17 @@ AliMikhailHaqCopulaFactory * AliMikhailHaqCopulaFactory::clone() const
 
 /* Here is the interface that all derived class must implement */
 
-AliMikhailHaqCopulaFactory::Implementation AliMikhailHaqCopulaFactory::build(const Sample & sample) const
+Distribution AliMikhailHaqCopulaFactory::build(const Sample & sample) const
 {
   return buildAsAliMikhailHaqCopula(sample).clone();
 }
 
-AliMikhailHaqCopulaFactory::Implementation AliMikhailHaqCopulaFactory::build(const Point & parameters) const
+Distribution AliMikhailHaqCopulaFactory::build(const Point & parameters) const
 {
   return buildAsAliMikhailHaqCopula(parameters).clone();
 }
 
-AliMikhailHaqCopulaFactory::Implementation AliMikhailHaqCopulaFactory::build() const
+Distribution AliMikhailHaqCopulaFactory::build() const
 {
   return buildAsAliMikhailHaqCopula().clone();
 }
@@ -120,7 +120,7 @@ AliMikhailHaqCopula AliMikhailHaqCopulaFactory::buildAsAliMikhailHaqCopula(const
     copula.setParameter(parameters);
     return copula;
   }
-  catch (InvalidArgumentException)
+  catch (InvalidArgumentException &)
   {
     throw InvalidArgumentException(HERE) << "Error: cannot build a AliMikhailHaqCopula from the given parameters";
   }
