@@ -2,7 +2,7 @@
 /**
  *  @brief The Arcsine distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -23,6 +23,7 @@
 #include "openturns/RandomGenerator.hxx"
 #include "openturns/SpecFunc.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
+#include "openturns/Distribution.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -222,6 +223,12 @@ Scalar Arcsine::getRoughness() const
   throw NotDefinedException(HERE) << "roughness of Arcsine distribution is not L2-integrable";
 }
 
+/* Compute the entropy of the distribution */
+Scalar Arcsine::computeEntropy() const
+{
+  return std::log(M_PI * (b_ - a_) / 4.0);
+}
+
 /* Compute the mean of the distribution */
 void Arcsine::computeMean() const
 {
@@ -260,9 +267,9 @@ Point Arcsine::getStandardMoment(const UnsignedInteger n) const
 }
 
 /* Get the standard representative in the parametric family, associated with the standard moments */
-Arcsine::Implementation Arcsine::getStandardRepresentative() const
+Distribution Arcsine::getStandardRepresentative() const
 {
-  return Arcsine(-1.0, 1.0).clone();
+  return new Arcsine(-1.0, 1.0);
 }
 
 /* Compute the covariance of the distribution */
