@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for Burr distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -66,7 +66,7 @@ struct BurrFactoryParameterConstraint
     Scalar sumScaledRatio = 0.0;
     for (UnsignedInteger i = 0; i < size; ++i)
     {
-      const Scalar x = sample_[i][0];
+      const Scalar x = sample_(i, 0);
       const Scalar xC = std::pow(x , c);
       const Scalar logX = std::log(x);
       const Scalar ratio = logX / (1.0 + xC);
@@ -89,17 +89,17 @@ struct BurrFactoryParameterConstraint
 
 /* Here is the interface that all derived class must implement */
 
-BurrFactory::Implementation BurrFactory::build(const Sample & sample) const
+Distribution BurrFactory::build(const Sample & sample) const
 {
   return buildAsBurr(sample).clone();
 }
 
-BurrFactory::Implementation BurrFactory::build(const Point & parameters) const
+Distribution BurrFactory::build(const Point & parameters) const
 {
   return buildAsBurr(parameters).clone();
 }
 
-BurrFactory::Implementation BurrFactory::build() const
+Distribution BurrFactory::build() const
 {
   return buildAsBurr().clone();
 }
@@ -133,7 +133,7 @@ Burr BurrFactory::buildAsBurr(const Sample & sample) const
   const Scalar c = solver.solve(f, 0.0, a, b, fA, fB);
   // Corresponding k estimate
   Scalar sumLogXC = 0.0;
-  for (UnsignedInteger i = 0; i < size; ++i) sumLogXC += log1p(std::pow(sample[i][0], c));
+  for (UnsignedInteger i = 0; i < size; ++i) sumLogXC += log1p(std::pow(sample(i, 0), c));
   const Scalar k = size / sumLogXC;
   Burr result(c, k);
   result.setDescription(sample.getDescription());
@@ -148,7 +148,7 @@ Burr BurrFactory::buildAsBurr(const Point & parameters) const
     distribution.setParameter(parameters);
     return distribution;
   }
-  catch (InvalidArgumentException)
+  catch (InvalidArgumentException &)
   {
     throw InvalidArgumentException(HERE) << "Error: cannot build a Burr distribution from the given parameters";
   }
