@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for ChiSquare distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -43,17 +43,17 @@ ChiSquareFactory * ChiSquareFactory::clone() const
 
 /* Here is the interface that all derived class must implement */
 
-ChiSquareFactory::Implementation ChiSquareFactory::build(const Sample & sample) const
+Distribution ChiSquareFactory::build(const Sample & sample) const
 {
   return buildAsChiSquare(sample).clone();
 }
 
-ChiSquareFactory::Implementation ChiSquareFactory::build(const Point & parameters) const
+Distribution ChiSquareFactory::build(const Point & parameters) const
 {
   return buildAsChiSquare(parameters).clone();
 }
 
-ChiSquareFactory::Implementation ChiSquareFactory::build() const
+Distribution ChiSquareFactory::build() const
 {
   return buildAsChiSquare().clone();
 }
@@ -81,7 +81,7 @@ ChiSquare ChiSquareFactory::buildAsChiSquare(const Point & parameters) const
     distribution.setParameter(parameters);
     return distribution;
   }
-  catch (InvalidArgumentException)
+  catch (InvalidArgumentException &)
   {
     throw InvalidArgumentException(HERE) << "Error: cannot build a ChiSquare distribution from the given parameters";
   }
