@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level class for all ComposedCopulas
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -23,13 +23,14 @@
 #include "openturns/ComposedCopula.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/IndependentCopula.hxx"
-#include "openturns/Exception.hxx"
+#include "openturns/MarginalDistribution.hxx"
 #include "openturns/RosenblattEvaluation.hxx"
 #include "openturns/InverseRosenblattEvaluation.hxx"
 #include "openturns/Log.hxx"
 #include "openturns/Normal.hxx"
 #include "openturns/NormalCopula.hxx"
 #include "openturns/SymbolicFunction.hxx"
+#include "openturns/SpecFunc.hxx"
 #include "openturns/ComposedFunction.hxx"
 #include "openturns/AggregatedFunction.hxx"
 
@@ -237,6 +238,32 @@ Scalar ComposedCopula::computePDF(const Point & point) const
   return productPDF;
 }
 
+/* Get the log-PDF of the ComposedCopula */
+Scalar ComposedCopula::computeLogPDF(const Point & point) const
+{
+  /* PDF = PDF_copula1x...xPDF_copula_n */
+  const UnsignedInteger dimension = getDimension();
+  if (isIndependent_) return IndependentCopula(dimension).computePDF(point);
+  if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
+  const UnsignedInteger size = copulaCollection_.getSize();
+  Scalar sumLogPDF = 0.0;
+  UnsignedInteger index = 0;
+  for (UnsignedInteger i = 0; i < size; ++i)
+  {
+    // If one component is outside of the support, the PDF is null
+    if ((point[i] <= 0.0) || (point[i] >= 1.0)) return -SpecFunc::LogMaxScalar;
+    const UnsignedInteger copulaDimension = copulaCollection_[i].getDimension();
+    Point component(copulaDimension);
+    for (UnsignedInteger j = 0; j < copulaDimension; ++j)
+    {
+      component[j] = point[index];
+      ++index;
+    }
+    sumLogPDF += copulaCollection_[i].computeLogPDF(component);
+  }
+  return sumLogPDF;
+}
+
 /* Get the CDF of the ComposedCopula */
 Scalar ComposedCopula::computeCDF(const Point & point) const
 {
@@ -459,15 +486,8 @@ Scalar ComposedCopula::computeConditionalQuantile(const Scalar q, const Point &
 }
 
 /* Get the distribution of the marginal distribution corresponding to indices dimensions
-   Some additional restriction occur for this copula: the indices must be of the form:
-   [i_1^1,...,i_k1^1,i_1^2,...,i_k2^2,...,i_1^n,...,i_kn^n]
-   where:
-   i_1^1,...,i_k1^1 is a subset of {0,...,dim_1-1},
-   i_1^2,...,i_k2^2 is a subset of {0,...,dim_2-1}+dim_1,
-   i_1^n,...,i_kn^n is a subset of {0,...,dim_n-1}+dim_1+...+dim_(n-1),
-   dim_1 = dimension(copula_1) etc.
 */
-ComposedCopula::Implementation ComposedCopula::getMarginal(const Indices & indices) const
+Distribution ComposedCopula::getMarginal(const Indices & indices) const
 {
   const UnsignedInteger dimension = getDimension();
   if (!indices.check(dimension)) throw InvalidArgumentException(HERE) << "Error: the indices of a marginal distribution must be in the range [0, dim-1] and must be different";
@@ -501,8 +521,9 @@ ComposedCopula::Implementation ComposedCopula::getMarginal(const Indices & indic
     if (copulaIndices.getSize() > 0) marginalCopulas.add(copulaCollection_[i].getMarginal(copulaIndices));
     // All the indices have been taken into account
     if (currentPosition == indicesSize) break;
-    // Check if a bad case occurs: one index related to copula i is found after indices related to copula j, with j > i
-    if (currentIndex < lowerIndex) throw InvalidArgumentException(HERE) << "Error: one index related to the ith copula has been found after indices related to the jth copula, with j > i";
+    // non-contiguous dependency blocs case
+    if (currentIndex < lowerIndex)
+      return new MarginalDistribution(*this, indices);
   }
   return new ComposedCopula(marginalCopulas);
 }
@@ -656,6 +677,17 @@ void ComposedCopula::computeCovariance() const
   isAlreadyComputedCovariance_ = true;
 }
 
+/* Compute the entropy of the distribution */
+Scalar ComposedCopula::computeEntropy() const
+{
+  Scalar entropy = 0.0;
+  if (isIndependent_) return entropy;
+  const UnsignedInteger size = copulaCollection_.getSize();
+  for (UnsignedInteger i = 0; i < size; ++i)
+    entropy += copulaCollection_[i].computeEntropy();
+  return entropy;
+}
+
 /* Method save() stores the object through the StorageManager */
 void ComposedCopula::save(Advocate & adv) const
 {
