@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level class for all ComposedDistributions
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -101,7 +101,7 @@ Bool ComposedDistribution::operator ==(const ComposedDistribution & other) const
   if (this == &other) return true;
   // The copula...
   if (!(hasIndependentCopula() && other.hasIndependentCopula())) return false;
-  if (!(copula_ == *other.getCopula())) return false;
+  if (!(copula_ == other.getCopula())) return false;
   // Then the marginals
   for (UnsignedInteger i = 0; i < dimension_; ++i)
   {
@@ -123,12 +123,12 @@ Bool ComposedDistribution::equals(const DistributionImplementation & other) cons
   // We coud go there eg. when comparing a ComposedDistribution([Normal()]*2) with a Normal(2)
   // The copula...
   if (!(hasIndependentCopula() && other.hasIndependentCopula())) return false;
-  if (!(copula_ == *other.getCopula())) return false;
+  if (!(copula_ == other.getCopula())) return false;
   // Then the marginals
   for (UnsignedInteger i = 0; i < dimension_; ++i)
   {
     const Distribution left(distributionCollection_[i]);
-    const Distribution right(*other.getMarginal(i));
+    const Distribution right(other.getMarginal(i));
     if (!(left == right)) return false;
   }
   return true;
@@ -234,9 +234,9 @@ void ComposedDistribution::setCopula(const Distribution & copula)
 
 
 /* Copula accessor */
-ComposedDistribution::Implementation ComposedDistribution::getCopula() const
+Distribution ComposedDistribution::getCopula() const
 {
-  return copula_.getImplementation();
+  return copula_;
 }
 
 /* Virtual constructor */
@@ -283,7 +283,7 @@ struct ComposedDistributionComputeSamplePolicy
   {
     for (UnsignedInteger i = r.begin(); i != r.end(); ++i)
       for (UnsignedInteger j = 0; j < dimension_; ++j)
-        output_[i][j] = distributionCollection_[j].computeQuantile(input_[i][j])[0];
+        output_(i, j) = distributionCollection_[j].computeQuantile(input_(i, j))[0];
   }
 
 }; /* end struct ComposedDistributionComputeSamplePolicy */
@@ -343,9 +343,10 @@ Point ComposedDistribution::computeDDF(const Point & point) const
   Point pdfMarginal(dimension);
   Point ddfMarginal(dimension);
   Scalar productPDF = 1.0;
+  Point component(1);
   for (UnsignedInteger i = 0; i < dimension; ++i)
   {
-    const Point component(Point(1, point[i]));
+    component[0] = point[i];
     uPoint[i] = distributionCollection_[i].computeCDF(component);
     pdfMarginal[i] = distributionCollection_[i].computePDF(component);
     ddfMarginal[i] = distributionCollection_[i].computeDDF(component)[0];
@@ -384,9 +385,10 @@ Scalar ComposedDistribution::computePDF(const Point & point) const
   }
   // General case
   Point uPoint(dimension);
+  Point component(1);
   for (UnsignedInteger i = 0; i < dimension; ++i)
   {
-    const Point component(Point(1, point[i]));
+    component[0] = point[i];
     uPoint[i] = distributionCollection_[i].computeCDF(component);
     productPDF *= distributionCollection_[i].computePDF(component);
   }
@@ -576,6 +578,15 @@ void ComposedDistribution::computeMean() const
   isAlreadyComputedMean_ = true;
 }
 
+/* Compute the entropy of the distribution */
+Scalar ComposedDistribution::computeEntropy() const
+{
+  Scalar entropy = copula_.computeEntropy();
+  for (UnsignedInteger i = 0; i < getDimension(); ++i)
+    entropy += distributionCollection_[i].computeEntropy();
+  return entropy;
+}
+
 /* Get the standard deviation of the distribution */
 Point ComposedDistribution::getStandardDeviation() const
 {
@@ -648,8 +659,8 @@ void ComposedDistribution::computeCovariance() const
       {
         const Scalar node = gaussNodes[nodeIndex];
         const Point q(marginalDistribution.computeQuantile(node));
-        marginalQuantiles[nodeIndex][component] = q[0];
-        marginalPDF[nodeIndex][component] = marginalDistribution.computePDF(q);
+        marginalQuantiles(nodeIndex, component) = q[0];
+        marginalPDF(nodeIndex, component) = marginalDistribution.computePDF(q);
       }
     }
     // Performs the integration for each covariance in the strictly lower triangle of the covariance matrix
@@ -668,8 +679,8 @@ void ComposedDistribution::computeCovariance() const
       {
         const Scalar nodeJ = gaussNodes[columnNodeIndex];
         const Scalar weightJ = gaussWeights[columnNodeIndex];
-        nodes2D[index][0] = nodeI;
-        nodes2D[index][1] = nodeJ;
+        nodes2D(index, 0) = nodeI;
+        nodes2D(index, 1) = nodeJ;
         weights2D[index] = weightI * weightJ;
         ++index;
       } // loop over J integration nodes
@@ -697,7 +708,7 @@ void ComposedDistribution::computeCovariance() const
           {
             for (UnsignedInteger columnNodeIndex = 0; columnNodeIndex < gaussWeights.getSize(); ++columnNodeIndex)
             {
-              covarianceIJ += weights2D[index] * (marginalQuantiles[rowNodeIndex][rowIndex] - muI) * (marginalQuantiles[columnNodeIndex][columnIndex] - muJ) * pdf2D[index];
+              covarianceIJ += weights2D[index] * (marginalQuantiles(rowNodeIndex, rowIndex) - muI) * (marginalQuantiles(columnNodeIndex, columnIndex) - muJ) * pdf2D[index];
               ++index;
             } // loop over J integration nodes
           } // loop over I integration nodes
@@ -729,16 +740,16 @@ Point ComposedDistribution::getKurtosis() const
 }
 
 /* Get the i-th marginal distribution */
-ComposedDistribution::Implementation ComposedDistribution::getMarginal(const UnsignedInteger i) const
+Distribution ComposedDistribution::getMarginal(const UnsignedInteger i) const
 {
   if (i >= getDimension()) throw InvalidArgumentException(HERE) << "The index of a marginal distribution must be in the range [0, dim-1]";
-  Distribution marginal(distributionCollection_[i]);
-  marginal.setDescription(Description(1, getDescription()[i]));
-  return marginal.getImplementation()->clone();
+  ComposedDistribution::Implementation marginal(distributionCollection_[i].getImplementation()->clone());
+  marginal->setDescription(Description(1, getDescription()[i]));
+  return marginal;
 }
 
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
-ComposedDistribution::Implementation ComposedDistribution::getMarginal(const Indices & indices) const
+Distribution ComposedDistribution::getMarginal(const Indices & indices) const
 {
   // This call will check that indices are correct
   const Copula marginalCopula(copula_.getMarginal(indices));
@@ -752,9 +763,9 @@ ComposedDistribution::Implementation ComposedDistribution::getMarginal(const Ind
     marginalDistributions.add(distributionCollection_[j]);
     marginalDescription[i] = description[j];
   }
-  ComposedDistribution marginal(marginalDistributions, marginalCopula);
-  marginal.setDescription(marginalDescription);
-  return marginal.clone();
+  ComposedDistribution::Implementation marginal(new ComposedDistribution(marginalDistributions, marginalCopula));
+  marginal->setDescription(marginalDescription);
+  return marginal;
 }
 
 /* Get the isoprobabilistic transformation */
@@ -903,9 +914,9 @@ ComposedDistribution::InverseIsoProbabilisticTransformation ComposedDistribution
 }
 
 /* Get the standard distribution */
-ComposedDistribution::Implementation ComposedDistribution::getStandardDistribution() const
+Distribution ComposedDistribution::getStandardDistribution() const
 {
-  return copula_.getStandardDistribution().getImplementation();
+  return copula_.getStandardDistribution();
 }
 
 /* Parameters value and description accessor */
