@@ -2,7 +2,7 @@
 /**
  *  @brief The CompositeDistribution distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -97,7 +97,9 @@ CompositeDistribution::CompositeDistribution(const Function & function,
   if (size != values.getSize()) throw InvalidArgumentException(HERE) << "Error: the size of the bounds=" << bounds.getSize() << " is not equal to the size of the values=" << values.getSize();
   probabilities_ = Point(size, 0.0);
   // Compute the probabilities
-  for (UnsignedInteger i = 0; i < size; ++i) probabilities_[i] = antecedent.computeCDF(bounds[i]);
+  // We start at i=1 because the first bound is the lower bound of the range, where CDF == 0.0
+  for (UnsignedInteger i = 1; i < size - 1; ++i) probabilities_[i] = antecedent.computeCDF(bounds[i]);
+  probabilities_[size - 1] = 1.0;
   increasing_ = Indices(size - 1);
   // Compute the variations
   for (UnsignedInteger i = 0; i < size - 1; ++i) increasing_[i] = values_[i + 1] > values[i];
@@ -289,7 +291,7 @@ String CompositeDistribution::__repr__() const
 String CompositeDistribution::__str__(const String & offset) const
 {
   OSS oss;
-  oss << offset << getClassName() << "=f(" << antecedent_.__str__() << ") with f=" << function_.getEvaluation()->__str__();
+  oss << offset << getClassName() << "=f(" << antecedent_.__str__() << ") with f=" << function_.getEvaluation().__str__();
   return oss;
 }
 
@@ -428,6 +430,19 @@ LevelSet CompositeDistribution::computeMinimumVolumeLevelSetWithThreshold(const
   return LevelSet(minimumVolumeLevelSetFunction, minusLogPDFThreshold);
 }
 
+/* Get the PDF singularities inside of the range - 1D only */
+Point CompositeDistribution::getSingularities() const
+{
+  if (values_.getSize() == 2) return Point(1, 0);
+  // The singularities are at the extrema of f
+  Point singularities(values_);
+  std::sort(singularities.begin(), singularities.end());
+  // Remove the end points
+  singularities.erase(0);
+  singularities.erase(singularities.getSize() - 1);
+  return singularities;
+}
+
 /* Parameters value and description accessor */
 CompositeDistribution::PointWithDescriptionCollection CompositeDistribution::getParametersCollection() const
 {
