@@ -2,7 +2,7 @@
 /**
  *  @brief The ConditionalDistribution distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -141,7 +141,7 @@ String ConditionalDistribution::__repr__() const
 String ConditionalDistribution::__str__(const String & offset) const
 {
   OSS oss(false);
-  oss << offset << getClassName() << "(X with X|Theta~" << conditionedDistribution_.getImplementation()->getClassName() << "(Theta), Theta=f(Y), f=" << linkFunction_.getEvaluation()->__str__() << ", Y~" << conditioningDistribution_.__str__() << ")";
+  oss << offset << getClassName() << "(X with X|Theta~" << conditionedDistribution_.getImplementation()->getClassName() << "(Theta), Theta=f(Y), f=" << linkFunction_.getEvaluation().__str__() << ", Y~" << conditioningDistribution_.__str__() << ")";
   return oss;
 }
 
@@ -258,7 +258,7 @@ void ConditionalDistribution::setConditionedAndConditioningDistributionsAndLinkF
       if (support.getSize() == 1)
       {
         diracMarginalsIndices_.add(i);
-        diracValues_.add(support[0][0]);
+        diracValues_.add(support(0, 0));
       } // Dirac marginal
       // Truly random discrete distribution
       else
@@ -276,7 +276,7 @@ void ConditionalDistribution::setConditionedAndConditioningDistributionsAndLinkF
     const ComposedDistribution measure(Collection< Distribution >(continuousDimension, Uniform()));
     const UnsignedInteger maximumNumber = static_cast< UnsignedInteger > (round(std::pow(ResourceMap::GetAsUnsignedInteger( "ConditionalDistribution-MaximumIntegrationNodesNumber" ), 1.0 / continuousDimension)));
     const UnsignedInteger candidateNumber = ResourceMap::GetAsUnsignedInteger( "ConditionalDistribution-MarginalIntegrationNodesNumber" );
-    if (candidateNumber > maximumNumber) LOGWARN(OSS() << "Warning! The requested number of marginal integration nodes=" << candidateNumber << " would lead to an excessive number of integration nodes=" << std::pow(maximumNumber, 1.0 * continuousDimension) << ". It has been reduced to " << maximumNumber << ". You should increase the ResourceMap key \"ConditionalDistribution-MaximumIntegrationNodesNumber\"");
+    if (candidateNumber > maximumNumber) LOGWARN(OSS() << "Warning! The requested number of marginal integration nodes=" << candidateNumber << " would lead to an excessive number of integration nodes=" << std::pow(candidateNumber, 1.0 * continuousDimension) << ". It has been reduced to " << maximumNumber << ". You should increase the ResourceMap key \"ConditionalDistribution-MaximumIntegrationNodesNumber\" or decrease the ResourceMap key \"ConditionalDistribution-MarginalIntegrationNodesNumber\"");
 
     GaussProductExperiment experiment(measure, Indices(continuousDimension, std::min(maximumNumber, candidateNumber)));
     continuousNodes_ = experiment.generateWithWeights(continuousWeights_);
@@ -284,7 +284,7 @@ void ConditionalDistribution::setConditionedAndConditioningDistributionsAndLinkF
     setIntegrationNodesNumber(std::min(maximumNumber, candidateNumber));
     // Normalization factor for the weights
     // Not needed as the Mixture will be automatically normalized
-    // const Scalar normalizationFactor(Interval(continuousLowerBounds, continuousUpperBounds).getNumericalVolume());
+    // const Scalar normalizationFactor(Interval(continuousLowerBounds, continuousUpperBounds).getVolume());
     continuousAtomsNumber = continuousNodes_.getSize();
   } // continuousDimension > 0
 
@@ -303,7 +303,7 @@ void ConditionalDistribution::setConditionedAndConditioningDistributionsAndLinkF
       Point discreteNode(discreteDimension);
       for (UnsignedInteger j = 0; j < discreteDimension; ++j)
       {
-        const Scalar rho = fractions[i][j];
+        const Scalar rho = fractions(i, j);
         const UnsignedInteger length = discreteSupports[j].getSize();
         const UnsignedInteger index = static_cast<UnsignedInteger>(round(rho * (length - 1)));
         discreteNode[j] = discreteSupports[j][index][0];
@@ -334,17 +334,20 @@ void ConditionalDistribution::setConditionedAndConditioningDistributionsAndLinkF
       y[diracMarginalsIndices_[i]] = diracValues_[i];
     // Second, the discrete components
     // For each combination of the discrete components
+    Sample currentY(discreteAtomsNumber, y);
     for (UnsignedInteger i = 0; i < discreteAtomsNumber; ++i)
     {
-      Point currentY(y);
       // Get the discrete values
-      const Point discreteNode(discreteNodes_[i]);
       for (UnsignedInteger j = 0; j < discreteDimension; ++j)
-        currentY[discreteMarginalsIndices_[j]] = discreteNode[j];
-      const Scalar w = conditioningDistribution.computePDF(currentY);
+        currentY(i, discreteMarginalsIndices_[j]) = discreteNodes_(i, j);
+    }
+    const Sample yPDF(conditioningDistribution.computePDF(currentY));
+    const Sample parameters(linkFunction_(currentY));
+    for (UnsignedInteger i = 0; i < discreteAtomsNumber; ++i)
+    {
       Distribution dist(conditionedDistribution);
-      dist.setWeight(w);
-      dist.setParameter(linkFunction_(currentY));
+      dist.setWeight(yPDF(i, 0));
+      dist.setParameter(parameters[i]);
       atoms[atomIndex] = dist;
       ++atomIndex;
     } // Discrete measure
@@ -363,19 +366,23 @@ void ConditionalDistribution::setConditionedAndConditioningDistributionsAndLinkF
     for (UnsignedInteger i = 0; i < diracDimension; ++i)
       y[diracMarginalsIndices_[i]] = diracValues_[i];
     // Continuous part using Gauss integration
+    Sample currentY(continuousAtomsNumber, y);
     for (UnsignedInteger i = 0; i < continuousAtomsNumber; ++i)
     {
-      Point currentY(y);
       // Complete the filling of theta using the Gauss integration node
-      const Point continuousNode(continuousNodes_[i]);
       for (UnsignedInteger j = 0; j < continuousDimension; ++j)
-        currentY[continuousMarginalsIndices_[j]] = continuousLowerBounds_[j] + 0.5 * (1.0 + continuousNode[j]) * (continuousUpperBounds_[j] - continuousLowerBounds_[j]);
-      const Scalar w = conditioningDistribution.computePDF(currentY) * continuousWeights_[i];
+        currentY(i, continuousMarginalsIndices_[j]) = continuousLowerBounds_[j] + 0.5 * (1.0 + continuousNodes_(i, j)) * (continuousUpperBounds_[j] - continuousLowerBounds_[j]);
+    }
+    const Sample yPDF(conditioningDistribution.computePDF(currentY));
+    const Sample parameters(linkFunction_(currentY));
+    for (UnsignedInteger i = 0; i < continuousAtomsNumber; ++i)
+    {
+      const Scalar w = yPDF(i, 0) * continuousWeights_[i];
       Distribution dist(conditionedDistribution);
       dist.setWeight(w);
-      dist.setParameter(linkFunction_(currentY));
+      dist.setParameter(parameters[i]);
       atoms[atomIndex] = dist;
-      LOGDEBUG(OSS() << "i=" << i << ", w=" << w << ", Y=" << currentY << ", dist=" << dist.__str__());
+      LOGDEBUG(OSS() << "i=" << i << ", w=" << w << ", Y=" << currentY[i] << ", dist=" << dist.__str__());
       ++atomIndex;
     } // Continuous measure
     // Now, update the underlying Mixture
@@ -392,28 +399,32 @@ void ConditionalDistribution::setConditionedAndConditioningDistributionsAndLinkF
     y[diracMarginalsIndices_[i]] = diracValues_[i];
   // Second, the discrete components
   // For each combination of the discrete components
+  Sample currentYs(0, y);
   for (UnsignedInteger i = 0; i < discreteAtomsNumber; ++i)
   {
     Point currentY(y);
     // Get the discrete values
-    const Point discreteNode(discreteNodes_[i]);
     for (UnsignedInteger j = 0; j < discreteDimension; ++j)
-      currentY[discreteMarginalsIndices_[j]] = discreteNode[j];
+      currentY[discreteMarginalsIndices_[j]] = discreteNodes_(i, j);
     // Now, complete by the discretization of the continuous part using Gauss integration
     for (UnsignedInteger j = 0; j < continuousAtomsNumber; ++j)
     {
       // Complete the filling of theta using the Gauss integration node
-      const Point continuousNode(continuousNodes_[j]);
       for (UnsignedInteger k = 0; k < continuousDimension; ++k)
-        currentY[continuousMarginalsIndices_[k]] = continuousLowerBounds_[k] + 0.5 * (1.0 + continuousNode[k]) * (continuousUpperBounds_[k] - continuousLowerBounds_[k]);
-      const Scalar w = conditioningDistribution.computePDF(currentY) * continuousWeights_[j];
-      Distribution dist(conditionedDistribution);
-      dist.setWeight(w);
-      dist.setParameter(linkFunction_(currentY));
-      atoms[atomIndex] = dist;
-      ++atomIndex;
-    } // Continuous atoms
-  } // Overall discretization
+        currentY[continuousMarginalsIndices_[k]] = continuousLowerBounds_[k] + 0.5 * (1.0 + continuousNodes_(j, k)) * (continuousUpperBounds_[k] - continuousLowerBounds_[k]);
+      currentYs.add(currentY);
+    }
+  }
+  const Sample yPDF(conditioningDistribution.computePDF(currentYs));
+  const Sample parameters(linkFunction_(currentYs));
+  for (UnsignedInteger i = 0; i < currentYs.getSize(); ++i)
+  {
+    Distribution dist(conditionedDistribution);
+    dist.setWeight(yPDF(i, 0) * continuousWeights_[i % continuousAtomsNumber]);
+    dist.setParameter(parameters[i]);
+    atoms[atomIndex] = dist;
+    ++atomIndex;
+  }
   // Now, update the underlying Mixture
   setDistributionCollection(atoms);
 }
@@ -457,23 +468,32 @@ Point ConditionalDistribution::computeExpectation(const Function & f,
     }
     // Second, the discrete components
     // For each combination of the discrete components
+    Sample currentThetas(0, theta);
     for (UnsignedInteger i = 0; i < discreteAtomsNumber; ++i)
     {
       Point currentTheta(theta);
       // Get the discrete values
-      const Point discreteNode(discreteNodes_[i]);
       Bool rejectNode = false;
       for (UnsignedInteger j = 0; j < discreteDimension; ++j)
       {
-        const Scalar value = discreteNode[j];
+        const Scalar value = discreteNodes_(i, j);
         currentTheta[discreteMarginalsIndices_[j]] = value;
         rejectNode = (value > thetaStar[i] + epsilon);
         if (rejectNode) break;
       }
       // Skip the current integration point if the current sub-manifold is outside of the integration region
-      if (rejectNode) continue;
-      const Scalar w = conditioningDistribution_.computePDF(currentTheta);
-      result += w * f(currentTheta);
+      if (!rejectNode)
+      {
+        currentThetas.add(currentTheta);
+      }
+    }
+    if (currentThetas.getSize() == 0)
+      return result;
+    const Sample currentThetasPDF(conditioningDistribution_.computePDF(currentThetas));
+    const Sample fCurrentThetas(f(currentThetas));
+    for (UnsignedInteger i = 0; i < currentThetas.getSize(); ++i)
+    {
+      result += currentThetasPDF(i, 0) * fCurrentThetas[i];
     } // Discrete measure
     return result;
   } // No continuous marginal
@@ -496,19 +516,21 @@ Point ConditionalDistribution::computeExpectation(const Function & f,
       theta[diracMarginalsIndices_[i]] = value;
     }
     // Continuous part using Gauss integration
+    Sample currentTheta(continuousAtomsNumber, theta);
     for (UnsignedInteger i = 0; i < continuousAtomsNumber; ++i)
     {
-      Point currentTheta(theta);
       // Complete the filling of theta using the Gauss integration node
-      const Point continuousNode(continuousNodes_[i]);
       for (UnsignedInteger j = 0; j < continuousDimension; ++j)
-        currentTheta[continuousMarginalsIndices_[j]] = continuousLowerBounds_[j] + 0.5 * (1.0 + continuousNode[j]) * (subPoint[j] - continuousLowerBounds_[j]);
+        currentTheta(i, continuousMarginalsIndices_[j]) = continuousLowerBounds_[j] + 0.5 * (1.0 + continuousNodes_(i, j)) * (subPoint[j] - continuousLowerBounds_[j]);
+    }
+    const Sample thetaPDF(conditioningDistribution_.computePDF(currentTheta));
+    const Sample fTheta(f(currentTheta));
+    for (UnsignedInteger i = 0; i < continuousAtomsNumber; ++i)
+    {
       // Current contribution to the CDF
-      const Scalar w = conditioningDistribution_.computePDF(currentTheta) * continuousWeights_[i];
-      const Point fTheta(f(currentTheta));
-      result += w * f(currentTheta);
+      result += (thetaPDF(i, 0) * continuousWeights_[i]) * fTheta[i];
     } // Continuous measure
-    result *= Interval(continuousLowerBounds_, subPoint).getNumericalVolume();
+    result *= Interval(continuousLowerBounds_, subPoint).getVolume();
     return result;
   } // No discrete marginal
 
@@ -528,39 +550,48 @@ Point ConditionalDistribution::computeExpectation(const Function & f,
   }
   // Second, the discrete components
   // For each combination of the discrete components
+  Sample currentThetas(0, theta);
   for (UnsignedInteger i = 0; i < discreteAtomsNumber; ++i)
   {
     Point currentTheta(theta);
     // Get the discrete values
-    const Point discreteNode(discreteNodes_[i]);
     Bool rejectNode;
     for (UnsignedInteger j = 0; j < discreteDimension; ++j)
     {
-      const Scalar value = discreteNode[j];
+      const Scalar value = discreteNodes_(i, j);
       currentTheta[discreteMarginalsIndices_[j]] = value;
       rejectNode = (value > thetaStar[i] + epsilon);
       if (rejectNode) break;
     }
     // Skip the current integration point if the current sub-manifold is outside of the integration region
-    if (rejectNode) continue;
-    // Now, complete by the discretization of the continuous part using Gauss integration
-    for (UnsignedInteger j = 0; j < continuousAtomsNumber; ++j)
+    if (!rejectNode)
     {
-      // Complete the filling of theta using the Gauss integration node
-      const Point continuousNode(continuousNodes_[j]);
-      for (UnsignedInteger k = 0; k < continuousDimension; ++k)
-        currentTheta[continuousMarginalsIndices_[k]] = continuousLowerBounds_[k] + 0.5 * (1.0 + continuousNode[k]) * (subPoint[k] - continuousLowerBounds_[k]);
-      const Scalar w = conditioningDistribution_.computePDF(currentTheta) * continuousWeights_[j];
-      const Point fTheta(f(currentTheta));
-      result += w * f(currentTheta);
-    } // Continuous atoms
-  } // Overall discretization
-  result *= Interval(continuousLowerBounds_, subPoint).getNumericalVolume();
+      for (UnsignedInteger j = 0; j < continuousAtomsNumber; ++j)
+      {
+        // Complete the filling of theta using the Gauss integration node
+        for (UnsignedInteger k = 0; k < continuousDimension; ++k)
+          currentTheta[continuousMarginalsIndices_[k]] = continuousLowerBounds_[k] + 0.5 * (1.0 + continuousNodes_(j, k)) * (subPoint[k] - continuousLowerBounds_[k]);
+        currentThetas.add(currentTheta);
+      } // Continuous atoms
+    }
+  }
+  if (currentThetas.getSize() > 0)
+  {
+    const Sample currentThetasPDF(conditioningDistribution_.computePDF(currentThetas));
+    const Sample fCurrentThetas(f(currentThetas));
+    for (UnsignedInteger i = 0; i < currentThetas.getSize(); ++i)
+    {
+      // Now, complete by the discretization of the continuous part using Gauss integration
+      const Point q(currentThetasPDF(i, 0) * fCurrentThetas[i]);
+      result += continuousWeights_[i % continuousAtomsNumber] * q;
+    }
+  }
+  result *= Interval(continuousLowerBounds_, subPoint).getVolume();
   return result;
 }
 
 /* Get the i-th marginal distribution */
-ConditionalDistribution::Implementation ConditionalDistribution::getMarginal(const UnsignedInteger i) const
+Distribution ConditionalDistribution::getMarginal(const UnsignedInteger i) const
 {
   const UnsignedInteger dimension = getDimension();
   if (i >= dimension) throw InvalidArgumentException(HERE) << "The index of a marginal distribution must be in the range [0, dim-1]";
@@ -570,7 +601,7 @@ ConditionalDistribution::Implementation ConditionalDistribution::getMarginal(con
 }
 
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
-ConditionalDistribution::Implementation ConditionalDistribution::getMarginal(const Indices & indices) const
+Distribution ConditionalDistribution::getMarginal(const Indices & indices) const
 {
   const UnsignedInteger dimension = getDimension();
   if (!indices.check(dimension)) throw InvalidArgumentException(HERE) << "The indices of a marginal distribution must be in the range [0, dim-1] and must be different";
