@@ -2,7 +2,7 @@
 /**
  *  @brief The Dirac distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -23,6 +23,7 @@
 #include "openturns/SpecFunc.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/Exception.hxx"
+#include "openturns/Distribution.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -167,6 +168,12 @@ Scalar Dirac::computeScalarQuantile(const Scalar prob,
   return point_[0];
 }
 
+/* Compute the entropy of the distribution */
+Scalar Dirac::computeEntropy() const
+{
+  return 0.0;
+}
+
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
 Complex Dirac::computeCharacteristicFunction(const Scalar u) const
 {
@@ -318,18 +325,18 @@ void Dirac::computeRange()
 }
 
 /* Get the i-th marginal distribution */
-Dirac::Implementation Dirac::getMarginal(const UnsignedInteger i) const
+Distribution Dirac::getMarginal(const UnsignedInteger i) const
 {
   const UnsignedInteger dimension = getDimension();
   if (i >= dimension) throw InvalidArgumentException(HERE) << "The index of a marginal distribution must be in the range [0, dim-1]";
   if (dimension == 1) return clone();
-  Dirac marginal(point_[i]);
-  marginal.setDescription(Description(1, getDescription()[i]));
-  return marginal.clone();
+  Dirac::Implementation marginal(new Dirac(point_[i]));
+  marginal->setDescription(Description(1, getDescription()[i]));
+  return marginal;
 }
 
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
-Dirac::Implementation Dirac::getMarginal(const Indices & indices) const
+Distribution Dirac::getMarginal(const Indices & indices) const
 {
   const UnsignedInteger dimension = getDimension();
   if (!indices.check(dimension)) throw InvalidArgumentException(HERE) << "The indices of a marginal distribution must be in the range [0, dim-1] and must be different";
@@ -344,9 +351,9 @@ Dirac::Implementation Dirac::getMarginal(const Indices & indices) const
     pointMarginal[i] = point_[index_i];
     marginalDescription[i] = description[index_i];
   }
-  Dirac marginal(pointMarginal);
-  marginal.setDescription(marginalDescription);
-  return marginal.clone();
+  Dirac::Implementation marginal(new Dirac(pointMarginal));
+  marginal->setDescription(marginalDescription);
+  return marginal;
 } // getMarginal(Indices)
 
 /* Check if the distribution is elliptical */
