@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for Dirac distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -44,17 +44,17 @@ DiracFactory * DiracFactory::clone() const
 
 /* Here is the interface that all derived class must implement */
 
-DiracFactory::Implementation DiracFactory::build(const Sample & sample) const
+Distribution DiracFactory::build(const Sample & sample) const
 {
   return buildAsDirac(sample).clone();
 }
 
-DiracFactory::Implementation DiracFactory::build(const Point & parameters) const
+Distribution DiracFactory::build(const Point & parameters) const
 {
   return buildAsDirac(parameters).clone();
 }
 
-DiracFactory::Implementation DiracFactory::build() const
+Distribution DiracFactory::build() const
 {
   return buildAsDirac().clone();
 }
@@ -80,7 +80,7 @@ Dirac DiracFactory::buildAsDirac(const Point & parameters) const
     distribution.setParameter(parameters);
     return distribution;
   }
-  catch (InvalidArgumentException)
+  catch (InvalidArgumentException &)
   {
     throw InvalidArgumentException(HERE) << "Error: cannot build a Dirac distribution from the given parameters";
   }
