@@ -2,7 +2,7 @@
 /**
  *  @brief The Dirichlet distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -352,6 +352,16 @@ void Dirichlet::computeMean() const
   isAlreadyComputedMean_ = true;
 }
 
+/* Compute the entropy of the distribution */
+Scalar Dirichlet::computeEntropy() const
+{
+  const UnsignedInteger dimension = getDimension();
+  Scalar entropy = -normalizationFactor_ - (dimension + 1 - sumTheta_) * SpecFunc::Psi(sumTheta_);
+  for (UnsignedInteger i = 0; i <= dimension; ++i)
+    entropy -= (theta_[i] - 1.0) * SpecFunc::Psi(theta_[i]);
+  return entropy;
+}
+
 /* Get the standard deviation of the distribution */
 Point Dirichlet::getStandardDeviation() const
 {
@@ -432,7 +442,7 @@ Point Dirichlet::getTheta() const
 }
 
 /* Get the i-th marginal distribution */
-Dirichlet::Implementation Dirichlet::getMarginal(const UnsignedInteger i) const
+Distribution Dirichlet::getMarginal(const UnsignedInteger i) const
 {
   const UnsignedInteger dimension = getDimension();
   if (i >= dimension) throw InvalidArgumentException(HERE) << "The index of a marginal distribution must be in the range [0, dim-1]";
@@ -440,13 +450,13 @@ Dirichlet::Implementation Dirichlet::getMarginal(const UnsignedInteger i) const
   Point thetaMarginal(2);
   thetaMarginal[0] = theta_[i];
   thetaMarginal[1] = sumTheta_ - theta_[i];
-  Dirichlet marginal(thetaMarginal);
-  marginal.setDescription(Description(1, getDescription()[i]));
-  return marginal.clone();
+  Dirichlet::Implementation marginal(new Dirichlet(thetaMarginal));
+  marginal->setDescription(Description(1, getDescription()[i]));
+  return marginal;
 }
 
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
-Dirichlet::Implementation Dirichlet::getMarginal(const Indices & indices) const
+Distribution Dirichlet::getMarginal(const Indices & indices) const
 {
   const UnsignedInteger dimension = getDimension();
   if (!indices.check(dimension)) throw InvalidArgumentException(HERE) << "The indices of a marginal distribution must be in the range [0, dim-1] and must be different";
@@ -465,7 +475,7 @@ Dirichlet::Implementation Dirichlet::getMarginal(const Indices & indices) const
     marginalDescription[i] = description[index_i];
   }
   thetaMarginal[outputDimension] = sumTheta_ - sumMarginal;
-  Dirichlet marginal(thetaMarginal);
+  Dirichlet* marginal(new Dirichlet(thetaMarginal));
   // Initialize the CDF computation if the data are available
   if (isInitializedCDF_)
   {
@@ -476,12 +486,12 @@ Dirichlet::Implementation Dirichlet::getMarginal(const Indices & indices) const
       marginalIntegrationNodes_.add(integrationNodes_[indices[i]]);
       marginalIntegrationWeights_.add(integrationWeights_[indices[i]]);
     }
-    marginal.integrationNodes_ = marginalIntegrationNodes_;
-    marginal.integrationWeights_ = marginalIntegrationWeights_;
-    marginal.isInitializedCDF_ = true;
+    marginal->integrationNodes_ = marginalIntegrationNodes_;
+    marginal->integrationWeights_ = marginalIntegrationWeights_;
+    marginal->isInitializedCDF_ = true;
   }
-  marginal.setDescription(marginalDescription);
-  return marginal.clone();
+  marginal->setDescription(marginalDescription);
+  return marginal;
 } // getMarginal(Indices)
 
 /* Tell if the distribution has independent marginals */
@@ -513,10 +523,10 @@ CorrelationMatrix Dirichlet::getSpearmanCorrelation() const
       Scalar rhoIJ = 0.0;
       for (UnsignedLong indexU = 0; indexU < nI; ++indexU)
       {
-        const Scalar u = 0.5 * (integrationNodes_[j][indexU] + 1.0);
+        const Scalar u = 0.5 * (integrationNodes_(j, indexU) + 1.0);
         for (UnsignedLong indexV = 0; indexV < nJ; ++indexV)
         {
-          Scalar v = 0.5 * (integrationNodes_[j][indexU] + 1.0) * (1.0 - u);
+          Scalar v = 0.5 * (integrationNodes_(j, indexU) + 1.0) * (1.0 - u);
         } // indexV
       } // indexU
     } // j
@@ -568,7 +578,7 @@ void Dirichlet::setParametersCollection(const PointCollection & parametersCollec
   for (UnsignedInteger i = 0; i < dimension; ++i)
   {
     theta[i] = parametersCollection[i][0];
-    lastTheta -= theta[i]; // substract each theta except the last one
+    lastTheta -= theta[i]; // subtract each theta except the last one
   }
   theta[dimension] = lastTheta;
   setTheta(theta);
