@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for Dirichlet distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -45,17 +45,17 @@ DirichletFactory * DirichletFactory::clone() const
 
 /* Here is the interface that all derived class must implement */
 
-DirichletFactory::Implementation DirichletFactory::build(const Sample & sample) const
+Distribution DirichletFactory::build(const Sample & sample) const
 {
   return buildAsDirichlet(sample).clone();
 }
 
-DirichletFactory::Implementation DirichletFactory::build(const Point & parameters) const
+Distribution DirichletFactory::build(const Point & parameters) const
 {
   return buildAsDirichlet(parameters).clone();
 }
 
-DirichletFactory::Implementation DirichletFactory::build() const
+Distribution DirichletFactory::build() const
 {
   return buildAsDirichlet().clone();
 }
@@ -75,7 +75,7 @@ Dirichlet DirichletFactory::buildAsDirichlet(const Sample & sample) const
     Scalar sum = 0.0;
     for (UnsignedInteger j = 0; j < dimension; ++j)
     {
-      const Scalar xIJ = sample[i][j];
+      const Scalar xIJ = sample(i, j);
       if (!(xIJ > 0.0)) throw InvalidArgumentException(HERE) << "Error: the sample contains points not in the unit simplex: x=" << sample[i];
       sum += xIJ;
       meanLog[j] += std::log(xIJ);
@@ -171,7 +171,7 @@ Dirichlet DirichletFactory::buildAsDirichlet(const Point & parameters) const
     distribution.setParameter(parameters);
     return distribution;
   }
-  catch (InvalidArgumentException)
+  catch (InvalidArgumentException &)
   {
     throw InvalidArgumentException(HERE) << "Error: cannot build a Dirichlet distribution from the given parameters";
   }
