@@ -2,7 +2,7 @@
 /**
  *  @brief The Epanechnikov distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -144,6 +144,12 @@ Scalar Epanechnikov::computeScalarQuantile(const Scalar prob,
   return 2.0 * std::cos(0.3333333333333333333333333 * std::acos(1.0 - 2.0 * prob) - 2.094395102393195492308429);
 }
 
+/* Compute the entropy of the distribution */
+Scalar Epanechnikov::computeEntropy() const
+{
+  return 5.0 / 3.0 - std::log(3.0);
+}
+
 /* Get the roughness, i.e. the L2-norm of the PDF */
 Scalar Epanechnikov::getRoughness() const
 {
