@@ -2,7 +2,7 @@
 /**
  *  @brief The FarlieGumbelMorgensternCopula distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,15 +14,17 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 #include <cmath>
 #include "openturns/FarlieGumbelMorgensternCopula.hxx"
 #include "openturns/RandomGenerator.hxx"
+#include "openturns/SpecFunc.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/Exception.hxx"
+#include "openturns/Distribution.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -278,7 +280,7 @@ Scalar FarlieGumbelMorgensternCopula::getTheta() const
 }
 
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
-FarlieGumbelMorgensternCopula::Implementation FarlieGumbelMorgensternCopula::getMarginal(const Indices & indices) const
+Distribution FarlieGumbelMorgensternCopula::getMarginal(const Indices & indices) const
 {
   if (!indices.check(2)) throw InvalidArgumentException(HERE) << "The indices of an archimedean copula must be in the range [0, 1] and must be different";
   // General case
@@ -300,6 +302,17 @@ FarlieGumbelMorgensternCopula::Implementation FarlieGumbelMorgensternCopula::get
   return result;
 }
 
+/* Compute the entropy of the distribution */
+Scalar FarlieGumbelMorgensternCopula::computeEntropy() const
+{
+  if (std::abs(theta_) <= 0.024604263883779147)
+  {
+    const Scalar theta2 = theta_ * theta_;
+    return -theta2 * (1.0 / 18.0 + theta2 * (1.0 / 300.0 + theta2 * (1.0 / 1470.0 + theta2 / 4536.0)));
+  }
+  return -((3.0 + theta_ * (4.0 + theta_)) * log1p(theta_) + (-3.0 + theta_ * (4.0 - theta_)) * log1p(-theta_)) / (8.0 * theta_) + (5.0 - (SpecFunc::DiLog(theta_) - SpecFunc::DiLog(-theta_)) / theta_) / 4.0;
+}
+
 /* Method save() stores the object through the StorageManager */
 void FarlieGumbelMorgensternCopula::save(Advocate & adv) const
 {
