@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for FarlieGumbelMorgensternCopula distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -47,17 +47,17 @@ FarlieGumbelMorgensternCopulaFactory * FarlieGumbelMorgensternCopulaFactory::clo
 
 /* Here is the interface that all derived class must implement */
 
-FarlieGumbelMorgensternCopulaFactory::Implementation FarlieGumbelMorgensternCopulaFactory::build(const Sample & sample) const
+Distribution FarlieGumbelMorgensternCopulaFactory::build(const Sample & sample) const
 {
   return buildAsFarlieGumbelMorgensternCopula(sample).clone();
 }
 
-FarlieGumbelMorgensternCopulaFactory::Implementation FarlieGumbelMorgensternCopulaFactory::build(const Point & parameters) const
+Distribution FarlieGumbelMorgensternCopulaFactory::build(const Point & parameters) const
 {
   return buildAsFarlieGumbelMorgensternCopula(parameters).clone();
 }
 
-FarlieGumbelMorgensternCopulaFactory::Implementation FarlieGumbelMorgensternCopulaFactory::build() const
+Distribution FarlieGumbelMorgensternCopulaFactory::build() const
 {
   return buildAsFarlieGumbelMorgensternCopula().clone();
 }
@@ -87,7 +87,7 @@ FarlieGumbelMorgensternCopula FarlieGumbelMorgensternCopulaFactory::buildAsFarli
     copula.setParameter(parameters);
     return copula;
   }
-  catch (InvalidArgumentException)
+  catch (InvalidArgumentException &)
   {
     throw InvalidArgumentException(HERE) << "Error: cannot build a FarlieGumbelMorgensternCopula from the given parameters";
   }
