@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for FisherSnedecor distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -46,17 +46,17 @@ FisherSnedecorFactory * FisherSnedecorFactory::clone() const
 
 /* Here is the interface that all derived class must implement */
 
-FisherSnedecorFactory::Implementation FisherSnedecorFactory::build(const Sample & sample) const
+Distribution FisherSnedecorFactory::build(const Sample & sample) const
 {
   return buildAsFisherSnedecor(sample).clone();
 }
 
-FisherSnedecorFactory::Implementation FisherSnedecorFactory::build(const Point & parameters) const
+Distribution FisherSnedecorFactory::build(const Point & parameters) const
 {
   return buildAsFisherSnedecor(parameters).clone();
 }
 
-FisherSnedecorFactory::Implementation FisherSnedecorFactory::build() const
+Distribution FisherSnedecorFactory::build() const
 {
   return buildAsFisherSnedecor().clone();
 }
@@ -68,18 +68,19 @@ DistributionFactoryResult FisherSnedecorFactory::buildEstimator(const Sample & s
 
 FisherSnedecor FisherSnedecorFactory::buildAsFisherSnedecor(const Sample & sample) const
 {
-  const UnsignedInteger dimension = build()->getParameterDimension();
+  const UnsignedInteger dimension = build().getParameterDimension();
   MaximumLikelihoodFactory factory(buildAsFisherSnedecor());
 
-  // override starting point
-  OptimizationAlgorithm solver(factory.getOptimizationAlgorithm());
-  solver.setStartingPoint(Point(dimension, 0.0));
-  factory.setOptimizationAlgorithm(solver);
-
-  // override bounds
   Point parametersLowerBound;
   parametersLowerBound.add(ResourceMap::GetAsScalar("FisherSnedecorFactory-D1LowerBound"));
   parametersLowerBound.add(ResourceMap::GetAsScalar("FisherSnedecorFactory-D2LowerBound"));
+
+  // override starting point
+  OptimizationAlgorithm solver(factory.getOptimizationAlgorithm());
+  solver.setStartingPoint(parametersLowerBound);
+  factory.setOptimizationAlgorithm(solver);
+
+  // override bounds
   Interval bounds(parametersLowerBound, Point(dimension, SpecFunc::MaxScalar), Interval::BoolCollection(dimension, true), Interval::BoolCollection(dimension, false));
   factory.setOptimizationBounds(bounds);
 
@@ -94,7 +95,7 @@ FisherSnedecor FisherSnedecorFactory::buildAsFisherSnedecor(const Point & parame
     distribution.setParameter(parameters);
     return distribution;
   }
-  catch (InvalidArgumentException)
+  catch (InvalidArgumentException &)
   {
     throw InvalidArgumentException(HERE) << "Error: cannot build a FisherSnedecor distribution from the given parameters";
   }
@@ -105,16 +106,4 @@ FisherSnedecor FisherSnedecorFactory::buildAsFisherSnedecor() const
   return FisherSnedecor();
 }
 
-/* Optimization solver accessor */
-OptimizationAlgorithm FisherSnedecorFactory::getOptimizationAlgorithm() const
-{
-  return solver_;
-}
-
-void FisherSnedecorFactory::setOptimizationAlgorithm(const OptimizationAlgorithm & solver)
-{
-  solver_ = solver;
-}
-
-
 END_NAMESPACE_OPENTURNS
