@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for FrankCopula distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -49,17 +49,17 @@ FrankCopulaFactory * FrankCopulaFactory::clone() const
 
 /* Here is the interface that all derived class must implement */
 
-FrankCopulaFactory::Implementation FrankCopulaFactory::build(const Sample & sample) const
+Distribution FrankCopulaFactory::build(const Sample & sample) const
 {
   return buildAsFrankCopula(sample).clone();
 }
 
-FrankCopulaFactory::Implementation FrankCopulaFactory::build(const Point & parameters) const
+Distribution FrankCopulaFactory::build(const Point & parameters) const
 {
   return buildAsFrankCopula(parameters).clone();
 }
 
-FrankCopulaFactory::Implementation FrankCopulaFactory::build() const
+Distribution FrankCopulaFactory::build() const
 {
   return buildAsFrankCopula().clone();
 }
@@ -113,7 +113,7 @@ FrankCopula FrankCopulaFactory::buildAsFrankCopula(const Point & parameters) con
     copula.setParameter(parameters);
     return copula;
   }
-  catch (InvalidArgumentException)
+  catch (InvalidArgumentException &)
   {
     throw InvalidArgumentException(HERE) << "Error: cannot build a FrankCopula from the given parameters";
   }
