@@ -2,7 +2,7 @@
 /**
  *  @brief The GeneralizedPareto distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -23,6 +23,7 @@
 #include "openturns/SpecFunc.hxx"
 #include "openturns/RandomGenerator.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
+#include "openturns/Distribution.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -196,6 +197,12 @@ LevelSet GeneralizedPareto::computeMinimumVolumeLevelSetWithThreshold(const Scal
   return LevelSet(minimumVolumeLevelSetFunction, minusLogPDFThreshold);
 }
 
+/* Compute the entropy of the distribution */
+Scalar GeneralizedPareto::computeEntropy() const
+{
+  return std::log(sigma_) + xi_ + 1.0;
+}
+
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
 Complex GeneralizedPareto::computeCharacteristicFunction(const Scalar x) const
 {
@@ -283,9 +290,9 @@ Point GeneralizedPareto::getStandardMoment(const UnsignedInteger n) const
 }
 
 /* Get the standard representative in the parametric family, associated with the standard moments */
-GeneralizedPareto::Implementation GeneralizedPareto::getStandardRepresentative() const
+Distribution GeneralizedPareto::getStandardRepresentative() const
 {
-  return GeneralizedPareto(1.0, xi_).clone();
+  return new GeneralizedPareto(1.0, xi_);
 }
 
 /* Compute the covariance of the distribution */
