@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for GeneralizedPareto distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -37,7 +37,7 @@ GeneralizedParetoFactory::GeneralizedParetoFactory(const OptimizationAlgorithm &
   , solver_(solver)
 {
   // Create the optimization solver parameters using the parameters in the ResourceMap
-  solver_.setMaximumIterationNumber(ResourceMap::GetAsUnsignedInteger("GeneralizedParetoFactory-MaximumEvaluationNumber"));
+  solver_.setMaximumEvaluationNumber(ResourceMap::GetAsUnsignedInteger("GeneralizedParetoFactory-MaximumEvaluationNumber"));
   solver_.setMaximumAbsoluteError(ResourceMap::GetAsScalar("GeneralizedParetoFactory-MaximumAbsoluteError"));
   solver_.setMaximumRelativeError(ResourceMap::GetAsScalar("GeneralizedParetoFactory-MaximumRelativeError"));
   solver_.setMaximumResidualError(ResourceMap::GetAsScalar("GeneralizedParetoFactory-MaximumObjectiveError"));
@@ -52,17 +52,17 @@ GeneralizedParetoFactory * GeneralizedParetoFactory::clone() const
 
 /* Here is the interface that all derived class must implement */
 
-GeneralizedParetoFactory::Implementation GeneralizedParetoFactory::build(const Sample & sample) const
+Distribution GeneralizedParetoFactory::build(const Sample & sample) const
 {
   return buildAsGeneralizedPareto(sample).clone();
 }
 
-GeneralizedParetoFactory::Implementation GeneralizedParetoFactory::build(const Point & parameters) const
+Distribution GeneralizedParetoFactory::build(const Point & parameters) const
 {
   return buildAsGeneralizedPareto(parameters).clone();
 }
 
-GeneralizedParetoFactory::Implementation GeneralizedParetoFactory::build() const
+Distribution GeneralizedParetoFactory::build() const
 {
   return buildAsGeneralizedPareto().clone();
 }
@@ -82,7 +82,7 @@ GeneralizedPareto GeneralizedParetoFactory::buildAsGeneralizedPareto(const Sampl
     {
       return buildMethodOfProbabilityWeightedMoments(sample);
     }
-    catch (InvalidArgumentException)
+    catch (InvalidArgumentException &)
     {
       // Nothing to do, fallback on the exponential regression
       LOGINFO("Method of probability weighted moment failed, using method of exponential regression");
@@ -90,15 +90,15 @@ GeneralizedPareto GeneralizedParetoFactory::buildAsGeneralizedPareto(const Sampl
     }
   } // small size
   try
-    {
-      return buildMethodOfExponentialRegression(sample);
-    }
-  catch (InvalidArgumentException)
-    {
-      // Nothing to do, fallback on the exponential regression
-      LOGINFO("Method of exponential regression failed, using method of probability weighted moment");
-      return buildMethodOfProbabilityWeightedMoments(sample);
-    }
+  {
+    return buildMethodOfExponentialRegression(sample);
+  }
+  catch (InvalidArgumentException &)
+  {
+    // Nothing to do, fallback on the exponential regression
+    LOGINFO("Method of exponential regression failed, using method of probability weighted moment");
+    return buildMethodOfProbabilityWeightedMoments(sample);
+  }
 }
 
 GeneralizedPareto GeneralizedParetoFactory::buildAsGeneralizedPareto(const Point & parameters) const
@@ -109,7 +109,7 @@ GeneralizedPareto GeneralizedParetoFactory::buildAsGeneralizedPareto(const Point
     distribution.setParameter(parameters);
     return distribution;
   }
-  catch (InvalidArgumentException)
+  catch (InvalidArgumentException &)
   {
     throw InvalidArgumentException(HERE) << "Error: cannot build a GeneralizedPareto distribution from the given parameters";
   }
@@ -149,11 +149,11 @@ struct GeneralizedParetoFactoryParameterConstraint
       const Scalar xNm1mJ = sortedSample(size_ - 1 - j, 0);
       const Scalar xNm2mJ = sortedSample(size_ - 2 - j, 0);
       if ((xNm1mJ == xMin) || (xNm2mJ == xMin))
-	{
-	  const String message("Cannot use exponential regression to estimate a GeneralizedPareto distribution when the mininmum value of the sample is repeated");
-	  LOGINFO(message);
-	  throw InvalidArgumentException(HERE) << message;
-	}
+      {
+        const String message("Cannot use exponential regression to estimate a GeneralizedPareto distribution when the mininmum value of the sample is repeated");
+        LOGINFO(message);
+        throw InvalidArgumentException(HERE) << message;
+      }
       sampleY_(j, 0) = (j + 1.0) * std::log((xNm1mJ - xMin) / (xNm2mJ - xMin));
     }
   };
@@ -245,10 +245,10 @@ GeneralizedPareto GeneralizedParetoFactory::buildMethodOfProbabilityWeightedMome
   const Scalar rho = m / mean;
   const Scalar xi = (1.0 - 4.0 * rho) / (1.0 - 2.0 * rho);
   if (xi <= -0.5)
-    {
-      const String message(OSS() << "Error: cannot estimate a GeneralizedPareto distribution with the method of probability weighted moments when the estimated xi parameter=" << xi << " is less than -0.5");
-      throw InvalidArgumentException(HERE) << message;
-    }
+  {
+    const String message(OSS() << "Error: cannot estimate a GeneralizedPareto distribution with the method of probability weighted moments when the estimated xi parameter=" << xi << " is less than -0.5");
+    throw InvalidArgumentException(HERE) << message;
+  }
   // sigma=2*m*/(1-2r)
   const Scalar sigma = 2.0 * m / (1.0 - 2.0 * rho);
   GeneralizedPareto result(sigma, xi);
