@@ -2,7 +2,7 @@
 /**
  *  @brief The Histogram distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -25,6 +25,7 @@
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/Exception.hxx"
 #include "openturns/SpecFunc.hxx"
+#include "openturns/Distribution.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -325,14 +326,14 @@ Point Histogram::getStandardMoment(const UnsignedInteger n) const
 }
 
 /* Get the standard representative in the parametric family, associated with the standard moments */
-Histogram::Implementation Histogram::getStandardRepresentative() const
+Distribution Histogram::getStandardRepresentative() const
 {
   const UnsignedInteger size = width_.getSize();
   // No need to transform an histogram if its range is already [-1.0, 1.0]
   if (first_ == -1.0 && std::abs(cumulatedWidth_[size - 1] - 2.0) <= ResourceMap::GetAsScalar("Distribution-DefaultQuantileEpsilon")) return clone();
   const Scalar first = -1.0;
   const Scalar factor = 2.0 / cumulatedWidth_[size - 1];
-  return Histogram(first, factor * width_, height_ / factor).clone();
+  return new Histogram(first, factor * width_, height_ / factor);
 }
 
 /* Parameters value and description accessor */
@@ -504,10 +505,10 @@ Graph Histogram::drawPDF(const Scalar xMin,
   if ((xMax < first_) || (xMin > first_ + cumulatedWidth_[size - 1]))
   {
     Sample data(2, 2);
-    data[0][0] = xMin;
-    data[0][1] = 0.0;
-    data[1][0] = xMax;
-    data[1][1] = 0.0;
+    data(0, 0) = xMin;
+    data(0, 1) = 0.0;
+    data(1, 0) = xMax;
+    data(1, 1) = 0.0;
     graphPDF.add(Curve(data, "red", "solid", 2, title));
     return graphPDF;
   }
@@ -518,10 +519,10 @@ Graph Histogram::drawPDF(const Scalar xMin,
   if (first_ + cumulatedWidth_[indexLeft] >= xMax)
   {
     Sample data(2, 2);
-    data[0][0] = xMin;
-    data[0][1] = height_[indexLeft];
-    data[1][0] = xMax;
-    data[1][1] = height_[indexLeft];
+    data(0, 0) = xMin;
+    data(0, 1) = height_[indexLeft];
+    data(1, 0) = xMax;
+    data(1, 1) = height_[indexLeft];
     graphPDF.add(Curve(data, "red", "solid", 2, title));
     return graphPDF;
   }
@@ -538,22 +539,22 @@ Graph Histogram::drawPDF(const Scalar xMin,
   if (xMin <= first_)
   {
     Sample data(2, 2);
-    data[0][0] = xMin;
-    data[0][1] = 0.0;
-    data[1][0] = first_;
-    data[1][1] = 0.0;
+    data(0, 0) = xMin;
+    data(0, 1) = 0.0;
+    data(1, 0) = first_;
+    data(1, 1) = 0.0;
     dataFull.add(data);
   }
   // The first class that appears in the graph is only partially included
   else
   {
     Sample data(3, 2);
-    data[0][0] = xMin;
-    data[0][1] = height_[indexLeft];
-    data[1][0] = first_ + cumulatedWidth_[indexLeft];
-    data[1][1] = data[0][1];
-    data[2][0] = data[1][0];
-    data[2][1] = 0.0;
+    data(0, 0) = xMin;
+    data(0, 1) = height_[indexLeft];
+    data(1, 0) = first_ + cumulatedWidth_[indexLeft];
+    data(1, 1) = data(0, 1);
+    data(2, 0) = data(1, 0);
+    data(2, 1) = 0.0;
     dataFull.add(data);
     shiftFull = 1;
   }
@@ -563,37 +564,37 @@ Graph Histogram::drawPDF(const Scalar xMin,
   for (UnsignedInteger i = indexLeft + shiftFull; i < indexRight; ++i)
   {
     Sample data(4, 2);
-    data[0][0] = startX;
-    data[0][1] = 0.0;
-    data[1][0] = startX;
-    data[1][1] = height_[i];
+    data(0, 0) = startX;
+    data(0, 1) = 0.0;
+    data(1, 0) = startX;
+    data(1, 1) = height_[i];
     startX += width_[i];
-    data[2][0] = startX;
-    data[2][1] = height_[i];
-    data[3][0] = startX;
-    data[3][1] = 0.0;
+    data(2, 0) = startX;
+    data(2, 1) = height_[i];
+    data(3, 0) = startX;
+    data(3, 1) = 0.0;
     dataFull.add(data);
   }
   // The last class is completely included
   if (indexRight == size)
   {
     Sample data(2, 2);
-    data[0][0] = first_ + cumulatedWidth_[size - 1];
-    data[0][1] = 0.0;
-    data[1][0] = xMax;
-    data[1][1] = 0.0;
+    data(0, 0) = first_ + cumulatedWidth_[size - 1];
+    data(0, 1) = 0.0;
+    data(1, 0) = xMax;
+    data(1, 1) = 0.0;
     dataFull.add(data);
   }
   // The last class that appears in the graph is only partially included
   else
   {
     Sample data(3, 2);
-    data[0][0] = first_ + cumulatedWidth_[indexRight - 1];
-    data[0][1] = 0.0;
-    data[1][0] = data[0][0];
-    data[1][1] = height_[indexRight];
-    data[2][0] = xMax;
-    data[2][1] = height_[indexRight];
+    data(0, 0) = first_ + cumulatedWidth_[indexRight - 1];
+    data(0, 1) = 0.0;
+    data(1, 0) = data(0, 0);
+    data(1, 1) = height_[indexRight];
+    data(2, 0) = xMax;
+    data(2, 1) = height_[indexRight];
     dataFull.add(data);
   }
   Curve curve(dataFull, "red", "solid", 2, "");
