@@ -2,7 +2,7 @@
 /**
  *  @brief The InverseChiSquare distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -24,6 +24,7 @@
 #include "openturns/SpecFunc.hxx"
 #include "openturns/DistFunc.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
+#include "openturns/Distribution.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -203,6 +204,12 @@ Scalar InverseChiSquare::computeComplementaryCDF(const Point & point) const
   return DistFunc::pGamma(0.5 * nu_, 0.5 / x);
 }
 
+/* Compute the entropy of the distribution */
+Scalar InverseChiSquare::computeEntropy() const
+{
+  return 0.5 * nu_ - M_LN2 + SpecFunc::LogGamma(0.5 * nu_) - (1.0 + 0.5 * nu_) * SpecFunc::Psi(0.5 * nu_);
+}
+
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
 Complex InverseChiSquare::computeCharacteristicFunction(const Scalar x) const
 {
@@ -288,9 +295,9 @@ Point InverseChiSquare::getStandardMoment(const UnsignedInteger n) const
 }
 
 /* Get the standard representative in the parametric family, associated with the standard moments */
-InverseChiSquare::Implementation InverseChiSquare::getStandardRepresentative() const
+Distribution InverseChiSquare::getStandardRepresentative() const
 {
-  return InverseChiSquare(nu_).clone();
+  return new InverseChiSquare(nu_);
 }
 
 /* Compute the covariance of the distribution */
