@@ -2,7 +2,7 @@
 /**
  *  @brief The InverseGamma distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -24,6 +24,7 @@
 #include "openturns/SpecFunc.hxx"
 #include "openturns/DistFunc.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
+#include "openturns/Distribution.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -238,6 +239,12 @@ Scalar InverseGamma::computeComplementaryCDF(const Point & point) const
   return DistFunc::pGamma(k_, 1.0 / (lambda_ * x));
 }
 
+/* Compute the entropy of the distribution */
+Scalar InverseGamma::computeEntropy() const
+{
+  return SpecFunc::LogGamma(k_) - (k_ + 1.0) * SpecFunc::Psi(k_) + k_ - std::log(lambda_);
+}
+
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
 Complex InverseGamma::computeCharacteristicFunction(const Scalar x) const
 {
@@ -323,9 +330,9 @@ Point InverseGamma::getStandardMoment(const UnsignedInteger n) const
 }
 
 /* Get the standard representative in the parametric family, associated with the standard moments */
-InverseGamma::Implementation InverseGamma::getStandardRepresentative() const
+Distribution InverseGamma::getStandardRepresentative() const
 {
-  return InverseGamma(k_, 1.0).clone();
+  return new InverseGamma(k_, 1.0);
 }
 
 /* Compute the covariance of the distribution */
