@@ -2,7 +2,7 @@
 /**
  *  @brief The KPermutationsDistribution distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -46,8 +46,7 @@ KPermutationsDistribution::KPermutationsDistribution()
   , n_(0)
 {
   setName("KPermutationsDistribution");
-  setK(1);
-  setN(1);
+  setKN(1, 1);
 }
 
 /* Parameters constructor */
@@ -58,9 +57,7 @@ KPermutationsDistribution::KPermutationsDistribution(const UnsignedInteger k,
   , n_(0)
 {
   setName("KPermutationsDistribution");
-  // This method compute the range also
-  setK(k);
-  setN(n);
+  setKN(k, n);
 }
 
 /* Comparison operator */
@@ -137,7 +134,7 @@ Scalar KPermutationsDistribution::computeLogPDF(const Point & point) const
     const Scalar k = point[i];
     if ((k < -supportEpsilon_) || (k > n_ + supportEpsilon_)) return SpecFunc::LogMinScalar;
     const UnsignedInteger ik = static_cast< UnsignedInteger > (round(k));
-    if (std::abs(k - ik) > supportEpsilon_) return SpecFunc::LogMinScalar;
+    if (std::abs(k - ik) > supportEpsilon_) return -SpecFunc::LogMaxScalar;
     x[i] = ik;
   }
   if (!x.check(n_)) return 0.0;
@@ -147,7 +144,7 @@ Scalar KPermutationsDistribution::computeLogPDF(const Point & point) const
 Scalar KPermutationsDistribution::computePDF(const Point & point) const
 {
   const Scalar logPDF = computeLogPDF(point);
-  if (logPDF == SpecFunc::LogMinScalar) return 0.0;
+  if (logPDF == -SpecFunc::LogMaxScalar) return 0.0;
   return std::exp(logPDF);
 }
 
@@ -179,18 +176,45 @@ Scalar KPermutationsDistribution::computeScalarQuantile(const Scalar prob,
   return (tail ? n_ - 1.0 - i : i);
 } // computeScalarQuantile
 
+/* Compute the quantile of the KPermutationsDistribution distribution */
+Point KPermutationsDistribution::computeQuantile(const Scalar prob,
+    const Bool tail,
+    Scalar & marginalProb) const
+{
+  const Scalar p = (tail ? 1.0 - prob : prob);
+  if (p <= 0.0) return Point(k_, 0.0);
+  if (p >= 1.0) return Point(k_, n_);
+  UnsignedInteger iMin = 0;
+  UnsignedInteger iMax = n_;
+  while (iMax > iMin + 1)
+  {
+    const UnsignedInteger iMiddle = (iMax + iMin) / 2;
+    const Scalar cdfMiddle = computeCDF(Point(k_, iMiddle));
+    if (cdfMiddle < p)
+    {
+      iMin = iMiddle;
+    }
+    else
+    {
+      iMax = iMiddle;
+    }
+  } // while
+  marginalProb = computeScalarQuantile(prob, tail);
+  return Point(k_, iMax);
+} // computeQuantile
+
 /* Get the i-th marginal distribution */
-KPermutationsDistribution::Implementation KPermutationsDistribution::getMarginal(const UnsignedInteger i) const
+Distribution KPermutationsDistribution::getMarginal(const UnsignedInteger i) const
 {
   const UnsignedInteger dimension = getDimension();
   if (i >= dimension) throw InvalidArgumentException(HERE) << "The index of a marginal distribution must be in the range [0, dim-1]";
-  KPermutationsDistribution marginal(1, n_);
-  marginal.setDescription(Description(1, getDescription()[i]));
-  return marginal.clone();
+  KPermutationsDistribution::Implementation marginal(new KPermutationsDistribution(1, n_));
+  marginal->setDescription(Description(1, getDescription()[i]));
+  return marginal;
 }
 
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
-KPermutationsDistribution::Implementation KPermutationsDistribution::getMarginal(const Indices & indices) const
+Distribution KPermutationsDistribution::getMarginal(const Indices & indices) const
 {
   const UnsignedInteger dimension = getDimension();
   if (!indices.check(dimension)) throw InvalidArgumentException(HERE) << "The indices of a marginal distribution must be in the range [0, dim-1] and must be different";
@@ -205,16 +229,25 @@ KPermutationsDistribution::Implementation KPermutationsDistribution::getMarginal
     const UnsignedInteger index_i = indices[i];
     marginalDescription[i] = description[index_i];
   }
-  KPermutationsDistribution marginal(outputDimension, n_);
-  marginal.setDescription(marginalDescription);
-  return marginal.clone();
+  KPermutationsDistribution::Implementation marginal(new KPermutationsDistribution(outputDimension, n_));
+  marginal->setDescription(marginalDescription);
+  return marginal;
 } // getMarginal(Indices)
 
 /* Get the support of a discrete distribution that intersect a given interval */
 Sample KPermutationsDistribution::getSupport(const Interval & interval) const
 {
   if (interval.getDimension() != getDimension()) throw InvalidArgumentException(HERE) << "Error: the given interval has a dimension that does not match the distribution dimension.";
-  return KPermutations(k_, n_).generate();
+  // Convert int values into float
+  const IndicesCollection intResult(KPermutations(k_, n_).generate());
+  const UnsignedInteger size = intResult.getSize();
+  if (size == 0) return Sample();
+  const UnsignedInteger dimension = intResult.cend_at(0) - intResult.cbegin_at(0);
+  Sample result(size, dimension);
+  for (UnsignedInteger i = 0; i < size; ++i)
+    for (UnsignedInteger j = 0; j < dimension; ++j)
+      result(i, j) = intResult(i, j);
+  return result;
 }
 
 /* Compute the mean of the distribution */
@@ -268,10 +301,11 @@ KPermutationsDistribution::PointWithDescriptionCollection KPermutationsDistribut
 void KPermutationsDistribution::setK(const UnsignedInteger k)
 {
   if (k == 0) throw InvalidArgumentException(HERE) << "Error: k must be > 0.";
+  if (k > n_) throw InvalidArgumentException(HERE) << "Error: k must be less or equal to n, here k=" << k << " and n=" << n_;
   if (k != k_)
   {
     k_ = k;
-    logPDFValue_ = SpecFunc::LnGamma(k_ + 1) - SpecFunc::LnGamma(n_ + 1);
+    logPDFValue_ = SpecFunc::LnGamma(n_ - k_ + 1) - SpecFunc::LnGamma(n_ + 1);
     setDimension(k);
     isAlreadyComputedMean_ = false;
     isAlreadyComputedCovariance_ = false;
@@ -289,10 +323,11 @@ UnsignedInteger KPermutationsDistribution::getK() const
 void KPermutationsDistribution::setN(const UnsignedInteger n)
 {
   if (n == 0) throw InvalidArgumentException(HERE) << "Error: n must be > 0.";
+  if (n < k_) throw InvalidArgumentException(HERE) << "Error: n must be greater or equal to k, here n=" << n << " and k=" << k_;
   if (n != n_)
   {
     n_ = n;
-    logPDFValue_ = SpecFunc::LnGamma(k_ + 1) - SpecFunc::LnGamma(n_ + 1);
+    logPDFValue_ = SpecFunc::LnGamma(n_ - k_ + 1) - SpecFunc::LnGamma(n_ + 1);
     isAlreadyComputedMean_ = false;
     isAlreadyComputedCovariance_ = false;
     computeRange();
@@ -304,6 +339,22 @@ UnsignedInteger KPermutationsDistribution::getN() const
   return n_;
 }
 
+/* K/N accessor */
+void KPermutationsDistribution::setKN(const UnsignedInteger k,
+                                      const UnsignedInteger n)
+{
+  if (k == 0) throw InvalidArgumentException(HERE) << "Error: k must be > 0.";
+  if (n == 0) throw InvalidArgumentException(HERE) << "Error: n must be > 0.";
+  if (k > n) throw InvalidArgumentException(HERE) << "Error: k must be less or equal to n, here k=" << k << " and n=" << n;
+  k_ = k;
+  setDimension(k);
+  n_ = n;
+  logPDFValue_ = SpecFunc::LnGamma(n_ - k_ + 1) - SpecFunc::LnGamma(n_ + 1);
+  isAlreadyComputedMean_ = false;
+  isAlreadyComputedCovariance_ = false;
+  computeRange();
+}
+
 /* Method save() stores the object through the StorageManager */
 void KPermutationsDistribution::save(Advocate & adv) const
 {
