@@ -8,7 +8,7 @@
  *         where:
  *         C = \frac{1}{N\prod_{k=1}^n h_k}
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -20,7 +20,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -220,7 +220,7 @@ Point KernelMixture::getRealization() const
   // Then add a random noise according to the product kernel
   const UnsignedInteger dimension = getDimension();
   const Sample kernelSample(kernel_.getSample(dimension));
-  for (UnsignedInteger i = 0; i < dimension; ++i) result[i] += bandwidth_[i] * kernelSample[i][0];
+  for (UnsignedInteger i = 0; i < dimension; ++i) result[i] += bandwidth_[i] * kernelSample(i, 0);
   return result;
 }
 
@@ -241,7 +241,7 @@ Point KernelMixture::computeDDF(const Point & point) const
     Scalar pdfAtom = 1.0;
     for (UnsignedInteger j = 0; j < dimension; ++j)
     {
-      atom[j] = (point[j] - sample_[i][j]) * bandwidthInverse_[j];
+      atom[j] = (point[j] - sample_(i, j)) * bandwidthInverse_[j];
       kernelPdfAtom[j] = kernel_.computePDF(Point(1, atom[j]));
       pdfAtom *= kernelPdfAtom[j];
     }
@@ -271,7 +271,7 @@ Scalar KernelMixture::computePDF(const Point & point) const
   {
     const Scalar x = point[0];
     const Scalar h = bandwidth_[0];
-    for(UnsignedInteger i = 0; i < size; ++i) pdfValue += kernel_.computePDF((x - sample_[i][0]) / h);
+    for(UnsignedInteger i = 0; i < size; ++i) pdfValue += kernel_.computePDF((x - sample_(i, 0)) / h);
     return pdfValue / (h * size);
   }
   // Quick rejection test
@@ -279,11 +279,11 @@ Scalar KernelMixture::computePDF(const Point & point) const
   const Scalar pdfEpsilon = kernel_.getPDFEpsilon();
   for(UnsignedInteger i = 0; i < size; ++i)
   {
-    Scalar pdfAtom = kernel_.computePDF(Point(1, (point[0] - sample_[i][0]) * bandwidthInverse_[0]));
+    Scalar pdfAtom = kernel_.computePDF(Point(1, (point[0] - sample_(i, 0)) * bandwidthInverse_[0]));
     for (UnsignedInteger j = 1; j < dimension; ++j)
     {
       if (pdfAtom < pdfEpsilon) break;
-      pdfAtom *= kernel_.computePDF(Point(1, (point[j] - sample_[i][j]) * bandwidthInverse_[j]));
+      pdfAtom *= kernel_.computePDF(Point(1, (point[j] - sample_(i, j)) * bandwidthInverse_[j]));
     }
     pdfValue += pdfAtom;
   } /* end for */
@@ -307,7 +307,7 @@ Scalar KernelMixture::computeCDF(const Point & point) const
     const Scalar x = point[0];
     const Scalar h = bandwidth_[0];
     for(UnsignedInteger i = 0; i < size; ++i)
-      cdfValue += kernel_.computeCDF((x - sample_[i][0]) / h);
+      cdfValue += kernel_.computeCDF((x - sample_(i, 0)) / h);
     return cdfValue / size;
   }
   // Check against the range of the distribution
@@ -325,11 +325,11 @@ Scalar KernelMixture::computeCDF(const Point & point) const
   const Scalar cdfEpsilon = kernel_.getCDFEpsilon();
   for (UnsignedInteger i = 0; i < size; ++i)
   {
-    Scalar cdfAtom = kernel_.computeCDF((point[0] - sample_[i][0]) * bandwidthInverse_[0]);
+    Scalar cdfAtom = kernel_.computeCDF((point[0] - sample_(i, 0)) * bandwidthInverse_[0]);
     for (UnsignedInteger j = 1; j < dimension; ++j)
     {
       if (cdfAtom < cdfEpsilon) break;
-      cdfAtom *= kernel_.computeCDF((point[j] - sample_[i][j]) * bandwidthInverse_[j]);
+      cdfAtom *= kernel_.computeCDF((point[j] - sample_(i, j)) * bandwidthInverse_[j]);
     }
     cdfValue += cdfAtom;
   } /* end for */
@@ -379,15 +379,14 @@ Scalar KernelMixture::computeSurvivalFunction(const Point & point) const
   const UnsignedInteger size = sample_.getSize();
   for (UnsignedInteger i = 0; i < size; ++i)
   {
-    Scalar cdfAtom = kernel_.computeSurvivalFunction((point[0] - sample_[i][0]) * bandwidthInverse_[0]);
+    Scalar cdfAtom = kernel_.computeSurvivalFunction((point[0] - sample_(i, 0)) * bandwidthInverse_[0]);
     for (UnsignedInteger j = 1; j < dimension; ++j)
     {
       if (cdfAtom < cdfEpsilon) break;
-      cdfAtom *= kernel_.computeSurvivalFunction((point[j] - sample_[i][j]) * bandwidthInverse_[j]);
+      cdfAtom *= kernel_.computeSurvivalFunction((point[j] - sample_(i, j)) * bandwidthInverse_[j]);
     }
     survivalValue += cdfAtom;
   } /* end for */
-  cdfEpsilon_ = kernel_.getCDFEpsilon() * size;
   return survivalValue / size;
 }
 
@@ -413,17 +412,17 @@ Scalar KernelMixture::computeProbability(const Interval & interval) const
   {
     const Scalar hInverse = bandwidthInverse_[0];
     for(UnsignedInteger i = 0; i < size; ++i)
-      probability += kernel_.computeProbability(Interval((lowerBound[0] - sample_[i][0]) * hInverse, (upperBound[0] - sample_[i][0]) * hInverse));
+      probability += kernel_.computeProbability(Interval((lowerBound[0] - sample_(i, 0)) * hInverse, (upperBound[0] - sample_(i, 0)) * hInverse));
     return probability / size;
   }
   const Scalar probabilityEpsilon = kernel_.getCDFEpsilon();
   for (UnsignedInteger i = 0; i < size; ++i)
   {
-    Scalar probabilityAtom = kernel_.computeProbability(Interval((lowerBound[0] - sample_[i][0]) * bandwidthInverse_[0], (upperBound[0] - sample_[i][0]) * bandwidthInverse_[0]));
+    Scalar probabilityAtom = kernel_.computeProbability(Interval((lowerBound[0] - sample_(i, 0)) * bandwidthInverse_[0], (upperBound[0] - sample_(i, 0)) * bandwidthInverse_[0]));
     for (UnsignedInteger j = 1; j < dimension; ++j)
     {
       if (probabilityAtom < probabilityEpsilon) break;
-      probabilityAtom *= kernel_.computeProbability(Interval((lowerBound[j] - sample_[i][j]) * bandwidthInverse_[j], (upperBound[j] - sample_[i][j]) * bandwidthInverse_[j]));
+      probabilityAtom *= kernel_.computeProbability(Interval((lowerBound[j] - sample_(i, j)) * bandwidthInverse_[j], (upperBound[j] - sample_(i, j)) * bandwidthInverse_[j]));
     }
     probability += probabilityAtom;
   } /* end for */
@@ -446,15 +445,15 @@ Scalar KernelMixture::computeScalarQuantile(const Scalar prob,
     // equivalent to CDF(x) = 1 - prob, but numerically different with an
     // accuracy that depends on prob.
     // The cut-off is around the mean value
-    if (prob <= ccdfApproximation_.getValues()[0][0]) return Brent(quantileEpsilon_, cdfEpsilon_, cdfEpsilon_, quantileIterations_).solve(ccdfApproximation_, prob, ccdfApproximation_.getLocations()[0], ccdfApproximation_.getLocations()[n - 1], ccdfApproximation_.getValues()[0][0], ccdfApproximation_.getValues()[n - 1][0]);
-    return Brent(quantileEpsilon_, cdfEpsilon_, cdfEpsilon_, quantileIterations_).solve(cdfApproximation_, 1.0 - prob, cdfApproximation_.getLocations()[0], cdfApproximation_.getLocations()[n - 1], cdfApproximation_.getValues()[0][0], cdfApproximation_.getValues()[n - 1][0]);
+    if (prob <= ccdfApproximation_.getValues()(0, 0)) return Brent(quantileEpsilon_, cdfEpsilon_, cdfEpsilon_, quantileIterations_).solve(ccdfApproximation_, prob, ccdfApproximation_.getLocations()[0], ccdfApproximation_.getLocations()[n - 1], ccdfApproximation_.getValues()(0, 0), ccdfApproximation_.getValues()[n - 1][0]);
+    return Brent(quantileEpsilon_, cdfEpsilon_, cdfEpsilon_, quantileIterations_).solve(cdfApproximation_, 1.0 - prob, cdfApproximation_.getLocations()[0], cdfApproximation_.getLocations()[n - 1], cdfApproximation_.getValues()(0, 0), cdfApproximation_.getValues()[n - 1][0]);
   }
   // Here we have to solve CDF(x) = prob which is mathematically
   // equivalent to ComplementaryCDF(x) = 1 - prob, but numerically
   // different with an accuracy that depends on prob.
   // The cut-off is around the mean value
-  if (prob <= cdfApproximation_.getValues()[n - 1][0]) return Brent(quantileEpsilon_, cdfEpsilon_, cdfEpsilon_, quantileIterations_).solve(cdfApproximation_, prob, cdfApproximation_.getLocations()[0], cdfApproximation_.getLocations()[n - 1], cdfApproximation_.getValues()[0][0], cdfApproximation_.getValues()[n - 1][0]);
-  return Brent(quantileEpsilon_, cdfEpsilon_, cdfEpsilon_, quantileIterations_).solve(ccdfApproximation_, 1.0 - prob, ccdfApproximation_.getLocations()[0], ccdfApproximation_.getLocations()[n - 1], ccdfApproximation_.getValues()[0][0], ccdfApproximation_.getValues()[n - 1][0]);
+  if (prob <= cdfApproximation_.getValues()[n - 1][0]) return Brent(quantileEpsilon_, cdfEpsilon_, cdfEpsilon_, quantileIterations_).solve(cdfApproximation_, prob, cdfApproximation_.getLocations()[0], cdfApproximation_.getLocations()[n - 1], cdfApproximation_.getValues()(0, 0), cdfApproximation_.getValues()[n - 1][0]);
+  return Brent(quantileEpsilon_, cdfEpsilon_, cdfEpsilon_, quantileIterations_).solve(ccdfApproximation_, 1.0 - prob, ccdfApproximation_.getLocations()[0], ccdfApproximation_.getLocations()[n - 1], ccdfApproximation_.getValues()(0, 0), ccdfApproximation_.getValues()[n - 1][0]);
 }
 
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
@@ -465,7 +464,7 @@ Complex KernelMixture::computeCharacteristicFunction(const Scalar x) const
   const UnsignedInteger size = sample_.getSize();
   for(UnsignedInteger i = 0; i < size; ++i)
   {
-    cfValue += kernel_.computeCharacteristicFunction(x * bandwidth_[0]) * std::exp(Complex(0.0, sample_[i][0] * x));
+    cfValue += kernel_.computeCharacteristicFunction(x * bandwidth_[0]) * std::exp(Complex(0.0, sample_(i, 0) * x));
   } /* end for */
   return cfValue * (1.0 / size);
 }
@@ -489,20 +488,20 @@ Point KernelMixture::computeCDFGradient(const Point & point) const
 }
 
 /* Get the i-th marginal distribution */
-KernelMixture::Implementation KernelMixture::getMarginal(const UnsignedInteger i) const
+Distribution KernelMixture::getMarginal(const UnsignedInteger i) const
 {
   const UnsignedInteger dimension = getDimension();
   if (i >= dimension) throw InvalidArgumentException(HERE) << "The index of a marginal distribution must be in the range [0, dim-1]";
   // Special case for dimension 1
   if (dimension == 1) return clone();
   // General case
-  KernelMixture marginal(kernel_, Point(1, bandwidth_[i]), sample_.getMarginal(i));
-  marginal.setDescription(Description(1, getDescription()[i]));
-  return marginal.clone();
+  KernelMixture::Implementation marginal(new KernelMixture(kernel_, Point(1, bandwidth_[i]), sample_.getMarginal(i)));
+  marginal->setDescription(Description(1, getDescription()[i]));
+  return marginal;
 }
 
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
-KernelMixture::Implementation KernelMixture::getMarginal(const Indices & indices) const
+Distribution KernelMixture::getMarginal(const Indices & indices) const
 {
   const UnsignedInteger dimension = getDimension();
   if (!indices.check(dimension)) throw InvalidArgumentException(HERE) << "The indices of a marginal distribution must be in the range [0, dim-1] and must be different";
@@ -519,9 +518,9 @@ KernelMixture::Implementation KernelMixture::getMarginal(const Indices & indices
     marginalBandwidth[i] = bandwidth_[index_i];
     marginalDescription[i] = description[index_i];
   }
-  KernelMixture marginal(kernel_, marginalBandwidth, sample_.getMarginal(indices));
-  marginal.setDescription(marginalDescription);
-  return marginal.clone();
+  KernelMixture::Implementation marginal(new KernelMixture(kernel_, marginalBandwidth, sample_.getMarginal(indices)));
+  marginal->setDescription(marginalDescription);
+  return marginal;
 }
 
 /* Compute the mean of the KernelMixture
@@ -626,7 +625,7 @@ KernelMixture::PointWithDescriptionCollection KernelMixture::getParametersCollec
     Description description(marginalParameters.getDimension());
     for (UnsignedInteger j = 0; j < size; ++j)
     {
-      marginalParameters[j] = sample_[j][i];
+      marginalParameters[j] = sample_(j, i);
       if (dimension > 1) description[j] = (OSS() << "x_" << j << "^" << i);
       else description[j] = (OSS() << "x_" << j);
     }
@@ -645,7 +644,7 @@ KernelMixture::PointWithDescriptionCollection KernelMixture::getParametersCollec
     for (UnsignedInteger i = 0; i < size; ++i)
       for (UnsignedInteger j = 0; j < dimension; ++j)
       {
-        dependence[index] = sample_[i][j];
+        dependence[index] = sample_(i, j);
         description[index] = (OSS() << "x_" << i << "^" << j);
         ++index;
       }
@@ -707,7 +706,7 @@ void KernelMixture::setParameter(const Point & parameter)
   {
     for (UnsignedInteger j = 0; j < dimension; ++ j)
     {
-      sample_[i][j] = parameter[index];
+      sample_(i, j) = parameter[index];
       ++ index;
     }
   }
