@@ -2,7 +2,7 @@
 /**
  *  @brief This class acts like a KernelMixture factory, implementing a
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -134,7 +134,7 @@ struct PluginConstraint
     {
       for (UnsignedInteger j = 0; j < i; ++j)
       {
-        const Scalar dx = sample_[i][0] - sample_[j][0];
+        const Scalar dx = sample_(i, 0) - sample_(j, 0);
         const Scalar x = dx / h;
         // Clipping: if x is large enough, the exponential factor is 0.0
         if (std::abs(x) < cutOffPlugin) phi += 2.0 * hermitePolynomial_(x) * std::exp(-0.5 * x * x);
@@ -215,14 +215,14 @@ Point KernelSmoothing::computeMixedBandwidth(const Sample & sample) const
   // Small sample, just return the plugin bandwidth
   if (size <= ResourceMap::GetAsUnsignedInteger( "KernelSmoothing-SmallSize" )) return computePluginBandwidth(sample);
   Sample smallSample(ResourceMap::GetAsUnsignedInteger( "KernelSmoothing-SmallSize" ), 1);
-  for (UnsignedInteger i = 0; i < ResourceMap::GetAsUnsignedInteger( "KernelSmoothing-SmallSize" ); ++i) smallSample[i][0] = sample[i][0];
+  for (UnsignedInteger i = 0; i < ResourceMap::GetAsUnsignedInteger( "KernelSmoothing-SmallSize" ); ++i) smallSample(i, 0) = sample(i, 0);
   const Scalar h1 = computePluginBandwidth(smallSample)[0];
   const Scalar h2 = computeSilvermanBandwidth(smallSample)[0];
   return computeSilvermanBandwidth(sample) * (h1 / h2);
 }
 
 /* Build a Normal kernel mixture based on the given sample. If no bandwith has already been set, Silverman's rule is used */
-KernelSmoothing::Implementation KernelSmoothing::build(const Sample & sample) const
+Distribution KernelSmoothing::build(const Sample & sample) const
 {
   // For 1D sample, use the rule that give the best tradeoff between speed and precision
   if (sample.getDimension() == 1) return build(sample, computeMixedBandwidth(sample));
@@ -235,8 +235,8 @@ KernelSmoothing::Implementation KernelSmoothing::build(const Sample & sample) co
  * If boundary correction: mirroring on the two sides, followed by truncation
  * If binning: condensation on a regular grid
  */
-KernelSmoothing::Implementation KernelSmoothing::build(const Sample & sample,
-    const Point & bandwidth) const
+Distribution KernelSmoothing::build(const Sample & sample,
+                                    const Point & bandwidth) const
 {
   const UnsignedInteger dimension = sample.getDimension();
   if (bandwidth.getDimension() != dimension) throw InvalidDimensionException(HERE) << "Error: the given bandwidth must have the same dimension as the given sample, here bandwidth dimension=" << bandwidth.getDimension() << " and sample dimension=" << dimension;
@@ -247,17 +247,17 @@ KernelSmoothing::Implementation KernelSmoothing::build(const Sample & sample,
   if (bined_ != mustBin) LOGINFO("Will not bin the data because the bin number is greater than the sample size");
   if ((dimension > 2) || ((!mustBin) && (!boundaryCorrection_)))
   {
-    KernelMixture result(kernel_, bandwidth, sample);
-    result.setDescription(sample.getDescription());
-    return result.clone();
+    KernelSmoothing::Implementation result(new KernelMixture(kernel_, bandwidth, sample));
+    result->setDescription(sample.getDescription());
+    return result;
   }
   const Point xmin(sample.getMin());
   const Point xmax(sample.getMax());
   if (xmin == xmax)
   {
-    Dirac result(xmin);
-    result.setDescription(sample.getDescription());
-    return result.clone();
+    KernelSmoothing::Implementation result(new Dirac(xmin));
+    result->setDescription(sample.getDescription());
+    return result;
   }
   // 2D binning?
   if ((dimension == 2) && mustBin)
@@ -277,11 +277,11 @@ KernelSmoothing::Implementation KernelSmoothing::build(const Sample & sample,
     for (UnsignedInteger i = 0; i < size; ++i)
     {
       UnsignedInteger indexX = 0;
-      Scalar sliceX = (sample[i][0] - (xmin[0] - hX)) / deltaX;
+      Scalar sliceX = (sample(i, 0) - (xmin[0] - hX)) / deltaX;
       if (sliceX >= 0.0) indexX = static_cast< UnsignedInteger > (trunc(sliceX));
       if (indexX >= binNumber_) indexX = binNumber_ - 1;
       UnsignedInteger indexY = 0;
-      Scalar sliceY = (sample[i][1] - (xmin[1] - hY)) / deltaY;
+      Scalar sliceY = (sample(i, 1) - (xmin[1] - hY)) / deltaY;
       if (sliceY >= 0.0) indexY = static_cast< UnsignedInteger > (trunc(sliceY));
       if (indexY >= binNumber_) indexY = binNumber_ - 1;
       ++reducedData[indexX + indexY * binNumber_];
@@ -298,9 +298,9 @@ KernelSmoothing::Implementation KernelSmoothing::build(const Sample & sample,
         atoms[i + j * binNumber_] = atom;
       }
     }
-    Mixture result(atoms, reducedData);
-    result.setDescription(sample.getDescription());
-    return result.clone();
+    KernelSmoothing::Implementation result(new Mixture(atoms, reducedData));
+    result->setDescription(sample.getDescription());
+    return result;
   } // 2D binning
 
   // Here we are in the 1D case, with at least binning or boundary boundary correction
@@ -322,9 +322,9 @@ KernelSmoothing::Implementation KernelSmoothing::build(const Sample & sample,
   // Now, work on the extended sample
   if (!mustBin)
   {
-    TruncatedDistribution result(KernelMixture(kernel_, bandwidth, newSample), xmin[0], xmax[0]);
-    result.setDescription(sample.getDescription());
-    return result.clone();
+    KernelSmoothing::Implementation result(new TruncatedDistribution(KernelMixture(kernel_, bandwidth, newSample), xmin[0], xmax[0]));
+    result->setDescription(sample.getDescription());
+    return result;
   }
   if (boundaryCorrection_)
   {
@@ -341,7 +341,7 @@ KernelSmoothing::Implementation KernelSmoothing::build(const Sample & sample,
   for (UnsignedInteger i = 0; i < size; ++i)
   {
     UnsignedInteger index = 0;
-    Scalar slice = (newSample[i][0] - (xminNew - h)) / delta;
+    Scalar slice = (newSample(i, 0) - (xminNew - h)) / delta;
     if (slice >= 0.0) index = static_cast< UnsignedInteger > (trunc(slice));
     if (index >= binNumber_) index = binNumber_ - 1;
     ++reducedData[index];
@@ -354,13 +354,13 @@ KernelSmoothing::Implementation KernelSmoothing::build(const Sample & sample,
   }
   if (boundaryCorrection_)
   {
-    TruncatedDistribution result(Mixture(atoms, reducedData), xmin[0], xmax[0]);
-    result.setDescription(sample.getDescription());
-    return result.clone();
+    KernelSmoothing::Implementation result(new TruncatedDistribution(Mixture(atoms, reducedData), xmin[0], xmax[0]));
+    result->setDescription(sample.getDescription());
+    return result;
   }
-  Mixture result(atoms, reducedData);
-  result.setDescription(sample.getDescription());
-  return result.clone();
+  KernelSmoothing::Implementation result(new Mixture(atoms, reducedData));
+  result->setDescription(sample.getDescription());
+  return result;
 }
 
 /* Bandwidth accessor */
