@@ -2,7 +2,7 @@
 /**
  *  @brief The Laplace distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -23,6 +23,7 @@
 #include "openturns/SpecFunc.hxx"
 #include "openturns/RandomGenerator.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
+#include "openturns/Distribution.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -149,6 +150,12 @@ Scalar Laplace::computeComplementaryCDF(const Point & point) const
   return 0.5 * std::exp(-u);
 }
 
+/* Compute the entropy of the distribution */
+Scalar Laplace::computeEntropy() const
+{
+  return 1.0 + M_LN2 - std::log(lambda_);
+}
+
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
 Complex Laplace::computeCharacteristicFunction(const Scalar x) const
 {
@@ -230,9 +237,9 @@ Point Laplace::getStandardMoment(const UnsignedInteger n) const
 }
 
 /* Get the standard representative in the parametric family, associated with the standard moments */
-Laplace::Implementation Laplace::getStandardRepresentative() const
+Distribution Laplace::getStandardRepresentative() const
 {
-  return Laplace(1.0, 0.0).clone();
+  return new Laplace(1.0, 0.0);
 }
 
 /* Compute the covariance of the distribution */
