@@ -2,7 +2,7 @@
 /**
  *  @brief The LogNormal distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -188,6 +188,12 @@ Scalar LogNormal::computeComplementaryCDF(const Point & point) const
 }
 
 
+/* Compute the entropy of the distribution */
+Scalar LogNormal::computeEntropy() const
+{
+  return 0.5 + muLog_ - std::log(normalizationFactor_);
+}
+
 /* Compute the integrand that is involved in the computation of the characteristic function */
 Complex LogNormal::characteristicIntegrand(const Scalar eta,
     const Scalar sStar) const
@@ -334,9 +340,9 @@ Point LogNormal::getStandardMoment(const UnsignedInteger n) const
 }
 
 /* Get the standard representative in the parametric family, associated with the standard moments */
-LogNormal::Implementation LogNormal::getStandardRepresentative() const
+Distribution LogNormal::getStandardRepresentative() const
 {
-  return LogNormal(muLog_, sigmaLog_, 0.0).clone();
+  return new LogNormal(muLog_, sigmaLog_, 0.0);
 }
 
 /* Compute the covariance of the distribution */
