@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for LogNormal distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -98,7 +98,7 @@ struct LogNormalFactoryLMLEParameterConstraint
     Point sums(4, 0.0);
     for (UnsignedInteger i = 0; i < size_; ++i)
     {
-      const Scalar delta = sample_[i][0] - gamma;
+      const Scalar delta = sample_(i, 0) - gamma;
       if (!(delta > 0.0)) throw InvalidArgumentException(HERE) << "Error: cannot estimate a LogNormal distribution based on the given sample using the method of local maximum likelihood, probably because the sample is constant.";
       const Scalar logDelta = std::log(delta);
       const Scalar inverseDelta = 1.0 / delta;
@@ -232,23 +232,23 @@ LogNormal LogNormalFactory::buildMethodOfModifiedMoments(const Sample & sample)
   return LogNormal(mu, sigma, gamma);
 }
 
-LogNormalFactory::Implementation LogNormalFactory::build(const Sample & sample) const
+Distribution LogNormalFactory::build(const Sample & sample) const
 {
   return build(sample, ResourceMap::GetAsUnsignedInteger("LogNormalFactory-EstimationMethod"));
 }
 
-LogNormalFactory::Implementation LogNormalFactory::build(const Sample & sample,
-    const UnsignedInteger method) const
+Distribution LogNormalFactory::build(const Sample & sample,
+                                     const UnsignedInteger method) const
 {
   return buildAsLogNormal(sample, method).clone();
 }
 
-LogNormalFactory::Implementation LogNormalFactory::build() const
+Distribution LogNormalFactory::build() const
 {
   return buildAsLogNormal().clone();
 }
 
-LogNormalFactory::Implementation LogNormalFactory::build(const Point & parameters) const
+Distribution LogNormalFactory::build(const Point & parameters) const
 {
   return buildAsLogNormal(parameters).clone();
 }
@@ -271,7 +271,7 @@ LogNormal LogNormalFactory::buildAsLogNormal(const Sample & sample,
       {
         return buildMethodOfLocalLikelihoodMaximization(sample);
       }
-      catch (InvalidArgumentException)
+      catch (InvalidArgumentException &)
       {
         // We switch to the moment estimate
         LOGWARN(OSS() << "Warning! Unable to bracket the location parameter gamma. Using the modified moment estimator.");
@@ -283,7 +283,7 @@ LogNormal LogNormalFactory::buildAsLogNormal(const Sample & sample,
       {
         return buildMethodOfModifiedMoments(sample);
       }
-      catch (InvalidArgumentException)
+      catch (InvalidArgumentException &)
       {
         // We switch to the moment estimate
         LOGWARN(OSS() << "Warning! Unable to bracket the shape parameter sigma. Using the classical moment estimator.");
@@ -306,7 +306,7 @@ LogNormal LogNormalFactory::buildAsLogNormal(const Point & parameters) const
     distribution.setParameter(parameters);
     return distribution;
   }
-  catch (InvalidArgumentException)
+  catch (InvalidArgumentException &)
   {
     throw InvalidArgumentException(HERE) << "Error: cannot build a LogNormal distribution from the given parameters";
   }
