@@ -2,7 +2,7 @@
 /**
  *  @brief The LogUniform distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -156,6 +156,12 @@ Scalar LogUniform::computeComplementaryCDF(const Point & point) const
   return (bLog_ - std::log(x)) / (bLog_ - aLog_);
 }
 
+/* Compute the entropy of the distribution */
+Scalar LogUniform::computeEntropy() const
+{
+  return std::log(bLog_ - aLog_) + 0.5 * (aLog_ + bLog_);
+}
+
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
 Complex LogUniform::computeCharacteristicFunction(const Scalar x) const
 {
