@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for LogUniform distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -44,17 +44,17 @@ LogUniformFactory * LogUniformFactory::clone() const
 
 /* Here is the interface that all derived class must implement */
 
-LogUniformFactory::Implementation LogUniformFactory::build(const Sample & sample) const
+Distribution LogUniformFactory::build(const Sample & sample) const
 {
   return buildAsLogUniform(sample).clone();
 }
 
-LogUniformFactory::Implementation LogUniformFactory::build(const Point & parameters) const
+Distribution LogUniformFactory::build(const Point & parameters) const
 {
   return buildAsLogUniform(parameters).clone();
 }
 
-LogUniformFactory::Implementation LogUniformFactory::build() const
+Distribution LogUniformFactory::build() const
 {
   return buildAsLogUniform().clone();
 }
@@ -90,7 +90,7 @@ LogUniform LogUniformFactory::buildAsLogUniform(const Point & parameters) const
     distribution.setParameter(parameters);
     return distribution;
   }
-  catch (InvalidArgumentException)
+  catch (InvalidArgumentException &)
   {
     throw InvalidArgumentException(HERE) << "Error: cannot build a LogUniform distribution from the given parameters";
   }
