@@ -2,7 +2,7 @@
 /**
  *  @brief The maximum entropy order statistics copula
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -104,7 +104,7 @@ PiecewiseHermiteEvaluation MaximumEntropyOrderStatisticsCopula::getApproximation
 }
 
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
-MaximumEntropyOrderStatisticsCopula::Implementation MaximumEntropyOrderStatisticsCopula::getMarginal(const Indices & indices) const
+Distribution MaximumEntropyOrderStatisticsCopula::getMarginal(const Indices & indices) const
 {
   const UnsignedInteger size = indices.getSize();
   if (size == 0) throw InvalidArgumentException(HERE) << "indices is empty";
@@ -113,20 +113,20 @@ MaximumEntropyOrderStatisticsCopula::Implementation MaximumEntropyOrderStatistic
   if (dimension == 1) return clone();
   if (size == 1)
   {
-    Implementation marginal(getMarginal(indices[0]));
+    Implementation marginal(getMarginal(indices[0]).getImplementation());
     marginal->setDescription(Description(1, getDescription()[indices[0]]));
     return marginal;
   }
   Description marginalDescription(0);
   const Description description(getDescription());
-  MaximumEntropyOrderStatisticsCopula marginal(distribution_.getMarginalAsMaximumEntropyOrderStatisticsDistribution(indices));
+  MaximumEntropyOrderStatisticsCopula::Implementation marginal(new MaximumEntropyOrderStatisticsCopula(distribution_.getMarginalAsMaximumEntropyOrderStatisticsDistribution(indices)));
   for (UnsignedInteger i = 0; i < size; ++i)
   {
     const UnsignedInteger j = indices[i];
     marginalDescription.add(description[j]);
   }
-  marginal.setDescription(marginalDescription);
-  return marginal.clone();
+  marginal->setDescription(marginalDescription);
+  return marginal;
 }
 
 
