@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level class for all Mixtures
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -254,7 +254,7 @@ void Mixture::setDistributionCollectionWithWeights(const DistributionCollection
   {
     const Scalar normalizedWeight = distributionCollection_[i].getWeight() / weightSum;
     distributionCollection_[i].setWeight(normalizedWeight);
-    x[i][0] = i;
+    x(i, 0) = i;
     p[i] = normalizedWeight;
     parallel = parallel && distributionCollection_[i].getImplementation()->isParallel();
   } /* end for */
@@ -402,7 +402,7 @@ Point Mixture::computeCDFGradient(const Point & point) const
 }
 
 /* Get the i-th marginal distribution */
-Mixture::Implementation Mixture::getMarginal(const UnsignedInteger i) const
+Distribution Mixture::getMarginal(const UnsignedInteger i) const
 {
   const UnsignedInteger dimension = getDimension();
   if (i >= dimension) throw InvalidArgumentException(HERE) << "The index of a marginal distribution must be in the range [0, dim-1]";
@@ -416,14 +416,14 @@ Mixture::Implementation Mixture::getMarginal(const UnsignedInteger i) const
     collection.add(distributionCollection_[index].getMarginal(i));
     collection[index].setWeight(distributionCollection_[index].getWeight());
   }
-  Mixture marginal(collection);
-  marginal.isCopula_ = isCopula_;
-  marginal.setDescription(Description(1, getDescription()[i]));
-  return marginal.clone();
+  Mixture* marginal(new Mixture(collection));
+  marginal->isCopula_ = isCopula_;
+  marginal->setDescription(Description(1, getDescription()[i]));
+  return marginal;
 }
 
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
-Mixture::Implementation Mixture::getMarginal(const Indices & indices) const
+Distribution Mixture::getMarginal(const Indices & indices) const
 {
   const UnsignedInteger dimension = getDimension();
   if (!indices.check(dimension)) throw InvalidArgumentException(HERE) << "The indices of a marginal distribution must be in the range [0, dim-1] and must be different";
@@ -444,10 +444,10 @@ Mixture::Implementation Mixture::getMarginal(const Indices & indices) const
     const UnsignedInteger index_i = indices[i];
     marginalDescription[i] = description[index_i];
   }
-  Mixture marginal(collection);
-  marginal.isCopula_ = isCopula_;
-  marginal.setDescription(marginalDescription);
-  return marginal.clone();
+  Mixture* marginal(new Mixture(collection));
+  marginal->isCopula_ = isCopula_;
+  marginal->setDescription(marginalDescription);
+  return marginal;
 }
 
 /* Compute the mean of the Mixture */
@@ -477,7 +477,7 @@ void Mixture::computeCovariance() const
       for(UnsignedInteger column = 0; column <= row; ++column)
         covariance_(row, column) += weightI * (covarianceI(row, column) + meanI[row] * meanI[column]);
   } /* end for */
-  // Then, substract E(X).E(X)^t
+  // Then, subtract E(X).E(X)^t
   const Point mean(getMean());
   for(UnsignedInteger row = 0; row < dimension; ++row)
     for(UnsignedInteger column = 0; column <= row; ++column)
