@@ -2,7 +2,7 @@
 /**
  *  @brief The Multinomial distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -399,20 +399,20 @@ Scalar Multinomial::computeConditionalQuantile(const Scalar q,
 }
 
 /* Get the i-th marginal distribution */
-Multinomial::Implementation Multinomial::getMarginal(const UnsignedInteger i) const
+Distribution Multinomial::getMarginal(const UnsignedInteger i) const
 {
   const UnsignedInteger dimension = getDimension();
   if (i >= dimension) throw InvalidArgumentException(HERE) << "The index of a marginal distribution must be in the range [0, dim-1]";
   // Special case for dimension 1
   if (dimension == 1) return clone();
   // General case
-  Binomial marginal(n_, p_[i]);
-  marginal.setDescription(Description(1, getDescription()[i]));
-  return marginal.clone();
+  Multinomial::Implementation marginal(new Binomial(n_, p_[i]));
+  marginal->setDescription(Description(1, getDescription()[i]));
+  return marginal;
 }
 
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
-Multinomial::Implementation Multinomial::getMarginal(const Indices & indices) const
+Distribution Multinomial::getMarginal(const Indices & indices) const
 {
   const UnsignedInteger dimension = getDimension();
   if (!indices.check(dimension)) throw InvalidArgumentException(HERE) << "The indices of a marginal distribution must be in the range [0, dim-1] and must be different";
@@ -430,9 +430,9 @@ Multinomial::Implementation Multinomial::getMarginal(const Indices & indices) co
     marginalP[i] = p_[index_i];
     marginalDescription[i] = description[index_i];
   }
-  Multinomial marginal(n_, marginalP);
-  marginal.setDescription(marginalDescription);
-  return marginal.clone();
+  Multinomial::Implementation marginal(new Multinomial(n_, marginalP));
+  marginal->setDescription(marginalDescription);
+  return marginal;
 } // getMarginal(Indices)
 
 /* Get the support of a discrete distribution that intersect a given interval */
