@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for NegativeBinomial distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -65,7 +65,7 @@ struct NegativeBinomialFactoryParameterConstraint
     const UnsignedInteger size = sample_.getSize();
     /* \sum_{i=1}^N \psi(x_i + r) */
     Scalar sumPsi = 0.0;
-    for (UnsignedInteger i = 0; i < size; ++i) sumPsi += SpecFunc::Psi(sample_[i][0] + r);
+    for (UnsignedInteger i = 0; i < size; ++i) sumPsi += SpecFunc::Psi(sample_(i, 0) + r);
     const Scalar value = sumPsi + size * (std::log(r / (r + mean_)) - SpecFunc::Psi(r));
     return Point(1, value);
   }
@@ -76,17 +76,17 @@ struct NegativeBinomialFactoryParameterConstraint
   Scalar mean_;
 };
 
-NegativeBinomialFactory::Implementation NegativeBinomialFactory::build(const Sample & sample) const
+Distribution NegativeBinomialFactory::build(const Sample & sample) const
 {
   return buildAsNegativeBinomial(sample).clone();
 }
 
-NegativeBinomialFactory::Implementation NegativeBinomialFactory::build(const Point & parameters) const
+Distribution NegativeBinomialFactory::build(const Point & parameters) const
 {
   return buildAsNegativeBinomial(parameters).clone();
 }
 
-NegativeBinomialFactory::Implementation NegativeBinomialFactory::build() const
+Distribution NegativeBinomialFactory::build() const
 {
   return buildAsNegativeBinomial().clone();
 }
@@ -101,7 +101,7 @@ NegativeBinomial NegativeBinomialFactory::buildAsNegativeBinomial(const Sample &
   const Scalar supportEpsilon = ResourceMap::GetAsScalar("DiscreteDistribution-SupportEpsilon");
   for (UnsignedInteger i = 0; i < size; ++i)
   {
-    const Scalar x = sample[i][0];
+    const Scalar x = sample(i, 0);
     const int iX(static_cast<int>(round(x)));
     // The sample must be made of nonnegative integral values
     if (std::abs(x - iX) > supportEpsilon || (iX < 0)) throw InvalidArgumentException(HERE) << "Error: can build a NegativeBinomial distribution only from a sample made of nonnegative integers, here x=" << x;
@@ -151,7 +151,7 @@ NegativeBinomial NegativeBinomialFactory::buildAsNegativeBinomial(const Point &
     distribution.setParameter(parameters);
     return distribution;
   }
-  catch (InvalidArgumentException)
+  catch (InvalidArgumentException &)
   {
     throw InvalidArgumentException(HERE) << "Error: cannot build a NegativeBinomial distribution from the given parameters";
   }
