@@ -2,7 +2,7 @@
 /**
  *  @brief The Normal distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -177,7 +177,7 @@ Sample Normal::getSample(const UnsignedInteger size) const
   const UnsignedInteger dimension = getDimension();
   Sample result(size, dimension);
   for (UnsignedInteger i = 0; i < size; ++i)
-    for (UnsignedInteger j = 0; j < dimension; ++j) result[i][j] = DistFunc::rNormal();
+    for (UnsignedInteger j = 0; j < dimension; ++j) result(i, j) = DistFunc::rNormal();
   if (hasIndependentCopula_) result *= sigma_;
   else result *= cholesky_;
   result += mean_;
@@ -245,7 +245,7 @@ Scalar Normal::computeCDF(const Point & point) const
   LOGINFO(OSS() << "In Normal::computeCDF, point=" << point << ", toKeep=" << toKeep << ", dimension=" << dimension << ", reducedPoint=" << reducedPoint);
   if (toKeep.getSize() == 0) return 1.0;
   // The point has some components greater than the corresponding range upper bound
-  if (toKeep.getSize() != dimension) return getMarginal(toKeep)->computeCDF(reducedPoint);
+  if (toKeep.getSize() != dimension) return getMarginal(toKeep).computeCDF(reducedPoint);
   /* General case */
   // For the bidimensional case, use specialized high precision routine
   if (dimension == 2) return DistFunc::pNormal2D(u[0], u[1], R_(0, 1));
@@ -350,10 +350,17 @@ Scalar Normal::computeCDF(const Point & point) const
     LOGINFO(OSS() << 0.1 * ((1000 * indexOuter) / outerMax) << "% value=" << value << " absolute precision(99%)=" << precision << " relative precision(99%)=" << ((value > 0.0) ? precision / value : -1.0));
   }
   RandomGenerator::SetState(initialState);
-  cdfEpsilon_ = precision;
   return value;
 } // computeCDF
 
+/* Compute the entropy of the distribution */
+Scalar Normal::computeEntropy() const
+{
+  // EllipticalDistribution::normalizationFactor_ == 1/sqrt(det(Sigma))
+  // normalizationFactor_ == 1/sqrt(2*Pi)^dim
+  return 0.5 * getDimension() - std::log(EllipticalDistribution::normalizationFactor_) - std::log(normalizationFactor_);
+}
+
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
 Complex Normal::computeCharacteristicFunction(const Scalar x) const
 {
@@ -540,7 +547,7 @@ Scalar Normal::computeConditionalQuantile(const Scalar q,
 }
 
 /* Get the i-th marginal distribution */
-Normal::Implementation Normal::getMarginal(const UnsignedInteger i) const
+Distribution Normal::getMarginal(const UnsignedInteger i) const
 {
   const UnsignedInteger dimension = getDimension();
   if (i >= dimension) throw InvalidArgumentException(HERE) << "The index of a marginal distribution must be in the range [0, dim-1]";
@@ -550,13 +557,13 @@ Normal::Implementation Normal::getMarginal(const UnsignedInteger i) const
   CorrelationMatrix R(1);
   Point sigma(1, sigma_[i]);
   Point mean(1, mean_[i]);
-  Normal marginal(mean, sigma, R);
-  marginal.setDescription(Description(1, getDescription()[i]));
-  return marginal.clone();
+  Normal::Implementation marginal(new Normal(mean, sigma, R));
+  marginal->setDescription(Description(1, getDescription()[i]));
+  return marginal;
 }
 
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
-Normal::Implementation Normal::getMarginal(const Indices & indices) const
+Distribution Normal::getMarginal(const Indices & indices) const
 {
   const UnsignedInteger dimension = getDimension();
   if (!indices.check(dimension)) throw InvalidArgumentException(HERE) << "The indices of a marginal distribution must be in the range [0, dim-1] and must be different";
@@ -581,9 +588,9 @@ Normal::Implementation Normal::getMarginal(const Indices & indices) const
     }
     marginalDescription[i] = description[index_i];
   }
-  Normal marginal(mean, sigma, R);
-  marginal.setDescription(marginalDescription);
-  return marginal.clone();
+  Normal::Implementation marginal(new Normal(mean, sigma, R));
+  marginal->setDescription(marginalDescription);
+  return marginal;
 } // getMarginal(Indices)
 
 /* Get the skewness of the distribution */
@@ -603,9 +610,9 @@ Point Normal::getStandardMoment(const UnsignedInteger n) const
 }
 
 /* Get the standard representative in the parametric family, associated with the standard moments */
-Normal::Implementation Normal::getStandardRepresentative() const
+Distribution Normal::getStandardRepresentative() const
 {
-  return Normal(0.0, 1.0).clone();
+  return new Normal(0.0, 1.0);
 }
 
 /* Get the roughness, i.e. the L2-norm of the PDF */
@@ -622,7 +629,7 @@ Point Normal::getKurtosis() const
 }
 
 /* Get the copula of the distribution */
-Normal::Implementation Normal::getCopula() const
+Distribution Normal::getCopula() const
 {
   return new NormalCopula(R_);
 }
