@@ -2,7 +2,7 @@
 /**
  *  @brief A class that implements a normal copula
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -132,7 +132,7 @@ struct NormalCopulaComputeSamplePolicy
   {
     for (UnsignedInteger i = r.begin(); i != r.end(); ++i)
       for (UnsignedInteger j = 0; j < dimension_; ++j)
-        output_[i][j] = DistFunc::pNormal(input_[i][j]);
+        output_(i, j) = DistFunc::pNormal(input_(i, j));
   }
 
 }; /* end struct NormalCopulaComputeSamplePolicy */
@@ -259,7 +259,7 @@ Scalar NormalCopula::computeCDF(const Point & point) const
   // use the associated normal distribution
   if (dimension == activeDimension) return normal_.computeCDF(normalPoint);
   // In the other case, we must use the appropriate marginal distribution
-  else return normal_.getMarginal(indices)->computeCDF(normalPoint);
+  else return normal_.getMarginal(indices).computeCDF(normalPoint);
 } // computeCDF
 
 /* Get the survival function of the distribution */
@@ -360,6 +360,12 @@ CorrelationMatrix NormalCopula::getKendallTau() const
   return tau;
 }
 
+/* Compute the entropy of the distribution */
+Scalar NormalCopula::computeEntropy() const
+{
+  return normal_.computeEntropy() - getDimension() * (SpecFunc::LOGSQRT2PI + 0.5);
+}
+
 /* Get the Shape matrix of the copula */
 CorrelationMatrix NormalCopula::getShapeMatrix() const
 {
@@ -435,7 +441,7 @@ Scalar NormalCopula::computeConditionalQuantile(const Scalar q,
 }
 
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
-NormalCopula::Implementation NormalCopula::getMarginal(const Indices & indices) const
+Distribution NormalCopula::getMarginal(const Indices & indices) const
 {
   const UnsignedInteger dimension = getDimension();
   if (!indices.check(dimension)) throw InvalidArgumentException(HERE) << "The indices of a marginal distribution must be in the range [0, dim-1] and must be different";
