@@ -2,7 +2,7 @@
 /**
  *  @brief The NormalGamma distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -95,8 +95,8 @@ NormalGamma::NormalGamma(const Scalar mu,
 /* Compute the numerical range of the distribution given the parameters values */
 void NormalGamma::computeRange()
 {
-  const Interval range0(getMarginal(0)->getRange());
-  const Interval range1(getMarginal(1)->getRange());
+  const Interval range0(getMarginal(0).getRange());
+  const Interval range1(getMarginal(1).getRange());
   Point lowerBound(2, 0.0);
   lowerBound[0] = range0.getLowerBound()[0];
   lowerBound[1] = range1.getLowerBound()[0];
@@ -282,7 +282,7 @@ Scalar NormalGamma::computeCDF(const Point & point) const
     return DistFunc::pGamma(alpha_, beta_ * y);
   }
   // Here the integration wrt x is given in closed form
-  const Function integrand(NormalGammaFunctions::KernelProbability(-SpecFunc::MaxNumericalScalar, x, kappa_, alpha_, beta_, logNormalization_, 0));
+  const Function integrand(NormalGammaFunctions::KernelProbability(-SpecFunc::MaxScalar, x, kappa_, alpha_, beta_, logNormalization_, 0));
   // Integrate over the interval (-inf, y] of the conditioning Gamma distribution
   const Scalar cdf = GaussKronrod().integrate(integrand, Interval(a, std::min(y, b)))[0];
   return cdf;
@@ -306,7 +306,7 @@ Scalar NormalGamma::computeSurvivalFunction(const Point & point) const
     return DistFunc::pGamma(alpha_, beta_ * y, true);
   }
   // Here the integration wrt x is given in closed form
-  const Function integrand(NormalGammaFunctions::KernelProbability(x, SpecFunc::MaxNumericalScalar, kappa_, alpha_, beta_, logNormalization_, 1));
+  const Function integrand(NormalGammaFunctions::KernelProbability(x, SpecFunc::MaxScalar, kappa_, alpha_, beta_, logNormalization_, 1));
   // Integrate over the interval [y, +inf) of the conditioning Gamma distribution
   const Scalar survival = GaussKronrod().integrate(integrand, Interval(std::max(y, a), b))[0];
   return survival;
@@ -336,6 +336,12 @@ Scalar NormalGamma::computeProbability(const Interval & interval) const
   return probability;
 }
 
+/* Compute the entropy of the distribution */
+Scalar NormalGamma::computeEntropy() const
+{
+  return alpha_ + (0.5 - alpha_) * SpecFunc::Psi(alpha_) + SpecFunc::LogGamma(alpha_) - 0.5 * (std::log(beta_) - M_LN2 + std::log(kappa_) - 1.0 - std::log(M_PI));
+}
+
 /* Parameters value and description accessor */
 Point NormalGamma::getParameter() const
 {
