@@ -2,7 +2,7 @@
 /**
  *  @brief OrderStatisticsMarginalChecker class
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -88,12 +88,12 @@ void OrderStatisticsMarginalChecker::check() const
   {
     const Scalar prob = (k + 1.0) / (quantileIteration + 1.0);
     Scalar qIm1 = collection_[0].computeQuantile(prob)[0];
-    quantiles[0][k] = qIm1;
+    quantiles(0, k) = qIm1;
     for (UnsignedInteger i = 1; i < size; ++ i)
     {
       const Scalar qI = collection_[i].computeQuantile(prob)[0];
       if (qIm1 >= qI) throw InvalidArgumentException(HERE) << "margins are not compatible: the quantile=" << qIm1 << " of margin " << i - 1 << " is greater than the quantile=" << qI << " of margin " << i << " at level " << prob;
-      quantiles[i][k] = qI;
+      quantiles(i, k) = qI;
       qIm1 = qI;
     }
   }
@@ -107,12 +107,12 @@ void OrderStatisticsMarginalChecker::check() const
   {
     const OrderStatisticsMarginalCheckerWrapper wrapper(collection_[i - 1], collection_[i]);
     Function f(bindMethod<OrderStatisticsMarginalCheckerWrapper, Point, Point>(wrapper, &OrderStatisticsMarginalCheckerWrapper::computeDelta, 1, 1));
-    f.setGradient(CenteredFiniteDifferenceGradient(step, f.getEvaluation()->clone()));
+    f.setGradient(CenteredFiniteDifferenceGradient(step, f.getEvaluation()));
 
     for (UnsignedInteger k = 0; k < quantileIteration; ++ k)
     {
       const Scalar xMin = quantiles[i - 1][k];
-      const Scalar xMax = quantiles[i][k];
+      const Scalar xMax = quantiles(i, k);
       const Scalar xMiddle = 0.5 * (xMin + xMax);
 
       // Define Optimization problem
@@ -138,7 +138,7 @@ Bool OrderStatisticsMarginalChecker::isCompatible() const
   {
     check();
   }
-  catch (InvalidArgumentException)
+  catch (InvalidArgumentException &)
   {
     compatible = false;
   }
