@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level class for all OrdinalSumCopulas
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -43,8 +43,8 @@ OrdinalSumCopula::OrdinalSumCopula()
   setName("OrdinalSumCopula");
   setDimension(2);
   Sample support(2, 1);
-  support[0][0] = 0.0;
-  support[1][0] = 1.0;
+  support(0, 0) = 0.0;
+  support(1, 0) = 1.0;
   blockDistribution_ = UserDefined(support);
   computeRange();
 }
@@ -112,7 +112,7 @@ String OrdinalSumCopula::__str__(const String & offset) const
   return oss;
 }
 
-/* Distribution collection accessor */
+/* Copula collection accessor */
 void OrdinalSumCopula::setCopulaCollection(const CopulaCollection & coll)
 {
   // Check if the collection is not empty
@@ -428,7 +428,7 @@ Scalar OrdinalSumCopula::computeConditionalQuantile(const Scalar q, const Point
 }
 
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
-OrdinalSumCopula::Implementation OrdinalSumCopula::getMarginal(const Indices & indices) const
+Distribution OrdinalSumCopula::getMarginal(const Indices & indices) const
 {
   const UnsignedInteger dimension = getDimension();
   if (!indices.check(dimension)) throw InvalidArgumentException(HERE) << "Error: the indices of a marginal distribution must be in the range [0, dim-1] and must be different";
