@@ -2,7 +2,7 @@
 /**
  *  @brief The RatioDistribution distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -173,20 +173,20 @@ Scalar RatioDistribution::computePDFQ1(const Scalar x,
   const Function pdfKernel(bindMethod<PDFKernelWrapper, Point, Point>(pdfKernelWrapper, &PDFKernelWrapper::eval, 1, 1));
   if (c == 0.0)
   {
-    if ((x >= 0.0) && (x < ad)) return algo.integrate(pdfKernel, Interval(a, b), pdfEpsilon_)[0];
-    if ((x >= ad) && (x <= bd)) return algo.integrate(pdfKernel, Interval(x / d, b), pdfEpsilon_)[0];
+    if ((x >= 0.0) && (x < ad)) return algo.integrate(pdfKernel, Interval(a, b))[0];
+    if ((x >= ad) && (x <= bd)) return algo.integrate(pdfKernel, Interval(x / d, b))[0];
     return 0.0;
   }
   if (ad <= bc)
   {
-    if ((x >= ac) && (x < ad)) return algo.integrate(pdfKernel, Interval(a, x / c), pdfEpsilon_)[0];
-    if ((x >= ad) && (x < bc)) return algo.integrate(pdfKernel, Interval(x / d, x / c), pdfEpsilon_)[0];
-    if ((x >= bc) && (x < bd)) return algo.integrate(pdfKernel, Interval(x / d, b), pdfEpsilon_)[0];
+    if ((x >= ac) && (x < ad)) return algo.integrate(pdfKernel, Interval(a, x / c))[0];
+    if ((x >= ad) && (x < bc)) return algo.integrate(pdfKernel, Interval(x / d, x / c))[0];
+    if ((x >= bc) && (x < bd)) return algo.integrate(pdfKernel, Interval(x / d, b))[0];
     return 0.0;
   }
-  if ((x >= ac) && (x < bc)) return algo.integrate(pdfKernel, Interval(a, x / c), pdfEpsilon_)[0];
-  if ((x >= bc) && (x < ad)) return algo.integrate(pdfKernel, Interval(a, b), pdfEpsilon_)[0];
-  if ((x >= ad) && (x < bd)) return algo.integrate(pdfKernel, Interval(x / d, b), pdfEpsilon_)[0];
+  if ((x >= ac) && (x < bc)) return algo.integrate(pdfKernel, Interval(a, x / c))[0];
+  if ((x >= bc) && (x < ad)) return algo.integrate(pdfKernel, Interval(a, b))[0];
+  if ((x >= ad) && (x < bd)) return algo.integrate(pdfKernel, Interval(x / d, b))[0];
   return 0.0;
 }
 
@@ -206,20 +206,20 @@ Scalar RatioDistribution::computePDFQ2(const Scalar x,
   const Function pdfKernel(bindMethod<PDFKernelWrapper, Point, Point>(pdfKernelWrapper, &PDFKernelWrapper::eval, 1, 1));
   if (c == 0.0)
   {
-    if ((x >= ad) && (x < bd)) return algo.integrate(pdfKernel, Interval(a, x / d), pdfEpsilon_)[0];
-    if ((x >= bd) && (x <= 0.0)) return algo.integrate(pdfKernel, Interval(a, b), pdfEpsilon_)[0];
+    if ((x >= ad) && (x < bd)) return algo.integrate(pdfKernel, Interval(a, x / d))[0];
+    if ((x >= bd) && (x <= 0.0)) return algo.integrate(pdfKernel, Interval(a, b))[0];
     return 0.0;
   }
   if (ac <= bd)
   {
-    if ((x >= ad) && (x < ac)) return algo.integrate(pdfKernel, Interval(a, x / d), pdfEpsilon_)[0];
-    if ((x >= ac) && (x < bd)) return algo.integrate(pdfKernel, Interval(x / c, x / d), pdfEpsilon_)[0];
-    if ((x >= bd) && (x < bc)) return algo.integrate(pdfKernel, Interval(x / c, b), pdfEpsilon_)[0];
+    if ((x >= ad) && (x < ac)) return algo.integrate(pdfKernel, Interval(a, x / d))[0];
+    if ((x >= ac) && (x < bd)) return algo.integrate(pdfKernel, Interval(x / c, x / d))[0];
+    if ((x >= bd) && (x < bc)) return algo.integrate(pdfKernel, Interval(x / c, b))[0];
     return 0.0;
   }
-  if ((x >= ad) && (x < bd)) return algo.integrate(pdfKernel, Interval(a, x / d), pdfEpsilon_)[0];
-  if ((x >= bd) && (x < ac)) return algo.integrate(pdfKernel, Interval(a, b), pdfEpsilon_)[0];
-  if ((x >= ac) && (x < bc)) return algo.integrate(pdfKernel, Interval(x / c, b), pdfEpsilon_)[0];
+  if ((x >= ad) && (x < bd)) return algo.integrate(pdfKernel, Interval(a, x / d))[0];
+  if ((x >= bd) && (x < ac)) return algo.integrate(pdfKernel, Interval(a, b))[0];
+  if ((x >= ac) && (x < bc)) return algo.integrate(pdfKernel, Interval(x / c, b))[0];
   return 0.0;
 }
 
@@ -239,20 +239,20 @@ Scalar RatioDistribution::computePDFQ3(const Scalar x,
   const Function pdfKernel(bindMethod<PDFKernelWrapper, Point, Point>(pdfKernelWrapper, &PDFKernelWrapper::eval, 1, 1));
   if (d == 0.0)
   {
-    if ((x >= bc) && (x < ac)) return algo.integrate(pdfKernel, Interval(a, x / c), pdfEpsilon_)[0];
-    if ((x >= 0.0) && (x < bc)) return algo.integrate(pdfKernel, Interval(a, b), pdfEpsilon_)[0];
+    if ((x >= bc) && (x < ac)) return algo.integrate(pdfKernel, Interval(a, x / c))[0];
+    if ((x >= 0.0) && (x < bc)) return algo.integrate(pdfKernel, Interval(a, b))[0];
     return 0.0;
   }
   if (ad <= bc)
   {
-    if ((x >= ad) && (x < ac)) return algo.integrate(pdfKernel, Interval(a, x / c), pdfEpsilon_)[0];
-    if ((x >= bc) && (x < ad)) return algo.integrate(pdfKernel, Interval(x / d, x / c), pdfEpsilon_)[0];
-    if ((x >= bd) && (x < bc)) return algo.integrate(pdfKernel, Interval(x / d, b), pdfEpsilon_)[0];
+    if ((x >= ad) && (x < ac)) return algo.integrate(pdfKernel, Interval(a, x / c))[0];
+    if ((x >= bc) && (x < ad)) return algo.integrate(pdfKernel, Interval(x / d, x / c))[0];
+    if ((x >= bd) && (x < bc)) return algo.integrate(pdfKernel, Interval(x / d, b))[0];
     return 0.0;
   }
-  if ((x >= bc) && (x < ac)) return algo.integrate(pdfKernel, Interval(a, x / c), pdfEpsilon_)[0];
-  if ((x >= ad) && (x < bc)) return algo.integrate(pdfKernel, Interval(a, b), pdfEpsilon_)[0];
-  if ((x >= bd) && (x < ad)) return algo.integrate(pdfKernel, Interval(x / d, b), pdfEpsilon_)[0];
+  if ((x >= bc) && (x < ac)) return algo.integrate(pdfKernel, Interval(a, x / c))[0];
+  if ((x >= ad) && (x < bc)) return algo.integrate(pdfKernel, Interval(a, b))[0];
+  if ((x >= bd) && (x < ad)) return algo.integrate(pdfKernel, Interval(x / d, b))[0];
   return 0.0;
 }
 
@@ -272,20 +272,20 @@ Scalar RatioDistribution::computePDFQ4(const Scalar x,
   const Function pdfKernel(bindMethod<PDFKernelWrapper, Point, Point>(pdfKernelWrapper, &PDFKernelWrapper::eval, 1, 1));
   if (d == 0.0)
   {
-    if ((x >= ac) && (x <= 0.0)) return algo.integrate(pdfKernel, Interval(a, b), pdfEpsilon_)[0];
-    if ((x >= bc) && (x < ac)) return algo.integrate(pdfKernel, Interval(x / c, b), pdfEpsilon_)[0];
+    if ((x >= ac) && (x <= 0.0)) return algo.integrate(pdfKernel, Interval(a, b))[0];
+    if ((x >= bc) && (x < ac)) return algo.integrate(pdfKernel, Interval(x / c, b))[0];
     return 0.0;
   }
   if (bd <= ac)
   {
-    if ((x >= bc) && (x < ac)) return algo.integrate(pdfKernel, Interval(a, x / d), pdfEpsilon_)[0];
-    if ((x >= ad) && (x < bc)) return algo.integrate(pdfKernel, Interval(x / c, x / d), pdfEpsilon_)[0];
-    if ((x >= bd) && (x < ad)) return algo.integrate(pdfKernel, Interval(x / c, b), pdfEpsilon_)[0];
+    if ((x >= bc) && (x < ac)) return algo.integrate(pdfKernel, Interval(a, x / d))[0];
+    if ((x >= ad) && (x < bc)) return algo.integrate(pdfKernel, Interval(x / c, x / d))[0];
+    if ((x >= bd) && (x < ad)) return algo.integrate(pdfKernel, Interval(x / c, b))[0];
     return 0.0;
   }
-  if ((x >= bd) && (x < ad)) return algo.integrate(pdfKernel, Interval(a, x / d), pdfEpsilon_)[0];
-  if ((x >= ac) && (x < bd)) return algo.integrate(pdfKernel, Interval(a, b), pdfEpsilon_)[0];
-  if ((x >= bc) && (x < ac)) return algo.integrate(pdfKernel, Interval(x / c, b), pdfEpsilon_)[0];
+  if ((x >= bd) && (x < ad)) return algo.integrate(pdfKernel, Interval(a, x / d))[0];
+  if ((x >= ac) && (x < bd)) return algo.integrate(pdfKernel, Interval(a, b))[0];
+  if ((x >= bc) && (x < ac)) return algo.integrate(pdfKernel, Interval(x / c, b))[0];
   return 0.0;
 }
 
@@ -298,7 +298,6 @@ Complex RatioDistribution::computeCharacteristicFunction(const Scalar x) const
   const Scalar varRight = right_.getCovariance()(0, 0);
   if (x * x * (varLeft + muLeft * muLeft + varRight + muRight * muRight) < 2.0 * SpecFunc::ScalarEpsilon) return Complex(1.0, -x * muLeft * muRight);
   if (std::abs(x) > ResourceMap::GetAsScalar("RatioDistribution-LargeCharacteristicFunctionArgument")) return ContinuousDistribution::computeCharacteristicFunction(x);
-  Complex result(0.0);
   const Scalar aLeft = left_.getRange().getLowerBound()[0];
   const Scalar bLeft = left_.getRange().getUpperBound()[0];
   GaussKronrod algo;
