@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for Rayleigh distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -44,17 +44,17 @@ RayleighFactory * RayleighFactory::clone() const
 
 /* Here is the interface that all derived class must implement */
 
-RayleighFactory::Implementation RayleighFactory::build(const Sample & sample) const
+Distribution RayleighFactory::build(const Sample & sample) const
 {
   return buildAsRayleigh(sample).clone();
 }
 
-RayleighFactory::Implementation RayleighFactory::build(const Point & parameters) const
+Distribution RayleighFactory::build(const Point & parameters) const
 {
   return buildAsRayleigh(parameters).clone();
 }
 
-RayleighFactory::Implementation RayleighFactory::build() const
+Distribution RayleighFactory::build() const
 {
   return buildAsRayleigh().clone();
 }
@@ -69,7 +69,7 @@ Rayleigh RayleighFactory::buildAsRayleigh(const Sample & sample) const
   Scalar sumSquares = 0.0;
   for (UnsignedInteger i = 0; i < size; ++i)
   {
-    const Scalar xI = sample[i][0] - gamma;
+    const Scalar xI = sample(i, 0) - gamma;
     sumSquares += xI * xI;
   }
   // Here we test on sumSquares in order to detect also overflows
@@ -86,7 +86,7 @@ Rayleigh RayleighFactory::buildAsRayleigh(const Sample & sample) const
     result.setDescription(sample.getDescription());
     return result;
   }
-  catch (InvalidArgumentException)
+  catch (InvalidArgumentException &)
   {
     throw InvalidArgumentException(HERE) << "Error: cannot estimate parameters of a Rayleigh distribution from the given sample";
   }
@@ -100,7 +100,7 @@ Rayleigh RayleighFactory::buildAsRayleigh(const Point & parameters) const
     distribution.setParameter(parameters);
     return distribution;
   }
-  catch (InvalidArgumentException)
+  catch (InvalidArgumentException &)
   {
     throw InvalidArgumentException(HERE) << "Error: cannot build a Rayleigh distribution from the given parameters";
   }
