@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for Rice distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -74,17 +74,17 @@ struct RiceFactoryParameterConstraint
 
 /* Here is the interface that all derived class must implement */
 
-RiceFactory::Implementation RiceFactory::build(const Sample & sample) const
+Distribution RiceFactory::build(const Sample & sample) const
 {
   return buildAsRice(sample).clone();
 }
 
-RiceFactory::Implementation RiceFactory::build(const Point & parameters) const
+Distribution RiceFactory::build(const Point & parameters) const
 {
   return buildAsRice(parameters).clone();
 }
 
-RiceFactory::Implementation RiceFactory::build() const
+Distribution RiceFactory::build() const
 {
   return buildAsRice().clone();
 }
@@ -137,7 +137,7 @@ Rice RiceFactory::buildAsRice(const Sample & sample) const
     result.setDescription(sample.getDescription());
     return result;
   }
-  catch (InvalidArgumentException)
+  catch (InvalidArgumentException &)
   {
     throw InvalidArgumentException(HERE) << "Error: cannot estimate parameters of a Rice distribution from the given sample";
   }
@@ -151,7 +151,7 @@ Rice RiceFactory::buildAsRice(const Point & parameters) const
     distribution.setParameter(parameters);
     return distribution;
   }
-  catch (InvalidArgumentException)
+  catch (InvalidArgumentException &)
   {
     throw InvalidArgumentException(HERE) << "Error: cannot build a Rice distribution from the given parameters";
   }
