@@ -2,7 +2,7 @@
 /**
  *  @brief The Student distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -219,7 +219,6 @@ Scalar Student::computeCDF(const Point & point) const
     // 0.1 * ((1000 * indexOuter) / outerMax) is to print percents with one figure after the decimal point
     LOGINFO(OSS() << 0.1 * ((1000 * indexOuter) / outerMax) << "% value=" << value << " absolute precision(99%)=" << precision << " relative precision(99%)=" << ((value > 0.0) ? precision / value : -1.0));
   }
-  cdfEpsilon_ = precision;
   return value;
 } // computeCDF
 
@@ -284,6 +283,15 @@ Scalar Student::computeProbability(const Interval & interval) const
   return value;
 }
 
+/* Compute the entropy of the distribution */
+Scalar Student::computeEntropy() const
+{
+  const UnsignedInteger dimension = getDimension();
+  // normalizationFactor_ == 1/\sqrt{|Det(\Sigma)|}
+  // studentNormalizationFactor_ = SpecFunc::LnGamma(0.5 * (nu + dimension)) - SpecFunc::LnGamma(0.5 * nu) - 0.5 * dimension * std::log(nu * M_PI);
+  return 0.5 * (nu_ + dimension) * (SpecFunc::Psi(0.5 * (nu_ + dimension)) - SpecFunc::Psi(0.5 * nu_)) - std::log(normalizationFactor_) - studentNormalizationFactor_;
+}
+
 /* Get the PDFGradient of the distribution */
 Point Student::computePDFGradient(const Point & point) const
 {
@@ -383,7 +391,7 @@ Scalar Student::computeConditionalQuantile(const Scalar q,
 }
 
 /* Get the i-th marginal distribution */
-Student::Implementation Student::getMarginal(const UnsignedInteger i) const
+Distribution Student::getMarginal(const UnsignedInteger i) const
 {
   if (i >= getDimension()) throw InvalidArgumentException(HERE) << "The index of a marginal distribution must be in the range [0, dim-1]";
   // Special case for dimension 1
@@ -392,13 +400,13 @@ Student::Implementation Student::getMarginal(const UnsignedInteger i) const
   const CorrelationMatrix R(1);
   const Point sigma(1, sigma_[i]);
   const Point mean(1, mean_[i]);
-  Student marginal(nu_, mean, sigma, R);
-  marginal.setDescription(Description(1, getDescription()[i]));
-  return marginal.clone();
+  Student::Implementation marginal(new Student(nu_, mean, sigma, R));
+  marginal->setDescription(Description(1, getDescription()[i]));
+  return marginal;
 }
 
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
-Student::Implementation Student::getMarginal(const Indices & indices) const
+Distribution Student::getMarginal(const Indices & indices) const
 {
   const UnsignedInteger dimension = getDimension();
   if (!indices.check(dimension)) throw InvalidArgumentException(HERE) << "The indices of a marginal distribution must be in the range [0, dim-1] and must be different";
@@ -420,9 +428,9 @@ Student::Implementation Student::getMarginal(const Indices & indices) const
     for (UnsignedInteger j = 0; j <= i; ++j) R(i, j) = R_(index_i, indices[j]);
     marginalDescription[i] = description[index_i];
   }
-  Student marginal(nu_, mean, sigma, R);
-  marginal.setDescription(marginalDescription);
-  return marginal.clone();
+  Student::Implementation marginal(new Student(nu_, mean, sigma, R));
+  marginal->setDescription(marginalDescription);
+  return marginal;
 } // getMarginal(Indices)
 
 /* Compute the radial distribution CDF */
@@ -494,9 +502,9 @@ Point Student::getStandardMoment(const UnsignedInteger n) const
 }
 
 /* Get the standard representative in the parametric family, associated with the standard moments */
-Student::Implementation Student::getStandardRepresentative() const
+Distribution Student::getStandardRepresentative() const
 {
-  return Student(nu_).clone();
+  return new Student(nu_);
 }
 
 /* Parameters value and description accessor */
