@@ -2,7 +2,7 @@
 /**
  *  @brief The Trapezoidal distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -23,6 +23,7 @@
 #include "openturns/RandomGenerator.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/SpecFunc.hxx"
+#include "openturns/Distribution.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -296,6 +297,12 @@ Scalar Trapezoidal::computeScalarQuantile(const Scalar prob,
   return d_ - std::sqrt(2.0 * (d_ - c_) * (1.0 - q) / h_);
 }
 
+/* Compute the entropy of the distribution */
+Scalar Trapezoidal::computeEntropy() const
+{
+  return 0.25 * h_ * ((b_ - a_) + (d_ - c_)) - std::log(h_);
+}
+
 /* Get the roughness, i.e. the L2-norm of the PDF */
 Scalar Trapezoidal::getRoughness() const
 {
@@ -394,9 +401,9 @@ Point Trapezoidal::getStandardMoment(const UnsignedInteger n) const
 }
 
 /* Get the standard representative in the parametric family, associated with the standard moments */
-Trapezoidal::Implementation Trapezoidal::getStandardRepresentative() const
+Distribution Trapezoidal::getStandardRepresentative() const
 {
-  return Trapezoidal(-1.0, 1.0 - 2.0 * (d_ - b_) / (d_ - a_), 1.0 - 2.0 * (d_ - c_) / (d_ - a_), 1.0).clone();
+  return new Trapezoidal(-1.0, 1.0 - 2.0 * (d_ - b_) / (d_ - a_), 1.0 - 2.0 * (d_ - c_) / (d_ - a_), 1.0);
 }
 
 /* Compute the covariance of the distribution */
