@@ -2,7 +2,7 @@
 /**
  *  @brief The Triangular distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -22,6 +22,7 @@
 #include "openturns/Triangular.hxx"
 #include "openturns/RandomGenerator.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
+#include "openturns/Distribution.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -242,6 +243,12 @@ Scalar Triangular::computeScalarQuantile(const Scalar prob,
   return b_ - std::sqrt((1.0 - prob) * ba * bm);
 }
 
+/* Compute the entropy of the distribution */
+Scalar Triangular::computeEntropy() const
+{
+  return 0.5 - std::log(2.0 / (b_ - a_));
+}
+
 /* Get the roughness, i.e. the L2-norm of the PDF */
 Scalar Triangular::getRoughness() const
 {
@@ -312,9 +319,9 @@ Point Triangular::getStandardMoment(const UnsignedInteger n) const
 }
 
 /* Get the standard representative in the parametric family, associated with the standard moments */
-Triangular::Implementation Triangular::getStandardRepresentative() const
+Distribution Triangular::getStandardRepresentative() const
 {
-  return Triangular(-1.0, ((m_ - a_) + (m_ - b_)) / (b_ - a_), 1.0).clone();
+  return new Triangular(-1.0, ((m_ - a_) + (m_ - b_)) / (b_ - a_), 1.0);
 }
 
 /* Parameters value accessor */
