@@ -2,7 +2,7 @@
 /**
  *  @brief The TruncatedNormal distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -25,6 +25,7 @@
 #include "openturns/SpecFunc.hxx"
 #include "openturns/Brent.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
+#include "openturns/Distribution.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -222,6 +223,12 @@ Scalar TruncatedNormal::computeComplementaryCDF(const Point & point) const
   return normalizationFactor_ * (PhiBNorm_ - DistFunc::pNormal((x - mu_) / sigma_));
 }
 
+/* Compute the entropy of the distribution */
+Scalar TruncatedNormal::computeEntropy() const
+{
+  return 0.5 - std::log(SpecFunc::ISQRT2PI * normalizationFactor_ / sigma_) + 0.5 * (aNorm_ * phiANorm_ - bNorm_ * phiBNorm_) * normalizationFactor_;
+}
+
 /* Get the product minimum volume interval containing a given probability of the distribution */
 Interval TruncatedNormal::computeMinimumVolumeIntervalWithMarginalProbability(const Scalar prob, Scalar & marginalProb) const
 {
@@ -421,9 +428,9 @@ Point TruncatedNormal::getKurtosis() const
 }
 
 /* Get the standard representative in the parametric family, associated with the standard moments */
-TruncatedNormal::Implementation TruncatedNormal::getStandardRepresentative() const
+Distribution TruncatedNormal::getStandardRepresentative() const
 {
-  return TruncatedNormal((2.0 * mu_ - (b_ + a_)) / (b_ - a_), 2.0 * sigma_ / (b_ - a_), -1.0, 1.0).clone();
+  return new TruncatedNormal((2.0 * mu_ - (b_ + a_)) / (b_ - a_), 2.0 * sigma_ / (b_ - a_), -1.0, 1.0);
 }
 
 /* Compute the covariance of the distribution */
