@@ -2,7 +2,7 @@
 /**
  *  @brief The UserDefined distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -157,17 +157,17 @@ Scalar UserDefined::computePDF(const Point & point) const
   // Quick search for 1D case
   const Scalar x = point[0];
   UnsignedInteger upper = size - 1;
-  Scalar xUpper = points_[upper][0];
+  Scalar xUpper = points_(upper, 0);
   if (x > xUpper + supportEpsilon_) return 0.0;
   UnsignedInteger lower = 0;
-  Scalar xLower = points_[lower][0];
+  Scalar xLower = points_(lower, 0);
   if (x < xLower - supportEpsilon_) return 0.0;
   // Use bisection search of the correct index
   while (upper - lower > 1)
   {
     // The integer arithmetic ensure that middle will be strictly between lower and upper as far as upper - lower > 1
     const UnsignedInteger middle = (upper + lower) / 2;
-    const Scalar xMiddle = points_[middle][0];
+    const Scalar xMiddle = points_(middle, 0);
     if (xMiddle > x + supportEpsilon_)
     {
       upper = middle;
@@ -209,17 +209,17 @@ Scalar UserDefined::computeCDF(const Point & point) const
   {
     const Scalar x = point[0];
     UnsignedInteger upper = size - 1;
-    Scalar xUpper = points_[upper][0];
+    Scalar xUpper = points_(upper, 0);
     if (x > xUpper - supportEpsilon_) return 1.0;
     UnsignedInteger lower = 0;
-    Scalar xLower = points_[lower][0];
+    Scalar xLower = points_(lower, 0);
     if (x <= xLower - supportEpsilon_) return 0.0;
     // Use dichotomic search of the correct index
     while (upper - lower > 1)
     {
       // The integer arithmetic insure that middle will be strictly between lower and upper as far as upper - lower > 1
       const UnsignedInteger middle = (upper + lower) / 2;
-      const Scalar xMiddle = points_[middle][0];
+      const Scalar xMiddle = points_(middle, 0);
       if (xMiddle > x + supportEpsilon_)
       {
         upper = middle;
@@ -335,7 +335,7 @@ Bool UserDefined::isIntegral() const
   const UnsignedInteger size = points_.getSize();
   for (UnsignedInteger i = 0; i < size; ++i)
   {
-    const Scalar x = points_[i][0];
+    const Scalar x = points_(i, 0);
     if (std::abs(x - round(x)) >= supportEpsilon_) return false;
   }
   return true;
@@ -383,7 +383,7 @@ UserDefined::PointWithDescriptionCollection UserDefined::getParametersCollection
     Description description(size);
     for (UnsignedInteger j = 0; j < size; ++j)
     {
-      point[j] = points_[j][i];
+      point[j] = points_(j, i);
       OSS oss;
       oss << "X^" << i << "_" << j;
       description[j] = oss;
@@ -417,7 +417,7 @@ Point UserDefined::getParameter() const
   {
     for (UnsignedInteger j = 0; j < size; ++ j)
     {
-      point[i * size + j] = points_[j][i];
+      point[i * size + j] = points_(j, i);
     }
   }
   for (UnsignedInteger i = 0; i < size; ++ i)
@@ -449,20 +449,20 @@ Description UserDefined::getParameterDescription() const
 
 
 /* Get the i-th marginal distribution */
-UserDefined::Implementation UserDefined::getMarginal(const UnsignedInteger i) const
+Distribution UserDefined::getMarginal(const UnsignedInteger i) const
 {
   const UnsignedInteger dimension = getDimension();
   if (i >= dimension) throw InvalidArgumentException(HERE) << "The index of a marginal distribution must be in the range [0, dim-1]";
   // Special case for dimension 1
   if (dimension == 1) return clone();
   // General case
-  UserDefined marginal(points_.getMarginal(i), probabilities_);
-  marginal.setDescription(Description(1, getDescription()[i]));
-  return marginal.clone();
+  UserDefined::Implementation marginal(new UserDefined(points_.getMarginal(i), probabilities_));
+  marginal->setDescription(Description(1, getDescription()[i]));
+  return marginal;
 }
 
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
-UserDefined::Implementation UserDefined::getMarginal(const Indices & indices) const
+Distribution UserDefined::getMarginal(const Indices & indices) const
 {
   const UnsignedInteger dimension = getDimension();
   if (!indices.check(dimension)) throw InvalidArgumentException(HERE) << "The indices of a marginal distribution must be in the range [0, dim-1] and must be different";
@@ -477,9 +477,9 @@ UserDefined::Implementation UserDefined::getMarginal(const Indices & indices) co
     const UnsignedInteger index_i = indices[i];
     marginalDescription[i] = description[index_i];
   }
-  UserDefined marginal(points_.getMarginal(indices), probabilities_);
-  marginal.setDescription(marginalDescription);
-  return marginal.clone();
+  UserDefined::Implementation marginal(new UserDefined(points_.getMarginal(indices), probabilities_));
+  marginal->setDescription(marginalDescription);
+  return marginal;
 } // getMarginal(Indices)
 
 /* Interface specific to UserDefined */
@@ -502,7 +502,7 @@ void UserDefined::setData(const Sample & sample,
   for (UnsignedInteger i = 0; i < size; ++i)
   {
     const Point x(sample[i]);
-    for (UnsignedInteger j = 0; j < dimension; ++j) weightedData[i][j] = x[j];
+    for (UnsignedInteger j = 0; j < dimension; ++j) weightedData(i, j) = x[j];
     weightedData[i][dimension] = weights[i];
   }
   // Sort the pairs
@@ -531,7 +531,7 @@ void UserDefined::setData(const Sample & sample,
   for (UnsignedInteger i = 0; i < size; ++i)
   {
     Point x(dimension);
-    for (UnsignedInteger j = 0; j < dimension; ++j) x[j] = weightedData[i][j];
+    for (UnsignedInteger j = 0; j < dimension; ++j) x[j] = weightedData(i, j);
     points_[i] = x;
     probabilities_[i] = std::max(0.0, std::min(1.0, weightedData[i][dimension]));
   }
@@ -563,7 +563,7 @@ Scalar UserDefined::computeScalarQuantile(const Scalar prob,
   UnsignedInteger index = 0;
   const Scalar p = tail ? 1 - prob : prob;
   while (cumulativeProbabilities_[index] < p) ++index;
-  return points_[index][0];
+  return points_(index, 0);
 }
 
 /* Merge the identical points of the support */
@@ -582,18 +582,25 @@ void UserDefined::compactSupport(const Scalar epsilon)
     const UnsignedInteger hashSize = 511;
     Collection<Indices> indices(hashSize);
     Collection<Indices> residuals(hashSize);
+    union
+    {
+      Scalar *s;
+      Unsigned64BitsInteger *u64;
+    } typepun;
     for (UnsignedInteger i = 0; i < size; ++i)
     {
       const Point x(points_[i]);
       Scalar roundedComponent = x[0];
       if (epsilon > 0.0) roundedComponent = epsilon * round(roundedComponent / epsilon);
-      UnsignedInteger index = *reinterpret_cast<Unsigned64BitsInteger*>(&roundedComponent);
+      typepun.s = &roundedComponent;
+      UnsignedInteger index = *typepun.u64;
       for (UnsignedInteger j = 1; j < dimension; ++j)
       {
         roundedComponent = x[j];
         if (epsilon > 0.0) roundedComponent = epsilon * round(roundedComponent / epsilon);
         // XOR based hash function on the binary representation of the floating point coordinates
-        index ^= *reinterpret_cast<Unsigned64BitsInteger*>(&roundedComponent);
+        typepun.s = &roundedComponent;
+        index ^= *typepun.u64;
       }
       const UnsignedInteger hash = index % hashSize;
       const UnsignedInteger quotient = index / hashSize;
@@ -654,11 +661,11 @@ void UserDefined::compactSupport(const Scalar epsilon)
     setData(compactX, compactP);
     return;
   }
-  Scalar lastLocation = points_[0][0];
+  Scalar lastLocation = points_(0, 0);
   Scalar lastWeight = probabilities_[0];
   for (UnsignedInteger i = 1; i < size; ++i)
   {
-    const Scalar currentLocation = points_[i][0];
+    const Scalar currentLocation = points_(i, 0);
     const Scalar currentWeight = probabilities_[i];
     // The current point must be merged
     if (std::abs(currentLocation - lastLocation) <= epsilon) lastWeight += probabilities_[i];
