@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for UserDefined distribution
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -43,18 +43,18 @@ UserDefinedFactory * UserDefinedFactory::clone() const
 
 /* Here is the interface that all derived class must implement */
 
-UserDefinedFactory::Implementation UserDefinedFactory::build(const Sample & sample) const
+Distribution UserDefinedFactory::build(const Sample & sample) const
 {
   return buildAsUserDefined(sample, 0.0).clone();
 }
 
-UserDefinedFactory::Implementation UserDefinedFactory::build(const Sample & sample,
-    const Scalar epsilon) const
+Distribution UserDefinedFactory::build(const Sample & sample,
+                                       const Scalar epsilon) const
 {
   return buildAsUserDefined(sample, epsilon).clone();
 }
 
-UserDefinedFactory::Implementation UserDefinedFactory::build() const
+Distribution UserDefinedFactory::build() const
 {
   return buildAsUserDefined().clone();
 }
