@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level class for all distributions
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -75,7 +75,7 @@ Bool Distribution::operator !=(const Distribution & other) const
 /* Addition operator */
 Distribution Distribution::operator + (const Distribution & other) const
 {
-  return getImplementation()->operator +(other.getImplementation());
+  return getImplementation()->operator +(other);
 }
 
 Distribution Distribution::operator + (const Scalar value) const
@@ -83,10 +83,10 @@ Distribution Distribution::operator + (const Scalar value) const
   return getImplementation()->operator +(value);
 }
 
-/* Substraction operator */
+/* Subtraction operator */
 Distribution Distribution::operator - (const Distribution & other) const
 {
-  return getImplementation()->operator -(other.getImplementation());
+  return getImplementation()->operator -(other);
 }
 
 Distribution Distribution::operator - (const Scalar value) const
@@ -97,7 +97,7 @@ Distribution Distribution::operator - (const Scalar value) const
 /* Multiplication operator */
 Distribution Distribution::operator * (const Distribution & other) const
 {
-  return getImplementation()->operator *(other.getImplementation());
+  return getImplementation()->operator *(other);
 }
 
 Distribution Distribution::operator * (const Scalar value) const
@@ -108,7 +108,7 @@ Distribution Distribution::operator * (const Scalar value) const
 /* Division operator */
 Distribution Distribution::operator / (const Distribution & other) const
 {
-  return getImplementation()->operator /(other.getImplementation());
+  return getImplementation()->operator /(other);
 }
 
 Distribution Distribution::operator / (const Scalar value) const
@@ -455,6 +455,12 @@ Complex Distribution::computeLogGeneratingFunction(const Complex & z) const
   return getImplementation()->computeLogGeneratingFunction(z);
 }
 
+/* Compute the entropy of the distribution */
+Scalar Distribution::computeEntropy() const
+{
+  return getImplementation()->computeEntropy();
+}
+
 /* Get the DDF of the distribution (for a sample) */
 Sample Distribution::computeDDF(const Sample & sample) const
 {
@@ -625,6 +631,12 @@ Sample Distribution::computeQuantile(const Point & prob,
   return getImplementation()->computeQuantile(prob, tail);
 }
 
+Scalar Distribution::computeScalarQuantile(const Scalar prob,
+    const Bool tail) const
+{
+  return getImplementation()->computeScalarQuantile(prob, tail);
+}
+
 /* Get the product minimum volume interval containing at least a given probability of the distribution.
    The minimum volume interval [a, b] is such that:
    a\in[lowerBound, F^{-1}(1-p)]
@@ -802,13 +814,13 @@ Scalar Distribution::computeRadialDistributionCDF (const Scalar radius,
 /* Get the i-th marginal distribution */
 Distribution Distribution::getMarginal(const UnsignedInteger i) const
 {
-  return *(getImplementation()->getMarginal(i));
+  return getImplementation()->getMarginal(i);
 }
 
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
 Distribution Distribution::getMarginal(const Indices & indices) const
 {
-  return *(getImplementation()->getMarginal(indices));
+  return getImplementation()->getMarginal(indices);
 }
 
 /* Get the copula of a distribution */
