@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level class for elliptical distributions
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -94,10 +94,10 @@ Bool EllipticalDistribution::equals(const DistributionImplementation & other) co
   // Are they both elliptical?
   if (!other.isElliptical()) return false;
   // The copula...
-  if ( !( (hasIndependentCopula() && other.hasIndependentCopula()) || (*getCopula() == *other.getCopula()) ) ) return false;
+  if ( !( (hasIndependentCopula() && other.hasIndependentCopula()) || (getCopula() == other.getCopula()) ) ) return false;
   // Then the marginals
   for (UnsignedInteger i = 0; i < dimension_; ++ i)
-    if (!(getMarginal(i)->operator == (*other.getMarginal(i)))) return false;
+    if (!(getMarginal(i).operator == (other.getMarginal(i)))) return false;
   return true;
 }
 
@@ -579,7 +579,7 @@ EllipticalDistribution::InverseIsoProbabilisticTransformation EllipticalDistribu
 
 /* Get the standard distribution, i.e. a distribution of the same kind but with zero mean,
  * unit marginal standard distribution and identity correlation */
-EllipticalDistribution::Implementation EllipticalDistribution::getStandardDistribution() const
+Distribution EllipticalDistribution::getStandardDistribution() const
 {
   EllipticalDistribution * p_standardDistribution(clone());
   const UnsignedInteger dimension = getDimension();
