@@ -4,7 +4,7 @@
  *  using a maximization of the likelihood function. We use here some articles of J.A.Mauricio (http://www.ucm.es/info/ecocuan/jam/)
  *  to use an efficient method
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -16,7 +16,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -46,7 +46,7 @@ static int modifiedCholeskyDecomposition(SquareMatrix &matrix,
 /* Default constructor */
 ARMALikelihoodFactory::ARMALikelihoodFactory()
   : ARMAFactoryImplementation()
-  , currentG_()
+  , currentG_(0)
   , w_()
   , dimension_(1)
   , covarianceMatrix_()
@@ -70,9 +70,9 @@ ARMALikelihoodFactory::ARMALikelihoodFactory(const UnsignedInteger p,
     const UnsignedInteger dimension,
     const Bool invertible)
   : ARMAFactoryImplementation(p, q, invertible)
-  , currentG_()
+  , currentG_(0)
   , w_()
-  , dimension_()
+  , dimension_(dimension)
   , covarianceMatrix_()
   , autoCovariance_()
   , crossCovariance_()
@@ -86,7 +86,6 @@ ARMALikelihoodFactory::ARMALikelihoodFactory(const UnsignedInteger p,
 {
   if (dimension == 0)
     throw InvalidArgumentException(HERE) << "Error : dimension could not be zero" ;
-  dimension_ = dimension;
   // Create the optimization solver parameters using the parameters in the ResourceMap
   initializeCobylaSolverParameter();
   if ((p != 0) || (q != 0))
@@ -108,9 +107,9 @@ ARMALikelihoodFactory::ARMALikelihoodFactory(const Indices & p,
     const UnsignedInteger dimension,
     const Bool invertible)
   : ARMAFactoryImplementation(p, q, invertible)
-  , currentG_()
+  , currentG_(0)
   , w_()
-  , dimension_()
+  , dimension_(dimension)
   , covarianceMatrix_()
   , autoCovariance_()
   , crossCovariance_()
@@ -124,7 +123,6 @@ ARMALikelihoodFactory::ARMALikelihoodFactory(const Indices & p,
 {
   if (dimension == 0)
     throw InvalidArgumentException(HERE) << "Error : dimension could not be zero" ;
-  dimension_ = dimension;
   // Create the optimization solver parameters using the parameters in the ResourceMap
   initializeCobylaSolverParameter();
 }
@@ -419,7 +417,7 @@ void ARMALikelihoodFactory::initializeCobylaSolverParameter()
   cobyla->setRhoBeg(ResourceMap::GetAsScalar("ARMALikelihoodFactory-DefaultRhoBeg"));
 
   solver_.setMaximumAbsoluteError(ResourceMap::GetAsScalar("ARMALikelihoodFactory-DefaultRhoEnd"));
-  solver_.setMaximumIterationNumber(ResourceMap::GetAsUnsignedInteger("ARMALikelihoodFactory-DefaultMaxFun"));
+  solver_.setMaximumEvaluationNumber(ResourceMap::GetAsUnsignedInteger("ARMALikelihoodFactory-DefaultMaxFun"));
 }
 
 /* Optimization solver accessor */
@@ -549,7 +547,7 @@ ARMA ARMALikelihoodFactory::build(const TimeSeries & timeSeries) const
 
   // passing time series to log likelihood function
   w_ = timeSeries;
-  const UnsignedInteger dimension = w_.getDimension();
+  const UnsignedInteger dimension = w_.getOutputDimension();
   if (dimension != dimension_)
     throw InvalidDimensionException(HERE) << "Error : expected time series of dimension " << dimension_
                                           << " here time series is of dimension " << dimension;
@@ -718,7 +716,7 @@ void ARMALikelihoodFactory::defaultInitialize() const
 {
   // Launch d times the WhittleFactory to get initial conditions for the optimization problem
   WhittleFactory factory(currentP_, currentQ_);
-  const Sample values(w_.getSample());
+  const Sample values(w_.getValues());
   const RegularGrid timeGrid(w_.getTimeGrid());
   for (UnsignedInteger d = 0; d < dimension_; ++d)
   {
