@@ -2,7 +2,7 @@
 /**
  *  @brief A class which implements the FunctionalBasisProcess process
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -39,17 +39,17 @@ static const Factory<FunctionalBasisProcess> Factory_FunctionalBasisProcess;
 FunctionalBasisProcess::FunctionalBasisProcess()
   : ProcessImplementation()
   , distribution_(Normal())
-  , basis_(Collection<Function>(1, SymbolicFunction("t", "t")))
+  , basis_(1, SymbolicFunction("t", "t"))
   , state_(1, 0.0)
 {
   // Set the dimension of the process
-  setDimension(1);
+  setOutputDimension(1);
   setDescription(basis_[0].getOutputDescription());
 }
 
 /* Standard constructor */
 FunctionalBasisProcess::FunctionalBasisProcess(const Distribution & distribution,
-    const Basis & basis)
+    const FunctionCollection & basis)
   : ProcessImplementation()
   , distribution_(distribution)
   , basis_()
@@ -62,7 +62,7 @@ FunctionalBasisProcess::FunctionalBasisProcess(const Distribution & distribution
 
 /* Standard constructor */
 FunctionalBasisProcess::FunctionalBasisProcess(const Distribution & distribution,
-    const Basis & basis,
+    const FunctionCollection & basis,
     const Mesh & mesh)
   : ProcessImplementation()
   , distribution_(distribution)
@@ -94,9 +94,6 @@ String FunctionalBasisProcess::__repr__() const
 CovarianceModel FunctionalBasisProcess::getCovarianceModel() const
 {
   const UnsignedInteger dimension = distribution_.getDimension();
-  Collection<Function> functions(dimension);
-  for (UnsignedInteger i = 0; i < dimension; ++i)
-    functions[i] = basis_.build(i);
   if (distribution_.hasIndependentCopula())
   {
     // We use the standard deviation as it is an O(dim) computation
@@ -104,9 +101,9 @@ CovarianceModel FunctionalBasisProcess::getCovarianceModel() const
     Point coefficients(distribution_.getStandardDeviation());
     for (UnsignedInteger i = 0; i < dimension; ++i)
       coefficients[i] *= coefficients[i];
-    return RankMCovarianceModel(coefficients, functions);
+    return RankMCovarianceModel(coefficients, basis_);
   }
-  return RankMCovarianceModel(distribution_.getCovariance(), functions);
+  return RankMCovarianceModel(distribution_.getCovariance(), basis_);
 }
 
 /* Is the process stationary ? */
@@ -132,12 +129,12 @@ Field FunctionalBasisProcess::getRealization() const
   const UnsignedInteger timeGridSize = mesh_.getVerticesNumber();
   const UnsignedInteger basisSize = basis_.getSize();
   // Loop over the time stamps
-  Sample result(timeGridSize, Point(dimension_, 0.0));
+  Sample result(timeGridSize, Point(getOutputDimension(), 0.0));
   // Loop over the basis
   for (UnsignedInteger j = 0; j < basisSize; ++j)
   {
     Sample currentBasisContribution(basis_[j](mesh_.getVertices()));
-    currentBasisContribution *= Point(dimension_, state_[j]);
+    currentBasisContribution *= Point(getOutputDimension(), state_[j]);
     result += currentBasisContribution;
   }
   result.setDescription(getDescription());
@@ -171,7 +168,7 @@ TimeSeries FunctionalBasisProcess::getFuture(const UnsignedInteger stepNumber) c
   const RegularGrid futureTimeGrid(timeGrid.getEnd(), timeStep, stepNumber);
   const UnsignedInteger basisSize = basis_.getSize();
   // Loop over the time stamps
-  Sample result(stepNumber, Point(dimension_, 0.0));
+  Sample result(stepNumber, Point(getOutputDimension(), 0.0));
   for (UnsignedInteger i = 0; i  < stepNumber; ++i)
   {
     const Point t(1, futureTimeGrid.getValue(i));
@@ -182,24 +179,24 @@ TimeSeries FunctionalBasisProcess::getFuture(const UnsignedInteger stepNumber) c
 }
 
 /* Get the marginal process corresponding to the i-th marginal component */
-FunctionalBasisProcess::Implementation FunctionalBasisProcess::getMarginal(const UnsignedInteger i) const
+Process FunctionalBasisProcess::getMarginal(const UnsignedInteger i) const
 {
-  if (i >= getDimension()) throw InvalidArgumentException(HERE) << "The index of a marginal process must be in the range [0, dim-1]";
+  if (i >= getOutputDimension()) throw InvalidArgumentException(HERE) << "The index of a marginal process must be in the range [0, dim-1]";
   return getMarginal(Indices(1, i));
 }
 
 /* Get the marginal random vector corresponding to indices components */
-FunctionalBasisProcess::Implementation FunctionalBasisProcess::getMarginal(const Indices & indices) const
+Process FunctionalBasisProcess::getMarginal(const Indices & indices) const
 {
-  if (!indices.check(getDimension())) throw InvalidArgumentException(HERE) << "The indices of a marginal process must be in the range [0, dim-1] and must be different";
+  if (!indices.check(getOutputDimension())) throw InvalidArgumentException(HERE) << "The indices of a marginal process must be in the range [0, dim-1] and must be different";
   // First the marginal distribution
   Distribution marginalDistribution(distribution_.getMarginal(indices));
   // Second the marginal basis
   const UnsignedInteger basisSize = basis_.getSize();
-  Basis marginalBasis(basisSize);
+  FunctionCollection marginalBasis(basisSize);
   for (UnsignedInteger i = 0; i < basisSize; ++i) marginalBasis[i] = basis_[i].getMarginal(indices);
   // Return the associated FunctionalBasisProcess
-  return FunctionalBasisProcess(marginalDistribution, marginalBasis, mesh_).clone();
+  return new FunctionalBasisProcess(marginalDistribution, marginalBasis, mesh_);
 }
 
 /* Distribution accessor */
@@ -217,13 +214,13 @@ void FunctionalBasisProcess::setDistribution(const Distribution & distribution)
 }
 
 /* Basis accessor */
-Basis FunctionalBasisProcess::getBasis() const
+FunctionalBasisProcess::FunctionCollection FunctionalBasisProcess::getBasis() const
 {
   return basis_;
 }
 
 /* Basis accessor */
-void FunctionalBasisProcess::setBasis(const Basis & basis)
+void FunctionalBasisProcess::setBasis(const FunctionCollection & basis)
 {
   const UnsignedInteger size = basis.getSize();
   // Check if the basis is not empty
@@ -231,14 +228,14 @@ void FunctionalBasisProcess::setBasis(const Basis & basis)
   // Check the basis against the distribution
   if (size != distribution_.getDimension() ) throw InvalidArgumentException(HERE) << "Error: the given basis has a size=" << size << " that does not match the distribution dimension=" << distribution_.getDimension();
   // Check if the functions in the basis are from R to R^n for the same n
-  dimension_ = basis[0].getOutputDimension();
+  setOutputDimension(basis[0].getOutputDimension());
   const UnsignedInteger inputDimension = mesh_.getDimension();
   for (UnsignedInteger i = 0; i < size; ++i)
   {
     // Check the input dimension
     if (basis[i].getInputDimension() != inputDimension) throw InvalidArgumentException(HERE) << "Error: the function at index=" << i << " has an input dimension=" << basis[i].getInputDimension() << " which is not equal to " << inputDimension << ".";
     // Check the output dimension
-    if (basis[i].getOutputDimension() != dimension_) throw InvalidArgumentException(HERE) << "Error: the function at index=" << i << " has an output dimension=" << basis[i].getOutputDimension() << " which is not equal to the process dimension=" << dimension_;
+    if (basis[i].getOutputDimension() != getOutputDimension()) throw InvalidArgumentException(HERE) << "Error: the function at index=" << i << " has an output dimension=" << basis[i].getOutputDimension() << " which is not equal to the process dimension=" << getOutputDimension();
   }
   basis_ = basis;
   setDescription(basis[0].getOutputDescription());
