@@ -2,7 +2,7 @@
 /**
  *  @brief A class which implements the Gaussian process
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -29,7 +29,11 @@
 #include "openturns/KPermutationsDistribution.hxx"
 #include "openturns/RandomGenerator.hxx"
 #include "openturns/HMatrixFactory.hxx"
+#ifdef OPENTURNS_HAVE_ANALYTICAL_PARSER
 #include "openturns/SymbolicFunction.hxx"
+#else
+#include "openturns/DatabaseFunction.hxx"
+#endif
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -49,10 +53,10 @@ GaussianProcess::GaussianProcess()
   , stationaryTrendValue_(0.0)
   , samplingMethod_(0)
 {
-#ifdef OPENTURNS_HAVE_MUPARSER
-  trend_ = TrendTransform(SymbolicFunction(Description::BuildDefault(covarianceModel_.getSpatialDimension(), "x"), Description(getDimension(), "0.0")));
+#ifdef OPENTURNS_HAVE_ANALYTICAL_PARSER
+  trend_ = TrendTransform(SymbolicFunction(Description::BuildDefault(covarianceModel_.getInputDimension(), "x"), Description(getOutputDimension(), "0.0")));
 #else
-  trend_ = TrendTransform(Function(Sample(1, covarianceModel_.getSpatialDimension()), Sample(1, getDimension())));
+  trend_ = TrendTransform(DatabaseFunction(Sample(1, covarianceModel_.getInputDimension()), Sample(1, getOutputDimension())));
 #endif
   setDescription(trend_.getOutputDescription());
 }
@@ -72,10 +76,10 @@ GaussianProcess::GaussianProcess(const TrendTransform & trend,
   , stationaryTrendValue_(trend.getOutputDimension())
   , samplingMethod_(0)
 {
-  if (trend.getInputDimension() != model.getSpatialDimension()) throw InvalidArgumentException(HERE) << "Error: the given trend has an input dimension=" << trend.getInputDimension() << " different from the second order model spatial dimension=" << model.getSpatialDimension();
-  if (trend.getOutputDimension() != model.getDimension()) throw InvalidArgumentException(HERE) << "Error: the given trend has an output dimension=" << trend.getOutputDimension() << " different from the second order model dimension=" << model.getDimension();
+  if (trend.getInputDimension() != model.getInputDimension()) throw InvalidArgumentException(HERE) << "Error: the given trend has an input dimension=" << trend.getInputDimension() << " different from the second order model spatial dimension=" << model.getInputDimension();
+  if (trend.getOutputDimension() != model.getOutputDimension()) throw InvalidArgumentException(HERE) << "Error: the given trend has an output dimension=" << trend.getOutputDimension() << " different from the second order model dimension=" << model.getOutputDimension();
   setMesh(mesh);
-  setDimension(model.getDimension());
+  setOutputDimension(model.getOutputDimension());
   setDescription(trend_.getOutputDescription());
 }
 
@@ -94,10 +98,10 @@ GaussianProcess::GaussianProcess(const TrendTransform & trend,
   , stationaryTrendValue_(trend.getOutputDimension())
   , samplingMethod_(0)
 {
-  if (trend.getInputDimension() != covarianceModel.getSpatialDimension()) throw InvalidArgumentException(HERE) << "Error: the given trend has an input dimension=" << trend.getInputDimension() << " different from the covariance model spatial dimension=" << covarianceModel.getSpatialDimension();
-  if (trend.getOutputDimension() != covarianceModel.getDimension()) throw InvalidArgumentException(HERE) << "Error: the given trend has an output dimension=" << trend.getOutputDimension() << " different from the covariance model dimension=" << covarianceModel.getDimension();
+  if (trend.getInputDimension() != covarianceModel.getInputDimension()) throw InvalidArgumentException(HERE) << "Error: the given trend has an input dimension=" << trend.getInputDimension() << " different from the covariance model spatial dimension=" << covarianceModel.getInputDimension();
+  if (trend.getOutputDimension() != covarianceModel.getOutputDimension()) throw InvalidArgumentException(HERE) << "Error: the given trend has an output dimension=" << trend.getOutputDimension() << " different from the covariance model dimension=" << covarianceModel.getOutputDimension();
   setMesh(mesh);
-  setDimension(covarianceModel.getDimension());
+  setOutputDimension(covarianceModel.getOutputDimension());
   setDescription(trend_.getOutputDescription());
 }
 
@@ -112,16 +116,16 @@ GaussianProcess::GaussianProcess(const SecondOrderModel & model,
   , hasStationaryTrend_(true)
   , checkedStationaryTrend_(true)
   , trend_()
-  , stationaryTrendValue_(model.getDimension())
+  , stationaryTrendValue_(model.getOutputDimension())
   , samplingMethod_(0)
 {
   // We use the upper class accessor to prevent the reinitialization of the flags
   ProcessImplementation::setMesh(mesh);
-  setDimension(model.getDimension());
-#ifdef OPENTURNS_HAVE_MUPARSER
-  trend_ = TrendTransform(SymbolicFunction(Description::BuildDefault(getSpatialDimension(), "x"), Description(getDimension(), "0.0")));
+  setOutputDimension(model.getOutputDimension());
+#ifdef OPENTURNS_HAVE_ANALYTICAL_PARSER
+  trend_ = TrendTransform(SymbolicFunction(Description::BuildDefault(getInputDimension(), "x"), Description(getOutputDimension(), "0.0")));
 #else
-  trend_ = TrendTransform(Function(Sample(1, getSpatialDimension()), Sample(1, getDimension())));
+  trend_ = TrendTransform(DatabaseFunction(Sample(1, getInputDimension()), Sample(1, getOutputDimension())));
 #endif
   setDescription(trend_.getOutputDescription());
 }
@@ -137,16 +141,16 @@ GaussianProcess::GaussianProcess(const CovarianceModel & covarianceModel,
   , hasStationaryTrend_(true)
   , checkedStationaryTrend_(true)
   , trend_()
-  , stationaryTrendValue_(covarianceModel.getDimension())
+  , stationaryTrendValue_(covarianceModel.getOutputDimension())
   , samplingMethod_(0)
 {
   // We use the upper class accessor to prevent the reinitialization of the flags
   ProcessImplementation::setMesh(mesh);
-  setDimension(covarianceModel.getDimension());
-#ifdef OPENTURNS_HAVE_MUPARSER
-  trend_ = TrendTransform(SymbolicFunction(Description::BuildDefault(getSpatialDimension(), "x"), Description(getDimension(), "0.0")));
+  setOutputDimension(covarianceModel.getOutputDimension());
+#ifdef OPENTURNS_HAVE_ANALYTICAL_PARSER
+  trend_ = TrendTransform(SymbolicFunction(Description::BuildDefault(getInputDimension(), "x"), Description(getOutputDimension(), "0.0")));
 #else
-  trend_ = TrendTransform(Function(Sample(1, getSpatialDimension()), Sample(1, getDimension())));
+  trend_ = TrendTransform(DatabaseFunction(Sample(1, getInputDimension()), Sample(1, getOutputDimension())));
 #endif
   setDescription(trend_.getOutputDescription());
 }
@@ -184,8 +188,8 @@ void GaussianProcess::initialize() const
     if (samplingMethod_ == 1)
     {
       LOGINFO(OSS() << "Assemble and factor the covariance matrix");
-      covarianceHMatrix_ = hmatFactory.build(mesh_.getVertices(), covarianceModel_.getDimension(), true, hmatrixParameters);
-      if (covarianceModel_.getDimension() == 1)
+      covarianceHMatrix_ = hmatFactory.build(mesh_.getVertices(), covarianceModel_.getOutputDimension(), true, hmatrixParameters);
+      if (covarianceModel_.getOutputDimension() == 1)
       {
         CovarianceAssemblyFunction simple(covarianceModel_, mesh_.getVertices(), cumulatedScaling);
         covarianceHMatrix_.assemble(simple, 'L');
@@ -200,7 +204,7 @@ void GaussianProcess::initialize() const
         covarianceHMatrix_.factorize("LLt");
         continuationCondition = false;
       }
-      catch (InternalException)
+      catch (InternalException &)
       {
         cumulatedScaling += scaling ;
         scaling *= 2.0;
@@ -288,7 +292,7 @@ void GaussianProcess::setSamplingMethod(const UnsignedInteger samplingMethod)
 {
   if (samplingMethod > 2)
     throw InvalidArgumentException(HERE) << "Sampling method should be 0 (Cholesky), 1 (H-Matrix implementation) or 2 (Gibbs, available only in dimension 1 ";
-  if ((samplingMethod == 2) && getDimension() != 1)
+  if ((samplingMethod == 2) && getOutputDimension() != 1)
     throw InvalidArgumentException(HERE) << "Sampling method Gibbs is available only in dimension 1 ";
   // Set the sampling method
   if (samplingMethod != samplingMethod_)
@@ -305,7 +309,7 @@ void GaussianProcess::setSamplingMethod(const UnsignedInteger samplingMethod)
 Field GaussianProcess::getRealization() const
 {
   Sample values;
-  if ((getDimension() == 1) && (samplingMethod_ == 2))
+  if ((getOutputDimension() == 1) && (samplingMethod_ == 2))
     values = getRealizationGibbs();
   else if (samplingMethod_ == 1)
     values = getRealizationHMatrix();
@@ -343,7 +347,7 @@ Sample GaussianProcess::getRealizationGibbs() const
       // Here we work on the normalized covariance, ie the correlation
       Sample covarianceRow(covarianceModel_.discretizeRow(vertices, index));
       diagonal[index] = covarianceRow[index][0];
-      const Point delta(1, (DistFunc::rNormal() - values[index][0]) / diagonal[index]);
+      const Point delta(1, (DistFunc::rNormal() - values(index, 0)) / diagonal[index]);
       values += covarianceRow * delta;
     }
   }
@@ -360,7 +364,7 @@ Sample GaussianProcess::getRealizationCholesky() const
   const UnsignedInteger fullSize = covarianceCholeskyFactor_.getDimension();
   const Point gaussianPoint(DistFunc::rNormal(fullSize));
 
-  SampleImplementation values(size, dimension_);
+  SampleImplementation values(size, getOutputDimension());
   const Point rawResult(covarianceCholeskyFactor_ * gaussianPoint);
   LOGINFO(OSS() << "In GaussianProcess::getRealizationCholesky(), size=" << size << ", fullSize=" << fullSize << ", gaussianPoint dimension=" << gaussianPoint.getDimension() << ", rawResult dimension=" << rawResult.getDimension());
   values.setData(rawResult);
@@ -376,7 +380,7 @@ Sample GaussianProcess::getRealizationHMatrix() const
 
   Point y(fullSize);
   covarianceHMatrix_.gemv('N', 1.0, gaussianPoint, 0.0, y);
-  Sample values(size, dimension_);
+  Sample values(size, getOutputDimension());
   values.getImplementation()->setData(y);
   return values;
 }
