@@ -4,7 +4,7 @@
  *         basis and eigenvalues of a given covariance model based on
  *         quadrature approximation.
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -16,7 +16,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -33,6 +33,7 @@
 #include "openturns/GaussProductExperiment.hxx"
 #include "openturns/EnumerateFunction.hxx"
 #include "openturns/OrthogonalProductPolynomialFactory.hxx"
+#include "openturns/Basis.hxx"
 #include "openturns/LegendreFactory.hxx"
 #include "openturns/SpecFunc.hxx"
 #include "openturns/ComposedFunction.hxx"
@@ -55,7 +56,6 @@ KarhunenLoeveQuadratureAlgorithm::KarhunenLoeveQuadratureAlgorithm()
   , domain_()
   , experiment_()
   , basis_()
-  , basisSize_(0)
   , mustScale_(false)
 {
   // Nothing to do
@@ -63,47 +63,54 @@ KarhunenLoeveQuadratureAlgorithm::KarhunenLoeveQuadratureAlgorithm()
 
 /* Constructor with parameters */
 KarhunenLoeveQuadratureAlgorithm::KarhunenLoeveQuadratureAlgorithm(const Domain & domain,
+    const Interval & domainBounds,
     const CovarianceModel & covariance,
     const WeightedExperiment & experiment,
-    const Basis & basis,
-    const UnsignedInteger basisSize,
+    const FunctionCollection & basis,
     const Bool mustScale,
     const Scalar threshold)
   : KarhunenLoeveAlgorithmImplementation(covariance, threshold)
   , domain_(domain)
+  , domainLowerBound_(domainBounds.getLowerBound())
+  , domainUpperBound_(domainBounds.getUpperBound())
   , experiment_(experiment)
   , basis_(basis)
-  , basisSize_(basisSize)
   , mustScale_(mustScale)
 {
   // Check the arguments
   const UnsignedInteger dimension = domain.getDimension();
   const Distribution distribution(experiment.getDistribution());
   if (dimension != distribution.getDimension()) throw InvalidArgumentException(HERE) << "Error: the domain dimension=" << dimension << " does not match the distribution dimension=" << distribution.getDimension() << " of the weighted experiment";
-  const Point domainLowerBound(domain.getLowerBound());
-  const Point domainUpperBound(domain.getUpperBound());
-  if (Interval(domainLowerBound, domainUpperBound).isNumericallyEmpty()) throw InvalidArgumentException(HERE) << "Error: the given domain is numerically empty.";
+  if (domainBounds.isNumericallyEmpty()) throw InvalidArgumentException(HERE) << "Error: the given domain is numerically empty.";
 }
 
 /* Constructor with parameters specialized to the case of Legendre polynomials and Gauss product quadrature */
 KarhunenLoeveQuadratureAlgorithm::KarhunenLoeveQuadratureAlgorithm(const Domain & domain,
+    const Interval & domainBounds,
     const CovarianceModel & covariance,
     const UnsignedInteger marginalDegree,
     const Scalar threshold)
   : KarhunenLoeveAlgorithmImplementation(covariance, threshold)
   , domain_(domain)
+  , domainLowerBound_(domainBounds.getLowerBound())
+  , domainUpperBound_(domainBounds.getUpperBound())
   , experiment_(GaussProductExperiment(ComposedDistribution(Collection<Distribution>(domain.getDimension(), Uniform())), Indices(domain.getDimension(), marginalDegree + 1)))
-    // Here we have to use the double/double version of std::pow to make VC++ happy. Grrr.
-  , basis_(OrthogonalProductPolynomialFactory(Collection<OrthogonalUniVariatePolynomialFamily>(domain.getDimension(), LegendreFactory()), EnumerateFunction(domain.getDimension(), SpecFunc::MaxScalar))), basisSize_(static_cast<UnsignedInteger>(std::floor(0.5 + std::pow(1.0 * marginalDegree, 1.0 * domain.getDimension()))))
   , mustScale_(true)
 {
   // Check the arguments
   const UnsignedInteger dimension = domain.getDimension();
   const Distribution distribution(experiment_.getDistribution());
   if (dimension != distribution.getDimension()) throw InvalidArgumentException(HERE) << "Error: the domain dimension=" << dimension << " does not match the distribution dimension=" << distribution.getDimension() << " of the weighted experiment";
-  const Point domainLowerBound(domain.getLowerBound());
-  const Point domainUpperBound(domain.getUpperBound());
-  if (Interval(domainLowerBound, domainUpperBound).isNumericallyEmpty()) throw InvalidArgumentException(HERE) << "Error: the given domain is numerically empty.";
+  if (domainBounds.isNumericallyEmpty()) throw InvalidArgumentException(HERE) << "Error: the given domain is numerically empty.";
+
+
+  // Here we have to use the double/double version of std::pow to make VC++ happy. Grrr.
+  const UnsignedInteger basisSize = static_cast<UnsignedInteger>(std::floor(0.5 + std::pow(1.0 * marginalDegree, 1.0 * dimension)));
+  const Basis basis(OrthogonalProductPolynomialFactory(Collection<OrthogonalUniVariatePolynomialFamily>(dimension, LegendreFactory()), EnumerateFunction(dimension, SpecFunc::MaxScalar)));
+  for(UnsignedInteger i = 0; i < basisSize; ++i)
+  {
+    basis_.add(basis.build(i));
+  }
 }
 
 /* Virtual constructor */
@@ -139,11 +146,9 @@ void KarhunenLoeveQuadratureAlgorithm::run()
   const UnsignedInteger domainDimension = domain_.getDimension();
   const Distribution distribution(experiment_.getDistribution());
   // First thing to do: build a linear transformation that maps the range of the distribution associated with the weighted experiment to the bounding box of the domain
-  const Point domainLowerBound(domain_.getLowerBound());
-  const Point domainUpperBound(domain_.getUpperBound());
   const Point distributionLowerBound(distribution.getRange().getLowerBound());
   const Point distributionUpperBound(distribution.getRange().getUpperBound());
-  const Bool hasSameBounds = (domainLowerBound == distributionLowerBound) && (domainUpperBound == distributionUpperBound);
+  const Bool hasSameBounds = (domainLowerBound_ == distributionLowerBound) && (domainUpperBound_ == distributionUpperBound);
   // The function scaling maps points in the range of the distribution into the domain
   Function scaling;
   Function inverseScaling;
@@ -153,11 +158,11 @@ void KarhunenLoeveQuadratureAlgorithm::run()
   {
     TriangularMatrix T(domainDimension);
     TriangularMatrix inverseT(domainDimension);
-    Point center((distributionUpperBound + distributionLowerBound) * 0.5);
-    Point constant((domainUpperBound + domainLowerBound) * 0.5);
+    const Point center((distributionUpperBound + distributionLowerBound) * 0.5);
+    const Point constant((domainUpperBound_ + domainLowerBound_) * 0.5);
     for (UnsignedInteger i = 0; i < domainDimension; ++i)
     {
-      T(i, i) = (domainUpperBound[i] - domainLowerBound[i]) / (distributionUpperBound[i] - distributionLowerBound[i]);
+      T(i, i) = (domainUpperBound_[i] - domainLowerBound_[i]) / (distributionUpperBound[i] - distributionLowerBound[i]);
       normalizationFactor *= T(i, i);
       inverseT(i, i) = 1.0 / T(i, i);
     }
@@ -165,10 +170,10 @@ void KarhunenLoeveQuadratureAlgorithm::run()
     inverseScaling = LinearFunction(constant, center, inverseT);
   }
   // Here we set the collection of functions
-  Collection<Function> coll(basisSize_);
-  for (UnsignedInteger i = 0; i < basisSize_; ++i)
-    if (!hasSameBounds && mustScale_) coll[i] = ComposedFunction(basis_.build(i), inverseScaling);
-    else coll[i] = basis_.build(i);
+  Collection<Function> coll(basis_.getSize());
+  for (UnsignedInteger i = 0; i < basis_.getSize(); ++i)
+    if (!hasSameBounds && mustScale_) coll[i] = ComposedFunction(basis_[i], inverseScaling);
+    else coll[i] = basis_[i];
   // Compute the integration nodes and weights
   Point rawWeights;
   WeightedExperiment experimentCopy(experiment_);
@@ -189,7 +194,7 @@ void KarhunenLoeveQuadratureAlgorithm::run()
     if (isInside)
     {
       nodes.add(rawNodes[i]);
-      weights.add(std::sqrt(normalizationFactor * rawWeights[i] / pdf[i][0]));
+      weights.add(std::sqrt(normalizationFactor * rawWeights[i] / pdf(i, 0)));
     }
   }
   const UnsignedInteger nodesNumber = nodes.getSize();
@@ -209,10 +214,10 @@ void KarhunenLoeveQuadratureAlgorithm::run()
   LOGINFO(OSS(false) << "Final number of integration nodes=" << nodesNumber);
   if (nodesNumber == 0) throw InternalException(HERE) << "Error: cannot compute a Karhunen Loeve decomposition with zero integration node.";
   LOGINFO("Compute the design matrix");
-  MatrixImplementation scaledTheta(nodesNumber, basisSize_);
+  MatrixImplementation scaledTheta(nodesNumber, basis_.getSize());
   UnsignedInteger indexTheta = 0;
   // scaledTheta(i,j)=w_i\theta_j(\xi_i)
-  for (UnsignedInteger j = 0; j < basisSize_; ++j)
+  for (UnsignedInteger j = 0; j < basis_.getSize(); ++j)
   {
     const Point thetaj(coll[j](nodes).getImplementation()->getData());
     for (UnsignedInteger i = 0; i < nodesNumber; ++i)
@@ -231,7 +236,7 @@ void KarhunenLoeveQuadratureAlgorithm::run()
 
   // Discretize the covariance model
   LOGINFO("Discretize the covariance matrix");
-  const UnsignedInteger dimension = covariance_.getDimension();
+  const UnsignedInteger dimension = covariance_.getOutputDimension();
   CovarianceMatrix C(covariance_.discretize(nodes));
   // Prepare the generalized eigenvalues problem
   // Step 1: scale C by the weights
@@ -264,8 +269,8 @@ void KarhunenLoeveQuadratureAlgorithm::run()
   // Here we have to expand scaledTheta if dimension > 1
   else
   {
-    omega = Matrix(nodesNumber * dimension, basisSize_ * dimension);
-    for (UnsignedInteger j = 0; j < basisSize_; ++j)
+    omega = Matrix(nodesNumber * dimension, basis_.getSize() * dimension);
+    for (UnsignedInteger j = 0; j < basis_.getSize(); ++j)
       for (UnsignedInteger i = 0; i < nodesNumber; ++i)
       {
         const Scalar value = scaledTheta(i, j);
@@ -288,9 +293,9 @@ void KarhunenLoeveQuadratureAlgorithm::run()
   // Here we have to expand cholesky if dimension > 1
   else
   {
-    choleskyBlock = TriangularMatrix(basisSize_ * dimension);
-    for (UnsignedInteger j = 0; j < basisSize_; ++j)
-      for (UnsignedInteger i = j; i < basisSize_; ++i)
+    choleskyBlock = TriangularMatrix(basis_.getSize() * dimension);
+    for (UnsignedInteger j = 0; j < basis_.getSize(); ++j)
+      for (UnsignedInteger i = j; i < basis_.getSize(); ++i)
       {
         const Scalar value = cholesky(i, j);
         for (UnsignedInteger k = 0; k < dimension; ++k)
@@ -313,55 +318,47 @@ void KarhunenLoeveQuadratureAlgorithm::run()
   // Last time we need cholesky, so we can overwrite it by eigenVectors
   LOGINFO("Get the generalized eigenvectors");
   eigenVectors = choleskyBlock.transpose().solveLinearSystem(eigenVectors, false).getImplementation();
-  LOGINFO("Sort the eigenvectors by decreasing eigenvalues");
-  Sample eigenPairs(augmentedDimension, augmentedDimension + 1);
+  LOGINFO("Post-process the eigenvalue problem");
+  Collection< std::pair<Scalar, UnsignedInteger> > eigenPairs(augmentedDimension);
+  for (UnsignedInteger i = 0; i < augmentedDimension; ++i)
+    eigenPairs[i] = std::pair<Scalar, UnsignedInteger>(-eigenValues[i], i);
+  // Sort the eigenvalues in decreasing order
+  std::sort(eigenPairs.begin(), eigenPairs.end());
+  Scalar cumulatedVariance = 0.0;
   for (UnsignedInteger i = 0; i < augmentedDimension; ++i)
   {
-    for (UnsignedInteger j = 0; j < augmentedDimension; ++j) eigenPairs[i][j] = eigenVectors(j, i);
-    eigenPairs[i][augmentedDimension] = -eigenValues[i];
-  }
-  eigenPairs = eigenPairs.sortAccordingToAComponent(augmentedDimension);
-  for (UnsignedInteger i = 0; i < augmentedDimension; ++i)
-  {
-    for (UnsignedInteger j = 0; j < augmentedDimension; ++j) eigenVectors(i, j) = eigenPairs[j][i];
-    eigenValues[i] = -eigenPairs[i][augmentedDimension];
+    eigenValues[i] = -eigenPairs[i].first;
+    cumulatedVariance += eigenValues[i];
   }
+  LOGDEBUG(OSS(false) << "eigenValues=" << eigenValues);
+  LOGINFO("Extract the relevant eigenpairs");
+  // Start at 0 if the given threshold is large (eg greater than 1)
   UnsignedInteger K = 0;
-  Scalar cumulatedVariance = std::abs(eigenValues[0]);
   // Find the cut-off in the eigenvalues
-  while ((K < eigenValues.getSize()) && (eigenValues[K] >= threshold_ * cumulatedVariance))
-  {
-    cumulatedVariance += eigenValues[K];
-    ++K;
-  }
+  while ((K < eigenValues.getSize()) && (eigenValues[K] >= threshold_ * cumulatedVariance)) ++K;
   LOGINFO(OSS() << "Selected " << K << " eigenvalues");
   // Reduce and rescale the eigenvectors
-  MatrixImplementation transposedProjection(nodesNumber * dimension, K);
+  MatrixImplementation projection(K, nodesNumber * dimension);
   Point selectedEV(K);
-  Basis modes(0);
+  Collection<Function> modes;
   ProcessSample modesAsProcessSample(Mesh(nodes), 0, dimension);
   SampleImplementation values(nodesNumber, dimension);
-  UnsignedInteger indexProjection = 0;
+  Point a(augmentedDimension, 1);
+  Point modeValues(nodesNumber * dimension);
   for (UnsignedInteger k = 0; k < K; ++k)
   {
     selectedEV[k] = eigenValues[k];
-    const MatrixImplementation a(*eigenVectors.getColumn(k).getImplementation());
-    const Scalar norm = (omega * Point(a)).norm();
+    const UnsignedInteger initialColumn = eigenPairs[k].second;
+    std::copy(eigenVectors.getImplementation()->begin() + initialColumn * augmentedDimension, eigenVectors.getImplementation()->begin() + (initialColumn + 1) * augmentedDimension, a.begin());
     // Store the eigen modes in two forms
-    Point modeValues(omega.getImplementation()->genProd(a));
-    const Scalar factor = modeValues[0] < 0.0 ? -1.0 / norm : 1.0 / norm;
-    // Unscale the values
-    for (UnsignedInteger i = 0; i < nodesNumber; ++i) modeValues[i] *= factor / weights[i];
-    values.setData(modeValues);
-    modesAsProcessSample.add(values);
-    if (dimension == 1)
-      modes.add(LinearCombinationFunction(coll, a * factor));
-    else
-    {
-      SampleImplementation aSample(basisSize_, dimension);
-      aSample.setData(a * factor);
-      modes.add(DualLinearCombinationFunction(coll, aSample));
-    }
+    // modeValues = omega.a
+    const Point omegaA(omega * a);
+    const Scalar norm = omegaA.norm();
+    const Scalar factor = omegaA[0] < 0.0 ? -1.0 / norm : 1.0 / norm;
+    // Scale a
+    a *= factor;
+    // Compute the values of the mode
+    // modeValues = \epsilon diag(1/w) omega.a / ||omega.a||
     // Build the relevant column of the transposed projection matrix
     // For k=1,...,K K is the number of selected modes
     // M_{k,:}[f(\xi_j)]=1/\sqrt{\lambda_k}\int_{\Omega}f(x)\phi_k(x)dx
@@ -369,21 +366,33 @@ void KarhunenLoeveQuadratureAlgorithm::run()
     //                =1/\sqrt{\lambda_k}\sum_{j=1}^N w_jf(\xi_j)\sum_{i=1}^P a_i^k\theta_i(\xi_j)
     // So M is KxNd, \omega is NdxPd, eigenVectors is PdxK
     // M^t=\omega * eigenVectors
-    MatrixImplementation b(omega.getImplementation()->genProd(a * (factor / sqrt(selectedEV[k]))));
-    UnsignedInteger indexB = 0;
+    // b = \epsilon diag(1/\sqrt{\lambda}) omega.a / ||omega.a||
+    UnsignedInteger index = 0;
+    const Scalar alphaK = factor / std::sqrt(selectedEV[k]);
     for (UnsignedInteger i = 0; i < nodesNumber; ++i)
     {
-      const Scalar wI = weights[i];
+      const Scalar wA = factor / weights[i];
+      const Scalar wB = weights[i] * alphaK;
       for (UnsignedInteger j = 0; j < dimension; ++j)
       {
-        b[indexB] *= wI;
-        ++indexB;
+        modeValues[index] = omegaA[index] * wA;
+        projection(k, i * dimension + j) = omegaA[index] * wB;
+        ++index;
       } // for j
     } // for i
-    std::copy(b.begin(), b.end(), transposedProjection.begin() + indexProjection);
-    indexProjection += b.getSize();
+    values.setData(modeValues);
+    modesAsProcessSample.add(values);
+    if (dimension == 1)
+      modes.add(LinearCombinationFunction(coll, a));
+    else
+    {
+      SampleImplementation aSample(basis_.getSize(), dimension);
+      // aSample = diag(1/w) omega.a / ||omega.a||^2
+      aSample.setData(a);
+      modes.add(DualLinearCombinationFunction(coll, aSample));
+    }
   }
-  result_ = KarhunenLoeveResultImplementation(covariance_, threshold_, selectedEV, modes, modesAsProcessSample, transposedProjection.transpose());
+  result_ = KarhunenLoeveResultImplementation(covariance_, threshold_, selectedEV, modes, modesAsProcessSample, projection);
 }
 
 /* Domain accessor */
@@ -399,17 +408,11 @@ WeightedExperiment KarhunenLoeveQuadratureAlgorithm::getExperiment() const
 }
 
 /* Basis accessor */
-Basis KarhunenLoeveQuadratureAlgorithm::getBasis() const
+KarhunenLoeveQuadratureAlgorithm::FunctionCollection KarhunenLoeveQuadratureAlgorithm::getBasis() const
 {
   return basis_;
 }
 
-/* BasisSize accessor */
-UnsignedInteger KarhunenLoeveQuadratureAlgorithm::getBasisSize() const
-{
-  return basisSize_;
-}
-
 /* MustScale accessor */
 Bool KarhunenLoeveQuadratureAlgorithm::getMustScale() const
 {
@@ -421,7 +424,9 @@ String KarhunenLoeveQuadratureAlgorithm::__repr__() const
 {
   OSS oss(true);
   oss << "class=" << KarhunenLoeveQuadratureAlgorithm::GetClassName()
-      << ", domain=" << domain_;
+      << ", domain=" << domain_
+      << ", domainLowerBound=" << domainLowerBound_
+      << ", domainUpperBound=" << domainUpperBound_;
   return oss;
 }
 
@@ -430,7 +435,9 @@ String KarhunenLoeveQuadratureAlgorithm::__str__(const String & offset) const
 {
   OSS oss(false);
   oss << "class=" << KarhunenLoeveQuadratureAlgorithm::GetClassName()
-      << ", domain=" << domain_;
+      << ", domain=" << domain_
+      << ", domainLowerBound=" << domainLowerBound_
+      << ", domainUpperBound=" << domainUpperBound_;
   return oss;
 }
 
@@ -439,9 +446,10 @@ void KarhunenLoeveQuadratureAlgorithm::save(Advocate & adv) const
 {
   KarhunenLoeveAlgorithmImplementation::save(adv);
   adv.saveAttribute( "domain_", domain_ );
+  adv.saveAttribute( "domainLowerBound_", domainLowerBound_ );
+  adv.saveAttribute( "domainUpperBound_", domainUpperBound_ );
   adv.saveAttribute( "experiment_", experiment_ );
   adv.saveAttribute( "basis_", basis_ );
-  adv.saveAttribute( "basisSize_", basisSize_ );
   adv.saveAttribute( "mustScale_", mustScale_ );
 }
 
@@ -450,9 +458,10 @@ void KarhunenLoeveQuadratureAlgorithm::load(Advocate & adv)
 {
   KarhunenLoeveAlgorithmImplementation::load(adv);
   adv.loadAttribute( "domain_", domain_ );
+  adv.loadAttribute( "domainLowerBound_", domainLowerBound_ );
+  adv.loadAttribute( "domainUpperBound_", domainUpperBound_ );
   adv.loadAttribute( "experiment_", experiment_ );
   adv.loadAttribute( "basis_", basis_ );
-  adv.loadAttribute( "basisSize_", basisSize_ );
   adv.loadAttribute( "mustScale_", mustScale_ );
 }
 
