@@ -3,7 +3,7 @@
  *  @brief StatTest implements statistical tests
  *  This statistical test enables user to check if a time series is stationary
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,7 +15,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -88,7 +88,7 @@ DickeyFullerTest::DickeyFullerTest(const TimeSeries & series,
   , sum_ti_(0.0)
   , sum_ti_ti_(0.0)
 {
-  if (series.getDimension() != 1)
+  if (series.getOutputDimension() != 1)
     throw InvalidDimensionException(HERE) << "Expected time series of dimension 1";
 
   // Build the estimation of parameters rho and \phi_i
@@ -494,14 +494,14 @@ TestResult DickeyFullerTest::testUnitRootAndNoLinearTrendInDriftAndLinearTrendMo
     LOGWARN("The model has no unit root. The result test may have no sense. The statistical \"testNoUnitRootAndNoLinearTrendInDriftAndLinearTrendModel\" test is suggested ");
   }
 
-  const Scalar c = (timeSeries_[T_][1] - timeSeries_[0][1]) / T_;
+  const Scalar c = (timeSeries_[T_][1] - timeSeries_(0, 1)) / T_;
   Scalar SCR3c = 0.0;
   Scalar SCR3 = 0.0;
 
   const RegularGrid timeGrid(timeSeries_.getTimeGrid());
   for (UnsignedInteger t = 0; t < T_; ++t)
   {
-    const Scalar deltaX = timeSeries_[t + 1][1] - timeSeries_[t][1];
+    const Scalar deltaX = timeSeries_[t + 1][1] - timeSeries_(t, 1);
     const Scalar epsilon_t = deltaX - c;
     SCR3c += epsilon_t * epsilon_t;
     // Perform since it is computed previously
@@ -580,7 +580,7 @@ TestResult DickeyFullerTest::testUnitRootAndNoDriftInDriftModel(const Scalar lev
 
   for (UnsignedInteger t = 0; t < T_; ++ t)
   {
-    const Scalar epsilon_t = timeSeries_[t + 1][1] - timeSeries_[t][1];
+    const Scalar epsilon_t = timeSeries_[t + 1][1] - timeSeries_(t, 1);
     SCR2c += epsilon_t * epsilon_t;
     // Perform since it is computed previously
     const Scalar X = timeSeries_.getValueAtIndex(t)[0];
