@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  NormalityTest.cxx
  *  @brief StatTest implements statistical tests
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,18 +14,16 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
 #include <cmath>
 #include <fstream>
-#include "NormalityTest.hxx"
-#include "Exception.hxx"
-#include "Path.hxx"
-#include "DistFunc.hxx"
+#include "openturns/NormalityTest.hxx"
+#include "openturns/Exception.hxx"
+#include "openturns/Path.hxx"
+#include "openturns/DistFunc.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -36,21 +33,21 @@ NormalityTest::NormalityTest()
 
 
 /* Anderson Darling normality test for normal distributions. */
-TestResult NormalityTest::AndersonDarlingNormal(const NumericalSample & sample,
-    const NumericalScalar level)
+TestResult NormalityTest::AndersonDarlingNormal(const Sample & sample,
+    const Scalar level)
 {
   if (sample.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: cannot perform an Anderson Darling normality test with sample of dimension > 1.";
   if (sample.getSize() < 8) throw InvalidArgumentException(HERE) << "Error: cannot perform an Anderson Darling normality test with sample of size < 8.";
-  NumericalSample sortedSample(sample.sort());
-  NumericalScalar mean(sortedSample.computeMean()[0]);
-  NumericalScalar sd(sortedSample.computeStandardDeviationPerComponent()[0]);
-  const UnsignedInteger size(sample.getSize());
-  NumericalScalar testStatistic(0.0);
-  UnsignedInteger effectiveIndex(0);
+  Sample sortedSample(sample.sort(0));
+  Scalar mean = sortedSample.computeMean()[0];
+  Scalar sd = sortedSample.computeStandardDeviationPerComponent()[0];
+  const UnsignedInteger size = sample.getSize();
+  Scalar testStatistic = 0.0;
+  UnsignedInteger effectiveIndex = 0;
   for (UnsignedInteger i = 0; i < size; ++i)
   {
-    NumericalScalar yi(DistFunc::pNormal((sortedSample[i][0] - mean) / sd));
-    NumericalScalar yni(1.0 - DistFunc::pNormal((sortedSample[size - i - 1][0] - mean) / sd));
+    Scalar yi = DistFunc::pNormal((sortedSample(i, 0) - mean) / sd);
+    Scalar yni = 1.0 - DistFunc::pNormal((sortedSample(size - i - 1, 0) - mean) / sd);
     if ((yi > 0.0) && (yni > 0.0))
     {
       testStatistic += (2.0 * effectiveIndex + 1) * (log(yi) + log(yni));
@@ -58,11 +55,11 @@ TestResult NormalityTest::AndersonDarlingNormal(const NumericalSample & sample,
     }
   }
   testStatistic /= effectiveIndex;
-  testStatistic = (-NumericalScalar(effectiveIndex) - testStatistic);
+  testStatistic = (-Scalar(effectiveIndex) - testStatistic);
   // Corrective factor for small sample size
-  NumericalScalar adjustedStatistic(testStatistic * (1.0 + 0.75 / effectiveIndex + 2.25 / (effectiveIndex * effectiveIndex)));
+  Scalar adjustedStatistic = testStatistic * (1.0 + 0.75 / effectiveIndex + 2.25 / (effectiveIndex * effectiveIndex));
   // Compute approximate p-value
-  NumericalScalar pValue(1.0);
+  Scalar pValue = 1.0;
   if (adjustedStatistic >= -1.38)
   {
     pValue = 1 - exp(-13.436 + 101.14 * adjustedStatistic - 223.73 * adjustedStatistic * adjustedStatistic);
@@ -87,26 +84,26 @@ TestResult NormalityTest::AndersonDarlingNormal(const NumericalSample & sample,
 }
 
 /* Cramer Von Mises normality test for normal distributions. */
-TestResult NormalityTest::CramerVonMisesNormal(const NumericalSample & sample,
-    const NumericalScalar level)
+TestResult NormalityTest::CramerVonMisesNormal(const Sample & sample,
+    const Scalar level)
 {
   if (sample.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: cannot perform a Cramer Von-Mises normality test with sample of dimension > 1.";
   if (sample.getSize() < 8) throw InvalidArgumentException(HERE) << "Error: cannot perform a Cramer Von-Mises normality test with sample of size < 8.";
-  NumericalSample sortedSample(sample.sort());
-  NumericalScalar mean(sortedSample.computeMean()[0]);
-  NumericalScalar sd(sortedSample.computeStandardDeviationPerComponent()[0]);
-  const UnsignedInteger size(sample.getSize());
-  NumericalScalar testStatistic(1.0 / (12.0 * size));
+  Sample sortedSample(sample.sort(0));
+  Scalar mean = sortedSample.computeMean()[0];
+  Scalar sd = sortedSample.computeStandardDeviationPerComponent()[0];
+  const UnsignedInteger size = sample.getSize();
+  Scalar testStatistic = 1.0 / (12.0 * size);
   for (UnsignedInteger i = 0; i < size; ++i)
   {
-    NumericalScalar yi(DistFunc::pNormal((sortedSample[i][0] - mean) / sd));
-    NumericalScalar delta(yi - (2.0 * i + 1.0) / (2.0 * size));
+    Scalar yi = DistFunc::pNormal((sortedSample(i, 0) - mean) / sd);
+    Scalar delta = yi - (2.0 * i + 1.0) / (2.0 * size);
     testStatistic += delta * delta;
   }
   // Corrective factor for small sample size
-  NumericalScalar adjustedStatistic(testStatistic * (1.0 + 0.5 / size));
+  Scalar adjustedStatistic = testStatistic * (1.0 + 0.5 / size);
   // Compute approximate p-value
-  NumericalScalar pValue(1.0);
+  Scalar pValue = 1.0;
   if (adjustedStatistic >= -0.2)
   {
     pValue = 1 - exp(-13.953 + 775.5 * adjustedStatistic - 12542.61 * adjustedStatistic * adjustedStatistic);
