@@ -1,9 +1,8 @@
 //                                               -*- C -*-
 /**
- *  @file  openturns_library_ok.c
  *  @brief This file contains a single C function to allow m4 easy detection
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,20 +14,20 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OTdebug.h"
+#include "openturns/OTdebug.h"
 
 /*
  * @fn     int openturns_library_ok()
  * @brief  A function that return 1 on success
  * @return The return code
  */
-int OT_API openturns_library_ok()
+int OT_API openturns_library_ok(void);
+
+int OT_API openturns_library_ok(void)
 {
   return 1;
 }
