@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_ARMACoefficients_std.cxx
  *  @brief The test file of class ARMACoefficients
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -38,7 +35,7 @@ int main(int argc, char *argv[])
   {
 
     /* Constructor with size */
-    const UnsignedInteger dim(2);
+    const UnsignedInteger dim = 2;
     SquareMatrix squareMatrix1(dim);
     squareMatrix1(0, 0) = 1.;
     squareMatrix1(1, 0) = 2.;
@@ -47,15 +44,15 @@ int main(int argc, char *argv[])
 
 
     /* Second matrix to add to the ARMACoefficients*/
-    double s = 3.;
-    SquareMatrix squareMatrix2 = squareMatrix1.operator * (s) ;
+    double s = 3.0;
+    SquareMatrix squareMatrix2 = squareMatrix1 * s;
 
     /* Last matrix to add to the ARMACoefficients*/
     double t = 1.5;
-    SquareMatrix squareMatrix3 = squareMatrix1.operator / (t) ;
+    SquareMatrix squareMatrix3 = squareMatrix1 / t;
 
     /* size : Number of matrix */
-    const UnsignedInteger size(3);
+    const UnsignedInteger size = 3;
 
     /* ARMACoefficients with default constructor */
     ARMACoefficients coefficients0;
@@ -87,17 +84,18 @@ int main(int argc, char *argv[])
     fullprint << "coefficients2 = " << coefficients2 << std::endl;
 
     /* 1D case */
-    NumericalPoint point(dim * dim, 1.0);
+    Point point(dim * dim, 1.0);
     point[0] = 1;
     point[1] = 2;
     point[2] = 3;
     point[3] = 4;
 
-    /* ARMACoefficients NumericalPoint constructor */
+    /* ARMACoefficients Point constructor */
     ARMACoefficients coefficients3(point);
+    coefficients3.add(s);
 
     /*fullprint of the new collection*/
-    fullprint << "Using NumericalPoint constructor " << std::endl;
+    fullprint << "Using Point constructor " << std::endl;
     fullprint << "coefficients3 = " << coefficients3 << std::endl;
 
     /* ARMACoefficients with polynomial constructor */
