@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_ARMAState_std.cxx
  *  @brief The test file of class ARMAState
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -37,12 +34,12 @@ int main(int argc, char *argv[])
 
     RandomGenerator::SetSeed(0);
     /* Constructor with size */
-    const UnsignedInteger dim(1);
-    const UnsignedInteger p(6);
-    const UnsignedInteger q(4);
+    const UnsignedInteger dim = 1;
+    const UnsignedInteger p = 6;
+    const UnsignedInteger q = 4;
 
-    NumericalSample valuesX(p, dim);
-    NumericalSample valuesEpsilon(q, dim);
+    Sample valuesX(p, dim);
+    Sample valuesEpsilon(q, dim);
 
     /**/
     for(UnsignedInteger j = 0 ; j < dim ; ++j)
