@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_ARMA_std.cxx
  *  @brief The test file of class ARMA
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -39,7 +36,7 @@ int main(int argc, char *argv[])
     RandomGenerator::SetSeed(0);
 
     /* Matrices of the process */
-    const UnsignedInteger dim(2);
+    const UnsignedInteger dim = 2;
     SquareMatrix squareMatrix1(dim);
     squareMatrix1(0, 0) = 0.2 ;
     squareMatrix1(1, 0) = 0.3 ;
@@ -55,8 +52,8 @@ int main(int argc, char *argv[])
     squareMatrix2(1, 1) = 0.5;
 
     /* ARMA(p, q) */
-    const UnsignedInteger p(1);
-    const UnsignedInteger q(1);
+    const UnsignedInteger p = 1;
+    const UnsignedInteger q = 1;
 
     /* ARMACoefficients with default constructor */
 
@@ -73,9 +70,9 @@ int main(int argc, char *argv[])
 
 
     /* Time grid creation and White Noise */
-    NumericalScalar Tmin(0.0);
-    NumericalScalar deltaT(0.1);
-    UnsignedInteger steps(11);
+    Scalar Tmin = 0.0;
+    Scalar deltaT = 0.1;
+    UnsignedInteger steps = 11;
 
     /* Initialization of the time grid timeGrid1*/
     RegularGrid timeGrid(Tmin, deltaT, steps);
@@ -98,8 +95,8 @@ int main(int argc, char *argv[])
     whiteNoise.setTimeGrid(timeGrid);
 
     /* Last coefficients values */
-    NumericalSample xValues(p, dim);
-    NumericalSample epsilonValues(q, dim);
+    Sample xValues(p, dim);
+    Sample epsilonValues(q, dim);
 
     for(UnsignedInteger j = 0 ; j < dim ; ++j)
     {
