@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_ArcsineFactory_std.cxx
  *  @brief The test file of class Arcsine for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2009-09-30 17:51:57 +0200 (mer. 30 sept. 2009)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,22 +33,22 @@ int main(int argc, char *argv[])
   try
   {
     Arcsine distribution(1., 2.5);
-    UnsignedInteger size(10000);
-    NumericalSample sample(distribution.getSample(size));
+    UnsignedInteger size = 10000;
+    Sample sample(distribution.getSample(size));
     ArcsineFactory factory;
     Distribution estimatedDistribution(factory.build(sample));
     fullprint << "Distribution          =" << distribution << std::endl;
     fullprint << "Estimated distribution=" << estimatedDistribution << std::endl;
     estimatedDistribution = factory.build();
     fullprint << "Default distribution=" << estimatedDistribution << std::endl;
-    estimatedDistribution = factory.build(distribution.getParametersCollection());
+    estimatedDistribution = factory.build(distribution.getParameter());
     fullprint << "Distribution from parameters=" << estimatedDistribution << std::endl;
     Arcsine estimatedArcsine(factory.buildAsArcsine(sample));
     fullprint << "Arcsine          =" << distribution << std::endl;
     fullprint << "Estimated Arcsine=" << estimatedArcsine << std::endl;
     estimatedArcsine = factory.buildAsArcsine();
     fullprint << "Default Arcsine=" << estimatedArcsine << std::endl;
-    estimatedArcsine = factory.buildAsArcsine(distribution.getParametersCollection());
+    estimatedArcsine = factory.buildAsArcsine(distribution.getParameter());
     fullprint << "Arcsine from parameters=" << estimatedArcsine << std::endl;
   }
   catch (TestFailed & ex)
