@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_AtomicFunctions_std.cxx
  *  @brief The test file of class AtomicFunctions for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,16 +14,19 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2010-02-04 16:44:49 +0100 (Thu, 04 Feb 2010)
  */
 #include <unistd.h> // sysconf
 #include <stdlib.h> // getenv
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#ifndef _MSC_VER
+# include <signal.h>
+# include <pthread.h>
+#endif
+
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
