@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_KrigingAlgorithm_std.cxx
- *  @brief The test file of KrigingAlgorithm class
+ *  @brief The test file of BasisFactory class
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,25 +14,24 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
 
-String printNumericalPoint(const NumericalPoint & point, const UnsignedInteger digits)
+String printPoint(const Point & point, const UnsignedInteger digits)
 {
   OSS oss;
   oss << "[";
-  NumericalScalar eps(pow(0.1, 1.0 * digits));
+  Scalar eps = pow(0.1, 1.0 * digits);
   for (UnsignedInteger i = 0; i < point.getDimension(); i++)
   {
-    oss << std::fixed << std::setprecision(digits) << (i == 0 ? "" : ",") << Bulk<double>((fabs(point[i]) < eps) ? fabs(point[i]) : point[i]);
+    oss << std::fixed << std::setprecision(digits) << (i == 0 ? "" : ",") << Bulk<double>((std::abs(point[i]) < eps) ? std::abs(point[i]) : point[i]);
   }
   oss << "]";
   return oss;
@@ -45,7 +43,7 @@ int main(int argc, char *argv[])
   {
     UnsignedInteger inputDimension = 2;
 
-    NumericalPoint x(inputDimension);
+    Point x(inputDimension);
     for (UnsignedInteger i = 0; i < inputDimension; ++ i)
     {
       x[i] = 2. + i;
@@ -57,8 +55,10 @@ int main(int argc, char *argv[])
       Basis basis(factory.build());
       std::cout << "basis=" << basis << std::endl;
 
-      NumericalMathFunction f(basis);
-      NumericalPoint y(f(x));
+      Indices indices(basis.getSize());
+      indices.fill();
+      AggregatedFunction f(basis.getSubBasis(indices));
+      Point y(f(x));
       std::cout << "y=" << y << std::endl;
     }
     {
@@ -67,8 +67,10 @@ int main(int argc, char *argv[])
       Basis basis(factory.build());
       std::cout << "basis=" << basis << std::endl;
 
-      NumericalMathFunction f(basis);
-      NumericalPoint y(f(x));
+      Indices indices(basis.getSize());
+      indices.fill();
+      AggregatedFunction f(basis.getSubBasis(indices));
+      Point y(f(x));
       std::cout << "y=" << y << std::endl;
     }
     {
@@ -77,8 +79,10 @@ int main(int argc, char *argv[])
       Basis basis(factory.build());
       std::cout << "basis=" << basis << std::endl;
 
-      NumericalMathFunction f(basis);
-      NumericalPoint y(f(x));
+      Indices indices(basis.getSize());
+      indices.fill();
+      AggregatedFunction f(basis.getSubBasis(indices));
+      Point y(f(x));
       std::cout << "y=" << y << std::endl;
     }
   }
