@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_Basis_std.cxx
  *  @brief The test file of class Basis for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2010-02-04 16:44:49 +0100 (Thu, 04 Feb 2010)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -43,10 +40,10 @@ int main(int argc, char *argv[])
     input.add(in);
     output[j].add(in);
   }
-  Collection<NumericalMathFunction> coll;
+  Collection<Function> coll;
   for ( UnsignedInteger j = 0; j < dimension; ++ j )
   {
-    NumericalMathFunction ei(input, output[j], output[j]);
+    SymbolicFunction ei(input, output[j]);
     coll.add(ei);
   }
 
