@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_BinomialFactory_std.cxx
  *  @brief The test file of class Binomial for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2010-02-04 16:44:49 +0100 (jeu. 04 févr. 2010)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,8 +33,8 @@ int main(int argc, char *argv[])
   try
   {
     Binomial distribution(15, 0.7);
-    UnsignedInteger size(10000);
-    NumericalSample sample(distribution.getSample(size));
+    UnsignedInteger size = 10000;
+    Sample sample(distribution.getSample(size));
     BinomialFactory factory;
     CovarianceMatrix covariance;
     // Distribution estimatedDistribution(factory.build(sample, covariance));
@@ -47,14 +44,14 @@ int main(int argc, char *argv[])
     // fullprint << "Covariance=" << covariance << std::endl;
     estimatedDistribution = factory.build();
     fullprint << "Default distribution=" << estimatedDistribution << std::endl;
-    estimatedDistribution = factory.build(distribution.getParametersCollection());
+    estimatedDistribution = factory.build(distribution.getParameter());
     fullprint << "Distribution from parameters=" << estimatedDistribution << std::endl;
     Binomial estimatedBinomial(factory.buildAsBinomial(sample));
     fullprint << "Binomial          =" << distribution << std::endl;
     fullprint << "Estimated binomial=" << estimatedBinomial << std::endl;
     estimatedBinomial = factory.buildAsBinomial();
     fullprint << "Default binomial=" << estimatedBinomial << std::endl;
-    estimatedBinomial = factory.buildAsBinomial(distribution.getParametersCollection());
+    estimatedBinomial = factory.buildAsBinomial(distribution.getParameter());
     fullprint << "Binomial from parameters=" << estimatedBinomial << std::endl;
   }
   catch (TestFailed & ex)
