@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_CalibrationStrategy_std.cxx
  *  @brief The test file of class CalibrationStrategy
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,15 +14,13 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
 #include <iostream>
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -39,8 +36,8 @@ int main(int argc, char *argv[])
     CalibrationStrategy myAlgo(Interval(0.3, 0.5));
     for ( UnsignedInteger i = 0; i < 4; ++ i )
     {
-      NumericalScalar rho = 0.1 + i * 0.2;
-      NumericalScalar updateFactor = myAlgo.computeUpdateFactor(rho);
+      Scalar rho = 0.1 + i * 0.2;
+      Scalar updateFactor = myAlgo.computeUpdateFactor(rho);
       fullprint << "updateFactor=" << updateFactor << std::endl;
     }
 
