@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_CauchyModel_std.cxx
  *  @brief The test file of class CauchyModel
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,12 +33,15 @@ int main(int argc, char *argv[])
   {
 
     /* Default dimension parameter to evaluate the model */
-    const UnsignedInteger defaultDimension(1);
+    const UnsignedInteger defaultDimension = 1;
+
+    /* Default spatial dimension parameter  */
+    const UnsignedInteger spatialDimension = 1;
 
     /* Amplitude values */
-    NumericalPoint amplitude(defaultDimension, 1.0);
+    Point amplitude(defaultDimension, 1.0);
     /* Scale values */
-    NumericalPoint scale(defaultDimension, 1.0);
+    Point scale(spatialDimension, 1.0);
 
 
     /* Default constructor */
@@ -49,40 +49,38 @@ int main(int argc, char *argv[])
     fullprint << "myDefautModel = " << myDefautModel << std::endl;
 
     /* Second order model with parameters */
-    CauchyModel myModel(amplitude, scale);
+    CauchyModel myModel(scale, amplitude);
     fullprint << "myModel = " << myModel << std::endl;
 
-    const NumericalScalar frequencyValue(1.0);
+    const Scalar frequencyValue = 1.0;
     fullprint << "spectral density matrix at f = " << frequencyValue << " : " << myModel(frequencyValue) << std::endl;
 
     /* Evaluation at time higher to check the decrease of the cauchy values */
-    const NumericalScalar frequencyValueHigh(10.0);
+    const Scalar frequencyValueHigh = 10.0;
     fullprint << "spectral density matrix at f = " << frequencyValueHigh << " : " << myModel(frequencyValueHigh) << std::endl;
 
     /* Default dimension parameter to evaluate the model */
-    const UnsignedInteger highDimension(3);
+    const UnsignedInteger highDimension = 3;
 
     /* Reallocation of adequate sizes*/
     amplitude.resize(highDimension);
-    scale.resize(highDimension);
 
     CorrelationMatrix spatialCorrelation(highDimension);
     for (UnsignedInteger index = 0 ; index < highDimension; ++index)
     {
-      // constant amplitude
-      amplitude[index] = 1.0 ;
-      scale[index] = (index + 1.0) / defaultDimension ;
+      // amplitude
+      amplitude[index] = (index + 1.0) / defaultDimension ;
       if (index > 0) spatialCorrelation(index, index - 1) = 1.0 / index;
     }
     fullprint << "spatialCorrelation=\n" << spatialCorrelation << std::endl;
     fullprint << "spatialCorrelation=\n" << spatialCorrelation.__str__() << std::endl;
 
     /* checking the cast */
-    SpectralModel mySpectralModel(CauchyModel(amplitude, scale, spatialCorrelation));
+    SpectralModel mySpectralModel(CauchyModel(scale, amplitude, spatialCorrelation));
     fullprint << "mySpectralModel = " << mySpectralModel << std::endl;
 
     /* Second order model - high dimension */
-    CauchyModel myHighModel(amplitude, scale, spatialCorrelation);
+    CauchyModel myHighModel(scale, amplitude, spatialCorrelation);
     fullprint << "myHighModel = " << myHighModel << std::endl;
 
     fullprint << "spectral density matrix at f = " << frequencyValue << " : " << myHighModel(frequencyValue).clean(1.0e-6) << std::endl;
@@ -93,10 +91,8 @@ int main(int argc, char *argv[])
     CovarianceMatrix spatialCovariance(highDimension);
     for (UnsignedInteger index = 0 ; index < highDimension; ++index)
     {
-      // constant amplitude
-      scale[index] = (index + 1.0) / defaultDimension ;
       spatialCovariance(index, index) = 1.0;
-      if (index > 0) spatialCorrelation(index, index - 1) = 1.0 / index;
+      if (index > 0) spatialCovariance(index, index - 1) = 1.0 / index;
     }
 
     /* constructor based on spatial covariance */
