@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_CenteredFiniteDifferenceHessian_std.cxx
  *  @brief The test file of class CenteredFiniteDifferenceHessian for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -34,18 +31,25 @@ int main(int argc, char *argv[])
 
   try
   {
-    NumericalScalar eps(1e-2);
+    Scalar eps = 1e-2;
     /** Instance creation */
-    NumericalMathFunction myFunc("TestResponseSurface");
-    NumericalPoint epsilon(myFunc.getInputDimension(), eps);
-    NumericalPoint in(epsilon.getDimension(), 1.0);
-    CenteredFiniteDifferenceHessian myHessian(epsilon, myFunc.getEvaluationImplementation());
+    Description input(2);
+    input[0] = "x1";
+    input[1] = "x2";
+    Description formula(3);
+    formula[0] = "x1*sin(x2)";
+    formula[1] = "cos(x1+x2)";
+    formula[2] = "(x2+1)*exp(x1-2*x2)";
+    SymbolicFunction myFunc(input, formula);
+    Point epsilon(myFunc.getInputDimension(), eps);
+    Point in(epsilon.getDimension(), 1.0);
+    CenteredFiniteDifferenceHessian myHessian(epsilon, myFunc.getEvaluation());
 
     fullprint << "myHessian=" << myHessian << std::endl;
     fullprint << "myFunc.hessian(" << in << ")=" << myFunc.hessian(in) << std::endl;
     fullprint << "myHessian.hessian(" << in << ")=" << myHessian.hessian(in) << std::endl;
     /** Substitute the hessian */
-    myFunc.setHessianImplementation(new CenteredFiniteDifferenceHessian(myHessian));
+    myFunc.setHessian(new CenteredFiniteDifferenceHessian(myHessian));
     fullprint << "myFunc.hessian(" << in << ")=" << myFunc.hessian(in) << " (after substitution)" << std::endl;
 
   }
