@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_ChiFactory_std.cxx
  *  @brief The test file of class Chi for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author lebrun
- *  @date   2008-07-03 08:31:34 +0200 (jeu. 03 juil. 2008)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,8 +33,8 @@ int main(int argc, char *argv[])
   try
   {
     Chi distribution(0.5);
-    UnsignedInteger size(10000);
-    NumericalSample sample(distribution.getSample(size));
+    UnsignedInteger size = 10000;
+    Sample sample(distribution.getSample(size));
     ChiFactory factory;
     CovarianceMatrix covariance;
     // Distribution estimatedDistribution(factory.build(sample, covariance));
@@ -61,7 +58,7 @@ int main(int argc, char *argv[])
     // fullprint << "Covariance=" << covariance << std::endl;
     estimatedDistribution = factory.build();
     fullprint << "Default distribution=" << estimatedDistribution << std::endl;
-    estimatedDistribution = factory.build(distribution.getParametersCollection());
+    estimatedDistribution = factory.build(distribution.getParameter());
     fullprint << "Distribution from parameters=" << estimatedDistribution << std::endl;
     Chi estimatedChi(factory.buildAsChi(sample));
     fullprint << "Chi          =" << distribution << std::endl;
@@ -69,7 +66,7 @@ int main(int argc, char *argv[])
     // fullprint << "Covariance=" << covariance << std::endl;
     estimatedChi = factory.buildAsChi();
     fullprint << "Default chi=" << estimatedChi << std::endl;
-    estimatedChi = factory.buildAsChi(distribution.getParametersCollection());
+    estimatedChi = factory.buildAsChi(distribution.getParameter());
     fullprint << "Chi from parameters=" << estimatedChi << std::endl;
   }
   catch (TestFailed & ex)
