@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_ComplexMatrix_std.cxx
  *  @brief The test file of class ComplexMatrix for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,19 +14,17 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
 
-typedef Collection<NumericalComplex> NumericalComplexCollection;
+typedef Collection<Complex> ComplexCollection;
 
 int main(int argc, char *argv[])
 {
@@ -51,10 +48,10 @@ int main(int argc, char *argv[])
   ComplexMatrix matrix1(2, 2);
 
   /* Check operator() methods */
-  matrix1(0, 0) = NumericalComplex(1., 1) ;
-  matrix1(1, 0) = NumericalComplex(2., -1) ;
-  matrix1(0, 1) = NumericalComplex(4., 2) ;
-  matrix1(1, 1) = NumericalComplex(3., 2) ;
+  matrix1(0, 0) = Complex(1., 1) ;
+  matrix1(1, 0) = Complex(2., -1) ;
+  matrix1(0, 1) = Complex(4., 2) ;
+  matrix1(1, 1) = Complex(3., 2) ;
 
   /* String converter */
   fullprint << "matrix1 = " << matrix1 << std::endl;
@@ -82,7 +79,7 @@ int main(int argc, char *argv[])
   fullprint << "test 4 : constructor with collection and array method" << std::endl;
 
   /* Create the collection of values */
-  Collection<NumericalComplex> elementsValues(6);
+  Collection<Complex> elementsValues(6);
   elementsValues[0] = 1.;
   elementsValues[1] = 2.;
   elementsValues[2] = 3.;
@@ -142,10 +139,10 @@ int main(int argc, char *argv[])
   fullprint << "sum1 equals sum2 = " << (sum1 == sum2) << std::endl;
 
 
-  /** TEST TEN : SUBSTRACTION METHOD */
-  fullprint << "test 10: substraction method" << std::endl;
+  /** TEST TEN : SUBTRACTION METHOD */
+  fullprint << "test 10: subtraction method" << std::endl;
 
-  /* Check substraction method */
+  /* Check subtraction method */
   ComplexMatrix diff = matrix1.operator - ( matrix4 ) ;
   fullprint << "diff = " << diff << std::endl;
 
@@ -162,20 +159,20 @@ int main(int argc, char *argv[])
   fullprint << "test 12 : multiplication with a numerical point method" << std::endl;
 
   /* Create the numerical point */
-  NumericalPoint pt ;
+  Point pt ;
   pt.add(1.) ;
   pt.add(2.) ;
   fullprint << "pt = " << pt << std::endl;
 
   /* Check the product method */
-  NumericalComplexCollection ptResult = matrix1.operator * ( pt ) ;
+  ComplexCollection ptResult = matrix1.operator * ( pt ) ;
   fullprint << "ptResult = " << ptResult << std::endl;
 
   /** TEST THIRTEEN : MULTIPLICATION AND DIVISION BY A NUMERICAL SCALAR METHODS */
   fullprint << "test 13 : multiplication and division by a complex methods" << std::endl;
 
   /* Check the multiplication method */
-  NumericalComplex s(3., 1.0);
+  Complex s(3., 1.0);
   ComplexMatrix scalprod1 = matrix1.operator * (s) ;
   ComplexMatrix scalprod2 = s * matrix1 ;
   ComplexMatrix scalprod3 = matrix1 * s ;
@@ -210,7 +207,7 @@ int main(int argc, char *argv[])
   fullprint << "test 15 : multiplication with a numerical point method" << std::endl;
 
   /* Create the numerical point */
-  NumericalPoint pt_test ;
+  Point pt_test ;
   pt_test.add(1.) ;
   pt_test.add(2.) ;
   fullprint << "pt_test = " << pt_test << std::endl;
@@ -224,7 +221,7 @@ int main(int argc, char *argv[])
   ComplexMatrix id = B.operator * (A);
 
   /* Check the product method */
-  NumericalComplexCollection ptResult2 = id.operator * ( pt_test ) ;
+  ComplexCollection ptResult2 = id.operator * ( pt_test ) ;
   fullprint << "A = " << A << std::endl;
   fullprint << "B = " << B << std::endl;
   fullprint << "id = " << id << std::endl;
