@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_ComposedCopula_std.cxx
  *  @brief The test file of class ComposedCopula for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -60,45 +57,70 @@ int main(int argc, char *argv[])
     fullprint << "Independent = " << (copula.hasIndependentCopula() ? "true" : "false") << std::endl;
 
     // Test for realization of copula
-    NumericalPoint oneRealization = copula.getRealization();
+    Point oneRealization = copula.getRealization();
     fullprint << "oneRealization=" << oneRealization << std::endl;
 
     // Test for sampling
     UnsignedInteger size = 10000;
-    NumericalSample oneSample = copula.getSample( size );
+    Sample oneSample = copula.getSample( size );
     fullprint << "oneSample first=" << oneSample[0] << " last=" << oneSample[size - 1] << std::endl;
     fullprint << "mean=" << oneSample.computeMean() << std::endl;
-    UnsignedInteger precision(PlatformInfo::GetNumericalPrecision());
-    PlatformInfo::SetNumericalPrecision(5);
+    UnsignedInteger precision = PlatformInfo::GetNumericalPrecision();
+    PlatformInfo::SetNumericalPrecision(4);
     fullprint << "covariance=" << oneSample.computeCovariance() << std::endl;
     PlatformInfo::SetNumericalPrecision(precision);
 
     // Define a point
-    NumericalPoint point( copula.getDimension(), 0.6 );
+    Point point( copula.getDimension(), 0.6 );
     fullprint << "Point= " << point << std::endl;
 
     // Show PDF and CDF of point
-    //NumericalScalar eps(1e-5);
-    NumericalPoint DDF = copula.computeDDF( point );
+    //Scalar eps(1e-5);
+    Point DDF = copula.computeDDF( point );
     fullprint << "ddf     =" << DDF << std::endl;
-    NumericalPoint ddfFD(copula.getDimension());
+    Point ddfFD(copula.getDimension());
     fullprint << "ddf (FD)=" << copula.ContinuousDistribution::computeDDF(point) << std::endl;
-    NumericalScalar PDF = copula.computePDF( point );
+    Scalar PDF = copula.computePDF( point );
     fullprint << "pdf     =" << PDF << std::endl;
-    NumericalScalar CDF = copula.computeCDF( point );
+    Scalar CDF = copula.computeCDF( point );
     fullprint << "cdf=" << CDF << std::endl;
-    //    NumericalPoint PDFgr = copula.computePDFGradient( point );
-    //    fullprint << "pdf gradient     =" << PDFgr << std::endl;
-    //    NumericalPoint CDFgr = copula.computeCDFGradient( point );
-    //    fullprint << "cdf gradient     =" << CDFgr << std::endl;
-    NumericalPoint quantile = copula.computeQuantile( 0.95 );
-    fullprint << "quantile=" << quantile << std::endl;
-    fullprint << "cdf(quantile)=" << copula.computeCDF(quantile) << std::endl;
-    NumericalPoint mean = copula.getMean();
+    Scalar Survival = copula.computeSurvivalFunction(point);
+    fullprint << "Survival      =" << Survival << std::endl;
+    fullprint << "Survival (ref)=" << copula.computeSurvivalFunction(point) << std::endl;
+    Point InverseSurvival = copula.computeInverseSurvivalFunction(0.95);
+    fullprint << "Inverse survival=" << InverseSurvival << std::endl;
+    fullprint << "Survival(inverse survival)=" << copula.computeSurvivalFunction(InverseSurvival) << std::endl;
+    // Get 50% quantile
+    Point quantile = copula.computeQuantile( 0.5 );
+    fullprint << "Quantile=" << quantile << std::endl;
+    fullprint << "CDF(quantile)=" << copula.computeCDF(quantile) << std::endl;
+
+    if (copula.getDimension() <= 2)
+    {
+      // Confidence regions
+      Scalar threshold;
+      fullprint << "Minimum volume interval=" << copula.computeMinimumVolumeIntervalWithMarginalProbability(0.95, threshold) << std::endl;
+      fullprint << "threshold=" << threshold << std::endl;
+      Scalar beta;
+      LevelSet levelSet(copula.computeMinimumVolumeLevelSetWithThreshold(0.95, beta));
+      fullprint << "Minimum volume level set=" << levelSet << std::endl;
+      fullprint << "beta=" << beta << std::endl;
+      fullprint << "Bilateral confidence interval=" << copula.computeBilateralConfidenceIntervalWithMarginalProbability(0.95, beta) << std::endl;
+      fullprint << "beta=" << beta << std::endl;
+      fullprint << "Unilateral confidence interval (lower tail)=" << copula.computeUnilateralConfidenceIntervalWithMarginalProbability(0.95, false, beta) << std::endl;
+      fullprint << "beta=" << beta << std::endl;
+      fullprint << "Unilateral confidence interval (upper tail)=" << copula.computeUnilateralConfidenceIntervalWithMarginalProbability(0.95, true, beta) << std::endl;
+      fullprint << "beta=" << beta << std::endl;
+    }
+
+    fullprint << "entropy=" << copula.computeEntropy() << std::endl;
+    fullprint << "entropy (MC)=" << -copula.computeLogPDF(copula.getSample(1000000)).computeMean()[0] << std::endl;
+    Point mean = copula.getMean();
     fullprint << "mean=" << mean << std::endl;
-    ComposedCopula::NumericalPointWithDescriptionCollection parameters = copula.getParametersCollection();
+    ComposedCopula::PointWithDescriptionCollection parameters = copula.getParametersCollection();
     fullprint << "parameters=" << parameters << std::endl;
     // Covariance and correlation
+    PlatformInfo::SetNumericalPrecision(4);
     CovarianceMatrix covariance = copula.getCovariance();
     fullprint << "covariance=" << covariance << std::endl;
     CorrelationMatrix correlation = copula.getCorrelation();
@@ -107,12 +129,13 @@ int main(int argc, char *argv[])
     fullprint << "spearman=" << spearman << std::endl;
     CorrelationMatrix kendall = copula.getKendallTau();
     fullprint << "kendall=" << kendall << std::endl;
+    PlatformInfo::SetNumericalPrecision(precision);
 
     // Specific to this copula
 
     // Extract a 5-D marginal
-    UnsignedInteger dim(5);
-    point = NumericalPoint(dim, 0.25);
+    UnsignedInteger dim = 5;
+    point = Point(dim, 0.25);
     Indices indices(dim, 0);
     indices[0] = 1;
     indices[1] = 2;
@@ -132,7 +155,7 @@ int main(int argc, char *argv[])
     // General case with normal standard distribution
     fullprint << "isoprobabilistic transformation (general normal)=" << copula.getIsoProbabilisticTransformation() << std::endl;
     // General case with non-normal standard distribution
-    collection[0] = SklarCopula(Student(3.0, NumericalPoint(2, 1.0), NumericalPoint(2, 3.0), CorrelationMatrix(2)));
+    collection[0] = SklarCopula(Student(3.0, Point(2, 1.0), Point(2, 3.0), CorrelationMatrix(2)));
     copula = ComposedCopula(collection);
     fullprint << "isoprobabilistic transformation (general non-normal)=" << copula.getIsoProbabilisticTransformation() << std::endl;
     // Special case, independent copula
@@ -143,7 +166,7 @@ int main(int argc, char *argv[])
     fullprint << "isoprobabilistic transformation (independent)=" << copula.getIsoProbabilisticTransformation() << std::endl;
     // Special case, single contributor
     collection = Collection<Copula>(1);
-    collection[0] = SklarCopula(Student(3.0, NumericalPoint(2, 1.0), NumericalPoint(2, 3.0), CorrelationMatrix(2)));
+    collection[0] = SklarCopula(Student(3.0, Point(2, 1.0), Point(2, 3.0), CorrelationMatrix(2)));
     copula = ComposedCopula(collection);
     fullprint << "isoprobabilistic transformation (single contributor)=" << copula.getIsoProbabilisticTransformation() << std::endl;
   }
@@ -156,3 +179,4 @@ int main(int argc, char *argv[])
 
   return ExitCode::Success;
 }
+
