@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_ComposedDistribution_large.cxx
  *  @brief The test file of class ComposedDistribution for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -32,19 +29,19 @@ int main(int argc, char *argv[])
   TESTPREAMBLE;
   OStream fullprint(std::cout);
   setRandomGenerator();
-  ResourceMap::Set("DistributionImplementation-Parallel", "0");
+  ResourceMap::Set("Distribution-Parallel", "0");
 
   try
   {
 
-    NumericalPoint meanPoint(1);
+    Point meanPoint(1);
     meanPoint[0] = 1.0;
-    NumericalPoint sigma(1);
+    Point sigma(1);
     sigma[0] = 3.0;
     CorrelationMatrix R(1);
     R(0, 0) = 1.0;
     // Create a collection of distribution
-    UnsignedInteger dimension(2000);
+    UnsignedInteger dimension = 2000;
     fullprint << "Creating a composed distribution of dimension " << dimension << std::endl;
     ComposedDistribution::DistributionCollection aCollection(dimension, Normal(meanPoint, sigma, R));
 
@@ -69,19 +66,19 @@ int main(int argc, char *argv[])
 
     // Test for sampling
     UnsignedInteger size = 10;
-    NumericalSample anotherSample = distribution.getSample( size );
+    Sample anotherSample = distribution.getSample( size );
 
     // Define a point
-    NumericalPoint zero(dimension, 0.0);
+    Point zero(dimension, 0.0);
 
     // Show PDF and CDF of zero point
-    NumericalScalar zeroPDF = distribution.computePDF( zero );
-    NumericalScalar zeroCDF = distribution.computeCDF( zero );
+    Scalar zeroPDF = distribution.computePDF( zero );
+    Scalar zeroCDF = distribution.computeCDF( zero );
     fullprint << " pdf=" << zeroPDF
               << " cdf=" << zeroCDF
               << std::endl;
     // Get 95% quantile
-    NumericalPoint quantile = distribution.computeQuantile( 0.95 );
+    Point quantile = distribution.computeQuantile( 0.95 );
     fullprint << "Quantile=" << quantile << std::endl;
     fullprint << "CDF(quantile)=" << distribution.computeCDF(quantile) << std::endl;
 
@@ -92,13 +89,13 @@ int main(int argc, char *argv[])
     fullprint << "indices=" << indices << std::endl;
     Distribution margins(distribution.getMarginal(indices));
     fullprint << "margins=" << margins << std::endl;
-    fullprint << "margins PDF=" << margins.computePDF(NumericalPoint(2)) << std::endl;
-    fullprint << "margins CDF=" << margins.computeCDF(NumericalPoint(2)) << std::endl;
+    fullprint << "margins PDF=" << margins.computePDF(Point(2)) << std::endl;
+    fullprint << "margins CDF=" << margins.computeCDF(Point(2)) << std::endl;
     quantile = margins.computeQuantile(0.5);
     fullprint << "margins quantile=" << quantile << std::endl;
     fullprint << "margins CDF(quantile)=" << margins.computeCDF(quantile) << std::endl;
     fullprint << "margins realization=" << margins.getRealization() << std::endl;
-    NumericalSample sample(margins.getSample(1000));
+    Sample sample(margins.getSample(1000));
     fullprint << "margins sample mean=" << sample.computeMean() << std::endl;
     fullprint << "margins sample covariance=" << sample.computeCovariance() << std::endl;
   }
