@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_ComposedDistribution_std.cxx
  *  @brief The test file of class ComposedDistribution for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -32,7 +29,7 @@ int main(int argc, char *argv[])
   TESTPREAMBLE;
   OStream fullprint(std::cout);
   setRandomGenerator();
-  ResourceMap::Set("DistributionImplementation-Parallel", "0");
+  ResourceMap::Set("Distribution-Parallel", "0");
 
   try
   {
@@ -40,11 +37,11 @@ int main(int argc, char *argv[])
     // Test basic functionnalities
     //checkClassWithClassName<TestObject>();
 
-    NumericalPoint mean(3);
+    Point mean(3);
     mean[0] = 1.0;
     mean[1] = 2.0;
     mean[2] = 3.0;
-    NumericalPoint sigma(3);
+    Point sigma(3);
     sigma[0] = 2.0;
     sigma[1] = 3.0;
     sigma[2] = 4.0;
@@ -74,14 +71,16 @@ int main(int argc, char *argv[])
     IndependentCopula aCopula(aCollection.getSize());
     aCopula.setName("Independent copula");
     // Instanciate one distribution object
-    ComposedDistribution distribution(aCollection, Copula(aCopula));
+    ComposedDistribution distribution(aCollection, aCopula);
     distribution.setName("myDist");
-    UnsignedInteger dim(distribution.getDimension());
+    UnsignedInteger dim = distribution.getDimension();
     fullprint << "Distribution " << distribution << std::endl;
     std::cout << "Distribution " << distribution << std::endl;
     fullprint << "Parameters " << distribution.getParametersCollection() << std::endl;
+    fullprint << "entropy=" << distribution.computeEntropy() << std::endl;
+    fullprint << "entropy (MC)=" << -distribution.computeLogPDF(distribution.getSample(1000000)).computeMean()[0] << std::endl;
     fullprint << "Mean " << distribution.getMean() << std::endl;
-    UnsignedInteger precision(PlatformInfo::GetNumericalPrecision());
+    UnsignedInteger precision = PlatformInfo::GetNumericalPrecision();
     PlatformInfo::SetNumericalPrecision(2);
     fullprint << "Covariance " << distribution.getCovariance() << std::endl;
     PlatformInfo::SetNumericalPrecision(precision);
@@ -95,34 +94,35 @@ int main(int argc, char *argv[])
     fullprint << "Independent copula= " << (distribution.hasIndependentCopula() ? "true" : "false") << std::endl;
 
     // Test for realization of distribution
-    NumericalPoint oneRealization = distribution.getRealization();
+    Point oneRealization = distribution.getRealization();
     fullprint << "oneRealization=" << oneRealization << std::endl;
 
     // Test for sampling
     UnsignedInteger size = 10;
-    NumericalSample oneSample = distribution.getSample( size );
+    Sample oneSample = distribution.getSample( size );
     fullprint << "oneSample=" << oneSample << std::endl;
 
     // Test for sampling
     size = 10000;
-    NumericalSample anotherSample = distribution.getSample( size );
+    Sample anotherSample = distribution.getSample( size );
     fullprint << "anotherSample mean=" << anotherSample.computeMean() << std::endl;
     fullprint << "anotherSample covariance=" << anotherSample.computeCovariance() << std::endl;
 
     // Define a point
-    NumericalPoint zero(dim, 0.0);
+    Point zero(dim, 0.0);
 
     // Show PDF and CDF of zero point
-    NumericalScalar zeroPDF = distribution.computePDF( zero );
-    NumericalScalar zeroCDF = distribution.computeCDF( zero );
+    Scalar zeroPDF = distribution.computePDF( zero );
+    Scalar zeroCDF = distribution.computeCDF( zero );
     fullprint << "Zero point= " << zero
               << " pdf=" << zeroPDF
               << " cdf=" << zeroCDF
               << std::endl;
     // Get 95% quantile
-    NumericalPoint quantile = distribution.computeQuantile( 0.95 );
+    Point quantile = distribution.computeQuantile( 0.95 );
     fullprint << "Quantile=" << quantile << std::endl;
     fullprint << "CDF(quantile)=" << distribution.computeCDF(quantile) << std::endl;
+
     // Reference
     Normal ref(mean, sigma, IdentityMatrix(distribution.getDimension()));
     fullprint << "Reference=" << std::endl;
@@ -136,8 +136,8 @@ int main(int argc, char *argv[])
     {
       Distribution margin(distribution.getMarginal(i));
       fullprint << "margin=" << margin << std::endl;
-      fullprint << "margin PDF=" << margin.computePDF(NumericalPoint(1)) << std::endl;
-      fullprint << "margin CDF=" << margin.computeCDF(NumericalPoint(1)) << std::endl;
+      fullprint << "margin PDF=" << margin.computePDF(Point(1)) << std::endl;
+      fullprint << "margin CDF=" << margin.computeCDF(Point(1)) << std::endl;
       fullprint << "margin quantile=" << margin.computeQuantile(0.95) << std::endl;
       fullprint << "margin realization=" << margin.getRealization() << std::endl;
     }
@@ -149,8 +149,8 @@ int main(int argc, char *argv[])
     fullprint << "indices=" << indices << std::endl;
     Distribution margins(distribution.getMarginal(indices));
     fullprint << "margins=" << margins << std::endl;
-    fullprint << "margins PDF=" << margins.computePDF(NumericalPoint(2)) << std::endl;
-    fullprint << "margins CDF=" << margins.computeCDF(NumericalPoint(2)) << std::endl;
+    fullprint << "margins PDF=" << margins.computePDF(Point(2)) << std::endl;
+    fullprint << "margins CDF=" << margins.computeCDF(Point(2)) << std::endl;
     quantile = margins.computeQuantile(0.5);
     fullprint << "margins quantile=" << quantile << std::endl;
     fullprint << "margins CDF(quantile)=" << margins.computeCDF(quantile) << std::endl;
@@ -163,31 +163,57 @@ int main(int argc, char *argv[])
     }
     NormalCopula anotherCopula(correlation);
     anotherCopula.setName("Normal copula");
-    distribution = ComposedDistribution(aCollection, Copula(anotherCopula));
+    distribution = ComposedDistribution(aCollection, anotherCopula);
     distribution.setName("myDist");
     Normal distributionRef(mean, sigma, correlation);
     fullprint << "Distribution " << distribution << std::endl;
     fullprint << "Parameters " << distribution.getParametersCollection() << std::endl;
     // Show PDF and CDF at point
-    NumericalPoint point(dim, 0.0);
+    Point point(dim, 0.0);
     fullprint << "PDF      =" << distribution.computePDF(point) << std::endl;
     fullprint << "PDF (ref)=" << distributionRef.computePDF(point) << std::endl;
     fullprint << "CDF      =" << distribution.computeCDF(point) << std::endl;
     fullprint << "CDF (ref)=" << distributionRef.computeCDF(point) << std::endl;
+    Scalar Survival = distribution.computeSurvivalFunction(point);
+    fullprint << "Survival      =" << Survival << std::endl;
+    fullprint << "Survival (ref)=" << distribution.computeSurvivalFunction(point) << std::endl;
+    Point InverseSurvival = distribution.computeInverseSurvivalFunction(0.95);
+    fullprint << "Inverse survival=" << InverseSurvival << std::endl;
+    fullprint << "Survival(inverse survival)=" << distribution.computeSurvivalFunction(InverseSurvival) << std::endl;
+
     // 95% quantile
     quantile = distribution.computeQuantile( 0.95 );
     fullprint << "Quantile      =" << quantile << std::endl;
     fullprint << "Quantile (ref)=" << distributionRef.computeQuantile( 0.95 ) << std::endl;
     fullprint << "CDF(quantile)=" << distribution.computeCDF(quantile) << std::endl;
+
+    // Confidence regions
+    if (distribution.getDimension() <= 2)
+    {
+      Scalar threshold;
+      fullprint << "Minimum volume interval=" << distribution.computeMinimumVolumeIntervalWithMarginalProbability(0.95, threshold) << std::endl;
+      fullprint << "threshold=" << threshold << std::endl;
+      Scalar beta;
+      LevelSet levelSet(distribution.computeMinimumVolumeLevelSetWithThreshold(0.95, beta));
+      fullprint << "Minimum volume level set=" << levelSet << std::endl;
+      fullprint << "beta=" << beta << std::endl;
+      fullprint << "Bilateral confidence interval=" << distribution.computeBilateralConfidenceIntervalWithMarginalProbability(0.95, beta) << std::endl;
+      fullprint << "beta=" << beta << std::endl;
+      fullprint << "Unilateral confidence interval (lower tail)=" << distribution.computeUnilateralConfidenceIntervalWithMarginalProbability(0.95, false, beta) << std::endl;
+      fullprint << "beta=" << beta << std::endl;
+      fullprint << "Unilateral confidence interval (upper tail)=" << distribution.computeUnilateralConfidenceIntervalWithMarginalProbability(0.95, true, beta) << std::endl;
+      fullprint << "beta=" << beta << std::endl;
+    }
+    // Moments
     fullprint << "Mean      =" << distribution.getMean() << std::endl;
     fullprint << "Mean (ref)=" << distributionRef.getMean() << std::endl;
-    NumericalPoint standardDeviation = distribution.getStandardDeviation();
+    Point standardDeviation = distribution.getStandardDeviation();
     fullprint << "Standard deviation      =" << standardDeviation << std::endl;
     fullprint << "Standard deviation (ref)=" << distributionRef.getStandardDeviation() << std::endl;
-    NumericalPoint skewness = distribution.getSkewness();
+    Point skewness = distribution.getSkewness();
     fullprint << "Skewness       =" << skewness << std::endl;
     fullprint << "Skewness (ref)==" << distributionRef.getSkewness() << std::endl;
-    NumericalPoint kurtosis = distribution.getKurtosis();
+    Point kurtosis = distribution.getKurtosis();
     fullprint << "Kurtosis      =" << kurtosis << std::endl;
     fullprint << "Kurtosis (ref)=" << distributionRef.getKurtosis() << std::endl;
     fullprint << "Covariance      =" << distribution.getCovariance() << std::endl;
@@ -205,3 +231,4 @@ int main(int argc, char *argv[])
 
   return ExitCode::Success;
 }
+
