@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_CompositeProcess_std.cxx
  *  @brief The test file of class CompositeProcess
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author lebrun
- *  @date   2011-12-05 17:31:12 +0100 (lun. 05 déc. 2011)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -40,9 +37,9 @@ int main(int argc, char *argv[])
 
 
     /* Time grid creation */
-    NumericalScalar Tmin(0.0);
-    NumericalScalar deltaT(0.1);
-    UnsignedInteger steps(11);
+    Scalar Tmin = 0.0;
+    Scalar deltaT = 0.1;
+    UnsignedInteger steps = 11;
 
     /* Initialization of the time grid timeGrid1*/
     RegularGrid timeGrid(Tmin, deltaT, steps);
@@ -59,10 +56,10 @@ int main(int argc, char *argv[])
     /* We build a 1D function */
     Description inputDescription(1, "x");
     Description formula(1, "2 * x + 5");
-    NumericalMathFunction myOneDimensionalFunction(inputDescription, formula);
+    SymbolicFunction myOneDimensionalFunction(inputDescription, formula);
 
     /* We build a spatial function */
-    SpatialFunction myFunction(myOneDimensionalFunction);
+    ValueFunction myFunction(myOneDimensionalFunction);
 
     /* Definition of the CompositeProcess */
     CompositeProcess myCompositeProcess(myFunction, myARMAProcess);
