@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_CorrectedLeaveOneOut_std.cxx
  *  @brief The test file of class CorrectedLeaveOneOut for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2010-02-04 16:44:49 +0100 (Thu, 04 Feb 2010)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -35,17 +32,16 @@ int main(int argc, char *argv[])
 
   UnsignedInteger size = 100;
   Uniform xuniform(0.9, 1.1);
-  NumericalSample x( xuniform.getSample(size) );
+  Sample x( xuniform.getSample(size) );
   Uniform yuniform(1.9, 2.1);
-  NumericalSample y( yuniform.getSample(size) );
-  NumericalMathFunction f( Description(1, "x"), Description(1, "y"), Description(1, "2.0*x") );
-  Basis basis;
-  basis.add(f);
-  Indices indices(basis.getSize());
+  Sample y( yuniform.getSample(size) );
+  SymbolicFunction f( Description(1, "x"), Description(1, "2.0*x") );
+  Collection<Function> basis(1, f);
+  Indices indices(1);
   indices.fill();
   FittingAlgorithm fittingAlgo = CorrectedLeaveOneOut();
 
-  NumericalScalar result = fittingAlgo.run(x, y, basis, indices);
+  Scalar result = fittingAlgo.run(x, y, basis, indices);
 
   fullprint << "result = " << result << std::endl;
 
@@ -55,9 +51,9 @@ int main(int argc, char *argv[])
     size = 2;
     x = xuniform.getSample(size);
     y = yuniform.getSample(size);
-    NumericalMathFunction f2( Description(1, "x"), Description(1, "y"), Description(1, "x^2") );
+    SymbolicFunction f2( Description(1, "x"), Description(1, "x^2") );
     basis.add(f2);
-    NumericalMathFunction f3( Description(1, "x"), Description(1, "y"), Description(1, "x^3") );
+    SymbolicFunction f3( Description(1, "x"), Description(1, "x^3") );
     basis.add(f3);
     indices = Indices(basis.getSize());
     indices.fill();
