@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_CorrelationAnalysis_std.cxx
  *  @brief Test file fo the correlation coefficients computation
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author lebrun
- *  @date   2008-04-15 16:24:44 +0200 (mar, 15 avr 2008)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -37,21 +34,17 @@ int main(int argc, char *argv[])
 
   try
   {
-    UnsignedInteger dimension(2);
-    UnsignedInteger sampleSize(1000);
+    UnsignedInteger dimension = 2;
+    UnsignedInteger sampleSize = 1000;
 
     // we create an analytical function
     Description input(dimension);
     input[0] = "x0";
     input[1] = "x1";
-
-    Description foutput(1, "f");
-
     Description formulas(1, "10+3*x0+x1");
+    SymbolicFunction analytical(input, formulas);
 
-    NumericalMathFunction analytical(input, foutput, formulas);
-
-    // we create a collection of uniform distributions over [-Pi; Pi[
+    // we create a collection of Normal centered distributions
     DistributionCollection aCollection;
     for(UnsignedInteger i = 0; i < dimension; ++i)
     {
@@ -66,10 +59,10 @@ int main(int argc, char *argv[])
     fullprint << "composite=" << composite << std::endl;
 
     // we create two input samples for the function
-    NumericalSample inputSample(randomVector.getSample(sampleSize));
-    NumericalSample outputSample(analytical(inputSample));
+    Sample inputSample(randomVector.getSample(sampleSize));
+    Sample outputSample(analytical(inputSample));
 
-    NumericalPoint src(CorrelationAnalysis::SRC(inputSample, outputSample));
+    Point src(CorrelationAnalysis::SRC(inputSample, outputSample));
     fullprint << "src=" << src << std::endl;
 
   }
