@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_DirichletFactory_std.cxx
  *  @brief The test file of class Dirichlet for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author lebrun
- *  @date   2011-01-12 22:41:37 +0100 (mer. 12 janv. 2011)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -35,14 +32,14 @@ int main(int argc, char *argv[])
 
   try
   {
-    NumericalPoint theta(0);
+    Point theta(0);
     theta.add(0.2);
     theta.add(0.3);
     theta.add(0.4);
     theta.add(0.5);
     Dirichlet distribution(theta);
-    UnsignedInteger size(10000);
-    NumericalSample sample(distribution.getSample(size));
+    UnsignedInteger size = 10000;
+    Sample sample(distribution.getSample(size));
     DirichletFactory factory;
     CovarianceMatrix covariance;
     // Distribution estimatedDistribution(factory.build(sample, covariance));
