@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_Dirichlet_std.cxx
  *  @brief The test file of class Dirichlet for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2010-02-04 16:44:49 +0100 (jeu. 04 févr. 2010)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -38,7 +35,7 @@ int main(int argc, char *argv[])
     // Instanciate one distribution object
     for (UnsignedInteger dim = 1; dim <= 2; dim++)
     {
-      NumericalPoint theta(dim + 1);
+      Point theta(dim + 1);
       for (UnsignedInteger i = 0; i <= dim; i++) theta[i] = 1.0 + (i + 1.0) / 4.0;
       Dirichlet distribution(theta);
       Description description(dim);
@@ -60,12 +57,12 @@ int main(int argc, char *argv[])
       fullprint << "Continuous = " << (distribution.isContinuous() ? "true" : "false") << std::endl;
 
       // Test for realization of distribution
-      NumericalPoint oneRealization = distribution.getRealization();
+      Point oneRealization = distribution.getRealization();
       fullprint << "oneRealization=" << oneRealization << std::endl;
 
       // Test for sampling
       UnsignedInteger size = 10000;
-      NumericalSample oneSample(distribution.getSample( size ));
+      Sample oneSample(distribution.getSample( size ));
       fullprint << "oneSample first=" << oneSample[0] << " last=" << oneSample[size - 1] << std::endl;
       fullprint << "mean=" << oneSample.computeMean() << std::endl;
       fullprint << "covariance=" << oneSample.computeCovariance() << std::endl;
@@ -81,38 +78,40 @@ int main(int argc, char *argv[])
       }
 
       // Define a point
-      NumericalPoint point( distribution.getDimension(), 0.5 / distribution.getDimension() );
+      Point point( distribution.getDimension(), 0.5 / distribution.getDimension() );
       fullprint << "Point=" << point << std::endl;
 
       // Show PDF and CDF of point
-      NumericalScalar LPDF = distribution.computeLogPDF( point );
+      Scalar LPDF = distribution.computeLogPDF( point );
       fullprint << "log pdf=" << LPDF << std::endl;
-      NumericalScalar PDF = distribution.computePDF( point );
+      Scalar PDF = distribution.computePDF( point );
       fullprint << "pdf=" << PDF << std::endl;
-      NumericalScalar CDF = distribution.computeCDF( point );
+      Scalar CDF = distribution.computeCDF( point );
       fullprint << "cdf=" << CDF << std::endl;
-      NumericalPoint quantile = distribution.computeQuantile( 0.95 );
+      Point quantile = distribution.computeQuantile( 0.95 );
       int oldPrecision = PlatformInfo::GetNumericalPrecision();
       PlatformInfo::SetNumericalPrecision( 4 );
       fullprint << "quantile=" << quantile << std::endl;
       PlatformInfo::SetNumericalPrecision( oldPrecision );
       fullprint << "cdf(quantile)=" << distribution.computeCDF(quantile) << std::endl;
-      NumericalPoint mean = distribution.getMean();
+      fullprint << "entropy=" << distribution.computeEntropy() << std::endl;
+      fullprint << "entropy (MC)=" << -distribution.computeLogPDF(distribution.getSample(1000000)).computeMean()[0] << std::endl;
+      Point mean = distribution.getMean();
       fullprint << "mean=" << mean << std::endl;
-      NumericalPoint standardDeviation = distribution.getStandardDeviation();
+      Point standardDeviation = distribution.getStandardDeviation();
       fullprint << "standard deviation=" << standardDeviation << std::endl;
-      NumericalPoint skewness = distribution.getSkewness();
+      Point skewness = distribution.getSkewness();
       fullprint << "skewness=" << skewness << std::endl;
-      NumericalPoint kurtosis = distribution.getKurtosis();
+      Point kurtosis = distribution.getKurtosis();
       fullprint << "kurtosis=" << kurtosis << std::endl;
       CovarianceMatrix covariance = distribution.getCovariance();
       fullprint << "covariance=" << covariance << std::endl;
 
       // get/set parameters collection
-      Dirichlet::NumericalPointWithDescriptionCollection parametersCollection(distribution.getParametersCollection());
+      Dirichlet::PointWithDescriptionCollection parametersCollection(distribution.getParametersCollection());
       fullprint << "parameters collection=" << parametersCollection << std::endl;
       fullprint << "before set=" << distribution << std::endl;
-      NumericalPoint theta2(dim + 1, 1.);
+      Point theta2(dim + 1, 1.);
       Dirichlet tmp(theta2);
       tmp.setParametersCollection(parametersCollection);
       fullprint << "after set= " << tmp << std::endl;
@@ -122,8 +121,8 @@ int main(int argc, char *argv[])
       {
         Distribution margin(distribution.getMarginal(i));
         fullprint << "margin=" << margin << std::endl;
-        fullprint << "margin PDF=" << margin.computePDF(NumericalPoint(1, 0.5)) << std::endl;
-        fullprint << "margin CDF=" << margin.computeCDF(NumericalPoint(1, 0.5)) << std::endl;
+        fullprint << "margin PDF=" << margin.computePDF(Point(1, 0.5)) << std::endl;
+        fullprint << "margin CDF=" << margin.computeCDF(Point(1, 0.5)) << std::endl;
         fullprint << "margin quantile=" << margin.computeQuantile(0.95) << std::endl;
         fullprint << "margin realization=" << margin.getRealization() << std::endl;
       }
@@ -136,9 +135,9 @@ int main(int argc, char *argv[])
         fullprint << "indices=" << indices << std::endl;
         Distribution margins(distribution.getMarginal(indices));
         fullprint << "margins=" << margins << std::endl;
-        fullprint << "margins PDF=" << margins.computePDF(NumericalPoint(2, 0.5)) << std::endl;
-        fullprint << "margins CDF=" << margins.computeCDF(NumericalPoint(2, 0.5)) << std::endl;
-        NumericalPoint quantile = margins.computeQuantile(0.95);
+        fullprint << "margins PDF=" << margins.computePDF(Point(2, 0.5)) << std::endl;
+        fullprint << "margins CDF=" << margins.computeCDF(Point(2, 0.5)) << std::endl;
+        quantile = margins.computeQuantile(0.95);
         fullprint << "margins quantile=" << quantile << std::endl;
         fullprint << "margins CDF(quantile)=" << margins.computeCDF(quantile) << std::endl;
         fullprint << "margins realization=" << margins.getRealization() << std::endl;
