@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_DistFunc_beta.cxx
  *  @brief The test file of class DistFunc for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -38,24 +35,24 @@ int main(int argc, char *argv[])
     // Beta related functions
     {
       // pBeta
-      NumericalScalar p1Min(0.2);
-      NumericalScalar p1Max(5.0);
-      UnsignedInteger n1(5);
-      NumericalScalar p2Min(0.2);
-      NumericalScalar p2Max(5.0);
-      UnsignedInteger n2(5);
-      NumericalScalar xMin(0.1);
-      NumericalScalar xMax(0.9);
-      UnsignedInteger nX(5);
+      Scalar p1Min = 0.2;
+      Scalar p1Max = 5.0;
+      UnsignedInteger n1 = 5;
+      Scalar p2Min = 0.2;
+      Scalar p2Max = 5.0;
+      UnsignedInteger n2 = 5;
+      Scalar xMin = 0.1;
+      Scalar xMax = 0.9;
+      UnsignedInteger nX = 5;
       for (UnsignedInteger i1 = 0; i1 < n1; ++i1)
       {
-        NumericalScalar p1(p1Min + (p1Max - p1Min) * i1 / (n1 - 1));
+        Scalar p1 = p1Min + (p1Max - p1Min) * i1 / (n1 - 1);
         for (UnsignedInteger i2 = 0; i2 < n2; ++i2)
         {
-          NumericalScalar p2(p2Min + (p2Max - p2Min) * i2 / (n2 - 1));
+          Scalar p2 = p2Min + (p2Max - p2Min) * i2 / (n2 - 1);
           for (UnsignedInteger iX = 0; iX < nX; ++iX)
           {
-            NumericalScalar x(xMin + (xMax - xMin) * iX / (nX - 1));
+            Scalar x = xMin + (xMax - xMin) * iX / (nX - 1);
             fullprint << "pBeta(" << p1 << ", " << p2 << ", " << x << ")=" << DistFunc::pBeta(p1, p2, x) << ", complementary=" << DistFunc::pBeta(p1, p2, x, true) << std::endl;
           }
         }
@@ -63,24 +60,24 @@ int main(int argc, char *argv[])
     } // pBeta
     {
       // qBeta
-      NumericalScalar p1Min(0.2);
-      NumericalScalar p1Max(5.0);
-      UnsignedInteger n1(5);
-      NumericalScalar p2Min(0.2);
-      NumericalScalar p2Max(5.0);
-      UnsignedInteger n2(5);
-      NumericalScalar qMin(0.1);
-      NumericalScalar qMax(0.9);
-      UnsignedInteger nQ(5);
+      Scalar p1Min = 0.2;
+      Scalar p1Max = 5.0;
+      UnsignedInteger n1 = 5;
+      Scalar p2Min = 0.2;
+      Scalar p2Max = 5.0;
+      UnsignedInteger n2 = 5;
+      Scalar qMin = 0.1;
+      Scalar qMax = 0.9;
+      UnsignedInteger nQ = 5;
       for (UnsignedInteger i1 = 0; i1 < n1; ++i1)
       {
-        NumericalScalar p1(p1Min + (p1Max - p1Min) * i1 / (n1 - 1));
+        Scalar p1 = p1Min + (p1Max - p1Min) * i1 / (n1 - 1);
         for (UnsignedInteger i2 = 0; i2 < n2; ++i2)
         {
-          NumericalScalar p2(p2Min + (p2Max - p2Min) * i2 / (n2 - 1));
+          Scalar p2 = p2Min + (p2Max - p2Min) * i2 / (n2 - 1);
           for (UnsignedInteger iQ = 0; iQ < nQ; ++iQ)
           {
-            NumericalScalar q(qMin + (qMax - qMin) * iQ / (nQ - 1));
+            Scalar q = qMin + (qMax - qMin) * iQ / (nQ - 1);
             fullprint << "qBeta(" << p1 << ", " << p2 << ", " << q << ")=" << DistFunc::qBeta(p1, p2, q) << ", complementary=" << DistFunc::qBeta(p1, p2, q, true) << std::endl;
           }
         }
@@ -88,19 +85,19 @@ int main(int argc, char *argv[])
     } // qBeta
     {
       // rBeta
-      NumericalScalar p1Min(0.2);
-      NumericalScalar p1Max(5.0);
-      UnsignedInteger n1(5);
-      NumericalScalar p2Min(0.2);
-      NumericalScalar p2Max(5.0);
-      UnsignedInteger n2(5);
-      UnsignedInteger nR(5);
+      Scalar p1Min = 0.2;
+      Scalar p1Max = 5.0;
+      UnsignedInteger n1 = 5;
+      Scalar p2Min = 0.2;
+      Scalar p2Max = 5.0;
+      UnsignedInteger n2 = 5;
+      UnsignedInteger nR = 5;
       for (UnsignedInteger i1 = 0; i1 < n1; ++i1)
       {
-        NumericalScalar p1(p1Min + (p1Max - p1Min) * i1 / (n1 - 1));
+        Scalar p1 = p1Min + (p1Max - p1Min) * i1 / (n1 - 1);
         for (UnsignedInteger i2 = 0; i2 < n2; ++i2)
         {
-          NumericalScalar p2(p2Min + (p2Max - p2Min) * i2 / (n2 - 1));
+          Scalar p2 = p2Min + (p2Max - p2Min) * i2 / (n2 - 1);
           for (UnsignedInteger iR = 0; iR < nR; ++iR)
           {
             fullprint << "rBeta(" << p1 << ", " << p2 << ")=" << DistFunc::rBeta(p1, p2) << std::endl;
