@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_DistFunc_kolmogorov.cxx
  *  @brief The test file of class DistFunc for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -52,7 +49,7 @@ int main(int argc, char *argv[])
     nValues.add(20000);
     nValues.add(100000);
     nValues.add(1000000);
-    NumericalPoint xValues(0);
+    Point xValues(0);
     xValues.add(0.0001);
     xValues.add(0.0002);
     xValues.add(0.0005);
@@ -75,12 +72,12 @@ int main(int argc, char *argv[])
     xValues.add(50.0);
     for (UnsignedInteger i = 0; i < nValues.getSize(); ++i)
     {
-      const UnsignedInteger n(nValues[i]);
+      const UnsignedInteger n = nValues[i];
       for (UnsignedInteger j = 0; j < xValues.getSize(); ++j)
       {
-        const NumericalScalar x(xValues[j]);
-        const NumericalScalar cdf(DistFunc::pKolmogorov(n, x));
-        const NumericalScalar ccdf(DistFunc::pKolmogorov(n, x, true));
+        const Scalar x = xValues[j];
+        const Scalar cdf = DistFunc::pKolmogorov(n, x);
+        const Scalar ccdf = DistFunc::pKolmogorov(n, x, true);
         fullprint << "pKolmogorov(" << n << ", " << x << ")=" << std::fixed << (cdf < 1e-16 ? 0.0 : cdf) << ", complementary=" << (ccdf < 1e-16 ? 0.0 : ccdf) << std::endl;
       }
     }
