@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_DistFunc_nonCentralChiSquare.cxx
  *  @brief The test file of class DistFunc for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -38,24 +35,24 @@ int main(int argc, char *argv[])
     // NonCentralChiSquare related functions
     {
       // dNonCentralChiSquare
-      NumericalScalar nuMin(0.2);
-      NumericalScalar nuMax(5.0);
-      UnsignedInteger n1(5);
-      NumericalScalar lambdaMin(0.2);
-      NumericalScalar lambdaMax(5.0);
-      UnsignedInteger n2(5);
-      NumericalScalar xMin(0.1);
-      NumericalScalar xMax(0.9);
-      UnsignedInteger nX(5);
+      Scalar nuMin = 0.2;
+      Scalar nuMax = 5.0;
+      UnsignedInteger n1 = 5;
+      Scalar lambdaMin = 0.2;
+      Scalar lambdaMax = 5.0;
+      UnsignedInteger n2 = 5;
+      Scalar xMin = 0.1;
+      Scalar xMax = 0.9;
+      UnsignedInteger nX = 5;
       for (UnsignedInteger i1 = 0; i1 < n1; ++i1)
       {
-        NumericalScalar nu(nuMin + (nuMax - nuMin) * i1 / (n1 - 1));
+        Scalar nu = nuMin + (nuMax - nuMin) * i1 / (n1 - 1);
         for (UnsignedInteger i2 = 0; i2 < n2; ++i2)
         {
-          NumericalScalar lambda(lambdaMin + (lambdaMax - lambdaMin) * i2 / (n2 - 1));
+          Scalar lambda = lambdaMin + (lambdaMax - lambdaMin) * i2 / (n2 - 1);
           for (UnsignedInteger iX = 0; iX < nX; ++iX)
           {
-            NumericalScalar x(xMin + (xMax - xMin) * iX / (nX - 1));
+            Scalar x = xMin + (xMax - xMin) * iX / (nX - 1);
             fullprint << "dNonCentralChiSquare(" << nu << ", " << lambda << ", " << x << ")=" << DistFunc::dNonCentralChiSquare(nu, lambda, x) << std::endl;
           }
         }
@@ -63,24 +60,24 @@ int main(int argc, char *argv[])
     } // dNonCentralChiSquare
     {
       // pNonCentralChiSquare
-      NumericalScalar nuMin(0.2);
-      NumericalScalar nuMax(5.0);
-      UnsignedInteger n1(5);
-      NumericalScalar lambdaMin(0.2);
-      NumericalScalar lambdaMax(5.0);
-      UnsignedInteger n2(5);
-      NumericalScalar xMin(0.1);
-      NumericalScalar xMax(0.9);
-      UnsignedInteger nX(5);
+      Scalar nuMin = 0.2;
+      Scalar nuMax = 5.0;
+      UnsignedInteger n1 = 5;
+      Scalar lambdaMin = 0.2;
+      Scalar lambdaMax = 5.0;
+      UnsignedInteger n2 = 5;
+      Scalar xMin = 0.1;
+      Scalar xMax = 0.9;
+      UnsignedInteger nX = 5;
       for (UnsignedInteger i1 = 0; i1 < n1; ++i1)
       {
-        NumericalScalar nu(nuMin + (nuMax - nuMin) * i1 / (n1 - 1));
+        Scalar nu = nuMin + (nuMax - nuMin) * i1 / (n1 - 1);
         for (UnsignedInteger i2 = 0; i2 < n2; ++i2)
         {
-          NumericalScalar lambda(lambdaMin + (lambdaMax - lambdaMin) * i2 / (n2 - 1));
+          Scalar lambda = lambdaMin + (lambdaMax - lambdaMin) * i2 / (n2 - 1);
           for (UnsignedInteger iX = 0; iX < nX; ++iX)
           {
-            NumericalScalar x(xMin + (xMax - xMin) * iX / (nX - 1));
+            Scalar x = xMin + (xMax - xMin) * iX / (nX - 1);
             fullprint << "pNonCentralChiSquare(" << nu << ", " << lambda << ", " << x << ")=" << DistFunc::pNonCentralChiSquare(nu, lambda, x) << ", complementary=" << DistFunc::pNonCentralChiSquare(nu, lambda, x, true) << std::endl;
           }
         }
@@ -88,19 +85,19 @@ int main(int argc, char *argv[])
     } // pNonCentralChiSquare
     {
       // rNonCentralChiSquare
-      NumericalScalar nuMin(0.2);
-      NumericalScalar nuMax(5.0);
-      UnsignedInteger n1(5);
-      NumericalScalar lambdaMin(0.2);
-      NumericalScalar lambdaMax(5.0);
-      UnsignedInteger n2(5);
-      UnsignedInteger nR(5);
+      Scalar nuMin = 0.2;
+      Scalar nuMax = 5.0;
+      UnsignedInteger n1 = 5;
+      Scalar lambdaMin = 0.2;
+      Scalar lambdaMax = 5.0;
+      UnsignedInteger n2 = 5;
+      UnsignedInteger nR = 5;
       for (UnsignedInteger i1 = 0; i1 < n1; ++i1)
       {
-        NumericalScalar nu(nuMin + (nuMax - nuMin) * i1 / (n1 - 1));
+        Scalar nu = nuMin + (nuMax - nuMin) * i1 / (n1 - 1);
         for (UnsignedInteger i2 = 0; i2 < n2; ++i2)
         {
-          NumericalScalar lambda(lambdaMin + (lambdaMax - lambdaMin) * i2 / (n2 - 1));
+          Scalar lambda = lambdaMin + (lambdaMax - lambdaMin) * i2 / (n2 - 1);
           for (UnsignedInteger iR = 0; iR < nR; ++iR)
           {
             fullprint << "rNonCentralChiSquare(" << nu << ", " << lambda << ")=" << DistFunc::rNonCentralChiSquare(nu, lambda) << std::endl;
