@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_Domain_std.cxx
  *  @brief The test file of class Domain for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -35,12 +32,12 @@ int main(int argc, char *argv[])
   try
   {
     // The 1D interface
-    UnsignedInteger dim(2);
-    NumericalPoint a(dim, -1.0);
-    NumericalPoint b(dim, 2.0);
+    UnsignedInteger dim = 2;
+    Point a(dim, -1.0);
+    Point b(dim, 2.0);
     Domain domain  = Interval(a, b);
-    NumericalPoint p1(dim, 0.5);
-    NumericalPoint p2(dim, 2.5);
+    Point p1(dim, 0.5);
+    Point p2(dim, 2.5);
     fullprint << "Domain= " << domain << std::endl;
     // Accessors
     fullprint << "Dimension= " << domain.getDimension() << std::endl;
