@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_Event_std.cxx
  *  @brief The test file of Event class
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -37,8 +34,8 @@ int main(int argc, char *argv[])
   {
 
     /* We create a numerical point of dimension 1 */
-    NumericalPoint point(4);
-    const NumericalPoint & ref_point(point);
+    Point point(4);
+    const Point & ref_point(point);
 
     point[0] = 101;
     point[1] = 202;
@@ -47,7 +44,7 @@ int main(int argc, char *argv[])
 
     fullprint << "point = " << ref_point << std::endl;
 
-    /* We create a 'constant' RandomVector from the NumericalPoint */
+    /* We create a 'constant' RandomVector from the Point */
     RandomVector vect(point);
     fullprint << "vect=" << vect << std::endl;
 
@@ -62,7 +59,7 @@ int main(int argc, char *argv[])
     input[1] = "F";
     input[2] = "L";
     input[3] = "I";
-    NumericalMathFunction myFunction(input, Description(1, "d"), Description(1, "-F*L^3/(3*E*I)"));
+    SymbolicFunction myFunction(input, Description(1, "-F*L^3/(3*E*I)"));
 
     /* We create a composite random vector */
     RandomVector output(myFunction, vect);
@@ -73,7 +70,7 @@ int main(int argc, char *argv[])
 
     /* We compute one realization of the event */
     fullprint << "myEvent realization=" << myEvent.getRealization() << std::endl;
-    fullprint << "myEvent antecedent realization=" << myEvent.getImplementation()->getAntecedent()->getRealization() << std::endl;
+    fullprint << "myEvent antecedent realization=" << myEvent.getImplementation()->getAntecedent().getRealization() << std::endl;
 
     /* We compute a sample of the event */
     fullprint << "myEvent sample=" << myEvent.getSample(10) << std::endl;
