@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_ExponentialFactory_std.cxx
  *  @brief The test file of class Exponential for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,8 +33,8 @@ int main(int argc, char *argv[])
   try
   {
     Exponential distribution(2.5, -1.3);
-    UnsignedInteger size(10000);
-    NumericalSample sample(distribution.getSample(size));
+    UnsignedInteger size = 10000;
+    Sample sample(distribution.getSample(size));
     ExponentialFactory factory;
     CovarianceMatrix covariance;
     // Distribution estimatedDistribution(factory.build(sample, covariance));
@@ -47,7 +44,7 @@ int main(int argc, char *argv[])
     // fullprint << "Covariance=" << covariance << std::endl;
     estimatedDistribution = factory.build();
     fullprint << "Default distribution=" << estimatedDistribution << std::endl;
-    estimatedDistribution = factory.build(distribution.getParametersCollection());
+    estimatedDistribution = factory.build(distribution.getParameter());
     fullprint << "Distribution from parameters=" << estimatedDistribution << std::endl;
     Exponential estimatedExponential(factory.buildAsExponential(sample));
     fullprint << "Exponential          =" << distribution << std::endl;
@@ -55,8 +52,15 @@ int main(int argc, char *argv[])
     // fullprint << "Covariance=" << covariance << std::endl;
     estimatedExponential = factory.buildAsExponential();
     fullprint << "Default exponential=" << estimatedExponential << std::endl;
-    estimatedExponential = factory.buildAsExponential(distribution.getParametersCollection());
+    estimatedExponential = factory.buildAsExponential(distribution.getParameter());
     fullprint << "Exponential from parameters=" << estimatedExponential << std::endl;
+    // Test for constant sample
+    sample = Sample(size, Point(1, 0.0));
+    estimatedDistribution = factory.build(sample);
+    fullprint << "Estimated distribution=" << estimatedDistribution << std::endl;
+    sample = Sample(size, Point(1, 1.0));
+    estimatedDistribution = factory.build(sample);
+    fullprint << "Estimated distribution=" << estimatedDistribution << std::endl;
   }
   catch (TestFailed & ex)
   {
