@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_ExponentialModel_std.cxx
  *  @brief The test file of class ExponentialModel
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,15 +33,15 @@ int main(int argc, char *argv[])
   {
 
     /* Default dimension parameter to evaluate the model */
-    const UnsignedInteger defaultDimension(1);
+    const UnsignedInteger defaultDimension = 1;
 
     /* Spatial dimension of the model */
-    const UnsignedInteger spatialDimension(1);
+    const UnsignedInteger spatialDimension = 1;
 
     /* Amplitude values */
-    NumericalPoint amplitude(defaultDimension, 1.0);
+    Point amplitude(defaultDimension, 2.0);
     /* Scale values */
-    NumericalPoint scale(defaultDimension, 1.0);
+    Point scale(spatialDimension, 1.0);
 
 
     /* Default constructor */
@@ -52,15 +49,15 @@ int main(int argc, char *argv[])
     fullprint << "myDefautModel = " << myDefautModel << std::endl;
 
     /* Second order model with parameters */
-    ExponentialModel myModel(spatialDimension, amplitude, scale);
+    ExponentialModel myModel(scale, amplitude);
     fullprint << "myModel = " << myModel << std::endl;
 
-    const NumericalScalar timeValueOne(1.0);
+    const Scalar timeValueOne = 1.0;
     fullprint << "covariance matrix at t = " << timeValueOne << " : " << myModel(timeValueOne) << std::endl;
     fullprint << "covariance matrix at t = " << -1.0 * timeValueOne << " : " << myModel(-1.0 * timeValueOne) << std::endl;
 
     /* Evaluation at time higher to check the decrease of the exponential values */
-    const NumericalScalar timeValueHigh(4.0);
+    const Scalar timeValueHigh = 4.0;
     fullprint << "covariance matrix at t = "  << timeValueHigh << " : " << myModel(timeValueHigh) << std::endl;
 
     /* Discretize the process on a small time grid */
@@ -68,27 +65,25 @@ int main(int argc, char *argv[])
     fullprint << "discretized covariance over the time grid=" << timeGrid << " is" << std::endl;
     fullprint << myModel.discretize(timeGrid) << std::endl;
     /* Default dimension parameter to evaluate the model */
-    const UnsignedInteger highDimension(3);
+    const UnsignedInteger highDimension = 3;
 
     /* Reallocation of adequate sizes*/
     amplitude.resize(highDimension);
-    scale.resize(highDimension);
 
     CorrelationMatrix spatialCorrelation(highDimension);
     for (UnsignedInteger index = 0 ; index < highDimension; ++index)
     {
       // constant amplitude
       amplitude[index] = 1.0 ;
-      scale[index] = (index + 1.0) / defaultDimension ;
       if (index > 0) spatialCorrelation(index, index - 1) = 1.0 / index;
     }
     fullprint << "spatialCorrelation=" << spatialCorrelation << std::endl;
     /* checking the cast*/
-    StationaryCovarianceModel mySecondOrderModel(ExponentialModel(spatialDimension, amplitude, scale, spatialCorrelation));
+    StationaryCovarianceModel mySecondOrderModel(ExponentialModel(scale, amplitude, spatialCorrelation));
     fullprint << "mySecondOrderModel = " << mySecondOrderModel << std::endl;
 
     /* Second order model - high dimension */
-    ExponentialModel myHighModel(spatialDimension, amplitude, scale, spatialCorrelation);
+    ExponentialModel myHighModel(scale, amplitude, spatialCorrelation);
     fullprint << "myHighModel = " << myHighModel << std::endl;
 
     fullprint << "covariance matrix at t = " << timeValueOne << " : " << myHighModel(timeValueOne) << std::endl;
