@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_FORM_draw.cxx
  *  @brief The test file of FORM class
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,26 +14,24 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
 
-String printNumericalPoint(const NumericalPoint & point, const UnsignedInteger digits)
+String printPoint(const Point & point, const UnsignedInteger digits)
 {
   OSS oss;
   oss << "[";
-  NumericalScalar eps(pow(0.1, 1.0 * digits));
+  Scalar eps = pow(0.1, 1.0 * digits);
   for (UnsignedInteger i = 0; i < point.getDimension(); i++)
   {
-    oss << std::fixed << std::setprecision(digits) << (i == 0 ? "" : ",") << Bulk<double>((fabs(point[i]) < eps) ? fabs(point[i]) : point[i]);
+    oss << std::fixed << std::setprecision(digits) << (i == 0 ? "" : ",") << Bulk<double>((std::abs(point[i]) < eps) ? std::abs(point[i]) : point[i]);
   }
   oss << "]";
   return oss;
@@ -53,19 +50,17 @@ int main(int argc, char *argv[])
     Description inputFunc(2);
     inputFunc[0] = "x0";
     inputFunc[1] = "x1";
-    Description outputFunc(1);
-    outputFunc[0] = "y0";
-    Description formulas(outputFunc.getSize());
+    Description formulas(1);
     formulas[0] = "-(6+x0^2-x1)";
     fullprint << "formulas=" << formulas << std::endl;
-    NumericalMathFunction myFunction(inputFunc, outputFunc, formulas);
+    SymbolicFunction myFunction(inputFunc, formulas);
 
-    UnsignedInteger dim(myFunction.getInputDimension());
+    UnsignedInteger dim = myFunction.getInputDimension();
     /* We create a normal distribution point of dimension 1 */
-    NumericalPoint mean(dim, 0.0);
+    Point mean(dim, 0.0);
     mean[0] = 5.0; // x0
     mean[1] = 2.1; // x1
-    NumericalPoint sigma(dim, 0.0);
+    Point sigma(dim, 0.0);
     sigma[0] = 3.3; // x0
     sigma[1] = 3.0; // x1
     IdentityMatrix R(dim);
@@ -91,8 +86,7 @@ int main(int argc, char *argv[])
 
     /* We create a NearestPoint algorithm */
     Cobyla myCobyla;
-    myCobyla.setSpecificParameters(CobylaSpecificParameters());
-    myCobyla.setMaximumIterationsNumber(100);
+    myCobyla.setMaximumEvaluationNumber(200);
     myCobyla.setMaximumAbsoluteError(1.0e-10);
     myCobyla.setMaximumRelativeError(1.0e-10);
     myCobyla.setMaximumResidualError(1.0e-10);
@@ -100,7 +94,7 @@ int main(int argc, char *argv[])
     fullprint << "myCobyla=" << myCobyla << std::endl << std::flush;
 
     /* We create a FORM algorithm */
-    /* The first parameter is a NearestPointAlgorithm */
+    /* The first parameter is an OptimizationAlgorithm */
     /* The second parameter is an event */
     /* The third parameter is a starting point for the design point research */
     FORM myAlgo(myCobyla, myEvent, mean);
@@ -112,32 +106,28 @@ int main(int argc, char *argv[])
 
     /* Stream out the result */
     FORMResult result(myAlgo.getResult());
-    UnsignedInteger digits(5);
-    fullprint << "importance factors=" << printNumericalPoint(result.getImportanceFactors(), digits) << std::endl;
-    fullprint << "importance factors (classical)=" << printNumericalPoint(result.getImportanceFactors(AnalyticalResult::CLASSICAL), digits) << std::endl;
+    UnsignedInteger digits = 5;
+    fullprint << "importance factors=" << printPoint(result.getImportanceFactors(), digits) << std::endl;
+    fullprint << "importance factors (classical)=" << printPoint(result.getImportanceFactors(AnalyticalResult::CLASSICAL), digits) << std::endl;
 
     /* Graph 1 : Importance Factors graph */
     Graph importanceFactorsGraph(result.drawImportanceFactors());
-    importanceFactorsGraph.draw("ImportanceFactorsDrawingFORM", 640, 480);
+    importanceFactorsGraph.draw("ImportanceFactorsDrawingFORM.png");
 
     /* Graph 1bis : Importance Factors graph */
     Graph classicalImportanceFactorsGraph(result.drawImportanceFactors(AnalyticalResult::CLASSICAL));
-    classicalImportanceFactorsGraph.draw("ClassicalImportanceFactorsDrawingFORM", 640, 480);
+    classicalImportanceFactorsGraph.draw("ClassicalImportanceFactorsDrawingFORM.png");
 
     /* Graph 2 : Hasofer Reliability Index Sensitivity Graphs graph */
     AnalyticalResult::GraphCollection reliabilityIndexSensitivityGraphs(result.drawHasoferReliabilityIndexSensitivity());
-    reliabilityIndexSensitivityGraphs[0].draw("HasoferReliabilityIndexMarginalSensitivityDrawing", 640, 480);
-    // Check that the correct files have been generated by computing their checksum
-    reliabilityIndexSensitivityGraphs[1].draw("HasoferReliabilityIndexOtherSensitivityDrawing", 640, 480);
-    // Check that the correct files have been generated by computing their checksum
+    reliabilityIndexSensitivityGraphs[0].draw("HasoferReliabilityIndexMarginalSensitivityDrawing.png");
+    reliabilityIndexSensitivityGraphs[1].draw("HasoferReliabilityIndexOtherSensitivityDrawing.png");
 
 
     /* Graph 3 : FORM Event Probability Sensitivity Graphs graph */
     AnalyticalResult::GraphCollection eventProbabilitySensitivityGraphs(result.drawEventProbabilitySensitivity());
-    eventProbabilitySensitivityGraphs[0].draw("EventProbabilityIndexMarginalSensitivityDrawing", 640, 480);
-    // Check that the correct files have been generated by computing their checksum
-    eventProbabilitySensitivityGraphs[1].draw("EventProbabilityIndexOtherSensitivityDrawing", 640, 480);
-    // Check that the correct files have been generated by computing their checksum
+    eventProbabilitySensitivityGraphs[0].draw("EventProbabilityIndexMarginalSensitivityDrawing.png");
+    eventProbabilitySensitivityGraphs[1].draw("EventProbabilityIndexOtherSensitivityDrawing.png");
 
   }
   catch (TestFailed & ex)
