@@ -1,10 +1,9 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_FilteringWindows_std.cxx
  *  @brief The test file of class FilteringWindows
  *         This tests the Hamming and Hanning classes
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -16,14 +15,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -47,13 +44,13 @@ int main(int argc, char *argv[])
 
     /* Evaluation of values between t=0 and t=1 using a step = 0.01 */
     const UnsignedInteger    steps(100);
-    const NumericalScalar tMin(0.0);
-    const NumericalScalar tMax(1.0);
-    const NumericalScalar tStep((tMax - tMin) / steps);
+    const Scalar tMin = 0.0;
+    const Scalar tMax = 1.0;
+    const Scalar tStep = (tMax - tMin) / steps;
 
     for (UnsignedInteger i = 0; i < steps + 1; ++i )
     {
-      const NumericalScalar t(tMin + i * tStep);
+      const Scalar t = tMin + i * tStep;
       fullprint << "t = " << t
                 << " Hanning = " << myHanningFilter(t)
                 << " Hamming = " << myHammingFilter(t) << std::endl;
