@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_FiniteDifferenceStep_std.cxx
  *  @brief The test file of class FiniteDifferenceStep for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -35,15 +32,15 @@ int main(int argc, char *argv[])
 
   try
   {
-    UnsignedInteger dimension( 2 );
-    NumericalPoint epsilon( dimension, 1e-5 );
-    NumericalPoint eta( dimension, 1.0 );
+    UnsignedInteger dimension = 2;
+    Point epsilon( dimension, 1e-5 );
+    Point eta( dimension, 1.0 );
     Collection<FiniteDifferenceStep> coll;
     coll.add(ConstantStep(epsilon));
     coll.add(BlendedStep(epsilon, eta));
 
 
-    NumericalPoint x(dimension, -3.0);
+    Point x(dimension, -3.0);
 
     for (UnsignedInteger i = 0; i < coll.getSize(); ++ i)
     {
