@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_FittingTest_std.cxx
  *  @brief The test file of class Test
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -89,27 +86,26 @@ int main(int argc, char *argv[])
   distributionCollection.add(poisson);
   discreteDistributionCollection.add(poisson);
 
-  Collection<UserDefinedPair> collection(3, UserDefinedPair(NumericalPoint(1), 0.0));
-
-  NumericalPoint point(1);
-  point[0] = 1.0;
-  collection[0] = UserDefinedPair(point, 0.3);
-  point[0] = 2.0;
-  collection[1] = UserDefinedPair(point, 0.2);
-  point[0] = 3.0;
-  collection[2] = UserDefinedPair(point, 0.5);
-  UserDefined userdefined(collection);
+  Sample x(3, 1);
+  x[0][0] = 1.0;
+  x[1][0] = 2.0;
+  x[2][0] = 3.0;
+  Point p(3);
+  p[0] = 0.3;
+  p[1] = 0.2;
+  p[2] = 0.5;
+  UserDefined userdefined(x, p);
   distributionCollection.add(userdefined);
   discreteDistributionCollection.add(userdefined);
 
-  UnsignedInteger size(100);
+  UnsignedInteger size = 100;
 
-  UnsignedInteger continuousDistributionNumber(continuousDistributionCollection.getSize());
-  UnsignedInteger discreteDistributionNumber(discreteDistributionCollection.getSize());
-  UnsignedInteger distributionNumber(continuousDistributionNumber + discreteDistributionNumber);
-  Collection<NumericalSample> sampleCollection(distributionNumber);
-  Collection<NumericalSample> continuousSampleCollection(continuousDistributionNumber);
-  Collection<NumericalSample> discreteSampleCollection(discreteDistributionNumber);
+  UnsignedInteger continuousDistributionNumber = continuousDistributionCollection.getSize();
+  UnsignedInteger discreteDistributionNumber = discreteDistributionCollection.getSize();
+  UnsignedInteger distributionNumber = continuousDistributionNumber + discreteDistributionNumber;
+  Collection<Sample> sampleCollection(distributionNumber);
+  Collection<Sample> continuousSampleCollection(continuousDistributionNumber);
+  Collection<Sample> discreteSampleCollection(discreteDistributionNumber);
   for (UnsignedInteger i = 0; i < continuousDistributionNumber; i++)
   {
     continuousSampleCollection[i] = continuousDistributionCollection[i].getSample(size);
@@ -124,7 +120,7 @@ int main(int argc, char *argv[])
   factoryCollection.add(UniformFactory());
   factoryCollection.add(BetaFactory());
   factoryCollection.add(NormalFactory());
-  NumericalSample aSample(Uniform(-1.5, 2.5).getSample(size));
+  Sample aSample(Uniform(-1.5, 2.5).getSample(size));
   TestResult bestResult;
   fullprint << "best model BIC=" << FittingTest::BestModelBIC(aSample, factoryCollection) << std::endl;
   fullprint << "best model Kolmogorov=" << FittingTest::BestModelKolmogorov(aSample, factoryCollection, bestResult) << std::endl;
@@ -134,8 +130,8 @@ int main(int argc, char *argv[])
   {
     for (UnsignedInteger j = 0; j < distributionNumber; j++)
     {
-      const NumericalScalar value(FittingTest::BIC(sampleCollection[i], distributionCollection[j], 0));
-      resultBIC(i, j) = (fabs(value) < 1.0e-6 ? 0.0 : value);
+      const Scalar value = FittingTest::BIC(sampleCollection[i], distributionCollection[j], 0);
+      resultBIC(i, j) = (std::abs(value) < 1.0e-6 ? 0.0 : value);
     }
   }
   fullprint << "resultBIC=" << resultBIC << std::endl;
@@ -144,8 +140,8 @@ int main(int argc, char *argv[])
   {
     for (UnsignedInteger j = 0; j < continuousDistributionNumber; j++)
     {
-      const NumericalScalar value(FittingTest::Kolmogorov(continuousSampleCollection[i], continuousDistributionCollection[j], 0.95, 0).getPValue());
-      resultKolmogorov(i, j) = (fabs(value) < 1.0e-6 ? 0.0 : value);
+      const Scalar value = FittingTest::Kolmogorov(continuousSampleCollection[i], continuousDistributionCollection[j], 0.95, 0).getPValue();
+      resultKolmogorov(i, j) = (std::abs(value) < 1.0e-6 ? 0.0 : value);
     }
   }
   fullprint << "resultKolmogorov=" << resultKolmogorov << std::endl;
@@ -154,8 +150,8 @@ int main(int argc, char *argv[])
   {
     for (UnsignedInteger j = 0; j < discreteDistributionNumber - 1; j++)
     {
-      const NumericalScalar value(FittingTest::ChiSquared(discreteSampleCollection[i], discreteDistributionCollection[j], 0.95, 0).getPValue());
-      resultChiSquared(i, j) = (fabs(value) < 1.0e-6 ? 0.0 : value);
+      const Scalar value = FittingTest::ChiSquared(discreteSampleCollection[i], discreteDistributionCollection[j], 0.95, 0).getPValue();
+      resultChiSquared(i, j) = (std::abs(value) < 1.0e-6 ? 0.0 : value);
     }
   }
   fullprint << "resultChiSquared=" << resultChiSquared << std::endl;
