@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_FrankCopulaFactory_std.cxx
  *  @brief The test file of class FrankCopula for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,8 +33,8 @@ int main(int argc, char *argv[])
   try
   {
     FrankCopula distribution(1.5);
-    UnsignedInteger size(1000);
-    NumericalSample sample(distribution.getSample(size));
+    UnsignedInteger size = 1000;
+    Sample sample(distribution.getSample(size));
     FrankCopulaFactory factory;
     CovarianceMatrix covariance;
     // Distribution estimatedDistribution(factory.build(sample, covariance));
@@ -47,14 +44,14 @@ int main(int argc, char *argv[])
     // fullprint << "Covariance=" << covariance << std::endl;
     estimatedDistribution = factory.build();
     fullprint << "Default distribution=" << estimatedDistribution << std::endl;
-    estimatedDistribution = factory.build(distribution.getParametersCollection());
+    estimatedDistribution = factory.build(distribution.getParameter());
     fullprint << "Distribution from parameters=" << estimatedDistribution << std::endl;
     FrankCopula estimatedFrankCopula(factory.buildAsFrankCopula(sample));
     fullprint << "FrankCopula          =" << distribution << std::endl;
     fullprint << "Estimated frankCopula=" << estimatedFrankCopula << std::endl;
     estimatedFrankCopula = factory.buildAsFrankCopula();
     fullprint << "Default frankCopula=" << estimatedFrankCopula << std::endl;
-    estimatedFrankCopula = factory.buildAsFrankCopula(distribution.getParametersCollection());
+    estimatedFrankCopula = factory.buildAsFrankCopula(distribution.getParameter());
     fullprint << "FrankCopula from parameters=" << estimatedFrankCopula << std::endl;
   }
   catch (TestFailed & ex)
