@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_FunctionalChaos_gsobol.cxx
  *  @brief The test file of FunctionalChaosAlgorithm class
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,22 +14,20 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2008-05-21 11:21:38 +0200 (mer. 21 mai 2008)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
 
-NumericalScalar sobol(const Indices & indices,
-                      const NumericalPoint & a)
+Scalar sobol(const Indices & indices,
+             const Point & a)
 {
-  NumericalScalar value(1.0);
+  Scalar value = 1.0;
   for (UnsignedInteger i = 0; i < indices.getSize(); ++i)
   {
     value *= 1.0 / (3.0 * pow(1.0 + a[indices[i]], 2.0));
@@ -48,16 +45,14 @@ int main(int argc, char *argv[])
   {
 
     // Problem parameters
-    UnsignedInteger dimension(5);
+    UnsignedInteger dimension = 5;
 
     // Reference analytical values
-    NumericalScalar meanTh(1.0);
-    NumericalScalar covTh(1.0);
-    NumericalPoint a(dimension);
+    Scalar meanTh = 1.0;
+    Scalar covTh = 1.0;
+    Point a(dimension);
     // Create the gSobol function
     Description inputVariables(dimension);
-    Description outputVariables(1);
-    outputVariables[0] = "y";
     Description formula(1);
     formula[0] = "1.0";
     for (UnsignedInteger i = 0; i < dimension; ++i)
@@ -69,7 +64,7 @@ int main(int argc, char *argv[])
     }
     --covTh;
 
-    NumericalMathFunction model(inputVariables, outputVariables, formula);
+    SymbolicFunction model(inputVariables, formula);
 
     // Create the input distribution
     Collection<Distribution> marginals(dimension);
@@ -92,10 +87,10 @@ int main(int argc, char *argv[])
     // We can choose amongst several strategies
     // First, the most efficient (but more complex!) strategy
     Collection<AdaptiveStrategy> listAdaptiveStrategy(0);
-    UnsignedInteger degree(4);
-    UnsignedInteger indexMax(enumerateFunction.getStrataCumulatedCardinal(degree));
-    UnsignedInteger basisDimension(enumerateFunction.getStrataCumulatedCardinal(degree / 2));
-    NumericalScalar threshold(1.0e-6);
+    UnsignedInteger degree = 4;
+    UnsignedInteger indexMax = enumerateFunction.getStrataCumulatedCardinal(degree);
+    UnsignedInteger basisDimension = enumerateFunction.getStrataCumulatedCardinal(degree / 2);
+    Scalar threshold = 1.0e-6;
     listAdaptiveStrategy.add(CleaningStrategy(productBasis, indexMax, basisDimension, threshold, false));
     // Second, the most used (and most basic!) strategy
     listAdaptiveStrategy.add(FixedStrategy(productBasis, enumerateFunction.getStrataCumulatedCardinal(degree)));
@@ -106,7 +101,7 @@ int main(int argc, char *argv[])
     {
       AdaptiveStrategy adaptiveStrategy(listAdaptiveStrategy[adaptiveStrategyIndex]);
       // Create the projection strategy
-      UnsignedInteger samplingSize(250);
+      UnsignedInteger samplingSize = 250;
       Collection<ProjectionStrategy> listProjectionStrategy(0);
       // The least squares strategy
       // Monte Carlo sampling
@@ -126,7 +121,7 @@ int main(int argc, char *argv[])
       {
         ProjectionStrategy projectionStrategy(listProjectionStrategy[projectionStrategyIndex]);
         // Create the polynomial chaos algorithm
-        NumericalScalar maximumResidual(1.0e-10);
+        Scalar maximumResidual = 1.0e-10;
         FunctionalChaosAlgorithm algo(model, distribution, adaptiveStrategy, projectionStrategy);
         algo.setMaximumResidual(maximumResidual);
         // Reinitialize the RandomGenerator to see the effect of the sampling method only
@@ -137,36 +132,37 @@ int main(int argc, char *argv[])
         // Examine the results
         FunctionalChaosResult result(algo.getResult());
         fullprint << "//////////////////////////////////////////////////////////////////////" << std::endl;
-        fullprint << adaptiveStrategy << std::endl;
-        fullprint << projectionStrategy << std::endl;
-        NumericalPoint residuals(result.getResiduals());
+        fullprint << algo.getAdaptiveStrategy() << std::endl;
+        fullprint << algo.getProjectionStrategy() << std::endl;
+        Point residuals(result.getResiduals());
         fullprint << "residuals=" << std::fixed << std::setprecision(5) << residuals << std::endl;
-        NumericalPoint relativeErrors(result.getRelativeErrors());
+        Point relativeErrors(result.getRelativeErrors());
         fullprint << "relative errors=" << std::fixed << std::setprecision(5) << relativeErrors << std::endl;
 
         // Post-process the results
         FunctionalChaosRandomVector vector(result);
-        NumericalScalar mean(vector.getMean()[0]);
-        fullprint << "mean=" << std::fixed << std::setprecision(5) << mean << " absolute error=" << std::scientific << std::setprecision(1) << fabs(mean - meanTh) << std::endl;
-        NumericalScalar variance(vector.getCovariance()(0, 0));
-        fullprint << "variance=" << std::fixed << std::setprecision(5) << variance << " absolute error=" << std::scientific << std::setprecision(1) << fabs(variance - covTh) << std::endl;
+        Scalar mean = vector.getMean()[0];
+        fullprint << "mean=" << std::fixed << std::setprecision(5) << mean << " absolute error=" << std::scientific << std::setprecision(1) << std::abs(mean - meanTh) << std::endl;
+        Scalar variance = vector.getCovariance()(0, 0);
+        fullprint << "variance=" << std::fixed << std::setprecision(5) << variance << " absolute error=" << std::scientific << std::setprecision(1) << std::abs(variance - covTh) << std::endl;
+        FunctionalChaosSobolIndices sensitivity(result);
         Indices indices(1);
         for(UnsignedInteger i = 0; i < dimension; ++i)
         {
           indices[0] = i;
-          NumericalScalar value(vector.getSobolIndex(i));
-          fullprint << "Sobol index " << i << " = " << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << fabs(value - sobol(indices, a) / covTh) << std::endl;
+          Scalar value = sensitivity.getSobolIndex(i);
+          fullprint << "Sobol index " << i << " = " << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << std::abs(value - sobol(indices, a) / covTh) << std::endl;
         }
         indices = Indices(2);
-        UnsignedInteger k(0);
+        UnsignedInteger k = 0;
         for (UnsignedInteger i = 0; i < dimension; ++i)
         {
           indices[0] = i;
           for (UnsignedInteger j = i + 1; j < dimension; ++j)
           {
             indices[1] = j;
-            NumericalScalar value(vector.getSobolIndex(indices));
-            fullprint << "Sobol index " << indices << " =" << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << fabs(value - sobol(indices, a) / covTh) << std::endl;
+            Scalar value = sensitivity.getSobolIndex(indices);
+            fullprint << "Sobol index " << indices << " =" << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << std::abs(value - sobol(indices, a) / covTh) << std::endl;
             k = k + 1;
           }
         }
@@ -174,8 +170,8 @@ int main(int argc, char *argv[])
         indices[0] = 0;
         indices[1] = 1;
         indices[2] = 2;
-        NumericalScalar value(vector.getSobolIndex(indices));
-        fullprint << "Sobol index " << indices << " =" << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << fabs(value - sobol(indices, a) / covTh) << std::endl;
+        Scalar value = sensitivity.getSobolIndex(indices);
+        fullprint << "Sobol index " << indices << " =" << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << std::abs(value - sobol(indices, a) / covTh) << std::endl;
       }
     }
   }
