@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_LeastSquaresMetaModelSelection_std.cxx
  *  @brief The test file of class LeastSquaresMetaModelSelection for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2010-02-04 16:44:49 +0100 (Thu, 04 Feb 2010)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -34,11 +31,11 @@ int main(int argc, char *argv[])
   //   Log::Show( Log::Flags() | Log::INFO );
 
   // Problem parameters
-  UnsignedInteger dimension(8);
+  UnsignedInteger dimension = 8;
 
   // Reference analytical values
-  NumericalScalar covTh(1.0);
-  NumericalPoint a(dimension);
+  Scalar covTh = 1.0;
+  Point a(dimension);
   a[0] = 1.0;
   a[1] = 2.0;
   a[2] = 5.0;
@@ -50,8 +47,6 @@ int main(int argc, char *argv[])
 
   // Create the gSobol function
   Description inputVariables(dimension);
-  Description outputVariables(1);
-  outputVariables[0] = "y";
   Description formula(1);
   formula[0] = "1.0";
   for (UnsignedInteger i = 0; i < dimension; ++i)
@@ -62,7 +57,7 @@ int main(int argc, char *argv[])
   }
   --covTh;
 
-  NumericalMathFunction model(inputVariables, outputVariables, formula);
+  SymbolicFunction model(inputVariables, formula);
 
   // Create the input distribution
   Collection<Distribution> marginalX(dimension);
@@ -78,15 +73,15 @@ int main(int argc, char *argv[])
   {
     polynomialCollection[i] = LegendreFactory();
   }
-  const NumericalScalar q(0.4);
+  const Scalar q = 0.4;
   HyperbolicAnisotropicEnumerateFunction enumerateFunction(dimension, q);
   OrthogonalProductPolynomialFactory productBasis(polynomialCollection, enumerateFunction);
 
   // design experiment
-  UnsignedInteger samplingSize( 100 );
+  UnsignedInteger samplingSize = 75;
 
   // build basis
-  UnsignedInteger basisSize( 917 );
+  UnsignedInteger basisSize = enumerateFunction.getStrataCumulatedCardinal(30);
 
   // run algorithm
   Collection<FittingAlgorithm> listFittingAlgorithm;
@@ -97,7 +92,7 @@ int main(int argc, char *argv[])
   {
     FixedStrategy adaptiveStrategy( productBasis, basisSize );
     FittingAlgorithm fittingAlgorithm( listFittingAlgorithm[fittingAlgorithmIndex] );
-    LeastSquaresStrategy projectionStrategy( LowDiscrepancyExperiment(SobolSequence(dimension), samplingSize), LeastSquaresMetaModelSelectionFactory ( LAR(), fittingAlgorithm) );
+    LeastSquaresStrategy projectionStrategy( LowDiscrepancyExperiment(SobolSequence(dimension), samplingSize), LeastSquaresMetaModelSelectionFactory (LARS(), fittingAlgorithm));
     FunctionalChaosAlgorithm algo(model, distribution, adaptiveStrategy, projectionStrategy);
     RandomGenerator::SetSeed(0);
     algo.run();
