@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_FunctionalChaos_ishigami.cxx
  *  @brief The test file of FunctionalChaosAlgoritm class
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2008-05-21 11:21:38 +0200 (mer. 21 mai 2008)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -37,40 +34,38 @@ int main(int argc, char *argv[])
   {
 
     // Problem parameters
-    UnsignedInteger dimension(3);
-    NumericalScalar a(7.0);
-    NumericalScalar b(0.1);
+    UnsignedInteger dimension = 3;
+    Scalar a = 7.0;
+    Scalar b = 0.1;
     // Reference analytical values
-    NumericalScalar meanTh(a / 2);
-    NumericalScalar covTh((pow(b, 2.0) * pow(M_PI, 8.0)) / 18.0 + (b * pow(M_PI, 4.0)) / 5.0 + (pow(a, 2.0)) / 8.0 + 1.0 / 2.0);
-    NumericalPoint sob_1(3);
+    Scalar meanTh = a / 2;
+    Scalar covTh = (pow(b, 2.0) * pow(M_PI, 8.0)) / 18.0 + (b * pow(M_PI, 4.0)) / 5.0 + (pow(a, 2.0)) / 8.0 + 1.0 / 2.0;
+    Point sob_1(3);
     sob_1[0] = (b * pow(M_PI, 4.0) / 5.0 + pow(b, 2.0) * pow(M_PI, 8.0) / 50.0 + 1.0 / 2.0) / covTh;
     sob_1[1] = (pow(a, 2.0) / 8.0) / covTh;
     sob_1[2] = 0.0;
-    NumericalPoint sob_2(3);
+    Point sob_2(3);
     sob_2[0] = 0.0;
     sob_2[1] = (pow(b, 2.0) * pow(M_PI, 8.0) / 18.0 - pow(b, 2.0) * pow(M_PI, 8.0) / 50.0) / covTh;
     sob_2[2] = 0.0;
-    NumericalPoint sob_3(1, 0.0);
-    NumericalPoint sob_T1(3);
+    Point sob_3(1, 0.0);
+    Point sob_T1(3);
     sob_T1[0] = sob_1[0] + sob_2[0] + sob_2[1] + sob_3[0];
     sob_T1[1] = sob_1[1] + sob_2[0] + sob_2[2] + sob_3[0];
     sob_T1[2] = sob_1[2] + sob_2[1] + sob_2[2] + sob_3[0];
-    NumericalPoint sob_T2(3);
+    Point sob_T2(3);
     sob_T2[0] = sob_2[0] + sob_3[0];
     sob_T2[1] = sob_2[1] + sob_3[0];
     sob_T2[2] = sob_2[2] + sob_3[0];
-    NumericalPoint sob_T3(sob_3);
+    Point sob_T3(sob_3);
     // Create the Ishigami function
     Description inputVariables(dimension);
     inputVariables[0] = "xi1";
     inputVariables[1] = "xi2";
     inputVariables[2] = "xi3";
-    Description outputVariables(1);
-    outputVariables[0] = "y";
     Description formula(1);
     formula[0] = (OSS() << "sin(xi1) + (" << a << ") * (sin(xi2)) ^ 2 + (" << b << ") * xi3^4 * sin(xi1)");
-    NumericalMathFunction model(inputVariables, outputVariables, formula);
+    SymbolicFunction model(inputVariables, formula);
 
     // Create the input distribution
     Collection<Distribution> marginals(dimension);
@@ -92,10 +87,10 @@ int main(int argc, char *argv[])
     // We can choose amongst several strategies
     // First, the most efficient (but more complex!) strategy
     Collection<AdaptiveStrategy> listAdaptiveStrategy(0);
-    UnsignedInteger degree(6);
-    UnsignedInteger indexMax(enumerateFunction.getStrataCumulatedCardinal(degree));
-    UnsignedInteger basisDimension(enumerateFunction.getStrataCumulatedCardinal(degree / 2));
-    NumericalScalar threshold(1.0e-6);
+    UnsignedInteger degree = 6;
+    UnsignedInteger indexMax = enumerateFunction.getStrataCumulatedCardinal(degree);
+    UnsignedInteger basisDimension = enumerateFunction.getStrataCumulatedCardinal(degree / 2);
+    Scalar threshold = 1.0e-6;
     listAdaptiveStrategy.add(CleaningStrategy(productBasis, indexMax, basisDimension, threshold, false));
     // Second, the most used (and most basic!) strategy
     listAdaptiveStrategy.add(FixedStrategy(productBasis, enumerateFunction.getStrataCumulatedCardinal(degree)));
@@ -108,7 +103,7 @@ int main(int argc, char *argv[])
     {
       AdaptiveStrategy adaptiveStrategy(listAdaptiveStrategy[adaptiveStrategyIndex]);
       // Create the projection strategy
-      UnsignedInteger samplingSize(250);
+      UnsignedInteger samplingSize = 250;
       Collection<ProjectionStrategy> listProjectionStrategy(0);
       // Monte Carlo sampling
       listProjectionStrategy.add(LeastSquaresStrategy(MonteCarloExperiment(samplingSize)));
@@ -127,7 +122,7 @@ int main(int argc, char *argv[])
       {
         ProjectionStrategy projectionStrategy(listProjectionStrategy[projectionStrategyIndex]);
         // Create the polynomial chaos algorithm
-        NumericalScalar maximumResidual(1.0e-10);
+        Scalar maximumResidual = 1.0e-10;
         FunctionalChaosAlgorithm algo(model, distribution, adaptiveStrategy, projectionStrategy);
         algo.setMaximumResidual(maximumResidual);
         // Reinitialize the RandomGenerator to see the effect of the sampling method only
@@ -137,34 +132,35 @@ int main(int argc, char *argv[])
         // Examine the results
         result = algo.getResult();
         fullprint << "//////////////////////////////////////////////////////////////////////" << std::endl;
-        fullprint << adaptiveStrategy << std::endl;
-        fullprint << projectionStrategy << std::endl;
-        NumericalPoint residuals(result.getResiduals());
+        fullprint << algo.getAdaptiveStrategy() << std::endl;
+        fullprint << algo.getProjectionStrategy() << std::endl;
+        Point residuals(result.getResiduals());
         fullprint << "residuals=" << std::fixed << std::setprecision(5) << residuals << std::endl;
-        NumericalPoint relativeErrors(result.getRelativeErrors());
+        Point relativeErrors(result.getRelativeErrors());
         fullprint << "relative errors=" << std::fixed << std::setprecision(5) << relativeErrors << std::endl;
 
         // Post-process the results
         FunctionalChaosRandomVector vector(result);
-        NumericalScalar mean(vector.getMean()[0]);
-        fullprint << "mean=" << std::fixed << std::setprecision(5) << mean << " absolute error=" << std::scientific << std::setprecision(1) << fabs(mean - meanTh) << std::endl;
-        NumericalScalar variance(vector.getCovariance()(0, 0));
-        fullprint << "variance=" << std::fixed << std::setprecision(5) << variance << " absolute error=" << std::scientific << std::setprecision(1) << fabs(variance - covTh) << std::endl;
+        Scalar mean = vector.getMean()[0];
+        fullprint << "mean=" << std::fixed << std::setprecision(5) << mean << " absolute error=" << std::scientific << std::setprecision(1) << std::abs(mean - meanTh) << std::endl;
+        Scalar variance = vector.getCovariance()(0, 0);
+        fullprint << "variance=" << std::fixed << std::setprecision(5) << variance << " absolute error=" << std::scientific << std::setprecision(1) << std::abs(variance - covTh) << std::endl;
+        FunctionalChaosSobolIndices sensitivity(result);
         for(UnsignedInteger i = 0; i < dimension; ++i)
         {
-          NumericalScalar value(vector.getSobolIndex(i));
-          fullprint << "Sobol index " << i << " = " << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << fabs(value - sob_1[i]) << std::endl;
+          Scalar value = sensitivity.getSobolIndex(i);
+          fullprint << "Sobol index " << i << " = " << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << std::abs(value - sob_1[i]) << std::endl;
         }
         Indices indices(2);
-        UnsignedInteger k(0);
+        UnsignedInteger k = 0;
         for (UnsignedInteger i = 0; i < dimension; ++i)
         {
           indices[0] = i;
           for (UnsignedInteger j = i + 1; j < dimension; ++j)
           {
             indices[1] = j;
-            NumericalScalar value(vector.getSobolIndex(indices));
-            fullprint << "Sobol index " << indices << " =" << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << fabs(value - sob_2[k]) << std::endl;
+            Scalar value = sensitivity.getSobolIndex(indices);
+            fullprint << "Sobol index " << indices << " =" << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << std::abs(value - sob_2[k]) << std::endl;
             k = k + 1;
           }
         }
@@ -172,12 +168,12 @@ int main(int argc, char *argv[])
         indices[0] = 0;
         indices[1] = 1;
         indices[2] = 2;
-        NumericalScalar value(vector.getSobolIndex(indices));
-        fullprint << "Sobol index " << indices << " =" << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << fabs(value - sob_3[0]) << std::endl;
+        Scalar value = sensitivity.getSobolIndex(indices);
+        fullprint << "Sobol index " << indices << " =" << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << std::abs(value - sob_3[0]) << std::endl;
         for (UnsignedInteger i = 0; i < dimension; ++i)
         {
-          NumericalScalar value(vector.getSobolTotalIndex(i));
-          fullprint << "Sobol total index " << i << " =" << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << fabs(value - sob_T1[i]) << std::endl;
+          Scalar value = sensitivity.getSobolTotalIndex(i);
+          fullprint << "Sobol total index " << i << " =" << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << std::abs(value - sob_T1[i]) << std::endl;
         }
         indices = Indices(2);
         k = 0;
@@ -187,8 +183,8 @@ int main(int argc, char *argv[])
           for (UnsignedInteger j = i + 1; j < dimension; ++j)
           {
             indices[1] = j;
-            NumericalScalar value(vector.getSobolTotalIndex(indices));
-            fullprint << "Sobol total index " << indices << " =" << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << fabs(value - sob_T2[k]) << std::endl;
+            Scalar value = sensitivity.getSobolTotalIndex(indices);
+            fullprint << "Sobol total index " << indices << " =" << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << std::abs(value - sob_T2[k]) << std::endl;
             k = k + 1;
           }
         }
@@ -196,8 +192,8 @@ int main(int argc, char *argv[])
         indices[0] = 0;
         indices[1] = 1;
         indices[2] = 2;
-        value = vector.getSobolTotalIndex(indices);
-        fullprint << "Sobol total index " << indices << " =" << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << fabs(value - sob_T3[0]) << std::endl;
+        value = sensitivity.getSobolTotalIndex(indices);
+        fullprint << "Sobol total index " << indices << " =" << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << std::abs(value - sob_T3[0]) << std::endl;
 
       }
     }
