@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_GaussProductExperiment_std.cxx
  *  @brief The test file of class GaussProductExperiment for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2008-05-21 17:44:02 +0200 (mer, 21 mai 2008)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -41,10 +38,15 @@ int main(int argc, char *argv[])
     Indices marginalDegrees(0);
     marginalDegrees.add(3);
     marginalDegrees.add(6);
+    // Test the constructor based on marginal degrees
+    fullprint << "experiment1=" << GaussProductExperiment(marginalDegrees) << std::endl;
+    // Test the constructor based on distribution
+    fullprint << "experiment2=" << GaussProductExperiment(distribution) << std::endl;
+    // Test the constructor based on marginal degrees and distribution
     GaussProductExperiment myPlane(distribution, marginalDegrees);
     fullprint << "myPlane = " << myPlane << std::endl;
-    NumericalPoint weights(0);
-    NumericalSample sample(myPlane.generateWithWeights(weights));
+    Point weights(0);
+    Sample sample(myPlane.generateWithWeights(weights));
     fullprint << "sample = " << sample << std::endl;
     fullprint << "weights = " << weights << std::endl;
   }
