@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_Graph_export.cxx
  *  @brief The test file of Graph class for EDF case number 1
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -34,13 +31,13 @@ int main(int argc, char *argv[])
 
   try
   {
-    UnsignedInteger maxPoint(101);
-    NumericalScalar xMin(-2.0 * M_PI);
-    NumericalScalar xMax(2.0 * M_PI);
-    NumericalSample data(maxPoint, 2);
+    UnsignedInteger maxPoint = 101;
+    Scalar xMin = -2.0 * M_PI;
+    Scalar xMax = 2.0 * M_PI;
+    Sample data(maxPoint, 2);
     for (UnsignedInteger i = 0; i < maxPoint; ++i)
     {
-      NumericalScalar x(xMin + (xMax - xMin) * i / (maxPoint - 1.0));
+      Scalar x = xMin + (xMax - xMin) * i / (maxPoint - 1.0);
       data[i][0] = x;
       data[i][1] = sin(x);
     }
