@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_Graph_mix.cxx
  *  @brief The test file of Graph class for EDF case number 9
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -37,11 +34,11 @@ int main(int argc, char *argv[])
   {
 
     // Instanciate one distribution object
-    UnsignedInteger dim(2);
-    NumericalPoint meanPoint(dim, 1.0);
+    UnsignedInteger dim = 2;
+    Point meanPoint(dim, 1.0);
     meanPoint[0] = 12.0;
     meanPoint[1] = 5.0;
-    NumericalPoint sigma(dim, 1.0);
+    Point sigma(dim, 1.0);
     sigma[0] = 3.0;
     sigma[1] = 1.0;
     CorrelationMatrix R = IdentityMatrix(dim);
@@ -55,8 +52,8 @@ int main(int argc, char *argv[])
 
     // Test for sampling
     UnsignedInteger size = 200;
-    NumericalSample sample(distribution.getSample( size ));
-    NumericalSample tmp(2, NumericalPoint(2));
+    Sample sample(distribution.getSample( size ));
+    Sample tmp(2, Point(2));
     tmp[0][0] = sample.getMin()[0];
     tmp[0][1] = meanPoint[1] - sigma[1] / sigma[0] * (meanPoint[0] - tmp[0][0]);
     tmp[1][0] = sample.getMax()[0];
@@ -68,7 +65,7 @@ int main(int argc, char *argv[])
     // Create the line
     Curve myLine(tmp, "red", "solid", 2, "Line");
 
-    NumericalPoint data(0);
+    Point data(0);
     Description palette;
     Description labels;
 
@@ -116,7 +113,7 @@ int main(int argc, char *argv[])
     labels.add("cumul candidats < 3.5% ");
     palette.add("purple");
 
-    NumericalPoint centre(2);
+    Point centre(2);
     centre[0] = 7.0;
     centre[1] = 10.0;
     // Create the piechart
@@ -132,7 +129,7 @@ int main(int argc, char *argv[])
     myGraph.add(myCloud);
     myGraph.add(myLine);
     myGraph.add(myPie);
-    myGraph.draw("Graph_mix_OT", 640, 480);
+    myGraph.draw("Graph_mix_OT.png");
 
 
     // Test if a drawable can be extracted from a graph to be added to another graph
@@ -142,7 +139,7 @@ int main(int argc, char *argv[])
     secondGraph.add(myLine);
     // Extract the drawable from the second graph and add it to the first graph
     firstGraph.add(secondGraph.getDrawables()[0]);
-    firstGraph.draw("OverallGraph");
+    firstGraph.draw("OverallGraph.png");
 
   }
   catch (TestFailed & ex)
