@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_HaselgroveSequence_std.cxx
  *  @brief Implementation of the Haselgrove' sequence
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2008-05-23 13:46:12 +0200 (ven, 23 mai 2008)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -39,24 +36,24 @@ int main(int argc, char *argv[])
     fullprint << sequence << std::endl;
 
     // Create a numerical sample of the sequence
-    NumericalSample haselgroveSample(sequence.generate(10));
+    Sample haselgroveSample(sequence.generate(10));
     fullprint << haselgroveSample << std::endl;
 
     // Create another Haselgrove' sequence of dimension 2 to estimate Pi in [0; 1)^2
-    UnsignedInteger dimension(2);
+    UnsignedInteger dimension = 2;
     sequence = HaselgroveSequence(dimension);
-    UnsignedInteger pointInsideCircle(0);
-    UnsignedInteger sampleSize(1000);
+    UnsignedInteger pointInsideCircle = 0;
+    UnsignedInteger sampleSize = 1000;
     for(UnsignedInteger i = 0; i < sampleSize; ++i)
     {
-      NumericalPoint haselgrovePoint(sequence.generate());
+      Point haselgrovePoint(sequence.generate());
       fullprint << haselgrovePoint << std::endl;
       if(haselgrovePoint.norm() < 1.0)
         ++ pointInsideCircle;
     }
-    NumericalScalar probabilityEstimate(1.0 * pointInsideCircle / sampleSize);
-    NumericalScalar probability(M_PI / 4.0);
-    NumericalScalar relativeError(fabs(probability - probabilityEstimate) / probability);
+    Scalar probabilityEstimate = 1.0 * pointInsideCircle / sampleSize;
+    Scalar probability = M_PI / 4.0;
+    Scalar relativeError = std::abs(probability - probabilityEstimate) / probability;
     fullprint << "sample size=" << sampleSize << std::endl;
     fullprint << "relative error to Pi=" << relativeError << std::endl;
   }
