@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_HermitianMatrix_std.cxx
  *  @brief The test file of class HermitianMatrix for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,19 +14,17 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
 
-typedef Collection<NumericalComplex> NumericalComplexCollection;
+typedef Collection<Complex> ComplexCollection;
 
 int main(int argc, char *argv[])
 {
@@ -55,7 +52,7 @@ int main(int argc, char *argv[])
 
     /* Check operator() methods */
     hermitianMatrix1(0, 0) = 1.0 ;
-    hermitianMatrix1(1, 0) = NumericalComplex(3.0, -1.0) ;
+    hermitianMatrix1(1, 0) = Complex(3.0, -1.0) ;
     hermitianMatrix1(1, 1) = 4.0 ;
 
     /* String converter */
@@ -107,17 +104,17 @@ int main(int argc, char *argv[])
     fullprint << "sum1 equals sum2 = " << (sum1 == sum2) << std::endl;
 
 
-    /** SUBSTRACTION METHOD */
-    fullprint << "test 7 : substraction method" << std::endl;
+    /** SUBTRACTION METHOD */
+    fullprint << "test 7 : subtraction method" << std::endl;
 
-    /* Check substraction method */
+    /* Check subtraction method */
     HermitianMatrix diff1 = hermitianMatrix1.operator - ( hermitianMatrix4 ) ;
     fullprint << "diff1 = " << diff1 << std::endl;
     SquareComplexMatrix mat(2);
-    mat(0, 0) = NumericalComplex(1.0, 2.0);
-    mat(0, 1) = NumericalComplex(3.0, 4.0);
-    mat(1, 0) = NumericalComplex(5.0, 6.0);
-    mat(1, 1) = NumericalComplex(7.0, 8.0);
+    mat(0, 0) = Complex(1.0, 2.0);
+    mat(0, 1) = Complex(3.0, 4.0);
+    mat(1, 0) = Complex(5.0, 6.0);
+    mat(1, 1) = Complex(7.0, 8.0);
     SquareComplexMatrix diff2 = hermitianMatrix1.operator - ( mat ) ;
     fullprint << "diff2 = " << diff2 << std::endl;
     SquareComplexMatrix diff3 = mat.operator - (hermitianMatrix1) ;
@@ -134,20 +131,20 @@ int main(int argc, char *argv[])
     fullprint << "test 9 : multiplication with a numerical point method" << std::endl;
 
     /* Create the numerical point */
-    NumericalPoint pt ;
+    Point pt ;
     pt.add(1.) ;
     pt.add(2.) ;
     fullprint << "pt = " << pt << std::endl;
 
     /* Check the product method */
-    NumericalComplexCollection ptResult = hermitianMatrix1.operator * ( pt )  ;
+    ComplexCollection ptResult = hermitianMatrix1.operator * ( pt )  ;
     fullprint << "ptResult = " << ptResult << std::endl;
 
     /** MULTIPLICATION AND DIVISION BY A NUMERICAL SCALAR METHODS */
     fullprint << "test 10 : multiplication and division by a numerical scalar methods" << std::endl;
 
     /* Check the multiplication method */
-    NumericalComplex s(3.0, 2.0);
+    Complex s(3.0, 2.0);
     HermitianMatrix scalprod1 = hermitianMatrix1.operator * (s) ;
     HermitianMatrix scalprod2 = s * hermitianMatrix1 ;
     fullprint << "scalprod1 = " << scalprod1 << std::endl;
