@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_HistogramFactory_std.cxx
  *  @brief The test file of class Histogram for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2010-02-04 16:44:49 +0100 (jeu. 04 févr. 2010)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -35,26 +32,51 @@ int main(int argc, char *argv[])
 
   try
   {
-    UnsignedInteger collectionSize(4);
-    Histogram::HistogramPairCollection collection(collectionSize);
-    collection[0] = HistogramPair(1.0, 0.5);
-    collection[1] = HistogramPair(0.7, 1.5);
-    collection[2] = HistogramPair(1.2, 3.5);
-    collection[3] = HistogramPair(0.9, 2.5);
-    Histogram distribution(-1.5, collection);
-    UnsignedInteger size(10000);
-    NumericalSample sample(distribution.getSample(size));
+    UnsignedInteger collectionSize = 4;
+    Point l(collectionSize);
+    l[0] = 1.0;
+    l[1] = 0.7;
+    l[2] = 1.2;
+    l[3] = 0.9;
+    Point h(collectionSize);
+    h[0] = 0.5;
+    h[1] = 1.5;
+    h[2] = 3.5;
+    h[3] = 2.5;
+    Histogram distribution(-1.5, l, h);
+    UnsignedInteger size = 10000;
+    Sample sample(distribution.getSample(size));
     HistogramFactory factory;
     Distribution estimatedDistribution(factory.build(sample));
     fullprint << "Distribution          =" << distribution << std::endl;
     fullprint << "Estimated distribution=" << estimatedDistribution << std::endl;
     estimatedDistribution = factory.build();
     fullprint << "Default distribution=" << estimatedDistribution << std::endl;
-    Histogram estimatedHistogram(factory.buildAsHistogram(sample));
-    fullprint << "Histogram          =" << distribution << std::endl;
-    fullprint << "Estimated histogram=" << estimatedHistogram << std::endl;
-    estimatedHistogram = factory.buildAsHistogram();
+    fullprint << "Silverman bandwidth=" << factory.computeSilvermanBandwidth(sample) << std::endl;
+    {
+      Histogram estimatedHistogram(factory.buildAsHistogram(sample));
+      fullprint << "Histogram          =" << distribution << std::endl;
+      fullprint << "Estimated histogram=" << estimatedHistogram << std::endl;
+    }
+    {
+      Histogram estimatedHistogram(factory.buildAsHistogram(sample, 0.1));
+      fullprint << "Histogram          =" << distribution << std::endl;
+      fullprint << "Estimated histogram=" << estimatedHistogram << std::endl;
+    }
+    {
+      Histogram estimatedHistogram(factory.buildAsHistogram(sample, UnsignedInteger(15)));
+      fullprint << "Histogram          =" << distribution << std::endl;
+      fullprint << "Estimated histogram=" << estimatedHistogram << std::endl;
+    }
+    Histogram estimatedHistogram(factory.buildAsHistogram());
     fullprint << "Default histogram=" << estimatedHistogram << std::endl;
+    // Test for constant sample
+    sample = Sample(size, Point(1, 0.0));
+    estimatedDistribution = factory.build(sample);
+    fullprint << "Estimated distribution=" << estimatedDistribution << std::endl;
+    sample = Sample(size, Point(1, 1.0));
+    estimatedDistribution = factory.build(sample);
+    fullprint << "Estimated distribution=" << estimatedDistribution << std::endl;
   }
   catch (TestFailed & ex)
   {
