@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_HistoryStrategy_std.cxx
  *  @brief The test file of class HistoryStrategy for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -34,15 +31,15 @@ int main(int argc, char *argv[])
 
   try
   {
-    UnsignedInteger size(10);
-    UnsignedInteger dimension(2);
-    NumericalSample sample(size, dimension);
+    UnsignedInteger size = 10;
+    UnsignedInteger dimension = 2;
+    Sample sample(size, dimension);
     // Fill-in the sample
     for (UnsignedInteger i = 0; i < size; ++i)
     {
       for (UnsignedInteger j = 0; j < dimension; ++j)
       {
-        sample[i][j] = i + NumericalScalar(j) / dimension;
+        sample[i][j] = i + Scalar(j) / dimension;
       }
     }
     fullprint << "sample=" << sample << std::endl;
@@ -55,6 +52,7 @@ int main(int argc, char *argv[])
     fullprint << "Null strategy sample=" << nullStrategy.getSample() << std::endl;
     // History using the Full strategy
     Full fullStrategy;
+    fullStrategy.setDimension(dimension);
     for (UnsignedInteger i = 0; i < size; ++i)
     {
       fullStrategy.store(sample[i]);
@@ -62,12 +60,14 @@ int main(int argc, char *argv[])
     fullprint << "Full strategy sample=" << fullStrategy.getSample() << std::endl;
     // History using the Last strategy, large storage
     Last lastStrategy(3 * size);
+    lastStrategy.setDimension(dimension);
     for (UnsignedInteger i = 0; i < size; ++i)
     {
       lastStrategy.store(sample[i]);
     }
     fullprint << "Last strategy sample (large storage)=" << lastStrategy.getSample() << std::endl;
     lastStrategy = Last(size / 3);
+    lastStrategy.setDimension(dimension);
     // History using the Last strategy, small storage
     for (UnsignedInteger i = 0; i < size; ++i)
     {
@@ -76,12 +76,14 @@ int main(int argc, char *argv[])
     fullprint << "Last strategy sample (small storage)=" << lastStrategy.getSample() << std::endl;
     // History using the Compact strategy, large storage
     Compact compactStrategy(3 * size);
+    compactStrategy.setDimension(dimension);
     for (UnsignedInteger i = 0; i < size; ++i)
     {
       compactStrategy.store(sample[i]);
     }
     fullprint << "Compact strategy sample (large storage)=" << compactStrategy.getSample() << std::endl;
     compactStrategy = Compact(size / 3);
+    compactStrategy.setDimension(dimension);
     // History using the Compact strategy, small storage
     for (UnsignedInteger i = 0; i < size; ++i)
     {
