@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_HyperbolicAnisotropicEnumerateFunction_std.cxx
  *  @brief The test file of class HyperbolicAnisotropicEnumerateFunction for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2008-05-21 17:44:02 +0200 (mer, 21 mai 2008)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -35,7 +32,7 @@ int main(int argc, char *argv[])
   try
   {
 
-    fullprint << "Default q : " << ResourceMap::GetAsNumericalScalar("HyperbolicAnisotropicEnumerateFunction-DefaultQ") << std::endl << std::endl;
+    fullprint << "Default q : " << ResourceMap::GetAsScalar("HyperbolicAnisotropicEnumerateFunction-DefaultQ") << std::endl << std::endl;
 
     // first verify consistency with LinearEnumerateFunction
     UnsignedInteger size = 10;
@@ -61,7 +58,7 @@ int main(int argc, char *argv[])
 
     // values with varying q
     size = 25;
-    NumericalPoint qValues;
+    Point qValues;
     qValues.add(0.75);
     qValues.add(0.5);
     qValues.add(0.25);
@@ -70,7 +67,7 @@ int main(int argc, char *argv[])
     {
       for (UnsignedInteger j = 0; j < qValues.getDimension(); ++ j)
       {
-        NumericalScalar q(qValues[j]);
+        Scalar q = qValues[j];
         fullprint << "First " << size << " values dimension=" << dimension << " q=" << q << std::endl;
         HyperbolicAnisotropicEnumerateFunction f( dimension,  q);
         for (UnsignedInteger index = 0; index < size; ++index)
