@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_IdentityMatrix_std.cxx
  *  @brief The test file for the IdentityMatrix class
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,20 +33,20 @@ int main(int argc, char *argv[])
   matrix1.setName("matrix1");
   fullprint << "matrix1 = " << matrix1 << std::endl;
 
-  NumericalPoint pt ;
+  Point pt ;
   pt.add(5.) ;
   pt.add(0.) ;
   fullprint << "pt = " << pt << std::endl;
 
-  NumericalPoint result ;
+  Point result ;
   result = matrix1.solveLinearSystem(pt);
   fullprint << "result = " << result << std::endl;
 
-  NumericalScalar determinant ;
+  Scalar determinant ;
   determinant = matrix1.computeDeterminant();
   fullprint << "determinant = " << determinant << std::endl;
 
-  Collection<NumericalScalar> ev(2);
+  Collection<Scalar> ev(2);
   ev = matrix1.computeEigenValues().getCollection();
   fullprint << "ev = " << ev << std::endl;
 
