@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_IndependentCopula_std.cxx
  *  @brief The test file of class IndependentCopula for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -47,7 +44,7 @@ int main(int argc, char *argv[])
     //    checkClassWithClassName<TestObject>();
 
     // Instanciate one distribution object
-    UnsignedInteger dim(3);
+    UnsignedInteger dim = 3;
     IndependentCopula copula(dim);
     fullprint << "Copula " << copula << std::endl;
     std::cout << "Copula " << copula << std::endl;
@@ -65,40 +62,63 @@ int main(int argc, char *argv[])
     fullprint << "Independent = " << (copula.hasIndependentCopula() ? "true" : "false") << std::endl;
 
     // Test for realization of copula
-    NumericalPoint oneRealization = copula.getRealization();
+    Point oneRealization = copula.getRealization();
     fullprint << "oneRealization=" << oneRealization << std::endl;
 
     // Test for sampling
     UnsignedInteger size = 10000;
-    NumericalSample oneSample = copula.getSample( size );
+    Sample oneSample = copula.getSample( size );
     fullprint << "oneSample first=" << oneSample[0] << " last=" << oneSample[size - 1] << std::endl;
     fullprint << "mean=" << oneSample.computeMean() << std::endl;
     fullprint << "covariance=" << oneSample.computeCovariance() << std::endl;
 
     // Define a point
-    NumericalPoint point( copula.getDimension(), 0.6 );
+    Point point( copula.getDimension(), 0.6 );
     fullprint << "Point= " << point << std::endl;
 
     // Show DDF, PDF and CDF of point
-    NumericalPoint  pointDDF = copula.computeDDF( point );
-    NumericalScalar pointPDF = copula.computePDF( point );
-    NumericalScalar pointCDF = copula.computeCDF( point );
+    Point  pointDDF = copula.computeDDF( point );
+    Scalar pointPDF = copula.computePDF( point );
+    Scalar pointCDF = copula.computeCDF( point );
     fullprint << "point= " << point
               << " ddf=" << pointDDF
               << " ddf (FD)=" << copula.ContinuousDistribution::computeDDF(point)
               << " pdf=" << pointPDF
               << " cdf=" << pointCDF
               << std::endl;
-    NumericalPoint PDFgr = copula.computePDFGradient( point );
+    Scalar Survival = copula.computeSurvivalFunction(point);
+    fullprint << "Survival      =" << Survival << std::endl;
+    fullprint << "Survival (ref)=" << copula.computeSurvivalFunction(point) << std::endl;
+    Point InverseSurvival = copula.computeInverseSurvivalFunction(0.95);
+    fullprint << "Inverse survival=" << InverseSurvival << std::endl;
+    fullprint << "Survival(inverse survival)=" << copula.computeSurvivalFunction(InverseSurvival) << std::endl;
+    // Get 50% quantile
+    Point quantile = copula.computeQuantile( 0.5 );
+    fullprint << "Quantile=" << quantile << std::endl;
+    fullprint << "CDF(quantile)=" << copula.computeCDF(quantile) << std::endl;
+
+    // Confidence regions
+    Scalar threshold;
+    fullprint << "Minimum volume interval=" << copula.computeMinimumVolumeIntervalWithMarginalProbability(0.95, threshold) << std::endl;
+    fullprint << "threshold=" << threshold << std::endl;
+    Scalar beta;
+    LevelSet levelSet(copula.computeMinimumVolumeLevelSetWithThreshold(0.95, beta));
+    fullprint << "Minimum volume level set=" << levelSet << std::endl;
+    fullprint << "beta=" << beta << std::endl;
+    fullprint << "Bilateral confidence interval=" << copula.computeBilateralConfidenceIntervalWithMarginalProbability(0.95, beta) << std::endl;
+    fullprint << "beta=" << beta << std::endl;
+    fullprint << "Unilateral confidence interval (lower tail)=" << copula.computeUnilateralConfidenceIntervalWithMarginalProbability(0.95, false, beta) << std::endl;
+    fullprint << "beta=" << beta << std::endl;
+    fullprint << "Unilateral confidence interval (upper tail)=" << copula.computeUnilateralConfidenceIntervalWithMarginalProbability(0.95, true, beta) << std::endl;
+    fullprint << "beta=" << beta << std::endl;
+
+    Point PDFgr = copula.computePDFGradient( point );
     fullprint << "pdf gradient     =" << PDFgr << std::endl;
-    NumericalPoint CDFgr = copula.computeCDFGradient( point );
+    Point CDFgr = copula.computeCDFGradient( point );
     fullprint << "cdf gradient     =" << CDFgr << std::endl;
-    NumericalPoint quantile = copula.computeQuantile( 0.95 );
-    fullprint << "quantile=" << quantile << std::endl;
-    fullprint << "cdf(quantile)=" << copula.computeCDF(quantile) << std::endl;
-    NumericalPoint mean = copula.getMean();
+    Point mean = copula.getMean();
     fullprint << "mean=" << mean << std::endl;
-    IndependentCopula::NumericalPointWithDescriptionCollection parameters = copula.getParametersCollection();
+    IndependentCopula::PointWithDescriptionCollection parameters = copula.getParametersCollection();
     fullprint << "parameters=" << parameters << std::endl;
     // Covariance and correlation
     CovarianceMatrix covariance = copula.getCovariance();
@@ -114,8 +134,8 @@ int main(int argc, char *argv[])
     {
       Copula margin(copula.getMarginal(i));
       fullprint << "margin=" << margin << std::endl;
-      fullprint << "margin PDF=" << margin.computePDF(NumericalPoint(1, 0.25)) << std::endl;
-      fullprint << "margin CDF=" << margin.computeCDF(NumericalPoint(1, 0.25)) << std::endl;
+      fullprint << "margin PDF=" << margin.computePDF(Point(1, 0.25)) << std::endl;
+      fullprint << "margin CDF=" << margin.computeCDF(Point(1, 0.25)) << std::endl;
       fullprint << "margin quantile=" << margin.computeQuantile(0.95) << std::endl;
       fullprint << "margin realization=" << margin.getRealization() << std::endl;
     }
@@ -127,8 +147,8 @@ int main(int argc, char *argv[])
     fullprint << "indices=" << indices << std::endl;
     Copula margins(copula.getMarginal(indices));
     fullprint << "margins=" << margins << std::endl;
-    fullprint << "margins PDF=" << margins.computePDF(NumericalPoint(2, 0.25)) << std::endl;
-    fullprint << "margins CDF=" << margins.computeCDF(NumericalPoint(2, 0.25)) << std::endl;
+    fullprint << "margins PDF=" << margins.computePDF(Point(2, 0.25)) << std::endl;
+    fullprint << "margins CDF=" << margins.computeCDF(Point(2, 0.25)) << std::endl;
     quantile = margins.computeQuantile(0.95);
     fullprint << "margins quantile=" << quantile << std::endl;
     fullprint << "margins CDF(quantile)=" << margins.computeCDF(quantile) << std::endl;
