@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_InverseBoxCoxTransform_std.cxx
  *  @brief The test file of class InverseBoxCoxTransform for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,24 +33,24 @@ int main(int argc, char *argv[])
   try
   {
     // Realization issued from a Normal distribution
-    const UnsignedInteger dimension(1);
+    const UnsignedInteger dimension = 1;
 
     // Fix the realization as a Normal
     // Parameters are done such as the values are positive
     Uniform myDistribution(-1, 1);
 
     // get a realization
-    const UnsignedInteger n(51);
-    const NumericalScalar timeStart(0.);
-    const NumericalScalar timeStep(0.1);
-    NumericalSample mySample(myDistribution.getSample(n));
+    const UnsignedInteger n = 51;
+    const Scalar timeStart = 0.;
+    const Scalar timeStep = 0.1;
+    Sample mySample(myDistribution.getSample(n));
     RegularGrid myTimeGrid(timeStart, timeStep, n);
 
     /* Create a TimeSeries */
     const TimeSeries myRealization(myTimeGrid, mySample);
 
     // Create the lambda parameter
-    NumericalPoint lambda(dimension);
+    Point lambda(dimension);
     for (UnsignedInteger index = 0 ; index < dimension; ++index)
     {
       lambda[index] = (index + 2) * 0.1;
