@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_InverseNatafIndependentCopulaGradient_std.cxx
  *  @brief The test file of class InverseNatafIndependentCopulaGradient for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -35,10 +32,10 @@ int main(int argc, char *argv[])
 
   try
   {
-    UnsignedInteger dim(2);
+    UnsignedInteger dim = 2;
     InverseNatafIndependentCopulaGradient transformation(dim);
     fullprint << "transformation=" << transformation << std::endl;
-    NumericalPoint point(dim, 0.75);
+    Point point(dim, 0.75);
     fullprint << "transformation(" << point << ")=" << transformation.gradient(point) << std::endl;
     fullprint << "input dimension=" << transformation.getInputDimension() << std::endl;
     fullprint << "output dimension=" << transformation.getOutputDimension() << std::endl;
