@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_InverseNormalFactory_std.cxx
  *  @brief The test file of class InverseNormal for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2011-04-11 12:32:27 +0200 (lun. 11 avril 2011)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,8 +33,8 @@ int main(int argc, char *argv[])
   try
   {
     InverseNormal distribution(2.5, 1.5);
-    UnsignedInteger size(10000);
-    NumericalSample sample(distribution.getSample(size));
+    UnsignedInteger size = 10000;
+    Sample sample(distribution.getSample(size));
     InverseNormalFactory factory;
     CovarianceMatrix covariance;
     // Distribution estimatedDistribution(factory.build(sample, covariance));
@@ -52,14 +49,14 @@ int main(int argc, char *argv[])
     // fullprint << "Covariance=" << covariance << std::endl;
     estimatedDistribution = factory.build();
     fullprint << "Default distribution=" << estimatedDistribution << std::endl;
-    estimatedDistribution = factory.build(distribution.getParametersCollection());
+    estimatedDistribution = factory.build(distribution.getParameter());
     fullprint << "Distribution from parameters=" << estimatedDistribution << std::endl;
     InverseNormal estimatedInverseNormal(factory.buildAsInverseNormal(sample));
     fullprint << "InverseNormal          =" << distribution << std::endl;
     fullprint << "Estimated inverseNormal=" << estimatedInverseNormal << std::endl;
     estimatedInverseNormal = factory.buildAsInverseNormal();
     fullprint << "Default inverseNormal=" << estimatedInverseNormal << std::endl;
-    estimatedInverseNormal = factory.buildAsInverseNormal(distribution.getParametersCollection());
+    estimatedInverseNormal = factory.buildAsInverseNormal(distribution.getParameter());
     fullprint << "InverseNormal from parameters=" << estimatedInverseNormal << std::endl;
   }
   catch (TestFailed & ex)
