@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_InverseTrendTransform_std.cxx
  *  @brief The test file of class InverseTrendTransform for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author lebrun
- *  @date   2011-12-19 23:37:21 +0100 (lun. 19 déc. 2011)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -42,7 +39,7 @@ int main(int argc, char *argv[])
     Description formula;
     formula.add("sin(t)");
     formula.add("cos(t)");
-    NumericalMathFunction myFunc(inputVars, formula);
+    SymbolicFunction myFunc(inputVars, formula);
     InverseTrendTransform myInverseTrendFunc(myFunc);
 
     fullprint << "myInverseTrendFunc=" << myInverseTrendFunc << std::endl;
@@ -54,10 +51,10 @@ int main(int argc, char *argv[])
 
     /* Create a TimeSeries */
     RegularGrid tg(0.0, 0.1, 11);
-    NumericalSample data(tg.getN(), 2);
+    Sample data(tg.getN(), 2);
     for (UnsignedInteger i = 0; i < data.getSize(); ++i)
     {
-      const NumericalScalar instant(tg.getStart() + i * tg.getStep());
+      const Scalar instant = tg.getStart() + i * tg.getStep();
       data(i, 0) = i + 1 + sin(instant);
       data(i, 1) = i + cos(instant);
     }
