@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_IsoProbabilisticTransformation_EllipticalCopula.cxx
  *  @brief The test file of class IsoProbabilisticTransformation for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -32,15 +29,15 @@ typedef Distribution::InverseIsoProbabilisticTransformation InverseIsoProbabilis
 
 SymmetricTensor clean(SymmetricTensor in)
 {
-  UnsignedInteger rowDim(in.getNbRows());
-  UnsignedInteger colDim(in.getNbColumns());
-  UnsignedInteger sheetDim(in.getNbSheets());
+  UnsignedInteger rowDim = in.getNbRows();
+  UnsignedInteger colDim = in.getNbColumns();
+  UnsignedInteger sheetDim = in.getNbSheets();
   for(UnsignedInteger i = 0; i < rowDim; i++)
     for(UnsignedInteger j = 0; j < colDim; j++)
       for (UnsignedInteger k = 0; k < sheetDim; k++)
       {
         in(i, j, k) = 1.e-4 * round(1.e4 * in(i, j, k));
-        if (fabs(in(i, j, k)) < 1.e-4) in(i, j, k) = 0.0;
+        if (std::abs(in(i, j, k)) < 1.e-4) in(i, j, k) = 0.0;
       }
   return in;
 }
@@ -59,7 +56,7 @@ int main(int argc, char *argv[])
     aCollection.add(Uniform(-1.0, 2.0));
     aCollection.add(Gamma(2.0, 2.0, 0.0));
 
-    UnsignedInteger dim(aCollection.getSize());
+    UnsignedInteger dim = aCollection.getSize();
 
     // Create a copula
     CorrelationMatrix RCopula(dim);
@@ -73,7 +70,7 @@ int main(int argc, char *argv[])
     ComposedDistribution distribution(aCollection, NormalCopula(RCopula));
     // Test for sampling
     UnsignedInteger size = 10000;
-    NumericalSample sample = distribution.getSample( size );
+    Sample sample = distribution.getSample( size );
     fullprint << "sample first=" << sample[0] << " last=" << sample[size - 1] << std::endl;
     // Should be close to [0.5, 1, 0.544439]
     fullprint << "sample mean=" << sample.computeMean() << std::endl;
@@ -82,7 +79,7 @@ int main(int argc, char *argv[])
 
     IsoProbabilisticTransformation transform(distribution.getIsoProbabilisticTransformation());
     fullprint << "isoprobabilistic transformation=" << transform << std::endl;
-    NumericalSample transformedSample(transform(sample));
+    Sample transformedSample(transform(sample));
     fullprint << "transformed sample first=" << transformedSample[0] << " last=" << transformedSample[size - 1] << std::endl;
     fullprint << "transformed sample mean=" << transformedSample.computeMean() << std::endl;
     fullprint << "transformed sample covariance=" << transformedSample.computeCovariance() << std::endl;
@@ -90,32 +87,32 @@ int main(int argc, char *argv[])
     // Test for evaluation
     InverseIsoProbabilisticTransformation inverseTransform(distribution.getInverseIsoProbabilisticTransformation());
     fullprint << "inverse isoprobabilistic transformation=" << inverseTransform << std::endl;
-    NumericalSample transformedBackSample(inverseTransform(transformedSample));
+    Sample transformedBackSample(inverseTransform(transformedSample));
     fullprint << "transformed back sample first=" << transformedBackSample[0] << " last=" << transformedBackSample[size - 1] << std::endl;
     fullprint << "transformed back sample mean=" << transformedBackSample.computeMean() << std::endl;
     fullprint << "transformed back sample covariance=" << transformedBackSample.computeCovariance() << std::endl;
-    NumericalPoint point(dim, 0.75);
+    Point point(dim, 0.75);
     fullprint << "point=" << point << std::endl;
-    NumericalPoint transformedPoint(transform(point));
+    Point transformedPoint(transform(point));
     fullprint << "transform value at point        =" << transformedPoint << std::endl;
     fullprint << "transform gradient at point     =" << transform.gradient(point).clean(1.0e-6) << std::endl;
-    fullprint << "transform gradient at point (FD)=" << CenteredFiniteDifferenceGradient(1.0e-5, transform.getEvaluationImplementation()).gradient(point).clean(1.0e-6) << std::endl;
+    fullprint << "transform gradient at point (FD)=" << CenteredFiniteDifferenceGradient(1.0e-5, transform.getEvaluation()).gradient(point).clean(1.0e-6) << std::endl;
     fullprint << "transform hessian at point      =" << std::setprecision(4) << clean(transform.hessian(point)) << std::endl;
-    fullprint << "transform hessian at point (FD) =" << std::setprecision(4) << clean(CenteredFiniteDifferenceHessian(1.0e-4, transform.getEvaluationImplementation()).hessian(point)) << std::endl;
+    fullprint << "transform hessian at point (FD) =" << std::setprecision(4) << clean(CenteredFiniteDifferenceHessian(1.0e-4, transform.getEvaluation()).hessian(point)) << std::endl;
     fullprint << "inverse transform value at transformed point        =" << inverseTransform(transformedPoint) << std::endl;
     fullprint << "inverse transform gradient at transformed point     =" << inverseTransform.gradient(transformedPoint).clean(1.0e-6) << std::endl;
-    fullprint << "inverse transform gradient at transformed point (FD)=" << CenteredFiniteDifferenceGradient(1.0e-5, inverseTransform.getEvaluationImplementation()).gradient(transformedPoint).clean(1.0e-6) << std::endl;
+    fullprint << "inverse transform gradient at transformed point (FD)=" << CenteredFiniteDifferenceGradient(1.0e-5, inverseTransform.getEvaluation()).gradient(transformedPoint).clean(1.0e-6) << std::endl;
     fullprint << "inverse transform hessian at transformed point      =" << std::setprecision(4) << clean(inverseTransform.hessian(transformedPoint)) << std::endl;
-    fullprint << "inverse transform hessian at transformed point (FD) =" << std::setprecision(4) << clean(CenteredFiniteDifferenceHessian(1.0e-4, inverseTransform.getEvaluationImplementation()).hessian(transformedPoint)) << std::endl;
+    fullprint << "inverse transform hessian at transformed point (FD) =" << std::setprecision(4) << clean(CenteredFiniteDifferenceHessian(1.0e-4, inverseTransform.getEvaluation()).hessian(transformedPoint)) << std::endl;
 
     // Test for parameters
-    fullprint << "parameters gradient at point=" << transform.parametersGradient(point) << std::endl;
+    fullprint << "parameters gradient at point=" << transform.parameterGradient(point) << std::endl;
     {
       // Validation using finite difference
-      NumericalScalar eps(1.0e-5);
-      NumericalScalar factor(1.0 / (2.0 * eps));
+      Scalar eps = 1.0e-5;
+      Scalar factor = 1.0 / (2.0 * eps);
       Matrix gradient(5, 2);
-      NumericalPoint dTdp;
+      Point dTdp;
       {
         // dT/dp0
         ComposedDistribution::DistributionCollection coll(aCollection);
@@ -174,13 +171,13 @@ int main(int argc, char *argv[])
       fullprint << "parameters gradient (FD)    =" << gradient << std::endl;
     }
     // Test for parameters
-    fullprint << "(inverse) parameters gradient at point=" << inverseTransform.parametersGradient(point) << std::endl;
+    fullprint << "(inverse) parameters gradient at point=" << inverseTransform.parameterGradient(point) << std::endl;
     {
       // Validation using finite difference
-      NumericalScalar eps(1.0e-5);
-      NumericalScalar factor(1.0 / (2.0 * eps));
+      Scalar eps = 1.0e-5;
+      Scalar factor = 1.0 / (2.0 * eps);
       Matrix gradient(5, 2);
-      NumericalPoint dTdp;
+      Point dTdp;
       {
         // dT/dp0
         ComposedDistribution::DistributionCollection coll(aCollection);
