@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_IsoProbabilisticTransformation_EllipticalDistribution.cxx
  *  @brief The test file of class IsoProbabilisticTransformation for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -30,23 +27,23 @@ using namespace OT::Test;
 typedef Distribution::IsoProbabilisticTransformation IsoProbabilisticTransformation;
 typedef Distribution::InverseIsoProbabilisticTransformation InverseIsoProbabilisticTransformation;
 
-NumericalPoint clean(NumericalPoint in)
+Point clean(Point in)
 {
-  UnsignedInteger dim(in.getDimension());
+  UnsignedInteger dim = in.getDimension();
   for(UnsignedInteger i = 0; i < dim; i++)
-    if (fabs(in[i]) < 1.e-10) in[i] = 0.0;
+    if (std::abs(in[i]) < 1.e-10) in[i] = 0.0;
   return in;
 }
 
 SymmetricTensor clean(SymmetricTensor in)
 {
-  UnsignedInteger rowDim(in.getNbRows());
-  UnsignedInteger colDim(in.getNbColumns());
-  UnsignedInteger sheetDim(in.getNbSheets());
+  UnsignedInteger rowDim = in.getNbRows();
+  UnsignedInteger colDim = in.getNbColumns();
+  UnsignedInteger sheetDim = in.getNbSheets();
   for(UnsignedInteger i = 0; i < rowDim; i++)
     for(UnsignedInteger j = 0; j < colDim; j++)
       for (UnsignedInteger k = 0; k < sheetDim; k++)
-        if (fabs(in(i, j, k)) < 1.e-6) in(i, j, k) = 0.0;
+        if (std::abs(in(i, j, k)) < 1.e-6) in(i, j, k) = 0.0;
   return in;
 }
 
@@ -59,11 +56,11 @@ int main(int argc, char *argv[])
   try
   {
     // Instanciate one distribution object
-    UnsignedInteger dim(3);
-    NumericalPoint meanPoint(dim, 1.0);
+    UnsignedInteger dim = 3;
+    Point meanPoint(dim, 1.0);
     meanPoint[0] = 0.5;
     meanPoint[1] = -0.5;
-    NumericalPoint sigma(dim, 1.0);
+    Point sigma(dim, 1.0);
     sigma[0] = 2.0;
     sigma[1] = 3.0;
     CorrelationMatrix R(dim);
@@ -76,14 +73,14 @@ int main(int argc, char *argv[])
 
     // Test for sampling
     UnsignedInteger size = 10000;
-    NumericalSample sample = distribution.getSample( size );
+    Sample sample = distribution.getSample( size );
     fullprint << "sample first=" << sample[0] << " last=" << sample[size - 1] << std::endl;
     fullprint << "sample mean=" << sample.computeMean() << std::endl;
     fullprint << "sample covariance=" << sample.computeCovariance() << std::endl;
 
     IsoProbabilisticTransformation transform(distribution.getIsoProbabilisticTransformation());
     fullprint << "isoprobabilistic transformation=" << transform << std::endl;
-    NumericalSample transformedSample(transform(sample));
+    Sample transformedSample(transform(sample));
     fullprint << "transformed sample first=" << transformedSample[0] << " last=" << transformedSample[size - 1] << std::endl;
     fullprint << "transformed sample mean=" << transformedSample.computeMean() << std::endl;
     fullprint << "transformed sample covariance=" << transformedSample.computeCovariance() << std::endl;
@@ -91,26 +88,26 @@ int main(int argc, char *argv[])
     // Test for evaluation
     InverseIsoProbabilisticTransformation inverseTransform(distribution.getInverseIsoProbabilisticTransformation());
     fullprint << "inverse isoprobabilistic transformation=" << inverseTransform << std::endl;
-    NumericalSample transformedBackSample(inverseTransform(transformedSample));
+    Sample transformedBackSample(inverseTransform(transformedSample));
     fullprint << "transformed back sample first=" << transformedBackSample[0] << " last=" << transformedBackSample[size - 1] << std::endl;
     fullprint << "transformed back sample mean=" << transformedBackSample.computeMean() << std::endl;
     fullprint << "transformed back sample covariance=" << transformedBackSample.computeCovariance() << std::endl;
-    NumericalPoint point(dim, 1.0);
+    Point point(dim, 1.0);
     fullprint << "point=" << point << std::endl;
-    NumericalPoint transformedPoint(transform(point));
+    Point transformedPoint(transform(point));
     fullprint << "transform value at point        =" << transformedPoint << std::endl;
     fullprint << "transform gradient at point     =" << transform.gradient(point).clean(1.0e-6) << std::endl;
-    fullprint << "transform gradient at point (FD)=" << CenteredFiniteDifferenceGradient(1.0e-5, transform.getEvaluationImplementation()).gradient(point).clean(1.0e-6) << std::endl;
+    fullprint << "transform gradient at point (FD)=" << CenteredFiniteDifferenceGradient(1.0e-5, transform.getEvaluation()).gradient(point).clean(1.0e-6) << std::endl;
     fullprint << "transform hessian at point      =" << clean(transform.hessian(point)) << std::endl;
-    fullprint << "transform hessian at point (FD) =" << clean(CenteredFiniteDifferenceHessian(1.0e-4, transform.getEvaluationImplementation()).hessian(point)) << std::endl;
+    fullprint << "transform hessian at point (FD) =" << clean(CenteredFiniteDifferenceHessian(1.0e-4, transform.getEvaluation()).hessian(point)) << std::endl;
     fullprint << "inverse transform value at transformed point        =" << inverseTransform(transformedPoint) << std::endl;
     fullprint << "inverse transform gradient at transformed point (FD)=" << inverseTransform.gradient(transformedPoint).clean(1.0e-6) << std::endl;
-    fullprint << "inverse transform gradient at transformed point     =" << CenteredFiniteDifferenceGradient(1.0e-5, inverseTransform.getEvaluationImplementation()).gradient(transformedPoint).clean(1.0e-6) << std::endl;
+    fullprint << "inverse transform gradient at transformed point     =" << CenteredFiniteDifferenceGradient(1.0e-5, inverseTransform.getEvaluation()).gradient(transformedPoint).clean(1.0e-6) << std::endl;
     fullprint << "inverse transform hessian at transformed point      =" << clean(inverseTransform.hessian(transformedPoint)) << std::endl;
-    fullprint << "inverse transform hessian at transformed point (FD) =" << clean(CenteredFiniteDifferenceHessian(1.0e-4, inverseTransform.getEvaluationImplementation()).hessian(transformedPoint)) << std::endl;
+    fullprint << "inverse transform hessian at transformed point (FD) =" << clean(CenteredFiniteDifferenceHessian(1.0e-4, inverseTransform.getEvaluation()).hessian(transformedPoint)) << std::endl;
 
     // Test for parameters
-    fullprint << "parameters gradient at point=" << transform.parametersGradient(point).clean(1.0e-6) << std::endl;
+    fullprint << "parameters gradient at point=" << transform.parameterGradient(point).clean(1.0e-6) << std::endl;
   }
   catch (TestFailed & ex)
   {
