@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_KFold_std.cxx
  *  @brief The test file of class KFold for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,15 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2010-02-04 16:44:49 +0100 (Thu, 04 Feb 2010)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
-#include "../src/Base/Func/NumericalMathFunction.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,17 +32,16 @@ int main(int argc, char *argv[])
 
   const UnsignedInteger size = 100;
   Uniform xuniform(0.9, 1.1);
-  NumericalSample x( xuniform.getSample(size) );
+  Sample x( xuniform.getSample(size) );
   Uniform yuniform(1.9, 2.1);
-  NumericalSample y( yuniform.getSample(size) );
-  NumericalMathFunction f( Description(1, "x"), Description(1, "y"), Description(1, "2.0*x") );
-  Basis basis;
-  basis.add(f);
+  Sample y( yuniform.getSample(size) );
+  SymbolicFunction f( Description(1, "x"), Description(1, "2.0*x") );
+  Collection<Function> basis(1, f);
   Indices indices(basis.getSize());
 
   FittingAlgorithm fittingAlgo = KFold();
 
-  NumericalScalar result = fittingAlgo.run(x, y, basis, indices);
+  Scalar result = fittingAlgo.run(x, y, basis, indices);
 
   fullprint << "result = " << result << std::endl;
 
