@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_KissFFT_std.cxx
  *  @brief The test file of class KissFFT
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,19 +14,17 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
 
-typedef Collection<NumericalComplex> NumericalComplexCollection;
+typedef Collection<Complex> ComplexCollection;
 
 int main(int argc, char *argv[])
 {
@@ -39,19 +36,19 @@ int main(int argc, char *argv[])
   {
 
     // for fft, the best implementation is given for N = 2^p
-    const UnsignedInteger size(16);
+    const UnsignedInteger size = 16;
 
     // collection for test
-    NumericalComplexCollection collection(size);
+    ComplexCollection collection(size);
 
     // Fill the data with artificial values
 
     // Create a complex gaussian sample
     for (UnsignedInteger index = 0; index < size; ++index)
     {
-      const NumericalScalar realPart( 0.1 * (1.0 + index) / size );
-      const NumericalScalar imagPart( 0.3 * (1.0 + index) / size );
-      collection[index] = NumericalComplex(realPart, imagPart);
+      const Scalar realPart = 0.1 * (1.0 + index) / size;
+      const Scalar imagPart = 0.3 * (1.0 + index) / size;
+      collection[index] = Complex(realPart, imagPart);
     }
 
     /* Instanciation of FFT class */
@@ -62,19 +59,19 @@ int main(int argc, char *argv[])
     fullprint << "collection = " << collection << std::endl;
 
     // FFT transform
-    const NumericalComplexCollection transformedCollection(myFFT.transform(collection));
+    const ComplexCollection transformedCollection(myFFT.transform(collection));
     fullprint << "FFT result = " << transformedCollection << std::endl;
 
     // Inverse transformation
-    const NumericalComplexCollection inverseTransformedCollection(myFFT.inverseTransform(transformedCollection));
+    const ComplexCollection inverseTransformedCollection(myFFT.inverseTransform(transformedCollection));
     fullprint << "FFT back=" << inverseTransformedCollection << std::endl;
 
-    const NumericalScalar threshold(1e-14);
+    const Scalar threshold = 1e-14;
 
     // 2D case now
-    const UnsignedInteger N(8);
+    const UnsignedInteger N = 8;
     Normal distribution(N);
-    NumericalSample sample(distribution.getSample(2 * N));
+    Sample sample(distribution.getSample(2 * N));
 
     // FFT transform
     const ComplexMatrix transformedSample(myFFT.transform2D(sample));
