@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_KrawtchoukFactory_std.cxx
  *  @brief The test file of class KrawtchoukFactory for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2008-05-21 17:44:02 +0200 (mer, 21 mai 2008)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -40,9 +37,9 @@ int main(int argc, char *argv[])
     {
       fullprint << "krawtchouk(" << i << ")=" << krawtchouk.build(i).__str__() << std::endl;
     }
-    NumericalPoint roots(krawtchouk.getRoots(10));
+    Point roots(krawtchouk.getRoots(10));
     fullprint << "krawtchouk(10) roots=" << roots << std::endl;
-    NumericalPoint weights;
+    Point weights;
     roots = krawtchouk.getNodesAndWeights(10, weights);
     fullprint << "krawtchouk(10) roots=" << roots << " and weights=" << weights << std::endl;
   }
