@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_LHSExperiment_std.cxx
  *  @brief The test file of class LHSExperiment for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2008-05-21 17:44:02 +0200 (mer, 21 mai 2008)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,13 +33,23 @@ int main(int argc, char *argv[])
   try
   {
     Normal distribution(4);
-    UnsignedInteger size(10);
+    UnsignedInteger size = 10;
     LHSExperiment myPlane(distribution, size);
     fullprint << "myPlane = " << myPlane << std::endl;
-    NumericalPoint weights(0);
-    NumericalSample sample(myPlane.generateWithWeights(weights));
-    fullprint << "sample = " << sample << std::endl;
+    Point weights(0);
+    Sample sample(myPlane.generateWithWeights(weights));
+    fullprint << "sample  = " << sample << std::endl;
     fullprint << "weights = " << weights << std::endl;
+    fullprint << "sample2 = " << myPlane.generate() << std::endl;
+    myPlane = LHSExperiment(distribution, size, true, true);
+    fullprint << "sample  = " << myPlane.generate() << std::endl;
+    fullprint << "sample2 = " << myPlane.generate() << std::endl;
+    myPlane = LHSExperiment(distribution, size, false, false);
+    fullprint << "sample  = " << myPlane.generate() << std::endl;
+    fullprint << "sample2 = " << myPlane.generate() << std::endl;
+    myPlane = LHSExperiment(distribution, size, true, false);
+    fullprint << "sample  = " << myPlane.generate() << std::endl;
+    fullprint << "sample2 = " << myPlane.generate() << std::endl;
   }
   catch (TestFailed & ex)
   {
