@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_LeastSquaresMetaModelSelectionFactory_std.cxx
  *  @brief The test file of class LeastSquaresMetaModelSelectionFactory for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2010-02-04 16:44:49 +0100 (Thu, 04 Feb 2010)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -32,17 +29,16 @@ int main(int argc, char *argv[])
   TESTPREAMBLE;
   OStream fullprint(std::cout);
 
-  NumericalSample x(1, 1);
-  NumericalSample y(1, 1);
-  NumericalPoint weight(1, 1.0);
-  Collection<NumericalMathFunction> coll;
-  coll.add(NumericalMathFunction("x", "x"));
-  Basis psi(coll);
+  Sample x(1, 1);
+  Sample y(1, 1);
+  Point weight(1, 1.0);
+  Collection<Function> coll;
+  coll.add(SymbolicFunction("x", "x"));
   Indices indices(coll.getSize());
   indices.fill();
 
-  LeastSquaresMetaModelSelectionFactory factory = LeastSquaresMetaModelSelectionFactory( LAR(), CorrectedLeaveOneOut() );
-  ApproximationAlgorithm algo(factory.build(x, y, weight, psi, indices));
+  LeastSquaresMetaModelSelectionFactory factory = LeastSquaresMetaModelSelectionFactory(LARS(), CorrectedLeaveOneOut());
+  ApproximationAlgorithm algo(factory.build(x, y, weight, coll, indices));
   fullprint << "algo = " << algo << std::endl;
 
   return ExitCode::Success;
