@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_LinearLeastSquares_std.cxx
  *  @brief The test file of class LinearLeastSquares for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -34,9 +31,16 @@ int main(int argc, char *argv[])
 
   try
   {
-    NumericalMathFunction myFunc("TestResponseSurface");
-    NumericalSample data(9, myFunc.getInputDimension());
-    NumericalPoint point(myFunc.getInputDimension());
+    Description input(2);
+    input[0] = "x1";
+    input[1] = "x2";
+    Description formula(3);
+    formula[0] = "x1*sin(x2)";
+    formula[1] = "cos(x1+x2)";
+    formula[2] = "(x2+1)*exp(x1-2*x2)";
+    SymbolicFunction myFunc(input, formula);
+    Sample data(9, myFunc.getInputDimension());
+    Point point(myFunc.getInputDimension());
     point[0] = 0.5;
     point[1] = 0.5;
     data[0] = point;
@@ -67,21 +71,21 @@ int main(int argc, char *argv[])
     {
       LinearLeastSquares myLeastSquares(data, myFunc);
       myLeastSquares.run();
-      NumericalMathFunction responseSurface(myLeastSquares.getResponseSurface());
+      Function responseSurface(myLeastSquares.getResponseSurface());
       fullprint << "myLeastSquares=" << myLeastSquares << std::endl;
       fullprint << "responseSurface=" << responseSurface << std::endl;
-      NumericalPoint in(myFunc.getInputDimension(), 0.1);
+      Point in(myFunc.getInputDimension(), 0.1);
       fullprint << "myFunc(" << in << ")=" << myFunc(in) << std::endl;
       fullprint << "responseSurface(" << in << ")=" << responseSurface(in) << std::endl;
     }
     {
-      NumericalSample dataOut(myFunc(data));
+      Sample dataOut(myFunc(data));
       LinearLeastSquares myLeastSquares(data, dataOut);
       myLeastSquares.run();
-      NumericalMathFunction responseSurface(myLeastSquares.getResponseSurface());
+      Function responseSurface(myLeastSquares.getResponseSurface());
       fullprint << "myLeastSquares=" << myLeastSquares << std::endl;
       fullprint << "responseSurface=" << responseSurface << std::endl;
-      NumericalPoint in(myFunc.getInputDimension(), 0.1);
+      Point in(myFunc.getInputDimension(), 0.1);
       fullprint << "myFunc(" << in << ")=" << myFunc(in) << std::endl;
       fullprint << "responseSurface(" << in << ")=" << responseSurface(in) << std::endl;
     }
