@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_LinearModelTest_std.cxx
  *  @brief The test file of class Test
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -33,8 +30,8 @@ int main(int argc, char *argv[])
   OStream fullprint(std::cout);
   setRandomGenerator();
 
-  UnsignedInteger size(100);
-  UnsignedInteger dim(10);
+  UnsignedInteger size = 100;
+  UnsignedInteger dim = 10;
   CorrelationMatrix R(dim);
   for (UnsignedInteger i = 0; i < dim; i++)
   {
@@ -43,12 +40,12 @@ int main(int argc, char *argv[])
       R(i, j) = (i + j + 1.0) / (2.0 * dim);
     }
   }
-  NumericalPoint mean(dim, 2.0);
-  NumericalPoint sigma(dim, 3.0);
+  Point mean(dim, 2.0);
+  Point sigma(dim, 3.0);
   Normal distribution(mean, sigma, R);
-  NumericalSample sample(distribution.getSample(size));
-  NumericalSample sampleX(size, dim - 1);
-  NumericalSample sampleY(size, 1);
+  Sample sample(distribution.getSample(size));
+  Sample sampleX(size, dim - 1);
+  Sample sampleY(size, 1);
   for (UnsignedInteger i = 0; i < size; i++)
   {
     sampleY[i][0] = sample[i][0];
@@ -57,7 +54,7 @@ int main(int argc, char *argv[])
       sampleX[i][j - 1] = sample[i][j];
     }
   }
-  NumericalSample sampleZ(size, 1);
+  Sample sampleZ(size, 1);
   for (UnsignedInteger i = 0; i < size; i++)
   {
     sampleZ[i][0] = sampleY[i][0] * sampleY[i][0];
