@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_LinearModel_std.cxx
  *  @brief The test file of class LinearModel
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,25 +33,22 @@ int main(int argc, char *argv[])
   /** TEST NUMBER ZERO : DEFAULT & COPY CONSTRUCTORs AND STRING CONVERTER */
   fullprint << "test number zero : default & copy constructors and string converter" << std::endl;
 
-  NumericalPoint vectR(1, 12.0);
-  NumericalSample testSample(1, 1);
+  Point vectR(1, 12.0);
+  Sample testSample(1, 1);
 
-  NumericalScalar begin(-1.0);
-  NumericalScalar end(36.92);
-  ConfidenceInterval testInterval(begin, end);
+  Scalar begin = -1.0;
+  Scalar end = 36.92;
+  Interval testInterval(Point(1, begin), Point(1, end));
   testInterval.setName("testInterval");
 
-  OT::Collection<ConfidenceInterval> coll;
-  coll.add(testInterval);
-
-  OT::Collection<NumericalScalar> valColl;
+  OT::Collection<Scalar> valColl;
   valColl.add(1.0);
 
   /* Default constructor */
-  LinearModel LM(vectR, coll, valColl);
+  LinearModel LM(vectR, testInterval, valColl);
   LinearModel LMcopy(LM);
 
-  /* Constructor from NumericalPoint */
+  /* Constructor from Point */
   LinearModel emptyLM(vectR);
 
   /* String converter */
@@ -74,9 +68,9 @@ int main(int argc, char *argv[])
   /** TEST NUMBER TWO : GET PREDICT/RESIDUAL */
   fullprint << "test number two : get predicted/residual" << std::endl;
   LinearModelFactory lmfact;
-  UnsignedInteger size(20);
-  NumericalSample oneSample(size, 1);
-  NumericalSample twoSample(size, 1);
+  UnsignedInteger size = 20;
+  Sample oneSample(size, 1);
+  Sample twoSample(size, 1);
   for (UnsignedInteger i = 0; i < size; ++i)
   {
     oneSample[i][0] = 7.0 * sin(-3.5 + (6.5 * i) / (size - 1.0)) + 2.0;
