@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_LinearTaylor_std.cxx
  *  @brief The test file of class LinearTaylor for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -34,22 +31,29 @@ int main(int argc, char *argv[])
 
   try
   {
-    NumericalScalar eps(0.2);
+    Scalar eps = 0.2;
     /** Instance creation */
-    NumericalMathFunction myFunc("TestResponseSurface");
-    NumericalPoint center(myFunc.getInputDimension());
+    Description input(2);
+    input[0] = "x1";
+    input[1] = "x2";
+    Description formula(3);
+    formula[0] = "x1*sin(x2)";
+    formula[1] = "cos(x1+x2)";
+    formula[2] = "(x2+1)*exp(x1-2*x2)";
+    SymbolicFunction myFunc(input, formula);
+    Point center(myFunc.getInputDimension());
     for(UnsignedInteger i = 0; i < center.getDimension(); i++)
     {
       center[i] = 1.0 + i;
     }
     LinearTaylor myTaylor(center, myFunc);
     myTaylor.run();
-    NumericalMathFunction responseSurface(myTaylor.getResponseSurface());
+    Function responseSurface(myTaylor.getResponseSurface());
     fullprint << "myTaylor=" << myTaylor << std::endl;
     fullprint << "responseSurface=" << responseSurface << std::endl;
     fullprint << "myFunc(" << center << ")=" << myFunc(center) << std::endl;
     fullprint << "responseSurface(" << center << ")=" << responseSurface(center) << std::endl;
-    NumericalPoint in(center);
+    Point in(center);
     in[0] += eps;
     in[1] -= eps / 2;
     fullprint << "myFunc(" << in << ")=" << myFunc(in) << std::endl;
