@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_LogNormalFactory_std.cxx
  *  @brief The test file of class LogNormal for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,25 +33,31 @@ int main(int argc, char *argv[])
   try
   {
     LogNormal distribution(1.5, 2.5, -1.5);
-    UnsignedInteger size(10000);
-    NumericalSample sample(distribution.getSample(size));
+    fullprint << "Distribution          =" << distribution << std::endl;
+    UnsignedInteger size = 10000;
+    Sample sample(distribution.getSample(size));
     LogNormalFactory factory;
     CovarianceMatrix covariance;
     // Distribution estimatedDistribution(factory.build(sample, covariance));
     Distribution estimatedDistribution(factory.build(sample));
-    fullprint << "Distribution          =" << distribution << std::endl;
     fullprint << "Estimated distribution=" << estimatedDistribution << std::endl;
+    estimatedDistribution = factory.build(sample, 0);
+    fullprint << "Estimated distribution (local likelihood)=" << estimatedDistribution << std::endl;
+    estimatedDistribution = factory.build(sample, 1);
+    fullprint << "Estimated distribution (modified moments)=" << estimatedDistribution << std::endl;
+    estimatedDistribution = factory.build(sample, 2);
+    fullprint << "Estimated distribution (moments)=" << estimatedDistribution << std::endl;
     // fullprint << "Covariance=" << covariance << std::endl;
     estimatedDistribution = factory.build();
     fullprint << "Default distribution=" << estimatedDistribution << std::endl;
-    estimatedDistribution = factory.build(distribution.getParametersCollection());
+    estimatedDistribution = factory.build(distribution.getParameter());
     fullprint << "Distribution from parameters=" << estimatedDistribution << std::endl;
     LogNormal estimatedLogNormal(factory.buildAsLogNormal(sample));
     fullprint << "LogNormal          =" << distribution << std::endl;
     fullprint << "Estimated logNormal=" << estimatedLogNormal << std::endl;
     estimatedLogNormal = factory.buildAsLogNormal();
     fullprint << "Default logNormal=" << estimatedLogNormal << std::endl;
-    estimatedLogNormal = factory.buildAsLogNormal(distribution.getParametersCollection());
+    estimatedLogNormal = factory.buildAsLogNormal(distribution.getParameter());
     fullprint << "LogNormal from parameters=" << estimatedLogNormal << std::endl;
   }
   catch (TestFailed & ex)
