@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_LogUniformFactory_std.cxx
  *  @brief The test file of class LogUniform for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2011-05-24 19:30:41 +0200 (mar. 24 mai 2011)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,8 +33,8 @@ int main(int argc, char *argv[])
   try
   {
     LogUniform distribution(1.0, 2.5);
-    UnsignedInteger size(10000);
-    NumericalSample sample(distribution.getSample(size));
+    UnsignedInteger size = 10000;
+    Sample sample(distribution.getSample(size));
     LogUniformFactory factory;
     CovarianceMatrix covariance;
     // Distribution estimatedDistribution(factory.build(sample, covariance));
@@ -47,15 +44,19 @@ int main(int argc, char *argv[])
     // fullprint << "Covariance=" << covariance << std::endl;
     estimatedDistribution = factory.build();
     fullprint << "Default distribution=" << estimatedDistribution << std::endl;
-    estimatedDistribution = factory.build(distribution.getParametersCollection());
+    estimatedDistribution = factory.build(distribution.getParameter());
     fullprint << "Distribution from parameters=" << estimatedDistribution << std::endl;
     LogUniform estimatedLogUniform(factory.buildAsLogUniform(sample));
     fullprint << "LogUniform          =" << distribution << std::endl;
     fullprint << "Estimated logUniform=" << estimatedLogUniform << std::endl;
     estimatedLogUniform = factory.buildAsLogUniform();
     fullprint << "Default logUniform=" << estimatedLogUniform << std::endl;
-    estimatedLogUniform = factory.buildAsLogUniform(distribution.getParametersCollection());
+    estimatedLogUniform = factory.buildAsLogUniform(distribution.getParameter());
     fullprint << "LogUniform from parameters=" << estimatedLogUniform << std::endl;
+    // Test for constant sample
+    sample = Sample(size, Point(1, 1.0));
+    estimatedDistribution = factory.build(sample);
+    fullprint << "Estimated distribution=" << estimatedDistribution << std::endl;
   }
   catch (TestFailed & ex)
   {
