@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_Log_std.cxx
  *  @brief The test file of class Log for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,16 +14,14 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OTtestcode.hxx"
-#include "OStream.hxx"
+#include "openturns/OTtestcode.hxx"
+#include "openturns/OStream.hxx"
 
-#include "Log.hxx"
+#include "openturns/Log.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -45,13 +42,6 @@ void* printInfo(void*)
 }
 
 
-void* printWrapper(void*)
-{
-  for(int i = 0; i < N; i++) LOGWRAPPER(OSS() << "Wrapper #" << i);
-  return NULL;
-}
-
-
 void* printUser(void*)
 {
   for(int i = 0; i < N; i++) LOGUSER(OSS() << "User #" << i);
@@ -90,9 +80,9 @@ int main(int argc, char *argv[])
   const int nbThreads = 128;
   pthread_t Threads[nbThreads];
 
-  const int nbFunctions = 7;
+  const int nbFunctions = 6;
   typedef void * (*FUNC) (void *);
-  FUNC Functions[nbFunctions] = { printDebug, printInfo, printWrapper, printUser, printWarn, printError, printTrace };
+  FUNC Functions[nbFunctions] = { printDebug, printInfo, printUser, printWarn, printError, printTrace };
 
   Log::Show( Log::ALL );
   Log::SetFile("Log_check.log");
