@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_MarginalTransformationEvaluation_std.cxx
  *  @brief The test file of class MarginalTransformationEvaluation for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -38,10 +35,10 @@ int main(int argc, char *argv[])
     MarginalTransformationEvaluation::DistributionCollection coll1(0);
     coll1.add(Normal(1.0, 2.5));
     coll1.add(Gamma(1.5, 3.0, 0.0));
-    NumericalPoint pointLow(0);
+    Point pointLow(0);
     pointLow.add(coll1[0].computeQuantile(0.25)[0]);
     pointLow.add(coll1[1].computeQuantile(0.25)[0]);
-    NumericalPoint pointHigh(0);
+    Point pointHigh(0);
     pointHigh.add(coll1[0].computeQuantile(0.75)[0]);
     pointHigh.add(coll1[1].computeQuantile(0.75)[0]);
     MarginalTransformationEvaluation::DistributionCollection coll2(0);
@@ -54,11 +51,11 @@ int main(int argc, char *argv[])
       fullprint << "transformation(" << pointLow << ")=" << transformation(pointLow) << std::endl;
       fullprint << "transformation(" << pointHigh << ")=" << transformation(pointHigh) << std::endl;
       // Validation using finite difference
-      NumericalScalar eps(1e-5);
-      NumericalScalar factor(1.0 / (2.0 * eps));
+      Scalar eps = 1e-5;
+      Scalar factor = 1.0 / (2.0 * eps);
       Matrix gradientLow(5, 2);
       Matrix gradientHigh(5, 2);
-      NumericalPoint dTdp;
+      Point dTdp;
       {
         // dT/dp0
         MarginalTransformationEvaluation::DistributionCollection coll(coll1);
@@ -129,9 +126,9 @@ int main(int argc, char *argv[])
         gradientHigh(4, 0) = dTdp[0];
         gradientHigh(4, 1) = dTdp[1];
       }
-      fullprint << "transformation    parameters gradient=" << transformation.parametersGradient(pointLow) << std::endl;
+      fullprint << "transformation    parameters gradient=" << transformation.parameterGradient(pointLow) << std::endl;
       fullprint << "finite difference parameters gradient=" << gradientLow << std::endl;
-      fullprint << "transformation    parameters gradient=" << transformation.parametersGradient(pointHigh) << std::endl;
+      fullprint << "transformation    parameters gradient=" << transformation.parameterGradient(pointHigh) << std::endl;
       fullprint << "finite difference parameters gradient=" << gradientHigh << std::endl;
       fullprint << "input dimension=" << transformation.getInputDimension() << std::endl;
       fullprint << "output dimension=" << transformation.getOutputDimension() << std::endl;
@@ -140,16 +137,16 @@ int main(int argc, char *argv[])
     {
       MarginalTransformationEvaluation transformation(coll1, MarginalTransformationEvaluation::TO);
       fullprint << "transformation=" << transformation << std::endl;
-      NumericalPoint uLow(coll1.getSize(), 0.25);
-      NumericalPoint uHigh(coll1.getSize(), 0.75);
+      Point uLow(coll1.getSize(), 0.25);
+      Point uHigh(coll1.getSize(), 0.75);
       fullprint << "transformation(" << uLow << ")=" << transformation(uLow) << std::endl;
       fullprint << "transformation(" << uHigh << ")=" << transformation(uHigh) << std::endl;
       // Validation using finite difference
-      NumericalScalar eps(1e-5);
-      NumericalScalar factor(1.0 / (2.0 * eps));
+      Scalar eps = 1e-5;
+      Scalar factor = 1.0 / (2.0 * eps);
       Matrix gradientLow(5, 2);
       Matrix gradientHigh(5, 2);
-      NumericalPoint dTdp;
+      Point dTdp;
       {
         // dT/dp0
         MarginalTransformationEvaluation::DistributionCollection coll(coll1);
@@ -220,9 +217,9 @@ int main(int argc, char *argv[])
         gradientHigh(4, 0) = dTdp[0];
         gradientHigh(4, 1) = dTdp[1];
       }
-      fullprint << "transformation    parameters gradient=" << transformation.parametersGradient(uLow) << std::endl;
+      fullprint << "transformation    parameters gradient=" << transformation.parameterGradient(uLow) << std::endl;
       fullprint << "finite difference parameters gradient=" << gradientLow << std::endl;
-      fullprint << "transformation    parameters gradient=" << transformation.parametersGradient(uHigh) << std::endl;
+      fullprint << "transformation    parameters gradient=" << transformation.parameterGradient(uHigh) << std::endl;
       fullprint << "finite difference parameters gradient=" << gradientHigh << std::endl;
       fullprint << "input dimension=" << transformation.getInputDimension() << std::endl;
       fullprint << "output dimension=" << transformation.getOutputDimension() << std::endl;
