@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_MarginalTransformationHessian_std.cxx
  *  @brief The test file of class MarginalTransformationHessian for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -39,10 +36,10 @@ int main(int argc, char *argv[])
     MarginalTransformationEvaluation::DistributionCollection coll1(0);
     coll1.add(Normal(1.0, 2.5));
     coll1.add(Gamma(1.5, 3.0));
-    NumericalPoint pointLow(0);
+    Point pointLow(0);
     pointLow.add(coll1[0].computeQuantile(0.25)[0]);
     pointLow.add(coll1[1].computeQuantile(0.25)[0]);
-    NumericalPoint pointHigh(0);
+    Point pointHigh(0);
     pointHigh.add(coll1[0].computeQuantile(0.75)[0]);
     pointHigh.add(coll1[1].computeQuantile(0.75)[0]);
     MarginalTransformationEvaluation::DistributionCollection coll2(0);
@@ -66,8 +63,8 @@ int main(int argc, char *argv[])
       MarginalTransformationEvaluation evaluation(coll1, MarginalTransformationEvaluation::TO);
       MarginalTransformationHessian transformation(evaluation);
       fullprint << "transformation=" << transformation << std::endl;
-      NumericalPoint uLow(coll1.getSize(), 0.25);
-      NumericalPoint uHigh(coll1.getSize(), 0.75);
+      Point uLow(coll1.getSize(), 0.25);
+      Point uHigh(coll1.getSize(), 0.75);
       fullprint << "transformation.hessian(" << uLow << ")=" << transformation.hessian(uLow) << std::endl;
       fullprint << "finite difference hessian(" << uLow << ")=" << CenteredFiniteDifferenceHessian(1.0e-4, evaluation.clone()).hessian(uLow) << std::endl;
       fullprint << "transformation.hessian(" << uHigh << ")=" << transformation.hessian(uHigh) << std::endl;
