@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_Matrix_std.cxx
  *  @brief The test file of class Matrix for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -134,10 +131,10 @@ int main(int argc, char *argv[])
   fullprint << "sum1 equals sum2 = " << (sum1 == sum2) << std::endl;
 
 
-  /** TEST NUMBER EIGHT : SUBSTRACTION METHOD */
-  fullprint << "test number eight : substraction method" << std::endl;
+  /** TEST NUMBER EIGHT : SUBTRACTION METHOD */
+  fullprint << "test number eight : subtraction method" << std::endl;
 
-  /* Check substraction method */
+  /* Check subtraction method */
   Matrix diff = matrix1.operator - ( matrix4 ) ;
   fullprint << "diff = " << diff << std::endl;
 
@@ -150,21 +147,21 @@ int main(int argc, char *argv[])
   fullprint << "prod = " << prod << std::endl;
 
 
-  /** TEST NUMBER TEN : MULTIPLICATION WITH A NUMERICAL POINT METHOD */
-  fullprint << "test number ten : multiplication with a numerical point method" << std::endl;
+  /** TEST NUMBER TEN : MULTIPLICATION WITH A POINT METHOD */
+  fullprint << "test number ten : multiplication with a point method" << std::endl;
 
-  /* Create the numerical point */
-  NumericalPoint pt ;
+  /* Create the point */
+  Point pt ;
   pt.add(1.) ;
   pt.add(2.) ;
   fullprint << "pt = " << pt << std::endl;
 
   /* Check the product method */
-  NumericalPoint ptResult = matrix1.operator * ( pt ) ;
+  Point ptResult = matrix1.operator * ( pt ) ;
   fullprint << "ptResult = " << ptResult << std::endl;
 
-  /** TEST NUMBER ELEVEN : MULTIPLICATION AND DIVISION BY A NUMERICAL SCALAR METHODS */
-  fullprint << "test number eleven : multiplication and division by a numerical scalar methods" << std::endl;
+  /** TEST NUMBER ELEVEN : MULTIPLICATION AND DIVISION BY A SCALAR METHODS */
+  fullprint << "test number eleven : multiplication and division by a scalar methods" << std::endl;
 
   /* Check the multiplication method */
   double s = 3.;
@@ -198,11 +195,11 @@ int main(int argc, char *argv[])
             << "matrix6 is empty = " << matrix6.isEmpty() << std::endl
             << "matrix0 is empty = " << matrix0.isEmpty() << std::endl;
 
-  /** TEST NUMBER FOURTEEN : MULTIPLICATION WITH A NUMERICAL POINT METHOD */
-  fullprint << "test number fourteen : multiplication with a numerical point method" << std::endl;
+  /** TEST NUMBER FOURTEEN : MULTIPLICATION WITH A POINT METHOD */
+  fullprint << "test number fourteen : multiplication with a point method" << std::endl;
 
-  /* Create the numerical point */
-  NumericalPoint pt_test ;
+  /* Create the point */
+  Point pt_test ;
   pt_test.add(1.) ;
   pt_test.add(2.) ;
   fullprint << "pt_test = " << pt_test << std::endl;
@@ -216,12 +213,64 @@ int main(int argc, char *argv[])
   Matrix id = B.operator * (A);
 
   /* Check the product method */
-  NumericalPoint ptResult2 = id.operator * ( pt_test ) ;
+  Point ptResult2 = id.operator * ( pt_test ) ;
   fullprint << "A = " << A << std::endl;
   fullprint << "B = " << B << std::endl;
   fullprint << "id = " << id << std::endl;
   fullprint << "ptResult2 = " << ptResult2 << std::endl;
 
 
+  /** TEST NUMBER FIFTEEN : MULTIPLICATION WITH A SAMPLE METHOD */
+  fullprint << "test number fifteen : multiplication with a sample method" << std::endl;
+  Sample S(2, 4);
+  S(0, 0) = 1.0;
+  S(0, 1) = 3.0;
+  S(0, 2) = -1.0;
+  S(0, 3) = -3.0;
+  S(1, 0) = -2.0;
+  S(1, 1) = -5.0;
+  S(1, 2) = 3.0;
+  S(1, 3) = 1.0;
+  Matrix matrix32 = Matrix(3, 2, elementsValues);
+  Matrix matrix23 = Matrix(2, 3, elementsValues);
+  Collection<double> elementsValues12(elementsValues);
+  for(UnsignedInteger i = 7; i < 13; ++i)
+    elementsValues12.add(i);
+  Matrix matrix34 = Matrix(3, 4, elementsValues12);
+  Matrix matrix43 = Matrix(4, 3, elementsValues12);
+  fullprint << "matrix32 = " << matrix32 << std::endl;
+  fullprint << "matrix23 = " << matrix23 << std::endl;
+  fullprint << "matrix34 = " << matrix34 << std::endl;
+  fullprint << "matrix43 = " << matrix43 << std::endl;
+  fullprint << "S = " << S << std::endl;
+  Sample resultS = matrix32.operator * (S);
+  fullprint << "matrix32*S = " << resultS << std::endl;
+  Sample resultS1(matrix32.getImplementation()->genSampleProd(S, false, false, 'L'));
+  fullprint << "matrix32*S = " << resultS1 << std::endl;
+  Sample resultS2(matrix23.getImplementation()->genSampleProd(S, true, false, 'L'));
+  fullprint << "matrix23^T*S = " << resultS2 << std::endl;
+  Sample resultS3(matrix43.getImplementation()->genSampleProd(S, false, false, 'R'));
+  fullprint << "S*matrix43 = " << resultS3 << std::endl;
+  Sample resultS4(matrix34.getImplementation()->genSampleProd(S, true, false, 'R'));
+  fullprint << "S*matrix34^T = " << resultS4 << std::endl;
+  Sample S2(4, 2);
+  S2(0, 0) = S(0, 0);
+  S2(1, 0) = S(0, 1);
+  S2(2, 0) = S(0, 2);
+  S2(3, 0) = S(0, 3);
+  S2(0, 1) = S(1, 0);
+  S2(1, 1) = S(1, 1);
+  S2(2, 1) = S(1, 2);
+  S2(3, 1) = S(1, 3);
+  fullprint << "S2 = " << S2 << std::endl;
+  Sample resultS1T(matrix32.getImplementation()->genSampleProd(S2, false, true, 'L'));
+  fullprint << "matrix32*S2^T = " << resultS1T << std::endl;
+  Sample resultS2T(matrix23.getImplementation()->genSampleProd(S2, true, true, 'L'));
+  fullprint << "matrix23^T*S2^T = " << resultS2T << std::endl;
+  Sample resultS3T(matrix43.getImplementation()->genSampleProd(S2, false, true, 'R'));
+  fullprint << "S2^T*matrix43 = " << resultS3T << std::endl;
+  Sample resultS4T(matrix34.getImplementation()->genSampleProd(S2, true, true, 'R'));
+  fullprint << "S2^T*matrix34^T = " << resultS4T << std::endl;
+
   return ExitCode::Success;
 }
