@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_MeixnerDistributionFactory_std.cxx
  *  @brief The test file of class MeixnerDistribution for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -35,9 +32,15 @@ int main(int argc, char *argv[])
 
   try
   {
+    ResourceMap::SetAsUnsignedInteger( "MeixnerDistribution-CDFIntegrationNodesNumber", 8 );
+    ResourceMap::SetAsUnsignedInteger( "MeixnerDistribution-CDFDiscretization", 100 );
+    ResourceMap::SetAsScalar( "MeixnerDistribution-MaximumAbsoluteError", 1.0e-6 );
+    ResourceMap::SetAsScalar( "MeixnerDistribution-MaximumRelativeError", 1.0e-6 );
+    ResourceMap::SetAsScalar( "MeixnerDistribution-MaximumConstraintError", 1.0e-6 );
+    ResourceMap::SetAsScalar( "MeixnerDistribution-MaximumObjectiveError", 1.0e-6 );
     MeixnerDistribution distribution(1.5, 0.5, 2.5, -0.5);
-    UnsignedInteger size(10000);
-    NumericalSample sample(distribution.getSample(size));
+    UnsignedInteger size = 1000;
+    Sample sample(distribution.getSample(size));
     MeixnerDistributionFactory factory;
     CovarianceMatrix covariance;
     // Distribution estimatedDistribution(factory.build(sample, covariance));
@@ -47,14 +50,14 @@ int main(int argc, char *argv[])
     // fullprint << "Covariance=" << covariance << std::endl;
     estimatedDistribution = factory.build();
     fullprint << "Default distribution=" << estimatedDistribution << std::endl;
-    estimatedDistribution = factory.build(distribution.getParametersCollection());
+    estimatedDistribution = factory.build(distribution.getParameter());
     fullprint << "Distribution from parameters=" << estimatedDistribution << std::endl;
     MeixnerDistribution estimatedMeixnerDistribution(factory.buildAsMeixnerDistribution(sample));
     fullprint << "MeixnerDistribution          =" << distribution << std::endl;
     fullprint << "Estimated meixnerDistribution=" << estimatedMeixnerDistribution << std::endl;
     estimatedMeixnerDistribution = factory.buildAsMeixnerDistribution();
     fullprint << "Default meixnerDistribution=" << estimatedMeixnerDistribution << std::endl;
-    estimatedMeixnerDistribution = factory.buildAsMeixnerDistribution(distribution.getParametersCollection());
+    estimatedMeixnerDistribution = factory.buildAsMeixnerDistribution(distribution.getParameter());
     fullprint << "MeixnerDistribution from parameters=" << estimatedMeixnerDistribution << std::endl;
   }
   catch (TestFailed & ex)
