@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_MinCopula_std.cxx
  *  @brief The test file of class MinCopula for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2011-11-17 13:46:13 +0100 (jeu. 17 nov. 2011)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,12 +33,14 @@ int main(int argc, char *argv[])
   try
   {
     // Instanciate one distribution object
-    UnsignedInteger dim(3);
+    UnsignedInteger dim = 3;
 
     MinCopula copula(dim);
     copula.setName("a min copula");
     fullprint << "Copula " << copula << std::endl;
     std::cout << "Copula " << copula << std::endl;
+    fullprint << "entropy=" << copula.computeEntropy() << std::endl;
+    fullprint << "entropy (MC)=" << -copula.computeLogPDF(copula.getSample(1000000)).computeMean()[0] << std::endl;
     fullprint << "Mean " << copula.getMean() << std::endl;
     // Is this copula an elliptical distribution?
     fullprint << "Elliptical distribution= " << (copula.isElliptical() ? "true" : "false") << std::endl;
@@ -53,37 +52,44 @@ int main(int argc, char *argv[])
     fullprint << "Independent copula= " << (copula.hasIndependentCopula() ? "true" : "false") << std::endl;
 
     // Test for realization of copula
-    NumericalPoint oneRealization = copula.getRealization();
+    Point oneRealization = copula.getRealization();
     fullprint << "oneRealization=" << oneRealization << std::endl;
 
     // Test for sampling
     UnsignedInteger size = 10;
-    NumericalSample oneSample = copula.getSample( size );
+    Sample oneSample = copula.getSample( size );
     fullprint << "oneSample=" << oneSample << std::endl;
 
     // Test for sampling
     size = 10000;
-    NumericalSample anotherSample = copula.getSample( size );
+    Sample anotherSample = copula.getSample( size );
     fullprint << "anotherSample mean=" << anotherSample.computeMean() << std::endl;
     fullprint << "anotherSample covariance=" << anotherSample.computeCovariance() << std::endl;
 
     // Define a point
-    NumericalPoint point(dim, 0.2);
+    Point point(dim, 0.2);
 
     // Show DDF, PDF and CDF of point
-    NumericalPoint  pointDDF = copula.computeDDF( point );
-    NumericalScalar pointPDF = copula.computePDF( point );
-    NumericalScalar pointCDF = copula.computeCDF( point );
+    Point  pointDDF = copula.computeDDF( point );
+    Scalar pointPDF = copula.computePDF( point );
+    Scalar pointCDF = copula.computeCDF( point );
     fullprint << "point= " << point
               << " ddf=" << pointDDF
               << " ddf (FD)=" << copula.ContinuousDistribution::computeDDF(point)
               << " pdf=" << pointPDF
               << " cdf=" << pointCDF
               << std::endl;
+    Scalar Survival = copula.computeSurvivalFunction(point);
+    fullprint << "Survival      =" << Survival << std::endl;
+    fullprint << "Survival (ref)=" << copula.computeSurvivalFunction(point) << std::endl;
+    Point InverseSurvival = copula.computeInverseSurvivalFunction(0.95);
+    fullprint << "Inverse survival=" << InverseSurvival << std::endl;
+    fullprint << "Survival(inverse survival)=" << copula.computeSurvivalFunction(InverseSurvival) << std::endl;
     // Get 50% quantile
-    NumericalPoint quantile = copula.computeQuantile( 0.5 );
+    Point quantile = copula.computeQuantile( 0.5 );
     fullprint << "Quantile=" << quantile << std::endl;
     fullprint << "CDF(quantile)=" << copula.computeCDF(quantile) << std::endl;
+
     // Covariance and correlation
     CovarianceMatrix covariance = copula.getCovariance();
     fullprint << "covariance=" << covariance << std::endl;
@@ -98,8 +104,8 @@ int main(int argc, char *argv[])
     {
       Copula margin(copula.getMarginal(i));
       fullprint << "margin=" << margin << std::endl;
-      fullprint << "margin PDF=" << margin.computePDF(NumericalPoint(1, 0.25)) << std::endl;
-      fullprint << "margin CDF=" << margin.computeCDF(NumericalPoint(1, 0.25)) << std::endl;
+      fullprint << "margin PDF=" << margin.computePDF(Point(1, 0.25)) << std::endl;
+      fullprint << "margin CDF=" << margin.computeCDF(Point(1, 0.25)) << std::endl;
       fullprint << "margin quantile=" << margin.computeQuantile(0.95) << std::endl;
       fullprint << "margin realization=" << margin.getRealization() << std::endl;
     }
@@ -111,8 +117,8 @@ int main(int argc, char *argv[])
     fullprint << "indices=" << indices << std::endl;
     Copula margins(copula.getMarginal(indices));
     fullprint << "margins=" << margins << std::endl;
-    fullprint << "margins PDF=" << margins.computePDF(NumericalPoint(2, 0.25)) << std::endl;
-    fullprint << "margins CDF=" << margins.computeCDF(NumericalPoint(2, 0.25)) << std::endl;
+    fullprint << "margins PDF=" << margins.computePDF(Point(2, 0.25)) << std::endl;
+    fullprint << "margins CDF=" << margins.computeCDF(Point(2, 0.25)) << std::endl;
     quantile = margins.computeQuantile(0.95);
     fullprint << "margins quantile=" << quantile << std::endl;
     fullprint << "margins CDF(quantile)=" << margins.computeCDF(quantile) << std::endl;
