@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_Mixture_std.cxx
  *  @brief The test file of class Mixture for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,21 +14,19 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
 
 int main(int argc, char *argv[])
 {
-  ResourceMap::Set("DistributionImplementation-parallel", "1");
+  ResourceMap::Set("Distribution-parallel", "1");
   TESTPREAMBLE;
   OStream fullprint(std::cout);
   setRandomGenerator();
@@ -47,12 +44,12 @@ int main(int argc, char *argv[])
       atoms[2] = Normal(3.0, 3.0);
       atoms[2].setWeight(4.0);
       Mixture distribution(atoms);
-      Mixture::NumericalPointWithDescriptionCollection parameters(distribution.getParametersCollection());
+      Mixture::PointWithDescriptionCollection parameters(distribution.getParametersCollection());
       fullprint << "parameters=" << parameters << std::endl;
       for (UnsignedInteger i = 0; i < 6; ++i) fullprint << "standard moment n=" << i << ", value=" << distribution.getStandardMoment(i) << std::endl;
-      fullprint << "Standard representative=" << distribution.getStandardRepresentative()->__str__() << std::endl;
+      fullprint << "Standard representative=" << distribution.getStandardRepresentative().__str__() << std::endl;
       // get weights used
-      NumericalPoint weights(distribution.getWeights());
+      Point weights(distribution.getWeights());
       fullprint << "weights=" << weights << std::endl;
       // Fix new weights
       weights[0] = 0.2;
@@ -61,11 +58,11 @@ int main(int argc, char *argv[])
       distribution.setWeights(weights);
       fullprint << "New weights=" << distribution.getWeights() << std::endl;
     }
-    UnsignedInteger dimension(3);
-    NumericalPoint meanPoint(dimension, 1.0);
+    UnsignedInteger dimension = 3;
+    Point meanPoint(dimension, 1.0);
     meanPoint[0] = 0.5;
     meanPoint[1] = -0.5;
-    NumericalPoint sigma(dimension, 1.0);
+    Point sigma(dimension, 1.0);
     sigma[0] = 2.0;
     sigma[1] = 3.0;
     CorrelationMatrix R(dimension);
@@ -77,13 +74,13 @@ int main(int argc, char *argv[])
     Mixture::DistributionCollection aCollection;
 
     aCollection.add( Normal(meanPoint, sigma, R) );
-    meanPoint += NumericalPoint(dimension, 1.0);
+    meanPoint += Point(dimension, 1.0);
     aCollection.add( Normal(meanPoint, sigma, R) );
-    meanPoint += NumericalPoint(dimension, 1.0);
+    meanPoint += Point(dimension, 1.0);
     aCollection.add( Normal(meanPoint, sigma, R) );
 
     // Instanciate one distribution object
-    Mixture distribution(aCollection, NumericalPoint(aCollection.getSize(), 2.0));
+    Mixture distribution(aCollection, Point(aCollection.getSize(), 2.0));
     fullprint << "Distribution " << distribution << std::endl;
     distribution = Mixture(aCollection);
     fullprint << "Distribution " << distribution.__str__() << std::endl;
@@ -95,12 +92,12 @@ int main(int argc, char *argv[])
     fullprint << "Continuous = " << (distribution.isContinuous() ? "true" : "false") << std::endl;
 
     // Test for realization of distribution
-    NumericalPoint oneRealization = distribution.getRealization();
+    Point oneRealization = distribution.getRealization();
     fullprint << "oneRealization=" << oneRealization << std::endl;
 
     // Test for sampling
     UnsignedInteger size = 1000;
-    NumericalSample oneSample = distribution.getSample( size );
+    Sample oneSample = distribution.getSample( size );
     fullprint << "oneSample first=" << oneSample[0] << " last=" << oneSample[size - 1] << std::endl;
     fullprint << "mean=" << oneSample.computeMean() << std::endl;
     fullprint << "covariance=" << oneSample.computeCovariance() << std::endl;
@@ -114,48 +111,71 @@ int main(int argc, char *argv[])
       }
     }
     // Define a point
-    NumericalPoint point( dimension, 1.0 );
+    Point point( dimension, 1.0 );
     fullprint << "Point= " << point << std::endl;
 
     // Show PDF and CDF of point
-    NumericalScalar eps(1e-5);
-    NumericalPoint DDF = distribution.computeDDF( point );
+    Scalar eps = 1e-5;
+    Point DDF = distribution.computeDDF( point );
     fullprint << "ddf     =" << DDF << std::endl;
-    NumericalPoint ddfFD(dimension);
+    Point ddfFD(dimension);
     for (UnsignedInteger i = 0; i < dimension; i++)
     {
-      NumericalPoint left(point);
+      Point left(point);
       left[i] += eps;
-      NumericalPoint right(point);
+      Point right(point);
       right[i] -= eps;
       ddfFD[i] = (distribution.computePDF(left) - distribution.computePDF(right)) / (2.0 * eps);
     }
     fullprint << "ddf (FD)=" << ddfFD << std::endl;
-    NumericalScalar LPDF = distribution.computeLogPDF( point );
+    Scalar LPDF = distribution.computeLogPDF( point );
     fullprint << "log pdf=" << LPDF << std::endl;
-    NumericalScalar PDF = distribution.computePDF( point );
+    Scalar PDF = distribution.computePDF( point );
     fullprint << "pdf     =" << PDF << std::endl;
     if (dimension == 1)
     {
-      fullprint << "pdf (FD)=" << (distribution.computeCDF( point + NumericalPoint(1, eps) ) - distribution.computeCDF( point  + NumericalPoint(1, -eps) )) / (2.0 * eps) << std::endl;
+      fullprint << "pdf (FD)=" << (distribution.computeCDF( point + Point(1, eps) ) - distribution.computeCDF( point  + Point(1, -eps) )) / (2.0 * eps) << std::endl;
     }
-    NumericalScalar CDF = distribution.computeCDF( point );
+    Scalar CDF = distribution.computeCDF( point );
     fullprint << "cdf=" << CDF << std::endl;
-    NumericalScalar CCDF = distribution.computeComplementaryCDF( point );
+    Scalar CCDF = distribution.computeComplementaryCDF( point );
     fullprint << "ccdf=" << CCDF << std::endl;
-    NumericalScalar Survival = distribution.computeSurvivalFunction( point );
+    Scalar Survival = distribution.computeSurvivalFunction( point );
     fullprint << "survival =" << Survival << std::endl;
+    Point InverseSurvival = distribution.computeInverseSurvivalFunction(0.95);
+    fullprint << "Inverse survival=" << InverseSurvival << std::endl;
+    fullprint << "Survival(inverse survival)=" << distribution.computeSurvivalFunction(InverseSurvival) << std::endl;
     if (dimension == 1)
     {
-      NumericalComplex CF = distribution.computeCharacteristicFunction( point[0] );
+      Complex CF = distribution.computeCharacteristicFunction( point[0] );
       fullprint << "characteristic function=" << CF << std::endl;
-      NumericalComplex LCF = distribution.computeLogCharacteristicFunction( point[0] );
+      Complex LCF = distribution.computeLogCharacteristicFunction( point[0] );
       fullprint << "log characteristic function=" << LCF << std::endl;
     }
-    NumericalPoint quantile = distribution.computeQuantile( 0.95 );
+    Point quantile = distribution.computeQuantile( 0.95 );
     fullprint << "quantile=" << quantile << std::endl;
     fullprint << "cdf(quantile)=" << distribution.computeCDF(quantile) << std::endl;
-    NumericalPoint mean = distribution.getMean();
+    if (distribution.getDimension() <= 2)
+    {
+      // Confidence regions
+      Scalar threshold;
+      fullprint << "Minimum volume interval=" << distribution.computeMinimumVolumeIntervalWithMarginalProbability(0.95, threshold) << std::endl;
+      fullprint << "threshold=" << threshold << std::endl;
+      Scalar beta;
+      LevelSet levelSet(distribution.computeMinimumVolumeLevelSetWithThreshold(0.95, beta));
+      fullprint << "Minimum volume level set=" << levelSet << std::endl;
+      fullprint << "beta=" << beta << std::endl;
+      fullprint << "Bilateral confidence interval=" << distribution.computeBilateralConfidenceIntervalWithMarginalProbability(0.95, beta) << std::endl;
+      fullprint << "beta=" << beta << std::endl;
+      fullprint << "Unilateral confidence interval (lower tail)=" << distribution.computeUnilateralConfidenceIntervalWithMarginalProbability(0.95, false, beta) << std::endl;
+      fullprint << "beta=" << beta << std::endl;
+      fullprint << "Unilateral confidence interval (upper tail)=" << distribution.computeUnilateralConfidenceIntervalWithMarginalProbability(0.95, true, beta) << std::endl;
+      fullprint << "beta=" << beta << std::endl;
+    }
+    // Takes too much time. Exact result is 6.0593
+    // fullprint << "entropy=" << distribution.computeEntropy() << std::endl;
+    // fullprint << "entropy (MC)=" << -distribution.computeLogPDF(distribution.getSample(1000000)).computeMean()[0] << std::endl;
+    Point mean = distribution.getMean();
     fullprint << "mean=" << mean << std::endl;
     CovarianceMatrix covariance = distribution.getCovariance();
     fullprint << "covariance=" << covariance << std::endl;
@@ -165,11 +185,11 @@ int main(int argc, char *argv[])
 //     fullprint << "spearman=" << spearman << std::endl;
 //     CovarianceMatrix kendall = distribution.getKendallTau();
 //     fullprint << "kendall=" << kendall << std::endl;
-    Mixture::NumericalPointWithDescriptionCollection parameters = distribution.getParametersCollection();
+    Mixture::PointWithDescriptionCollection parameters = distribution.getParametersCollection();
     fullprint << "parameters=" << parameters << std::endl;
 
     // Constructor with separate weights. Also check small weights removal
-    NumericalPoint weights;
+    Point weights;
     Mixture::DistributionCollection atoms;
     weights.add(1.0e-20);
     atoms.add(Normal(1.0, 1.0));
@@ -194,3 +214,4 @@ int main(int argc, char *argv[])
 
   return ExitCode::Success;
 }
+
