@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_Multinomial_std.cxx
  *  @brief The test file of class Multinomial for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -30,7 +27,7 @@ using namespace OT::Test;
 class TestObject : public Multinomial
 {
 public:
-  TestObject() : Multinomial(5, NumericalPoint(3, 0.25)) {}
+  TestObject() : Multinomial(5, Point(3, 0.25)) {}
   virtual ~TestObject() {}
 };
 
@@ -51,7 +48,7 @@ int main(int argc, char *argv[])
     }
 
     // Instanciate one distribution object
-    Multinomial distribution(5, NumericalPoint(3, 0.25));
+    Multinomial distribution(5, Point(3, 0.25));
     fullprint << "Distribution " << distribution << std::endl;
     std::cout << "Distribution " << distribution << std::endl;
 
@@ -62,40 +59,42 @@ int main(int argc, char *argv[])
     fullprint << "Continuous = " << (distribution.isContinuous() ? "true" : "false") << std::endl;
 
     // Test for realization of distribution
-    NumericalPoint oneRealization = distribution.getRealization();
+    Point oneRealization = distribution.getRealization();
     fullprint << "oneRealization=" << oneRealization << std::endl;
 
     // Test for sampling
     UnsignedInteger size = 10000;
-    NumericalSample oneSample = distribution.getSample( size );
+    Sample oneSample = distribution.getSample( size );
     fullprint << "oneSample first=" << oneSample[0] << " last=" << oneSample[size - 1] << std::endl;
     fullprint << "mean=" << oneSample.computeMean() << std::endl;
     fullprint << "covariance=" << oneSample.computeCovariance() << std::endl;
     // Support
-    NumericalSample support(distribution.getSupport());
+    Sample support(distribution.getSupport());
     fullprint << "support=" << support << std::endl;
-    Interval interval(NumericalPoint(distribution.getDimension(), 1.0), NumericalPoint(distribution.getDimension(), 3.0));
-    NumericalSample restrictedSupport(distribution.getSupport(interval));
+    Interval interval(Point(distribution.getDimension(), 1.0), Point(distribution.getDimension(), 3.0));
+    Sample restrictedSupport(distribution.getSupport(interval));
     fullprint << "support restricted to the interval=" << interval << " gives=" << restrictedSupport << std::endl;
     // Define a point
-    NumericalPoint point( distribution.getDimension(), 1.0 );
+    Point point( distribution.getDimension(), 1.0 );
     fullprint << "Point= " << point << std::endl;
 
     // Show PDF and CDF of point
-    NumericalScalar LPDF = distribution.computeLogPDF( point );
+    Scalar LPDF = distribution.computeLogPDF( point );
     fullprint << "log pdf=" << LPDF << std::endl;
-    NumericalScalar PDF = distribution.computePDF( point );
+    Scalar PDF = distribution.computePDF( point );
     fullprint << "pdf     =" << PDF << std::endl;
-    NumericalScalar CDF = distribution.computeCDF( point );
+    Scalar CDF = distribution.computeCDF( point );
     fullprint << "cdf=" << std::setprecision(5) << CDF << std::setprecision(6) << std::endl;
-    NumericalScalar CCDF = distribution.computeComplementaryCDF( point );
+    Scalar CCDF = distribution.computeComplementaryCDF( point );
     fullprint << "ccdf=" << std::setprecision(5) << CCDF << std::setprecision(6) << std::endl;
-    //    NumericalScalar Survival = distribution.computeSurvivalFunction( point );
+    //    Scalar Survival = distribution.computeSurvivalFunction( point );
     //    fullprint << "survival=" << Survival << std::endl;
-    NumericalPoint quantile = distribution.computeQuantile( 0.95 );
+    Point quantile = distribution.computeQuantile( 0.95 );
     fullprint << "quantile=" << quantile << std::endl;
     fullprint << "cdf(quantile)=" << distribution.computeCDF(quantile) << std::endl;
-    NumericalPoint mean = distribution.getMean();
+    fullprint << "entropy=" << distribution.computeEntropy() << std::endl;
+    fullprint << "entropy (MC)=" << -distribution.computeLogPDF(distribution.getSample(1000000)).computeMean()[0] << std::endl;
+    Point mean = distribution.getMean();
     fullprint << "mean=" << mean << std::endl;
     CovarianceMatrix covariance = distribution.getCovariance();
     fullprint << "covariance=" << covariance << std::endl;
@@ -105,7 +104,7 @@ int main(int argc, char *argv[])
     //    fullprint << "spearman=" << spearman << std::endl;
     //    CovarianceMatrix kendall = distribution.getKendallTau();
     //    fullprint << "kendall=" << kendall << std::endl;
-    Multinomial::NumericalPointWithDescriptionCollection parameters = distribution.getParametersCollection();
+    Multinomial::PointWithDescriptionCollection parameters = distribution.getParametersCollection();
     fullprint << "parameters=" << parameters << std::endl;
   }
   catch (TestFailed & ex)
