@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_NormalCopulaFactory_std.cxx
  *  @brief The test file of class NormalCopula for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -35,7 +32,7 @@ int main(int argc, char *argv[])
 
   try
   {
-    UnsignedInteger dim(3);
+    UnsignedInteger dim = 3;
     CorrelationMatrix R(dim);
     for (UnsignedInteger i = 0; i < dim; i++)
     {
@@ -45,8 +42,8 @@ int main(int argc, char *argv[])
       }
     }
     NormalCopula distribution(R);
-    UnsignedInteger size(10000);
-    NumericalSample sample(distribution.getSample(size));
+    UnsignedInteger size = 10000;
+    Sample sample(distribution.getSample(size));
     NormalCopulaFactory factory;
     CovarianceMatrix covariance;
     // Distribution estimatedDistribution(factory.build(sample, covariance));
