@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_NormalFactory_std.cxx
  *  @brief The test file of class Normal for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -35,9 +32,9 @@ int main(int argc, char *argv[])
 
   try
   {
-    UnsignedInteger dim(3);
-    NumericalPoint mean(dim);
-    NumericalPoint sigma(dim);
+    UnsignedInteger dim = 3;
+    Point mean(dim);
+    Point sigma(dim);
     CorrelationMatrix R(dim);
     for (UnsignedInteger i = 0; i < dim; i++)
     {
@@ -49,8 +46,8 @@ int main(int argc, char *argv[])
       }
     }
     Normal distribution(mean, sigma, R);
-    UnsignedInteger size(10000);
-    NumericalSample sample(distribution.getSample(size));
+    UnsignedInteger size = 10000;
+    Sample sample(distribution.getSample(size));
     NormalFactory factory;
     CovarianceMatrix covariance;
     // Distribution estimatedDistribution(factory.build(sample, covariance));
@@ -60,14 +57,14 @@ int main(int argc, char *argv[])
     // fullprint << "Covariance=" << covariance << std::endl;
     estimatedDistribution = factory.build();
     fullprint << "Default distribution=" << estimatedDistribution << std::endl;
-    estimatedDistribution = factory.build(distribution.getParametersCollection());
+    estimatedDistribution = factory.build(distribution.getParameter());
     fullprint << "Distribution from parameters=" << estimatedDistribution << std::endl;
     Normal estimatedNormal(factory.buildAsNormal(sample));
     fullprint << "Normal          =" << distribution << std::endl;
     fullprint << "Estimated normal=" << estimatedNormal << std::endl;
     estimatedNormal = factory.buildAsNormal();
     fullprint << "Default normal=" << estimatedNormal << std::endl;
-    estimatedNormal = factory.buildAsNormal(distribution.getParametersCollection());
+    estimatedNormal = factory.buildAsNormal(distribution.getParameter());
     fullprint << "Normal from parameters=" << estimatedNormal << std::endl;
   }
   catch (TestFailed & ex)
