@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_Normal_large.cxx
  *  @brief The test file of class Normal for large dimension vector
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -37,9 +34,9 @@ int main(int argc, char *argv[])
   {
     // Big test case for correlated components
     // Instanciate one distribution object
-    UnsignedInteger dim(4);
-    NumericalPoint meanPoint(dim, 1.0);
-    NumericalPoint sigma(dim, 1.0);
+    UnsignedInteger dim = 4;
+    Point meanPoint(dim, 1.0);
+    Point sigma(dim, 1.0);
     CorrelationMatrix R(dim);
     for (UnsignedInteger i = 1; i < dim; i++)
     {
@@ -50,27 +47,27 @@ int main(int argc, char *argv[])
 
     // Test for sampling
     UnsignedInteger size = 1000;
-    NumericalSample oneSample = distribution.getSample( size );
+    Sample oneSample = distribution.getSample( size );
     fullprint << "sample of size " << size << " first=" << oneSample[0] << " last=" << oneSample[oneSample.getSize() - 1] << std::endl;
-    NumericalPoint mean(oneSample.computeMean());
+    Point mean(oneSample.computeMean());
     fullprint << "mean error (relative)=" << (mean - meanPoint).norm() / meanPoint.norm() << std::endl;
     CovarianceMatrix covariance(oneSample.computeCovariance());
-    NumericalScalar errorCovariance(0.0);
+    Scalar errorCovariance = 0.0;
     for (UnsignedInteger i = 0; i < dim; i++)
     {
       for (UnsignedInteger j = 0; j < dim; j++)
       {
-        errorCovariance += fabs(covariance(i, j) - sigma[i] * sigma[j] * R(i, j));
+        errorCovariance += std::abs(covariance(i, j) - sigma[i] * sigma[j] * R(i, j));
       }
     }
     fullprint << "covariance error (absolute, normalized)=" << errorCovariance / (dim * dim) << std::endl;
 
     // Define a point
-    NumericalPoint zero(dim, 0.0);
+    Point zero(dim, 0.0);
 
     // Show PDF of zero point
-    NumericalScalar zeroPDF = distribution.computePDF( zero );
-    NumericalScalar zeroCDF = distribution.computeCDF( zero );
+    Scalar zeroPDF = distribution.computePDF( zero );
+    Scalar zeroCDF = distribution.computeCDF( zero );
     fullprint << "Zero point= " << zero
               << " pdf=" << zeroPDF
               << " cdf=" << zeroCDF
@@ -81,8 +78,8 @@ int main(int argc, char *argv[])
     {
       Distribution margin(distribution.getMarginal(i));
       fullprint << "margin=" << margin << std::endl;
-      fullprint << "margin PDF=" << margin.computePDF(NumericalPoint(1)) << std::endl;
-      fullprint << "margin CDF=" << margin.computeCDF(NumericalPoint(1)) << std::endl;
+      fullprint << "margin PDF=" << margin.computePDF(Point(1)) << std::endl;
+      fullprint << "margin CDF=" << margin.computeCDF(Point(1)) << std::endl;
       fullprint << "margin quantile=" << margin.computeQuantile(0.5) << std::endl;
       fullprint << "margin realization=" << margin.getRealization() << std::endl;
     }
@@ -94,9 +91,9 @@ int main(int argc, char *argv[])
     fullprint << "indices=" << indices << std::endl;
     Distribution margins(distribution.getMarginal(indices));
     fullprint << "margins=" << margins << std::endl;
-    fullprint << "margins PDF=" << margins.computePDF(NumericalPoint(2)) << std::endl;
-    fullprint << "margins CDF=" << margins.computeCDF(NumericalPoint(2)) << std::endl;
-    NumericalPoint quantile = margins.computeQuantile(0.5);
+    fullprint << "margins PDF=" << margins.computePDF(Point(2)) << std::endl;
+    fullprint << "margins CDF=" << margins.computeCDF(Point(2)) << std::endl;
+    Point quantile = margins.computeQuantile(0.5);
     fullprint << "margins quantile=" << quantile << std::endl;
     fullprint << "margins CDF(quantile)=" << margins.computeCDF(quantile) << std::endl;
     fullprint << "margins realization=" << margins.getRealization() << std::endl;
@@ -104,8 +101,8 @@ int main(int argc, char *argv[])
 
     // Very big test case for independent components
     dim = 200;
-    meanPoint = NumericalPoint(dim, 0.1);
-    sigma = NumericalPoint(dim, 1.0);
+    meanPoint = Point(dim, 0.1);
+    sigma = Point(dim, 1.0);
 
     distribution = Normal(meanPoint, sigma, IdentityMatrix(dim));
     fullprint << "Has independent copula? " << (distribution.hasIndependentCopula() ? "true" : "false") << std::endl;
@@ -120,13 +117,13 @@ int main(int argc, char *argv[])
     {
       for (UnsignedInteger j = 0; j < dim; j++)
       {
-        errorCovariance += fabs(covariance(i, j) - (i == j ? sigma[i] * sigma[j] : 0));
+        errorCovariance += std::abs(covariance(i, j) - (i == j ? sigma[i] * sigma[j] : 0));
       }
     }
     fullprint << "covariance error (absolute, normalized)=" << errorCovariance / (dim * dim) << std::endl;
 
     // Define a point
-    zero = NumericalPoint(dim, 0.0);
+    zero = Point(dim, 0.0);
 
     // Show PDF and CDF of zero point
     zeroPDF = distribution.computePDF( zero );
