@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_Normal_std.cxx
  *  @brief The test file of class Normal for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,35 +14,34 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
 
-inline NumericalScalar clean(NumericalScalar in)
+inline Scalar clean(Scalar in)
 {
-  if (fabs(in) < 1.e-10) in = 0.0;
+  if (std::abs(in) < 1.e-10) in = 0.0;
   return in;
 }
 
-inline NumericalPoint clean(NumericalPoint in)
+inline Point clean(Point in)
 {
-  UnsignedInteger dim(in.getDimension());
+  UnsignedInteger dim = in.getDimension();
   for(UnsignedInteger i = 0; i < dim; i++)
-    if (fabs(in[i]) < 1.e-10) in[i] = 0.0;
+    if (std::abs(in[i]) < 1.e-10) in[i] = 0.0;
   return in;
 }
 
 int main(int argc, char *argv[])
 {
   TESTPREAMBLE;
+
   OStream fullprint(std::cout);
   setRandomGenerator();
   try
@@ -52,8 +50,8 @@ int main(int argc, char *argv[])
     for (UnsignedInteger dim = 1; dim <= 4; dim++)
     {
       fullprint << "\n*** Case " << dim << " ***\n" << std::endl;
-      NumericalPoint meanPoint(dim, 0.0);
-      NumericalPoint sigma(dim);
+      Point meanPoint(dim, 0.0);
+      Point sigma(dim);
       for (UnsignedInteger i = 0; i < dim; i++)
       {
         sigma[i] = i + 1.0;
@@ -75,7 +73,7 @@ int main(int argc, char *argv[])
       fullprint << std::setprecision(5);
       fullprint << "Parameters collection=" << distribution.getParametersCollection() << std::endl;
       for (UnsignedInteger i = 0; i < 6; ++i) fullprint << "standard moment n=" << i << ", value=" << distribution.getStandardMoment(i) << std::endl;
-      fullprint << "Standard representative=" << distribution.getStandardRepresentative()->__str__() << std::endl;
+      fullprint << "Standard representative=" << distribution.getStandardRepresentative().__str__() << std::endl;
       fullprint << "Distribution " << distribution << std::endl;
       std::cout << "Distribution " << distribution << std::endl;
 
@@ -86,12 +84,12 @@ int main(int argc, char *argv[])
       fullprint << "Continuous = " << (distribution.isContinuous() ? "true" : "false") << std::endl;
 
       // Test for realization of distribution
-      NumericalPoint oneRealization = distribution.getRealization();
+      Point oneRealization = distribution.getRealization();
       fullprint << "oneRealization=" << oneRealization << std::endl;
 
       // Test for sampling
       UnsignedInteger size = 10000;
-      NumericalSample oneSample(distribution.getSample( size ));
+      Sample oneSample(distribution.getSample( size ));
       fullprint << "oneSample first=" << oneSample[0] << " last=" << oneSample[size - 1] << std::endl;
       fullprint << "mean=" << oneSample.computeMean() << std::endl;
       fullprint << "covariance=" << oneSample.computeCovariance() << std::endl;
@@ -107,39 +105,42 @@ int main(int argc, char *argv[])
       }
 
       // Define a point
-      NumericalPoint point( distribution.getDimension(), 0.5 );
+      Point point( distribution.getDimension(), 0.5 );
       fullprint << "Point= " << point << std::endl;
 
       // Show PDF and CDF of point
-      NumericalScalar eps(1e-4);
-      NumericalPoint DDF = distribution.computeDDF( point );
+      Scalar eps = 1e-4;
+      Point DDF = distribution.computeDDF( point );
       fullprint << "ddf     =" << clean(DDF) << std::endl;
-      NumericalPoint ddfFD(distribution.ContinuousDistribution::computeDDF(point));
+      Point ddfFD(distribution.ContinuousDistribution::computeDDF(point));
       fullprint << "ddf (FD)=" << clean(ddfFD) << std::endl;
-      NumericalScalar LPDF = distribution.computeLogPDF( point );
+      Scalar LPDF = distribution.computeLogPDF( point );
       fullprint << "log pdf=" << LPDF << std::endl;
-      NumericalScalar PDF = distribution.computePDF( point );
+      Scalar PDF = distribution.computePDF( point );
       fullprint << "pdf     =" << PDF << std::endl;
       if (dim == 1)
       {
-        fullprint << "pdf (FD)=" << clean((distribution.computeCDF( point + NumericalPoint(1, eps) ) - distribution.computeCDF( point  + NumericalPoint(1, -eps) )) / (2.0 * eps)) << std::endl;
+        fullprint << "pdf (FD)=" << clean((distribution.computeCDF( point + Point(1, eps) ) - distribution.computeCDF( point  + Point(1, -eps) )) / (2.0 * eps)) << std::endl;
       }
-      NumericalScalar CDF = distribution.computeCDF( point );
+      Scalar CDF = distribution.computeCDF( point );
       fullprint << "cdf=" << CDF << std::endl;
       if (dim == 1)
       {
-        NumericalScalar CCDF = distribution.computeComplementaryCDF( point );
+        Scalar CCDF = distribution.computeComplementaryCDF( point );
         fullprint << "ccdf=" << CCDF << std::endl;
       }
-      NumericalScalar Survival = distribution.computeSurvivalFunction( point );
+      Scalar Survival = distribution.computeSurvivalFunction( point );
       fullprint << "survival=" << Survival << std::endl;
-      NumericalComplex CF = distribution.computeCharacteristicFunction( point );
+      Point InverseSurvival = distribution.computeInverseSurvivalFunction(0.95);
+      fullprint << "Inverse survival=" << InverseSurvival << std::endl;
+      fullprint << "Survival(inverse survival)=" << distribution.computeSurvivalFunction(InverseSurvival) << std::endl;
+      Complex CF = distribution.computeCharacteristicFunction( point );
       fullprint << "characteristic function=" << CF << std::endl;
-      NumericalComplex LCF = distribution.computeLogCharacteristicFunction( point );
+      Complex LCF = distribution.computeLogCharacteristicFunction( point );
       fullprint << "log characteristic function=" << LCF << std::endl;
-      NumericalPoint PDFgr = distribution.computePDFGradient( point );
+      Point PDFgr = distribution.computePDFGradient( point );
       fullprint << "pdf gradient     =" << clean(PDFgr) << std::endl;
-      NumericalPoint PDFgrFD(2 * dim);
+      Point PDFgrFD(2 * dim);
       for (UnsignedInteger i = 0; i < dim; i++)
       {
         meanPoint[i] += eps;
@@ -159,21 +160,40 @@ int main(int argc, char *argv[])
         sigma[i] += eps;
       }
       fullprint << "pdf gradient (FD)=" << clean(PDFgrFD) << std::endl;
-      NumericalPoint CDFgr = distribution.computeCDFGradient( point );
+      Point CDFgr = distribution.computeCDFGradient( point );
       fullprint << "cdf gradient     =" << CDFgr << std::endl;
-      NumericalPoint quantile = distribution.computeQuantile( 0.95 );
+      Point quantile = distribution.computeQuantile( 0.95 );
       int oldPrecision = PlatformInfo::GetNumericalPrecision();
       PlatformInfo::SetNumericalPrecision( 4 );
       fullprint << "quantile=" << quantile << std::endl;
       PlatformInfo::SetNumericalPrecision( oldPrecision );
       fullprint << "cdf(quantile)=" << distribution.computeCDF(quantile) << std::endl;
-      NumericalPoint mean = distribution.getMean();
+      if (distribution.getDimension() <= 2)
+      {
+        // Confidence regions
+        Scalar threshold;
+        fullprint << "Minimum volume interval=" << distribution.computeMinimumVolumeIntervalWithMarginalProbability(0.95, threshold) << std::endl;
+        fullprint << "threshold=" << threshold << std::endl;
+        Scalar beta;
+        LevelSet levelSet(distribution.computeMinimumVolumeLevelSetWithThreshold(0.95, beta));
+        fullprint << "Minimum volume level set=" << levelSet << std::endl;
+        fullprint << "beta=" << beta << std::endl;
+        fullprint << "Bilateral confidence interval=" << distribution.computeBilateralConfidenceIntervalWithMarginalProbability(0.95, beta) << std::endl;
+        fullprint << "beta=" << beta << std::endl;
+        fullprint << "Unilateral confidence interval (lower tail)=" << distribution.computeUnilateralConfidenceIntervalWithMarginalProbability(0.95, false, beta) << std::endl;
+        fullprint << "beta=" << beta << std::endl;
+        fullprint << "Unilateral confidence interval (upper tail)=" << distribution.computeUnilateralConfidenceIntervalWithMarginalProbability(0.95, true, beta) << std::endl;
+        fullprint << "beta=" << beta << std::endl;
+      }
+      fullprint << "entropy=" << distribution.computeEntropy() << std::endl;
+      fullprint << "entropy (MC)=" << -distribution.computeLogPDF(distribution.getSample(1000000)).computeMean()[0] << std::endl;
+      Point mean = distribution.getMean();
       fullprint << "mean=" << mean << std::endl;
-      NumericalPoint standardDeviation = distribution.getStandardDeviation();
+      Point standardDeviation = distribution.getStandardDeviation();
       fullprint << "standard deviation=" << standardDeviation << std::endl;
-      NumericalPoint skewness = distribution.getSkewness();
+      Point skewness = distribution.getSkewness();
       fullprint << "skewness=" << skewness << std::endl;
-      NumericalPoint kurtosis = distribution.getKurtosis();
+      Point kurtosis = distribution.getKurtosis();
       fullprint << "kurtosis=" << kurtosis << std::endl;
       CovarianceMatrix covariance = distribution.getCovariance();
       fullprint << "covariance=" << covariance << std::endl;
@@ -183,32 +203,32 @@ int main(int argc, char *argv[])
       fullprint << "spearman=" << spearman << std::endl;
       CovarianceMatrix kendall = distribution.getKendallTau();
       fullprint << "kendall=" << kendall << std::endl;
-      Normal::NumericalPointWithDescriptionCollection parameters = distribution.getParametersCollection();
+      Normal::PointWithDescriptionCollection parameters = distribution.getParametersCollection();
       fullprint << "parameters=" << parameters << std::endl;
       for (UnsignedInteger i = 0; i < 6; ++i) fullprint << "standard moment n=" << i << ", value=" << distribution.getStandardMoment(i) << std::endl;
-      fullprint << "Standard representative=" << distribution.getStandardRepresentative()->__str__() << std::endl;
+      fullprint << "Standard representative=" << distribution.getStandardRepresentative().__str__() << std::endl;
 
       // Specific to this distribution
-      NumericalScalar beta(point.normSquare());
-      NumericalScalar densityGenerator(distribution.computeDensityGenerator(beta));
+      Scalar beta = point.normSquare();
+      Scalar densityGenerator = distribution.computeDensityGenerator(beta);
       fullprint << "density generator=" << densityGenerator << std::endl;
       fullprint << "pdf via density generator=" << distribution.EllipticalDistribution::computePDF(point) << std::endl;
-      NumericalScalar densityGeneratorDerivative(distribution.computeDensityGeneratorDerivative(beta));
+      Scalar densityGeneratorDerivative = distribution.computeDensityGeneratorDerivative(beta);
       fullprint << "density generator derivative     =" << densityGeneratorDerivative << std::endl;
       fullprint << "density generator derivative (FD)=" << clean((distribution.computeDensityGenerator(beta + eps) - distribution.computeDensityGenerator(beta - eps)) / (2.0 * eps)) << std::endl;
-      NumericalScalar densityGeneratorSecondDerivative(distribution.computeDensityGeneratorSecondDerivative(beta));
+      Scalar densityGeneratorSecondDerivative = distribution.computeDensityGeneratorSecondDerivative(beta);
       fullprint << "density generator second derivative     =" << densityGeneratorSecondDerivative << std::endl;
       fullprint << "density generator second derivative (FD)=" << clean((distribution.computeDensityGeneratorDerivative(beta + eps) - distribution.computeDensityGeneratorDerivative(beta - eps)) / (2.0 * eps)) << std::endl;
       // Compute the radial CDF
-      NumericalScalar radius(2.0);
+      Scalar radius = 2.0;
       fullprint << "Radial CDF(" << radius << ")=" << distribution.computeRadialDistributionCDF(radius) << std::endl;
       // Extract the marginals
       for (UnsignedInteger i = 0; i < dim; i++)
       {
         Distribution margin(distribution.getMarginal(i));
         fullprint << "margin=" << margin << std::endl;
-        fullprint << "margin PDF=" << margin.computePDF(NumericalPoint(1, 0.5)) << std::endl;
-        fullprint << "margin CDF=" << margin.computeCDF(NumericalPoint(1, 0.5)) << std::endl;
+        fullprint << "margin PDF=" << margin.computePDF(Point(1, 0.5)) << std::endl;
+        fullprint << "margin CDF=" << margin.computeCDF(Point(1, 0.5)) << std::endl;
         fullprint << "margin quantile=" << margin.computeQuantile(0.95) << std::endl;
         fullprint << "margin realization=" << margin.getRealization() << std::endl;
       }
@@ -221,8 +241,8 @@ int main(int argc, char *argv[])
         fullprint << "indices=" << indices << std::endl;
         Distribution margins(distribution.getMarginal(indices));
         fullprint << "margins=" << margins << std::endl;
-        fullprint << "margins PDF=" << margins.computePDF(NumericalPoint(2, 0.5)) << std::endl;
-        fullprint << "margins CDF=" << margins.computeCDF(NumericalPoint(2, 0.5)) << std::endl;
+        fullprint << "margins PDF=" << margins.computePDF(Point(2, 0.5)) << std::endl;
+        fullprint << "margins CDF=" << margins.computeCDF(Point(2, 0.5)) << std::endl;
         quantile = margins.computeQuantile(0.95);
         fullprint << "margins quantile=" << quantile << std::endl;
         fullprint << "margins CDF(quantile)=" << margins.computeCDF(quantile) << std::endl;
@@ -234,7 +254,41 @@ int main(int argc, char *argv[])
       fullprint << "invchol=" << invChol.clean(1.0e-6) << std::endl;
       fullprint << "chol*t(chol)=" << (chol * chol.transpose()).clean(1.0e-6) << std::endl;
       fullprint << "chol*invchol=" << (chol * invChol).clean(1.0e-6) << std::endl;
-    }
+      {
+        // Comparison with another elliptical distribution
+        const Bool equal = distribution == Student(4.5, meanPoint, sigma, R);
+        fullprint << "Comparison with a Student distribution " << std::boolalpha << equal << std::endl;
+      }
+      {
+        // Comparison with a non-elliptical distribution
+        const Bool equal = distribution == Exponential();
+        fullprint << "Comparison with an Exponential distribution " << std::boolalpha << equal << std::endl;
+      }
+      {
+        // Comparison with itself
+        const Bool equal = distribution == distribution;
+        fullprint << "Comparison with itself " << std::boolalpha << equal << std::endl;
+      }
+      // {
+      //   // Comparison with itself, as a Distribution
+      //   const Bool equal = distribution == Distribution(distribution);
+      //   fullprint << "Comparison with itself as a distribution" << std::boolalpha << equal << std::endl;
+      // }
+      {
+        // Comparison with a clone
+        Normal other(distribution.getDimension());
+        other.setParameter(distribution.getParameter());
+        const Bool equal = distribution == other;
+        fullprint << "Comparison with a clone " << std::boolalpha << equal << std::endl;
+      }
+      {
+        // Comparison with another member of the same family
+        Normal other(distribution.getDimension());
+        other.setParameter(distribution.getParameter() * 0.5);
+        const Bool equal = distribution == other;
+        fullprint << "Comparison with another member " << std::boolalpha << equal << std::endl;
+      }
+    } // dim
   }
   catch (TestFailed & ex)
   {
