@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_Normal_wrongarg.cxx
  *  @brief The test file of class Normal with wrong arguments
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -30,7 +27,7 @@ using namespace OT::Test;
 class TestObject : public Normal
 {
 public:
-  TestObject() : Normal(NumericalPoint(1), NumericalPoint(1), CorrelationMatrix(1)) {}
+  TestObject() : Normal(Point(1), Point(1), CorrelationMatrix(1)) {}
   virtual ~TestObject() {}
 };
 
@@ -47,9 +44,9 @@ int main(int argc, char *argv[])
     {
 
       // Instanciate one distribution object
-      NumericalPoint meanPoint(1);
+      Point meanPoint(1);
       meanPoint[0] = 1.0;
-      NumericalPoint sigma(1);
+      Point sigma(1);
       sigma[0] = 1.0;
       CorrelationMatrix R(1);
       R(0, 0) = 1.0;
