@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_NormalityTest_std.cxx
  *  @brief The test file of class Test
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -89,27 +86,26 @@ int main(int argc, char *argv[])
   distributionCollection.add(poisson);
   discreteDistributionCollection.add(poisson);
 
-  Collection<UserDefinedPair> collection(3, UserDefinedPair(NumericalPoint(1), 0.0));
-
-  NumericalPoint point(1);
-  point[0] = 1.0;
-  collection[0] = UserDefinedPair(point, 0.3);
-  point[0] = 2.0;
-  collection[1] = UserDefinedPair(point, 0.2);
-  point[0] = 3.0;
-  collection[2] = UserDefinedPair(point, 0.5);
-  UserDefined userdefined(collection);
+  Sample x(3, 1);
+  x[0][0] = 1.0;
+  x[1][0] = 2.0;
+  x[2][0] = 3.0;
+  Point p(3);
+  p[0] = 0.3;
+  p[1] = 0.2;
+  p[2] = 0.5;
+  UserDefined userdefined(x, p);
   distributionCollection.add(userdefined);
   discreteDistributionCollection.add(userdefined);
 
-  UnsignedInteger size(10000);
+  UnsignedInteger size = 10000;
 
-  UnsignedInteger continuousDistributionNumber(continuousDistributionCollection.getSize());
-  UnsignedInteger discreteDistributionNumber(discreteDistributionCollection.getSize());
-  UnsignedInteger distributionNumber(continuousDistributionNumber + discreteDistributionNumber);
-  Collection<NumericalSample> sampleCollection(distributionNumber);
-  Collection<NumericalSample> continuousSampleCollection(continuousDistributionNumber);
-  Collection<NumericalSample> discreteSampleCollection(discreteDistributionNumber);
+  UnsignedInteger continuousDistributionNumber = continuousDistributionCollection.getSize();
+  UnsignedInteger discreteDistributionNumber = discreteDistributionCollection.getSize();
+  UnsignedInteger distributionNumber = continuousDistributionNumber + discreteDistributionNumber;
+  Collection<Sample> sampleCollection(distributionNumber);
+  Collection<Sample> continuousSampleCollection(continuousDistributionNumber);
+  Collection<Sample> discreteSampleCollection(discreteDistributionNumber);
   for (UnsignedInteger i = 0; i < continuousDistributionNumber; i++)
   {
     continuousSampleCollection[i] = continuousDistributionCollection[i].getSample(size);
@@ -123,7 +119,7 @@ int main(int argc, char *argv[])
     sampleCollection[continuousDistributionNumber + i] = discreteSampleCollection[i];
   }
   // Test the normality of several samples using the Anderson Darling test
-  NumericalPoint andersonDarlingResult(distributionNumber);
+  Point andersonDarlingResult(distributionNumber);
   for (UnsignedInteger i = 0; i < distributionNumber; i++)
   {
     TestResult result(NormalityTest::AndersonDarlingNormal(sampleCollection[i]));
@@ -132,7 +128,7 @@ int main(int argc, char *argv[])
   }
   fullprint << "andersonDarlingResult=" << andersonDarlingResult << std::endl;
   // Test the normality of several samples using the Cramer Von Mises test
-  NumericalPoint cramerVonMisesResult(distributionNumber);
+  Point cramerVonMisesResult(distributionNumber);
   for (UnsignedInteger i = 0; i < distributionNumber; i++)
   {
     TestResult result(NormalityTest::CramerVonMisesNormal(sampleCollection[i]));
