@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_ResourceMap_std.cxx
  *  @brief The test file of class ResourceMap for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2009-09-30 17:51:57 +0200 (mer. 30 sept. 2009)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,9 +33,6 @@ int main(int argc, char *argv[])
   {
     // As the result of these methods is installation dependent, don't check the output
     fullprint << "Installation directory=" << Path::GetInstallationDirectory() << std::endl;
-    Path::DirectoryList wrapperDirectoryList(Path::GetWrapperDirectoryList());
-    for (UnsignedInteger i = 0; i < wrapperDirectoryList.size(); ++i)
-      fullprint << "wrapperDirectoryList[" << i << "]=" << wrapperDirectoryList[i] << std::endl;
     Path::DirectoryList configDirectoryList(Path::GetConfigDirectoryList());
     for (UnsignedInteger i = 0; i < configDirectoryList.size(); ++i)
       fullprint << "configDirectoryList[" << i << "]=" << configDirectoryList[i] << std::endl;
