@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_PenalizedLeastSquaresAlgorithm_std.cxx
  *  @brief The test file of class PenalizedLeastSquaresAlgorithm for the standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2007-08-01 16:47:51 +0200 (mer, 01 aoû 2007)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -34,45 +31,42 @@ int main(int argc, char *argv[])
 
   try
   {
-    UnsignedInteger dimension(2);
+    UnsignedInteger dimension = 2;
     // Reference function
     Description inVar(dimension);
     inVar[0] = "x1";
     inVar[1] = "x2";
-    Description outVar(1);
-    outVar[0] = "y";
     Description formula(1);
     formula[0] = "x1^3+1.5*x2^3-x1*x2";
-    NumericalMathFunction model(inVar, outVar, formula);
+    SymbolicFunction model(inVar, formula);
 
     // Basis upon which we will project the model
-    PenalizedLeastSquaresAlgorithm::NumericalMathFunctionCollection coll(4);
+    PenalizedLeastSquaresAlgorithm::FunctionCollection coll(4);
     formula[0] = "x1";
-    coll[0] = NumericalMathFunction(inVar, outVar, formula);
+    coll[0] = SymbolicFunction(inVar, formula);
     formula[0] = "x2";
-    coll[1] = NumericalMathFunction(inVar, outVar, formula);
+    coll[1] = SymbolicFunction(inVar, formula);
     formula[0] = "x1^2";
-    coll[2] = NumericalMathFunction(inVar, outVar, formula);
+    coll[2] = SymbolicFunction(inVar, formula);
     formula[0] = "x2^2";
-    coll[3] = NumericalMathFunction(inVar, outVar, formula);
-    Basis basis(coll);
+    coll[3] = SymbolicFunction(inVar, formula);
     Indices indices(coll.getSize());
     indices.fill();
 
     // Input sample
-    UnsignedInteger size(5);
-    NumericalSample inputSample(size * size, dimension);
-    NumericalPoint weight(inputSample.getSize());
+    UnsignedInteger size = 5;
+    Sample inputSample(size * size, dimension);
+    Point weight(inputSample.getSize());
     for (UnsignedInteger i = 0; i < inputSample.getSize(); ++i)
     {
-      inputSample[i][0] = NumericalScalar(i % size) / size;
-      inputSample[i][1] = NumericalScalar (i / size) / size;
+      inputSample[i][0] = Scalar(i % size) / size;
+      inputSample[i][1] = Scalar (i / size) / size;
       weight[i] = (i % size + 1) * (i / size + 1);
     }
-    NumericalScalar penalizationFactor(0.25);
+    Scalar penalizationFactor = 0.25;
     // Uniform weight, no penalization
     {
-      PenalizedLeastSquaresAlgorithm algo(inputSample, model(inputSample), NumericalPoint(inputSample.getSize(), 1.0), basis, indices);
+      PenalizedLeastSquaresAlgorithm algo(inputSample, model(inputSample), Point(inputSample.getSize(), 1.0), coll, indices);
       fullprint << "Uniform weight, no penalization" << std::endl;
       fullprint << "Coefficients=" << algo.getCoefficients() << std::endl;
       fullprint << "Residual=" << algo.getResidual() << std::endl;
@@ -80,21 +74,21 @@ int main(int argc, char *argv[])
     }
     // Uniform weight, spherical penalization
     {
-      PenalizedLeastSquaresAlgorithm algo(inputSample, model(inputSample), NumericalPoint(inputSample.getSize(), 1.0), basis, indices, penalizationFactor);
+      PenalizedLeastSquaresAlgorithm algo(inputSample, model(inputSample), Point(inputSample.getSize(), 1.0), coll, indices, penalizationFactor);
       fullprint << "Uniform weight, spherical penalization" << std::endl;
       fullprint << "Coefficients=" << algo.getCoefficients() << std::endl;
       fullprint << "Residual=" << algo.getResidual() << std::endl;
     }
     // Non uniform weight, no penalization
     {
-      PenalizedLeastSquaresAlgorithm algo(inputSample, model(inputSample), weight, basis, indices);
+      PenalizedLeastSquaresAlgorithm algo(inputSample, model(inputSample), weight, coll, indices);
       fullprint << "Non uniform weight, no penalization" << std::endl;
       fullprint << "Coefficients=" << algo.getCoefficients() << std::endl;
       fullprint << "Residual=" << algo.getResidual() << std::endl;
     }
     // Non uniform weight, spherical penalization
     {
-      PenalizedLeastSquaresAlgorithm algo(inputSample, model(inputSample), weight, basis, indices, penalizationFactor);
+      PenalizedLeastSquaresAlgorithm algo(inputSample, model(inputSample), weight, coll, indices, penalizationFactor);
       fullprint << "Non uniform weight, spherical penalization" << std::endl;
       fullprint << "Coefficients=" << algo.getCoefficients() << std::endl;
       fullprint << "Residual=" << algo.getResidual() << std::endl;
@@ -106,7 +100,7 @@ int main(int argc, char *argv[])
         penalizationMatrix(i, i) = 1.0;
       for (UnsignedInteger i = 0; i < 3; ++i)
         penalizationMatrix(i, i + 1) = 1.0 / 8.0;
-      PenalizedLeastSquaresAlgorithm algo(inputSample, model(inputSample), weight, basis, indices, penalizationFactor, penalizationMatrix);
+      PenalizedLeastSquaresAlgorithm algo(inputSample, model(inputSample), weight, coll, indices, penalizationFactor, penalizationMatrix);
       fullprint << "Non uniform weight, non spherical penalization" << std::endl;
       fullprint << "Coefficients=" << algo.getCoefficients() << std::endl;
       fullprint << "Residual=" << algo.getResidual() << std::endl;
