@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_ProcessSample_std.cxx
  *  @brief The test file of class ProcessSample for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-04-18 17:56:46 +0200 (Wed, 18 Apr 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -40,7 +37,7 @@ int main(int argc, char *argv[])
     // We create a sample and we fill it
     const UnsignedInteger size = 6;
     const UnsignedInteger dimension = 1;
-    NumericalSample sample(size, dimension);
+    Sample sample(size, dimension);
     for (UnsignedInteger i = 0; i < size; ++i)
       for (UnsignedInteger j = 0; j < dimension; ++j)
         sample[i][j] = i + j + 1;
@@ -78,7 +75,7 @@ int main(int argc, char *argv[])
     //    TimeSeriesCollection collection;
     //    collection.add(timeSerie);
 
-    //    sample.scale( NumericalPoint( 1, 0.1 ) );
+    //    sample.scale( Point( 1, 0.1 ) );
     //    TimeSeries newtimeSeries(timeGrid, sample);
     //    collection.add( newtimeSeries );
 
