@@ -2,7 +2,7 @@
 /**
  *  @brief The test file of class RandomMixture for standard methods
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -115,6 +115,9 @@ int main(int argc, char *argv[])
       Point quantileComp = distribution.computeQuantile( 0.95, true );
       fullprint << "quantile comp.=" << quantileComp << std::endl;
       fullprint << "cdfComp(quantileComp)=" << distribution.computeComplementaryCDF(quantileComp) << std::endl;
+      fullprint << "entropy      =" << distribution.computeEntropy() << std::endl;
+      fullprint << "entropy (ref)=" << distributionReference.computeEntropy() << std::endl;
+      fullprint << "entropy (MC)=" << -distribution.computeLogPDF(distribution.getSample(1000000)).computeMean()[0] << std::endl;
       Point mean = distribution.getMean();
       fullprint << "mean      =" << mean << std::endl;
       fullprint << "mean (ref)=" << distributionReference.getMean() << std::endl;
@@ -134,7 +137,7 @@ int main(int argc, char *argv[])
       fullprint << "parameters=" << parameters << std::endl;
       /*    distribution.setIntegrationNodesNumber(6);
             for (UnsignedInteger i = 0; i < 6; ++i) fullprint << "standard moment n=" << i << ", value=" << distribution.getStandardMoment(i) << std::endl;*/
-      fullprint << "Standard representative=" << distribution.getStandardRepresentative()->__str__() << std::endl;
+      fullprint << "Standard representative=" << distribution.getStandardRepresentative().__str__() << std::endl;
       fullprint << "blockMin=" << distribution.getBlockMin() << std::endl;
       fullprint << "blockMax=" << distribution.getBlockMax() << std::endl;
       fullprint << "maxSize=" << distribution.getMaxSize() << std::endl;
@@ -209,6 +212,7 @@ int main(int argc, char *argv[])
     fullprint << "mean = " <<  distribution2D.getMean() << std::endl;
     fullprint << "cov = " << distribution2D.getCovariance() << std::endl;
     fullprint << "sigma = " << distribution2D.getStandardDeviation() << std::endl;
+    fullprint << "entropy      =" << distribution.computeEntropy() << std::endl;
     distribution2D.setBlockMin(3);
     distribution2D.setBlockMax(10);
 
@@ -316,6 +320,7 @@ int main(int argc, char *argv[])
     fullprint << "mean = " <<  dist_3D.getMean() << std::endl;
     fullprint << "cov = " << dist_3D.getCovariance() << std::endl;
     fullprint << "sigma = " << dist_3D.getStandardDeviation() << std::endl;
+    fullprint << "entropy      =" << distribution.computeEntropy() << std::endl;
 
     // Total number of points (is (2+2)**3)
     // Test is CPU consuming
