@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_RandomVector_conditional.cxx
  *  @brief The test file of distribution-based conditional RandomVector class
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -56,11 +53,11 @@ int main(int argc, char *argv[])
 
     /* Check standard methods of class RandomVector */
     fullprint << "vect dimension=" << vect.getDimension() << std::endl;
-    NumericalPoint p;
-    NumericalPoint r(vect.getRealization(p));
+    Point p;
+    Point r(vect.getRealization(p));
     fullprint << "vect realization=" << r << std::endl;
     fullprint << "parameters value=" << p << std::endl;
-    distribution.setParametersCollection(p);
+    distribution.setParameter(p);
     RandomGenerator::SetSeed(0);
     /* Generate a parameter set to put the random generator into the proper state */
     randomParameters.getRealization();
