@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_RandomVector_constant.cxx
  *  @brief The test file of 'constant' RandomVector class
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,8 +33,8 @@ int main(int argc, char *argv[])
   {
 
     /* We create a numerical point of dimension 4 */
-    NumericalPoint point(4);
-    const NumericalPoint & ref_point(point);
+    Point point(4);
+    const Point & ref_point(point);
 
     point[0] = 101.0;
     point[1] = 102.0;
@@ -46,7 +43,7 @@ int main(int argc, char *argv[])
 
     fullprint << "point = " << ref_point << std::endl;
 
-    /* We create a 'constant' RandomVector from the NumericalPoint */
+    /* We create a 'constant' RandomVector from the Point */
     RandomVector vect = ConstantRandomVector(point);
     fullprint << "vect=" << vect << std::endl;
 
@@ -58,7 +55,7 @@ int main(int argc, char *argv[])
     fullprint << "vect sample =" << vect.getSample(5) << std::endl;
 
     /* We create a numerical point of dimension 4 */
-    NumericalPointWithDescription pointWithDescription(4);
+    PointWithDescription pointWithDescription(4);
     pointWithDescription[0] = 101.0;
     pointWithDescription[1] = 102.0;
     pointWithDescription[2] = 103.0;
@@ -72,7 +69,7 @@ int main(int argc, char *argv[])
 
     fullprint << "point with description= " << pointWithDescription << std::endl;
 
-    /* We create a 'constant' RandomVector from the NumericalPoint */
+    /* We create a 'constant' RandomVector from the Point */
     RandomVector vect2 = ConstantRandomVector(pointWithDescription);
     fullprint << "vect2=" << vect2 << std::endl;
   }
