@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_RayleighFactory_std.cxx
  *  @brief The test file of class Rayleigh for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author lebrun
- *  @date   2008-07-03 08:31:34 +0200 (jeu. 03 juil. 2008)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,8 +33,8 @@ int main(int argc, char *argv[])
   try
   {
     Rayleigh distribution(2.5, -1.0);
-    UnsignedInteger size(10000);
-    NumericalSample sample(distribution.getSample(size));
+    UnsignedInteger size = 10000;
+    Sample sample(distribution.getSample(size));
     RayleighFactory factory;
     CovarianceMatrix covariance;
     // Distribution estimatedDistribution(factory.build(sample, covariance));
@@ -47,15 +44,22 @@ int main(int argc, char *argv[])
     // fullprint << "Covariance=" << covariance << std::endl;
     estimatedDistribution = factory.build();
     fullprint << "Default distribution=" << estimatedDistribution << std::endl;
-    estimatedDistribution = factory.build(distribution.getParametersCollection());
+    estimatedDistribution = factory.build(distribution.getParameter());
     fullprint << "Distribution from parameters=" << estimatedDistribution << std::endl;
     Rayleigh estimatedRayleigh(factory.buildAsRayleigh(sample));
     fullprint << "Rayleigh          =" << distribution << std::endl;
     fullprint << "Estimated rayleigh=" << estimatedRayleigh << std::endl;
     estimatedRayleigh = factory.buildAsRayleigh();
     fullprint << "Default rayleigh=" << estimatedRayleigh << std::endl;
-    estimatedRayleigh = factory.buildAsRayleigh(distribution.getParametersCollection());
+    estimatedRayleigh = factory.buildAsRayleigh(distribution.getParameter());
     fullprint << "Rayleigh from parameters=" << estimatedRayleigh << std::endl;
+    // Test for constant sample
+    sample = Sample(size, Point(1, 0.0));
+    estimatedDistribution = factory.build(sample);
+    fullprint << "Estimated distribution=" << estimatedDistribution << std::endl;
+    sample = Sample(size, Point(1, 1.0));
+    estimatedDistribution = factory.build(sample);
+    fullprint << "Estimated distribution=" << estimatedDistribution << std::endl;
   }
   catch (TestFailed & ex)
   {
