@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_Secant_std.cxx
  *  @brief The test file of class Secant for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -37,14 +34,12 @@ int main(int argc, char *argv[])
     /** Analytical construction */
     Description input(1);
     input[0] = "x";
-    Description output(1);
-    output[0] = "y";
-    Description formulas(output.getSize());
+    Description formulas(1);
     formulas[0] = "x-cos(x)";
-    NumericalMathFunction analytical(input, output, formulas);
+    SymbolicFunction analytical(input, formulas);
     Secant myAlgo;
     fullprint << "myAlgo=" << myAlgo << std::endl;
-    NumericalScalar value(0.0);
+    Scalar value = 0.0;
     fullprint << "Solve " << formulas[0] << "=" << value << " for " << input[0] << std::endl;
     OSS oss;
     oss.setPrecision(5);
