@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_SecondOrderModel_std.cxx
  *  @brief The test file of class SecondOrderModel
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author lebrun
- *  @date   2011-12-05 17:31:12 +0100 (lun. 05 déc. 2011)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,22 +33,22 @@ int main(int argc, char *argv[])
   {
 
     /* Default dimension parameter to evaluate the model */
-    const UnsignedInteger dimension(1);
+    const UnsignedInteger dimension = 1;
 
     /* Spatial dimension of the the model */
-    const UnsignedInteger spatialDimension(1);
+    const UnsignedInteger spatialDimension = 1;
 
     /* Amplitude values */
-    NumericalPoint amplitude(dimension, 1.0);
+    Point amplitude(dimension, 1.0);
     /* Scale values */
-    NumericalPoint scale(dimension, 1.0);
+    Point scale(spatialDimension, 1.0);
 
     /* Covariance model */
-    ExponentialModel myCovarianceModel(spatialDimension, amplitude, scale);
+    ExponentialModel myCovarianceModel(scale, amplitude);
     fullprint << "myCovarianceModel = " << myCovarianceModel << std::endl;
 
     /* Spectral model  */
-    CauchyModel mySpectralModel(amplitude, scale);
+    CauchyModel mySpectralModel(scale, amplitude);
     fullprint << "mySpectralModel = " << mySpectralModel << std::endl;
 
     /* We build the second order model using covariance and spectral models */
@@ -59,8 +56,8 @@ int main(int argc, char *argv[])
     fullprint << "myModel = " << myModel << std::endl;
 
     /* Some computations ==> call the sub models methods */
-    const NumericalScalar instant(1.0);
-    const NumericalScalar frequency(0.5);
+    const Scalar instant = 1.0;
+    const Scalar frequency = 0.5;
     fullprint << "covariance matrix at t = " << instant << " : " << myModel.computeCovariance(instant) << std::endl;
     fullprint << "covariance matrix at t = " << -instant << " : " << myModel.computeCovariance(-instant) << std::endl;
     fullprint << "spectral density at f = " << frequency << " : " << myModel.computeSpectralDensity(frequency) << std::endl;
