@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_SimulationSensitivityAnalysis_std.cxx
  *  @brief The test file of class SimulationSensitivityAnalysis for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2011-11-17 13:46:13 +0100 (jeu. 17 nov. 2011)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,7 +33,7 @@ int main(int argc, char *argv[])
   try
   {
     /* Uncertain parameters*/
-    Normal distribution(NumericalPoint(3, 1.0), NumericalPoint(3, 2.0), CorrelationMatrix(3));
+    Normal distribution(Point(3, 1.0), Point(3, 2.0), CorrelationMatrix(3));
     distribution.setName("Unnamed");
     /* Model */
     Description input(3);
@@ -45,20 +42,18 @@ int main(int argc, char *argv[])
     input[2] = "z";
     Description formulas(1);
     formulas[0] = "x-1.5*y+2*z";
-    NumericalMathFunction f(input, formulas);
-    /* Must activate the history mechanism if one want to perform sensitivity analysis */
-    f.enableHistory();
+    SymbolicFunction f(input, formulas);
     /* Sampling */
-    UnsignedInteger size(100);
-    NumericalSample inputSample(distribution.getSample(size));
-    NumericalSample outputSample(f(inputSample));
+    UnsignedInteger size = 100;
+    Sample inputSample(distribution.getSample(size));
+    Sample outputSample(f(inputSample));
     Collection<ComparisonOperator> comparisonOperators(4);
     comparisonOperators[0] = Less();
     comparisonOperators[1] = LessOrEqual();
     comparisonOperators[2] = Greater();
     comparisonOperators[3] = GreaterOrEqual();
     ResourceMap::SetAsUnsignedInteger("SimulationSensitivityAnalysis-DefaultSampleMargin", 10);
-    NumericalScalar threshold(3.0);
+    Scalar threshold = 3.0;
     for (UnsignedInteger i = 0; i < 4; ++i)
     {
       {
@@ -80,12 +75,12 @@ int main(int argc, char *argv[])
         fullprint << "importanceFactorsRangeGraphThreshold=" << importanceFactorsRangeGraphThreshold << std::endl;
       }
 
-      /* Clear the history of the model */
-      f.clearHistory();
+      /* Must activate the history mechanism if one want to perform sensitivity analysis */
+      MemoizeFunction fh(f);
 
       /* Analysis based on an event */
       RandomVector X(distribution);
-      RandomVector Y(f, X);
+      RandomVector Y(fh, X);
       Event event(Y, comparisonOperators[i], threshold);
       /* Get a sample of the event to simulate a Monte Carlo analysis. We don't care
          of the result as the interesting values are stored in the model history */
