@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_SquareComplexMatrix_std.cxx
  *  @brief The test file of class SquareComplexMatrix for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,19 +14,17 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
 
-typedef Collection<NumericalComplex> NumericalComplexCollection;
+typedef Collection<Complex> ComplexCollection;
 
 int main(int argc, char *argv[])
 {
@@ -54,10 +51,10 @@ int main(int argc, char *argv[])
     SquareComplexMatrix squareComplexMatrix1(2);
 
     /* Check operator() methods */
-    squareComplexMatrix1(0, 0) = NumericalComplex(1.0, 1.0) ;
-    squareComplexMatrix1(0, 1) = NumericalComplex(3.0, 1.0) ;
-    squareComplexMatrix1(1, 0) = NumericalComplex(0.0, 1.0) ;
-    squareComplexMatrix1(1, 1) = NumericalComplex(5.0, 1.0) ;
+    squareComplexMatrix1(0, 0) = Complex(1.0, 1.0) ;
+    squareComplexMatrix1(0, 1) = Complex(3.0, 1.0) ;
+    squareComplexMatrix1(1, 0) = Complex(0.0, 1.0) ;
+    squareComplexMatrix1(1, 1) = Complex(5.0, 1.0) ;
 
     /* String converter */
     fullprint << "squareComplexMatrix1 = " << squareComplexMatrix1 << std::endl;
@@ -106,10 +103,10 @@ int main(int argc, char *argv[])
     fullprint << "sum1 equals sum2 = " << (sum1 == sum2) << std::endl;
 
 
-    /** SUBSTRACTION METHOD */
-    fullprint << "test 7 : substraction method" << std::endl;
+    /** SUBTRACTION METHOD */
+    fullprint << "test 7 : subtraction method" << std::endl;
 
-    /* Check substraction method */
+    /* Check subtraction method */
     SquareComplexMatrix diff = squareComplexMatrix1.operator - ( squareComplexMatrix4 ) ;
     fullprint << "diff = " << diff << std::endl;
 
@@ -124,20 +121,20 @@ int main(int argc, char *argv[])
     fullprint << "test 9 : multiplication with a numerical point method" << std::endl;
 
     /* Create the numerical point */
-    NumericalComplexCollection pt(2) ;
-    pt[0] = NumericalComplex(1.0, 1.0)  ;
-    pt[1] = NumericalComplex(0.0, 1.0) ;
+    ComplexCollection pt(2) ;
+    pt[0] = Complex(1.0, 1.0)  ;
+    pt[1] = Complex(0.0, 1.0) ;
     fullprint << "pt = " << pt << std::endl;
 
     /* Check the product method */
-    NumericalComplexCollection ptResult = squareComplexMatrix1.operator * ( pt )  ;
+    ComplexCollection ptResult = squareComplexMatrix1.operator * ( pt )  ;
     fullprint << "ptResult = " << ptResult << std::endl;
 
     /** MULTIPLICATION AND DIVISION BY A NUMERICAL SCALAR METHODS */
     fullprint << "test 10 : multiplication and division by a numerical scalar methods" << std::endl;
 
     /* Check the multiplication method */
-    NumericalComplex s(2.0, 1.0);
+    Complex s(2.0, 1.0);
     SquareComplexMatrix scalprod1 = squareComplexMatrix1.operator * (s) ;
     SquareComplexMatrix scalprod2 = s * squareComplexMatrix1 ;
     fullprint << "scalprod1 = " << scalprod1 << std::endl;
