@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_StandardDistributionPolynomialFactory_std.cxx
  *  @brief The test file of class StandardDistributionPolynomialFactory for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,18 +14,24 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2008-05-21 17:44:02 +0200 (mer, 21 mai 2008)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
 
+UniVariatePolynomial clean(const UniVariatePolynomial & polynomial)
+{
+  Point coefficients(polynomial.getCoefficients());
+  for (UnsignedInteger i = 0; i < coefficients.getDimension(); ++i)
+    if (std::abs(coefficients[i]) < 1.0e-10) coefficients[i] = 0.0;
+  return coefficients;
+}
+
 int main(int argc, char *argv[])
 {
   TESTPREAMBLE;
@@ -34,29 +39,36 @@ int main(int argc, char *argv[])
 
   try
   {
-    const UnsignedInteger iMax(5);
+    const UnsignedInteger iMax = 5;
     Collection<Distribution> distributionCollection;
     distributionCollection.add(Laplace(1.0, 0.0));
     distributionCollection.add(Logistic(0.0, 1.0));
-    distributionCollection.add(LogNormal(0.0, 1.0, 0.0));
     distributionCollection.add(Normal(0.0, 1.0));
+    distributionCollection.add(Normal(1.0, 1.0));
     distributionCollection.add(Rayleigh(1.0));
-    distributionCollection.add(Student(22));
+    distributionCollection.add(Student(22.0));
     distributionCollection.add(Triangular(-1.0, 0.3, 1.0));
     distributionCollection.add(Uniform(-1.0, 1.0));
+    distributionCollection.add(Uniform(-1.0, 3.0));
     distributionCollection.add(Weibull(1.0, 3.0));
+    distributionCollection.add(Beta(1.0, 3.0, -1.0, 1.0));
+    distributionCollection.add(Beta(0.5, 1.0, -1.0, 1.0));
+    distributionCollection.add(Beta(0.5, 1.0, -2.0, 3.0));
+    distributionCollection.add(Gamma(1.0, 3.0));
+    distributionCollection.add(Arcsine());
     for (UnsignedInteger n = 0; n < distributionCollection.getSize(); ++n)
     {
       const Distribution distribution(distributionCollection[n]);
       const String name(distribution.getImplementation()->getClassName());
-      StandardDistributionPolynomialFactory polynomialFactory(distribution);
+      // Must use this construction for some compilers
+      StandardDistributionPolynomialFactory polynomialFactory = StandardDistributionPolynomialFactory(AdaptiveStieltjesAlgorithm(distribution));
       fullprint << "polynomialFactory(" << name << "=" << polynomialFactory << std::endl;
       for (UnsignedInteger i = 0; i < iMax; ++i)
-        fullprint << name << " polynomial(" << i << ")=" << polynomialFactory.build(i).__str__() << std::endl;
-      NumericalPoint roots(polynomialFactory.getRoots(iMax - 1));
+        fullprint << name << " polynomial(" << i << ")=" << clean(polynomialFactory.build(i)).__str__() << std::endl;
+      Point roots(polynomialFactory.getRoots(iMax - 1));
       fullprint << name << " polynomial(" << iMax - 1 << ") roots=" << roots << std::endl;
-      NumericalPoint weights;
-      NumericalPoint nodes(polynomialFactory.getNodesAndWeights(iMax - 1, weights));
+      Point weights;
+      Point nodes(polynomialFactory.getNodesAndWeights(iMax - 1, weights));
       fullprint << name << " polynomial(" << iMax - 1 << ") nodes=" << nodes << " and weights=" << weights <<  std::endl;
     }
   }
