@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_StandardEvent_std.cxx
  *  @brief The test file of StandardEvent class
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -42,12 +39,12 @@ int main(int argc, char *argv[])
     input[1] = "F";
     input[2] = "L";
     input[3] = "I";
-    NumericalMathFunction myFunction(input, Description(1, "d"), Description(1, "-F*L^3/(3*E*I)"));
+    SymbolicFunction myFunction(input, Description(1, "-F*L^3/(3*E*I)"));
 
-    UnsignedInteger dim(myFunction.getInputDimension());
+    UnsignedInteger dim = myFunction.getInputDimension();
     /* We create a normal distribution point of dimension dim */
-    NumericalPoint mean(dim, 0.0);
-    NumericalPoint sigma(dim, 1.0);
+    Point mean(dim, 0.0);
+    Point sigma(dim, 1.0);
     Normal myDistribution(mean, sigma, IdentityMatrix(dim));
 
     /* We create a 'usual' RandomVector from the Distribution */
@@ -61,10 +58,10 @@ int main(int argc, char *argv[])
     fullprint << "myStandardEvent=" << myStandardEvent << std::endl;
     /* We compute one realization of the event */
     fullprint << "myStandardEvent realization (as a RandomVector)=" << myStandardEvent.RandomVector::getRealization() << std::endl;
-    fullprint << "myStandardEvent antecedent realization (as a RandomVector)=" << myStandardEvent.RandomVector::getImplementation()->getAntecedent()->getRealization() << std::endl;
+    fullprint << "myStandardEvent antecedent realization (as a RandomVector)=" << myStandardEvent.RandomVector::getImplementation()->getAntecedent().getRealization() << std::endl;
     fullprint << "myStandardEvent realization=" << myStandardEvent.getRealization() << std::endl;
-    fullprint << "myStandardEvent antecedent realization=" << myStandardEvent.getImplementation()->getAntecedent()->getRealization() << std::endl;
-    fullprint << "myStandardEvent antecedent distribution cdf=" << myStandardEvent.getImplementation()->getAntecedent()->getDistribution().computeCDF(NumericalPoint(dim, 1.0)) << std::endl;
+    fullprint << "myStandardEvent antecedent realization=" << myStandardEvent.getImplementation()->getAntecedent().getRealization() << std::endl;
+    fullprint << "myStandardEvent antecedent distribution cdf=" << myStandardEvent.getImplementation()->getAntecedent().getDistribution().computeCDF(Point(dim, 1.0)) << std::endl;
     /* We compute a sample of the event */
     fullprint << "myStandardEvent sample=" << myStandardEvent.getSample(10) << std::endl;
 
@@ -89,8 +86,8 @@ int main(int argc, char *argv[])
 
     /* Check if the StandardEvent is really a StandardEvent */
     /* Get a sample from the second antecedent of the standard event */
-    UnsignedInteger size(2000);
-    NumericalSample sample(stdEvent.getImplementation()->getAntecedent()->getSample(size));
+    UnsignedInteger size = 2000;
+    Sample sample(stdEvent.getImplementation()->getAntecedent().getSample(size));
     /* Check if the sample mean is nearly the null vector */
     fullprint << "sample mean=" << sample.computeMean() << std::endl;
     /* Check if the sample covariance is nearly the identity matrix */
@@ -99,24 +96,28 @@ int main(int argc, char *argv[])
     fullprint << "Failure probability (Event)=" << myEvent.getSample(size).computeMean() << std::endl;
     fullprint << "Failure probability (StandardEvent)=" << stdEvent.getSample(size).computeMean() << std::endl;
 
-    Collection<UserDefinedPair> collection(3, UserDefinedPair(NumericalPoint(dim), 0.0));
-    NumericalPoint point(dim);
+    Sample x(3, dim);
+    Point point(dim);
     point[0] = 1.0;
     point[1] = 0.5;
     point[2] = 1.0;
     point[3] = 0.5;
-    collection[0] = UserDefinedPair(point, 0.3);
+    x[0] = point;
     point[0] = 2.0;
     point[1] = 1.0;
     point[2] = 2.0;
     point[3] = 1.0;
-    collection[1] = UserDefinedPair(point, 0.325);
+    x[1] = point;
     point[0] = 3.0;
     point[1] = 1.5;
     point[2] = 3.0;
     point[3] = 1.5;
-    collection[2] = UserDefinedPair(point, 0.375);
-    UserDefined myDistribution3(collection);
+    x[2] = point;
+    Point p(3);
+    p[0] = 0.0;
+    p[1] = 0.3;
+    p[2] = 0.325;
+    UserDefined myDistribution3(x, p);
     /* We create a 'usual' RandomVector from the Distribution */
     RandomVector vect3(myDistribution3);
 
