@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_StrongMaximumTest_tabulatedValues.cxx
  *  @brief The test file of StrongMaximumTest class
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -44,7 +41,7 @@ int main(int argc, char *argv[])
 
     for (UnsignedInteger indexDimension = 0; indexDimension < dimension.getSize(); indexDimension++)
     {
-      UnsignedInteger dim(dimension[indexDimension]);
+      UnsignedInteger dim = dimension[indexDimension];
       fullprint << "dimension = " << dim << std::endl;
 
       /* We create a numerical math function */
@@ -55,11 +52,11 @@ int main(int argc, char *argv[])
         oss << "x" << i + 1;
         inputVar[i] = oss;
       }
-      NumericalMathFunction myFunction(inputVar, Description(1, "y"), Description(1, "0"));
+      SymbolicFunction myFunction(inputVar, Description(1, "0"));
 
       /* We create a normal distribution point of dimension 1 */
-      NumericalPoint mean(dim, 0.0);
-      NumericalPoint sigma(dim, 1.0);
+      Point mean(dim, 0.0);
+      Point sigma(dim, 1.0);
       IdentityMatrix R(dim);
       Normal myDistribution(mean, sigma, R);
 
@@ -72,24 +69,24 @@ int main(int argc, char *argv[])
       /* We create a StandardEvent from this RandomVector */
       StandardEvent myStandardEvent(output, Less(), 2.0);
 
-      Normal std(NumericalPoint(1, 0.0), NumericalPoint(1, 1.0), IdentityMatrix(1));
+      Normal std(Point(1, 0.0), Point(1, 1.0), IdentityMatrix(1));
 
-      NumericalPoint beta(3);
+      Point beta(3);
       beta[0] = round(-std.computeQuantile(1e-3)[0]);
       beta[1] = round(-std.computeQuantile(1e-5)[0]);
       beta[2] = round(-std.computeQuantile(1e-7)[0]);
 
-      NumericalPoint importanceLevel(3);
+      Point importanceLevel(3);
       importanceLevel[0] = 0.01;
       importanceLevel[1] = 0.05;
       importanceLevel[2] = 0.10;
 
-      NumericalPoint accuracyLevel(3);
+      Point accuracyLevel(3);
       accuracyLevel[0] = 1.5;
       accuracyLevel[1] = 2.0;
       accuracyLevel[2] = 4.0;
 
-      NumericalPoint confidenceLevel(3);
+      Point confidenceLevel(3);
       confidenceLevel[0] = 0.90;
       confidenceLevel[1] = 0.95;
       confidenceLevel[2] = 0.99;
@@ -114,7 +111,7 @@ int main(int argc, char *argv[])
       {
 
         /* We create the design point */
-        NumericalPoint designPoint(dim, 0.0);
+        Point designPoint(dim, 0.0);
         designPoint[0] = beta[indexBeta];
 
         /* loop on the importance level epsilon */
@@ -164,7 +161,7 @@ int main(int argc, char *argv[])
       {
 
         /* We create the design point */
-        NumericalPoint designPoint(dim, 0.0);
+        Point designPoint(dim, 0.0);
         designPoint[0] = beta[indexBeta];
 
         /* loop on the importance level epsilon */
