@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_Student_std.cxx
  *  @brief The test file of class Student for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -58,12 +55,12 @@ int main(int argc, char *argv[])
     fullprint << "Continuous = " << (distribution.isContinuous() ? "true" : "false") << std::endl;
 
     // Test for realization of distribution
-    NumericalPoint oneRealization = distribution.getRealization();
+    Point oneRealization = distribution.getRealization();
     fullprint << "oneRealization=" << oneRealization << std::endl;
 
     // Test for sampling
     UnsignedInteger size = 10000;
-    NumericalSample oneSample = distribution.getSample( size );
+    Sample oneSample = distribution.getSample( size );
     fullprint << "oneSample first=" << oneSample[0] << " last=" << oneSample[size - 1] << std::endl;
     fullprint << "mean=" << oneSample.computeMean() << std::endl;
     fullprint << "covariance=" << oneSample.computeCovariance() << std::endl;
@@ -75,55 +72,74 @@ int main(int argc, char *argv[])
     }
 
     // Define a point
-    NumericalPoint point( distribution.getDimension(), 1.0 );
+    Point point( distribution.getDimension(), 1.0 );
     fullprint << "Point= " << point << std::endl;
 
     // Show PDF and CDF of point
-    NumericalScalar eps(1e-5);
-    NumericalPoint DDF = distribution.computeDDF( point );
+    Scalar eps = 1e-5;
+    Point DDF = distribution.computeDDF( point );
     fullprint << "ddf     =" << DDF << std::endl;
-    fullprint << "ddf (FD)=" << NumericalPoint(1, (distribution.computePDF( point + NumericalPoint(1, eps) ) - distribution.computePDF( point  + NumericalPoint(1, -eps) )) / (2.0 * eps)) << std::endl;
-    NumericalScalar LPDF = distribution.computeLogPDF( point );
+    fullprint << "ddf (FD)=" << Point(1, (distribution.computePDF( point + Point(1, eps) ) - distribution.computePDF( point  + Point(1, -eps) )) / (2.0 * eps)) << std::endl;
+    Scalar LPDF = distribution.computeLogPDF( point );
     fullprint << "log pdf=" << LPDF << std::endl;
-    NumericalScalar PDF = distribution.computePDF( point );
+    Scalar PDF = distribution.computePDF( point );
     fullprint << "pdf     =" << PDF << std::endl;
-    fullprint << "pdf (FD)=" << (distribution.computeCDF( point + NumericalPoint(1, eps) ) - distribution.computeCDF( point  + NumericalPoint(1, -eps) )) / (2.0 * eps) << std::endl;
-    NumericalScalar CDF = distribution.computeCDF( point );
+    fullprint << "pdf (FD)=" << (distribution.computeCDF( point + Point(1, eps) ) - distribution.computeCDF( point  + Point(1, -eps) )) / (2.0 * eps) << std::endl;
+    Scalar CDF = distribution.computeCDF( point );
     fullprint << "cdf=" << CDF << std::endl;
-    NumericalScalar CCDF = distribution.computeComplementaryCDF( point );
+    Scalar CCDF = distribution.computeComplementaryCDF( point );
     fullprint << "ccdf=" << CCDF << std::endl;
-    NumericalScalar Survival = distribution.computeSurvivalFunction( point );
+    Scalar Survival = distribution.computeSurvivalFunction( point );
     fullprint << "survival=" << Survival << std::endl;
-    NumericalPoint PDFgr = distribution.computePDFGradient( point );
+    Point InverseSurvival = distribution.computeInverseSurvivalFunction(0.95);
+    fullprint << "Inverse survival=" << InverseSurvival << std::endl;
+    fullprint << "Survival(inverse survival)=" << distribution.computeSurvivalFunction(InverseSurvival) << std::endl;
+    Point PDFgr = distribution.computePDFGradient( point );
     fullprint << "pdf gradient     =" << PDFgr << std::endl;
-    NumericalPoint PDFgrFD(3);
+    Point PDFgrFD(3);
     PDFgrFD[0] = (Student(distribution.getNu() + eps, distribution.getMean(), distribution.getSigma(), distribution.getCorrelation()).computePDF(point) -
                   Student(distribution.getNu() - eps, distribution.getMean(), distribution.getSigma(), distribution.getCorrelation()).computePDF(point)) / (2.0 * eps);
-    PDFgrFD[1] = (Student(distribution.getNu(), distribution.getMean() + NumericalPoint(1, eps), distribution.getSigma(), distribution.getCorrelation()).computePDF(point) -
-                  Student(distribution.getNu(), distribution.getMean() - NumericalPoint(1, eps), distribution.getSigma(), distribution.getCorrelation()).computePDF(point)) / (2.0 * eps);
-    PDFgrFD[2] = (Student(distribution.getNu(), distribution.getMean(), distribution.getSigma() + NumericalPoint(1, eps), distribution.getCorrelation()).computePDF(point) -
-                  Student(distribution.getNu(), distribution.getMean(), distribution.getSigma() - NumericalPoint(1, eps), distribution.getCorrelation()).computePDF(point)) / (2.0 * eps);
+    PDFgrFD[1] = (Student(distribution.getNu(), distribution.getMean() + Point(1, eps), distribution.getSigma(), distribution.getCorrelation()).computePDF(point) -
+                  Student(distribution.getNu(), distribution.getMean() - Point(1, eps), distribution.getSigma(), distribution.getCorrelation()).computePDF(point)) / (2.0 * eps);
+    PDFgrFD[2] = (Student(distribution.getNu(), distribution.getMean(), distribution.getSigma() + Point(1, eps), distribution.getCorrelation()).computePDF(point) -
+                  Student(distribution.getNu(), distribution.getMean(), distribution.getSigma() - Point(1, eps), distribution.getCorrelation()).computePDF(point)) / (2.0 * eps);
     fullprint << "pdf gradient (FD)=" << PDFgrFD << std::endl;
-    NumericalPoint CDFgr = distribution.computeCDFGradient( point );
+    Point CDFgr = distribution.computeCDFGradient( point );
     fullprint << "cdf gradient     =" << CDFgr << std::endl;
-    NumericalPoint CDFgrFD(3);
+    Point CDFgrFD(3);
     CDFgrFD[0] = (Student(distribution.getNu() + eps, distribution.getMean(), distribution.getSigma(), distribution.getCorrelation()).computeCDF(point) -
                   Student(distribution.getNu() - eps, distribution.getMean(), distribution.getSigma(), distribution.getCorrelation()).computeCDF(point)) / (2.0 * eps);
-    CDFgrFD[1] = (Student(distribution.getNu(), distribution.getMean() + NumericalPoint(1, eps), distribution.getSigma(), distribution.getCorrelation()).computeCDF(point) -
-                  Student(distribution.getNu(), distribution.getMean() - NumericalPoint(1, eps), distribution.getSigma(), distribution.getCorrelation()).computeCDF(point)) / (2.0 * eps);
-    CDFgrFD[2] = (Student(distribution.getNu(), distribution.getMean(), distribution.getSigma() + NumericalPoint(1, eps), distribution.getCorrelation()).computeCDF(point) -
-                  Student(distribution.getNu(), distribution.getMean(), distribution.getSigma() - NumericalPoint(1, eps), distribution.getCorrelation()).computeCDF(point)) / (2.0 * eps);
+    CDFgrFD[1] = (Student(distribution.getNu(), distribution.getMean() + Point(1, eps), distribution.getSigma(), distribution.getCorrelation()).computeCDF(point) -
+                  Student(distribution.getNu(), distribution.getMean() - Point(1, eps), distribution.getSigma(), distribution.getCorrelation()).computeCDF(point)) / (2.0 * eps);
+    CDFgrFD[2] = (Student(distribution.getNu(), distribution.getMean(), distribution.getSigma() + Point(1, eps), distribution.getCorrelation()).computeCDF(point) -
+                  Student(distribution.getNu(), distribution.getMean(), distribution.getSigma() - Point(1, eps), distribution.getCorrelation()).computeCDF(point)) / (2.0 * eps);
     fullprint << "cdf gradient (FD)=" << CDFgrFD << std::endl;
-    NumericalPoint quantile = distribution.computeQuantile( 0.95 );
+    Point quantile = distribution.computeQuantile( 0.95 );
     fullprint << "quantile=" << quantile << std::endl;
     fullprint << "cdf(quantile)=" << distribution.computeCDF(quantile) << std::endl;
-    NumericalPoint mean = distribution.getMean();
+    // Confidence regions
+    Scalar threshold;
+    fullprint << "Minimum volume interval=" << distribution.computeMinimumVolumeIntervalWithMarginalProbability(0.95, threshold) << std::endl;
+    fullprint << "threshold=" << threshold << std::endl;
+    Scalar beta;
+    LevelSet levelSet(distribution.computeMinimumVolumeLevelSetWithThreshold(0.95, beta));
+    fullprint << "Minimum volume level set=" << levelSet << std::endl;
+    fullprint << "beta=" << beta << std::endl;
+    fullprint << "Bilateral confidence interval=" << distribution.computeBilateralConfidenceIntervalWithMarginalProbability(0.95, beta) << std::endl;
+    fullprint << "beta=" << beta << std::endl;
+    fullprint << "Unilateral confidence interval (lower tail)=" << distribution.computeUnilateralConfidenceIntervalWithMarginalProbability(0.95, false, beta) << std::endl;
+    fullprint << "beta=" << beta << std::endl;
+    fullprint << "Unilateral confidence interval (upper tail)=" << distribution.computeUnilateralConfidenceIntervalWithMarginalProbability(0.95, true, beta) << std::endl;
+    fullprint << "beta=" << beta << std::endl;
+    fullprint << "entropy=" << distribution.computeEntropy() << std::endl;
+    fullprint << "entropy (MC)=" << -distribution.computeLogPDF(distribution.getSample(1000000)).computeMean()[0] << std::endl;
+    Point mean = distribution.getMean();
     fullprint << "mean=" << mean << std::endl;
-    NumericalPoint standardDeviation = distribution.getStandardDeviation();
+    Point standardDeviation = distribution.getStandardDeviation();
     fullprint << "standard deviation=" << standardDeviation << std::endl;
-    NumericalPoint skewness = distribution.getSkewness();
+    Point skewness = distribution.getSkewness();
     fullprint << "skewness=" << skewness << std::endl;
-    NumericalPoint kurtosis = distribution.getKurtosis();
+    Point kurtosis = distribution.getKurtosis();
     fullprint << "kurtosis=" << kurtosis << std::endl;
     CovarianceMatrix covariance = distribution.getCovariance();
     fullprint << "covariance=" << covariance << std::endl;
@@ -133,20 +149,21 @@ int main(int argc, char *argv[])
     fullprint << "spearman=" << spearman << std::endl;
     CovarianceMatrix kendall = distribution.getKendallTau();
     fullprint << "kendall=" << kendall << std::endl;
-    Student::NumericalPointWithDescriptionCollection parameters = distribution.getParametersCollection();
+    Student::PointWithDescriptionCollection parameters = distribution.getParametersCollection();
     fullprint << "parameters=" << parameters << std::endl;
+    distribution.setParametersCollection(parameters);
     for (UnsignedInteger i = 0; i < 6; ++i) fullprint << "standard moment n=" << i << ", value=" << distribution.getStandardMoment(i) << std::endl;
-    fullprint << "Standard representative=" << distribution.getStandardRepresentative()->__str__() << std::endl;
+    fullprint << "Standard representative=" << distribution.getStandardRepresentative().__str__() << std::endl;
 
     // Specific to this distribution
-    NumericalScalar beta(point.normSquare());
-    NumericalScalar densityGenerator(distribution.computeDensityGenerator(beta));
+    beta = point.normSquare();
+    Scalar densityGenerator = distribution.computeDensityGenerator(beta);
     fullprint << "density generator=" << densityGenerator << std::endl;
     fullprint << "pdf via density generator=" << distribution.EllipticalDistribution::computePDF(point) << std::endl;
-    NumericalScalar densityGeneratorDerivative(distribution.computeDensityGeneratorDerivative(beta));
+    Scalar densityGeneratorDerivative = distribution.computeDensityGeneratorDerivative(beta);
     fullprint << "density generator derivative     =" << densityGeneratorDerivative << std::endl;
     fullprint << "density generator derivative (FD)=" << (distribution.computeDensityGenerator(beta + eps) - distribution.computeDensityGenerator(beta - eps)) / (2.0 * eps) << std::endl;
-    NumericalScalar densityGeneratorSecondDerivative(distribution.computeDensityGeneratorSecondDerivative(beta));
+    Scalar densityGeneratorSecondDerivative = distribution.computeDensityGeneratorSecondDerivative(beta);
     fullprint << "density generator second derivative     =" << densityGeneratorSecondDerivative << std::endl;
     fullprint << "density generator second derivative (FD)=" << (distribution.computeDensityGeneratorDerivative(beta + eps) - distribution.computeDensityGeneratorDerivative(beta - eps)) / (2.0 * eps) << std::endl;
 
