@@ -2,7 +2,7 @@
 /**
  *  @brief The test file of class Study for standard methods
  *
- *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
@@ -393,7 +393,7 @@ int main(int argc, char *argv[])
     // Create a Cobyla algorithm
     Cobyla cobyla;
     study.add("cobyla", cobyla);
-    cobyla.setMaximumIterationNumber(100);
+    cobyla.setMaximumEvaluationNumber(100);
     cobyla.setMaximumAbsoluteError(1.0e-10);
     cobyla.setMaximumRelativeError(1.0e-10);
     cobyla.setMaximumResidualError(1.0e-10);
@@ -737,7 +737,7 @@ int main(int argc, char *argv[])
     FunctionalBasisProcess functionalBasisProcess;
     {
       UnsignedInteger basisDimension = 10;
-      Basis basis(basisDimension);
+      Collection<Function> basis(basisDimension);
       Collection<Distribution> coefficients(basisDimension);
       for (UnsignedInteger i = 0; i < basisDimension; ++i)
       {
@@ -913,7 +913,7 @@ int main(int argc, char *argv[])
       aCollection.add( Normal(mean, Point(2, 1.0), R) );
       Mixture distribution(aCollection, Point(aCollection.getSize(), 1.0));
       MixtureClassifier classifier(distribution);
-      Basis experts(0);
+      Collection<Function> experts(0);
       experts.add(SymbolicFunction("x", "-x"));
       experts.add(SymbolicFunction("x", "x"));
       expertMixture = ExpertMixture(experts, classifier);
@@ -1108,6 +1108,31 @@ int main(int argc, char *argv[])
 
     // cleanup
     Os::Remove(fileName);
+
+    // Create a Study Object by giving its name
+    {
+      Study study(fileName);
+      Point point(4);
+      point[0] = std::numeric_limits<Scalar>::quiet_NaN();
+      point[1] = sqrt(-1.0);
+      point[2] = std::numeric_limits<Scalar>::infinity();
+      point[3] = -std::numeric_limits<Scalar>::infinity();
+      study.add("point", point);
+      study.save();
+      Study study2(fileName);
+      study2.load();
+      Point point2;
+      study2.fillObject("point", point2);
+      for (UnsignedInteger j = 0; j < point2.getDimension(); ++ j)
+      {
+        std::cout << "j=" << j;
+        std::cout << " isnormal=" << SpecFunc::IsNormal(point2[j]);
+        std::cout << " isnan=" << SpecFunc::IsNaN(point2[j]);
+        std::cout << " isinf=" << SpecFunc::IsInf(point2[j]) << std::endl;
+      }
+      // cleanup
+      Os::Remove(fileName);
+    }
   }
   catch (TestFailed & ex)
   {
