@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_SymmetricMatrix_std.cxx
  *  @brief The test file of class SymmetricMatrix for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-04-18 17:56:46 +0200 (Wed, 18 Apr 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -122,10 +119,10 @@ int main(int argc, char *argv[])
     fullprint << "sum1 equals sum2 = " << (sum1 == sum2) << std::endl;
 
 
-    /** TEST NUMBER EIGHT : SUBSTRACTION METHOD */
-    fullprint << "test number eight : substraction method" << std::endl;
+    /** TEST NUMBER EIGHT : SUBTRACTION METHOD */
+    fullprint << "test number eight : subtraction method" << std::endl;
 
-    /* Check substraction method */
+    /* Check subtraction method */
     SymmetricMatrix diff = SymmetricMatrix1.operator - ( SymmetricMatrix4 ) ;
     fullprint << "diff = " << diff << std::endl;
     fullprint << "diff = " << diff.__str__() << std::endl;
@@ -144,13 +141,13 @@ int main(int argc, char *argv[])
     fullprint << "test number ten : multiplication with a numerical point method" << std::endl;
 
     /* Create the numerical point */
-    NumericalPoint pt ;
+    Point pt ;
     pt.add(1.) ;
     pt.add(2.) ;
     fullprint << "pt = " << pt << std::endl;
 
     /* Check the product method */
-    NumericalPoint ptResult = SymmetricMatrix1.operator * ( pt )  ;
+    Point ptResult = SymmetricMatrix1.operator * ( pt )  ;
     fullprint << "ptResult = " << ptResult << std::endl;
 
     /** TEST NUMBER ELEVEN : MULTIPLICATION AND DIVISION BY A NUMERICAL SCALAR METHODS */
@@ -185,6 +182,44 @@ int main(int argc, char *argv[])
               << "SymmetricMatrix1 is empty = " << SymmetricMatrix1.isEmpty() << std::endl
               << "SymmetricMatrix5 is empty = " << SymmetricMatrix5.isEmpty() << std::endl;
 
+
+    SquareMatrix L(2);
+    L(0, 0) = 2.4;
+    L(1, 0) = 4.0;
+    L(0, 1) = 3.0;
+    L(1, 1) = 1.0;
+
+    SymmetricMatrix SM(2);
+    SM(0, 0) = 1.5;
+    SM(1, 0) = 1.1;
+    SM(1, 1) = 3.0;
+
+    SquareMatrix M(2);
+    M(0, 0) = 1.5;
+    M(1, 0) = 1.1;
+    M(0, 1) = 1.1;
+    M(1, 1) = 3.0;
+
+    Matrix M2(2, 2);
+    M2(0, 0) = 1.5;
+    M2(1, 0) = 1.1;
+    M2(0, 1) = 1.1;
+    M2(1, 1) = 3.0;
+
+    fullprint << "L * SM = " << L * SM << std::endl;
+    fullprint << "L * M = " << L * M << std::endl;
+
+    fullprint << "M2 * SM = " << M2 * SM << std::endl;
+    fullprint << "M * SM = " << M * SM << std::endl;
+
+    Matrix M3(2, 3);
+    M3(0, 0) = 1.5;
+    M3(1, 0) = 1.1;
+    M3(0, 1) = 1.1;
+    M3(1, 1) = 3.0;
+    M3(0, 2) = 7.1;
+    M3(1, 2) = 9.0;
+    fullprint << "SM * M3 = " << SM * M3 << std::endl;
   }
   catch (TestFailed & ex)
   {
