@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_TestResult_std.cxx
  *  @brief The test file of class TestResult
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -40,8 +37,8 @@ int main(int argc, char *argv[])
     /* Default constructor */
     String type = "testResult";
     Bool testBool = 1;
-    NumericalScalar testVal = 0.372;
-    NumericalScalar testThres = 0.42;
+    Scalar testVal = 0.372;
+    Scalar testThres = 0.42;
     TestResult testResultTest(type, testBool, testVal, testThres);
 
     /* String converter */
@@ -69,8 +66,8 @@ int main(int argc, char *argv[])
     fullprint << "testResultTest2 = testResultTest " << (testResultTest2 == testResultTest) << std::endl;
     String typeDiff = "testResult2";
     Bool testBoolDiff = 0;
-    NumericalScalar testValDiff = 0.02;
-    NumericalScalar testThresDiff = 0.12;
+    Scalar testValDiff = 0.02;
+    Scalar testThresDiff = 0.12;
     TestResult testResultTestDiff(typeDiff, testBoolDiff, testValDiff, testThresDiff);
     fullprint << "testResultTestDiff = testResultTest " << (testResultTestDiff == testResultTest) << std::endl;
 
