@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_TrapezoidalFactory_std.cxx
  *  @brief The test file of class Trapezoidal for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author dutka
- *  @date   2009-09-30 17:51:57 +0200 (mer. 30 sept. 2009)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,8 +33,8 @@ int main(int argc, char *argv[])
   try
   {
     Trapezoidal distribution( 1.0, 2.3, 4.5, 5.0 );
-    UnsignedInteger size(10000);
-    NumericalSample sample(distribution.getSample(size));
+    UnsignedInteger size = 10000;
+    Sample sample(distribution.getSample(size));
     TrapezoidalFactory factory;
     Distribution estimatedDistribution(factory.build(sample));
     fullprint << "Distribution          =" << distribution << std::endl;
@@ -47,7 +44,7 @@ int main(int argc, char *argv[])
     PlatformInfo::SetNumericalPrecision( oldPrecision );
     estimatedDistribution = factory.build();
     fullprint << "Default distribution=" << estimatedDistribution << std::endl;
-    estimatedDistribution = factory.build(distribution.getParametersCollection());
+    estimatedDistribution = factory.build(distribution.getParameter());
     fullprint << "Distribution from parameters=" << estimatedDistribution << std::endl;
     Trapezoidal estimatedTrapezoidal(factory.buildAsTrapezoidal(sample));
     fullprint << "Trapezoidal          =" << distribution << std::endl;
@@ -57,8 +54,15 @@ int main(int argc, char *argv[])
     PlatformInfo::SetNumericalPrecision( oldPrecision );
     estimatedTrapezoidal = factory.buildAsTrapezoidal();
     fullprint << "Default trapezoidal=" << estimatedTrapezoidal << std::endl;
-    estimatedTrapezoidal = factory.buildAsTrapezoidal(distribution.getParametersCollection());
+    estimatedTrapezoidal = factory.buildAsTrapezoidal(distribution.getParameter());
     fullprint << "Trapezoidal from parameters=" << estimatedTrapezoidal << std::endl;
+    // Test for constant sample
+    sample = Sample(size, Point(1, 0.0));
+    estimatedDistribution = factory.build(sample);
+    fullprint << "Estimated distribution=" << estimatedDistribution << std::endl;
+    sample = Sample(size, Point(1, 1.0));
+    estimatedDistribution = factory.build(sample);
+    fullprint << "Estimated distribution=" << estimatedDistribution << std::endl;
   }
   catch (TestFailed & ex)
   {
