@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_TrendFactory_std.cxx
  *  @brief The test file of class TrendFactory for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author haddad
- *  @date   2011-12-15 16:16:52 +0100 (jeu. 15 déc. 2011)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -42,21 +39,21 @@ int main(int argc, char *argv[])
     outVar[0] = "y";
     Description formula(1);
 
-    Collection<NumericalMathFunction> functions(3);
+    Collection<Function> functions(3);
 
     formula[0] = "1";
-    functions[0] = NumericalMathFunction(inVar, outVar, formula);
+    functions[0] = SymbolicFunction(inVar, formula);
 
     formula[0] = "cos(2 * t)";
-    functions[1] = NumericalMathFunction(inVar, outVar, formula);
+    functions[1] = SymbolicFunction(inVar, formula);
 
     formula[0] = "sin(2 * t)";
-    functions[2] = NumericalMathFunction(inVar, outVar, formula);
+    functions[2] = SymbolicFunction(inVar, formula);
 
 
     // We build the weights
-    NumericalSample coefficients(0, 2);
-    NumericalPoint p(2);
+    Sample coefficients(0, 2);
+    Point p(2);
     p[0] = 1.5;
     p[1] = 2.5;
     coefficients.add(p);
@@ -69,20 +66,20 @@ int main(int argc, char *argv[])
     coefficients.add(p);
 
     // Third, build the function
-    NumericalMathFunction myFunction(functions, coefficients);
+    DualLinearCombinationFunction myFunction(functions, coefficients);
 
 
     // Fourth : we build a time series for estimation
     // it issued from a white noise
-    const UnsignedInteger dimension(2);
+    const UnsignedInteger dimension = 2;
 
     // Fix the realization as a Normal
-    Normal noiseDistribution(NumericalPoint(dimension, 0.), NumericalPoint(dimension, 1.), CorrelationMatrix(dimension));
+    Normal noiseDistribution(Point(dimension, 0.), Point(dimension, 1.), CorrelationMatrix(dimension));
 
     // TimeGrid parameters
-    const UnsignedInteger N(1000);
-    const NumericalScalar timeStart(0.);
-    const NumericalScalar timeStep(0.1);
+    const UnsignedInteger N = 1000;
+    const Scalar timeStart = 0.;
+    const Scalar timeStep = 0.1;
     RegularGrid timeGrid(timeStart, timeStep, N);
 
     // White noise
