@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_TrendTransform_std.cxx
  *  @brief The test file of class TrendTransform for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -42,7 +39,7 @@ int main(int argc, char *argv[])
     Description formula;
     formula.add("sin(t)");
     formula.add("cos(t)");
-    NumericalMathFunction myFunc(inputVars, formula);
+    SymbolicFunction myFunc(inputVars, formula);
     TrendTransform myTrendFunc(myFunc);
 
     fullprint << "myTrendFunc=" << myTrendFunc << std::endl;
@@ -54,7 +51,7 @@ int main(int argc, char *argv[])
 
     /* Create a TimeSeries */
     RegularGrid tg(0.0, 0.1, 11);
-    NumericalSample data(tg.getN(), 2);
+    Sample data(tg.getN(), 2);
     for (UnsignedInteger i = 0; i < data.getSize(); ++i)
       for (UnsignedInteger j = 0; j < data.getDimension(); ++j)
         data(i, j) = i * data.getDimension() + j;
