@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_TriangularComplexMatrix_std.cxx
  *  @brief The test file of class TriangularComplexMatrix for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,19 +14,17 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
 
-typedef Collection<NumericalComplex> NumericalComplexCollection;
+typedef Collection<Complex> ComplexCollection;
 
 int main(int argc, char *argv[])
 {
@@ -55,7 +52,7 @@ int main(int argc, char *argv[])
 
     /* Check operator() methods */
     triangularMatrix1(0, 0) = 1. ;
-    triangularMatrix1(1, 0) = NumericalComplex(3., 1.0) ;
+    triangularMatrix1(1, 0) = Complex(3., 1.0) ;
     triangularMatrix1(1, 1) = 4. ;
 
     /* String converter */
@@ -113,10 +110,10 @@ int main(int argc, char *argv[])
     fullprint << "sum1 equals sum2 = " << (sum1 == sum2) << std::endl;
 
 
-    /** SUBSTRACTION METHOD */
-    fullprint << "test 7 : substraction method" << std::endl;
+    /** SUBTRACTION METHOD */
+    fullprint << "test 7 : subtraction method" << std::endl;
 
-    /* Check substraction method */
+    /* Check subtraction method */
     SquareComplexMatrix diff = triangularMatrix1.operator - ( triangularMatrix4 ) ;
     fullprint << "diff = " << diff << std::endl;
 
@@ -131,33 +128,33 @@ int main(int argc, char *argv[])
     fullprint << "test 9 : multiplication with a numerical point method" << std::endl;
 
     /* Create the numerical point */
-    NumericalPoint pt ;
+    Point pt ;
     pt.add(1.) ;
     pt.add(2.) ;
     fullprint << "pt = " << pt << std::endl;
 
     /* Check the product method */
-    NumericalComplexCollection ptResult = triangularMatrix1.operator * ( pt )  ;
+    ComplexCollection ptResult = triangularMatrix1.operator * ( pt )  ;
     fullprint << "ptResult = " << ptResult << std::endl;
 
     /**  MULTIPLICATION WITH A NUMERICAL COMPLEX COLLECTION METHOD */
     fullprint << "test 10 : multiplication with a numerical complex collection method" << std::endl;
 
     /* Create the numerical point */
-    NumericalComplexCollection ptComplexe ;
-    ptComplexe.add(NumericalComplex(1., 5)) ;
-    ptComplexe.add(NumericalComplex(0., 1)) ;
+    ComplexCollection ptComplexe ;
+    ptComplexe.add(Complex(1., 5)) ;
+    ptComplexe.add(Complex(0., 1)) ;
     fullprint << "ptComplexe = " << ptComplexe << std::endl;
 
     /* Check the product method */
-    NumericalComplexCollection ptResult2 = triangularMatrix1.operator * ( ptComplexe )  ;
+    ComplexCollection ptResult2 = triangularMatrix1.operator * ( ptComplexe )  ;
     fullprint << "ptResult2 = " << ptResult2 << std::endl;
 
     /** MULTIPLICATION AND DIVISION BY A NUMERICAL SCALAR METHODS */
     fullprint << "test 11 : multiplication and division by a numerical scalar methods" << std::endl;
 
     /* Check the multiplication method */
-    NumericalComplex s(3.0, 2.0);
+    Complex s(3.0, 2.0);
     TriangularComplexMatrix scalprod1 = triangularMatrix1.operator * (s) ;
     TriangularComplexMatrix scalprod2 = s * triangularMatrix1 ;
     fullprint << "scalprod1 = " << scalprod1 << std::endl;
