@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_TriangularMatrix_std.cxx
  *  @brief The test file of class TriangularMatrix for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,19 +14,17 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
 
-typedef Collection<NumericalScalar> NumericalScalarCollection;
+typedef Collection<Scalar> ScalarCollection;
 
 int main(int argc, char *argv[])
 {
@@ -109,10 +106,10 @@ int main(int argc, char *argv[])
     fullprint << "sum1 equals sum2 = " << (sum1 == sum2) << std::endl;
 
 
-    /** SUBSTRACTION METHOD */
-    fullprint << "test 7 : substraction method" << std::endl;
+    /** SUBTRACTION METHOD */
+    fullprint << "test 7 : subtraction method" << std::endl;
 
-    /* Check substraction method */
+    /* Check subtraction method */
     SquareMatrix diff = triangularMatrix1.operator - ( triangularMatrix4 ) ;
     fullprint << "diff = " << diff << std::endl;
 
@@ -127,33 +124,33 @@ int main(int argc, char *argv[])
     fullprint << "test 9 : multiplication with a numerical point method" << std::endl;
 
     /* Create the numerical point */
-    NumericalPoint pt ;
+    Point pt ;
     pt.add(1.) ;
     pt.add(2.) ;
     fullprint << "pt = " << pt << std::endl;
 
     /* Check the product method */
-    NumericalScalarCollection ptResult = triangularMatrix1.operator * ( pt )  ;
+    ScalarCollection ptResult = triangularMatrix1.operator * ( pt )  ;
     fullprint << "ptResult = " << ptResult << std::endl;
 
     /**  MULTIPLICATION WITH A NUMERICAL COMPLEX COLLECTION METHOD */
     fullprint << "test 10 : multiplication with a numerical scalar collection method" << std::endl;
 
     /* Create the numerical point */
-    NumericalScalarCollection ptScalar ;
+    ScalarCollection ptScalar ;
     ptScalar.add(1.) ;
     ptScalar.add(0.) ;
     fullprint << "ptScalar = " << ptScalar << std::endl;
 
     /* Check the product method */
-    NumericalScalarCollection ptResult2 = triangularMatrix1.operator * ( ptScalar )  ;
+    ScalarCollection ptResult2 = triangularMatrix1.operator * ( ptScalar )  ;
     fullprint << "ptResult2 = " << ptResult2 << std::endl;
 
     /** MULTIPLICATION AND DIVISION BY A NUMERICAL SCALAR METHODS */
     fullprint << "test 11 : multiplication and division by a numerical scalar methods" << std::endl;
 
     /* Check the multiplication method */
-    NumericalScalar s(3.0);
+    Scalar s = 3.0;
     TriangularMatrix scalprod1 = triangularMatrix1.operator * (s) ;
     TriangularMatrix scalprod2 = s * triangularMatrix1 ;
     fullprint << "scalprod1 = " << scalprod1 << std::endl;
