@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_TruncatedNormalFactory_std.cxx
  *  @brief The test file of class TruncatedNormal for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -35,10 +32,10 @@ int main(int argc, char *argv[])
 
   try
   {
-    NumericalPoint mu(4, 0.0);
-    NumericalPoint sigma(4, 1.0);
-    NumericalPoint a(4);
-    NumericalPoint b(4);
+    Point mu(4, 0.0);
+    Point sigma(4, 1.0);
+    Point a(4);
+    Point b(4);
     a[0] = -4.0;
     b[0] = 4.0;
     a[1] = -1.0;
@@ -47,12 +44,12 @@ int main(int argc, char *argv[])
     b[2] = 2.0;
     a[3] = 3.0;
     b[3] = 6.0;
-    PlatformInfo::SetNumericalPrecision(4);
     for (UnsignedInteger i = 0; i < 4; i++)
     {
+      PlatformInfo::SetNumericalPrecision(i == 2 ? 1 : 2);
       TruncatedNormal distribution(mu[i], sigma[i], a[i], b[i]);
-      UnsignedInteger size(10000);
-      NumericalSample sample(distribution.getSample(size));
+      UnsignedInteger size = 10000;
+      Sample sample(distribution.getSample(size));
       TruncatedNormalFactory factory;
       CovarianceMatrix covariance;
       // Distribution estimatedDistribution(factory.build(sample, covariance));
@@ -62,16 +59,27 @@ int main(int argc, char *argv[])
       // fullprint << "Covariance=" << covariance << std::endl;
       estimatedDistribution = factory.build();
       fullprint << "Default distribution=" << estimatedDistribution << std::endl;
-      estimatedDistribution = factory.build(distribution.getParametersCollection());
+      estimatedDistribution = factory.build(distribution.getParameter());
       fullprint << "Distribution from parameters=" << estimatedDistribution << std::endl;
       TruncatedNormal estimatedTruncatedNormal(factory.buildAsTruncatedNormal(sample));
       fullprint << "TruncatedNormal          =" << distribution << std::endl;
       fullprint << "Estimated TruncatedNormal=" << estimatedTruncatedNormal << std::endl;
       estimatedTruncatedNormal = factory.buildAsTruncatedNormal();
       fullprint << "Default TruncatedNormal=" << estimatedTruncatedNormal << std::endl;
-      estimatedTruncatedNormal = factory.buildAsTruncatedNormal(distribution.getParametersCollection());
+      estimatedTruncatedNormal = factory.buildAsTruncatedNormal(distribution.getParameter());
       fullprint << "TruncatedNormal from parameters=" << estimatedTruncatedNormal << std::endl;
     }
+    // Test for constant sample
+    TruncatedNormalFactory factory;
+    UnsignedInteger size = 10000;
+    Sample sample(size, Point(1, 0.0));
+    // Test for constant sample
+    sample = Sample(size, Point(1, 0.0));
+    Distribution estimatedDistribution(factory.build(sample));
+    fullprint << "Estimated distribution=" << estimatedDistribution << std::endl;
+    sample = Sample(size, Point(1, 1.0));
+    estimatedDistribution = factory.build(sample);
+    fullprint << "Estimated distribution=" << estimatedDistribution << std::endl;
   }
   catch (TestFailed & ex)
   {
