@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_UniVariatePolynomial_std.cxx
  *  @brief The test file of class UniVariatePolynomial for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2007-05-02 14:59:25 +0200 (Wed, 02 May 2007)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,7 +33,7 @@ int main(int argc, char *argv[])
   {
     // Default constructor: null polynomial
     UniVariatePolynomial P;
-    NumericalScalar point(1.2);
+    Scalar point = 1.2;
     fullprint << "P=" << P << std::endl;
     fullprint << "P(" << point << ")=" << P(point) << std::endl;
 
@@ -76,14 +73,14 @@ int main(int argc, char *argv[])
     fullprint << "P2=" << P2 << std::endl;
     fullprint << "P1+P2=" << P1 + P2 << std::endl;
 
-    // Substraction of two polynomials
+    // Subtraction of two polynomials
     fullprint << "P1-P2=" << P1 - P2 << std::endl;
 
     // Multiplication of two polynomials
     fullprint << "P1*P2=" << P1 * P2 << std::endl;
 
     // Multiplication of two polynomials using FFT
-    ResourceMap::SetAsUnsignedInteger("UniVariatePolynomialImplementation-LargeDegree", 0);
+    ResourceMap::SetAsUnsignedInteger("UniVariatePolynomial-LargeDegree", 0);
     fullprint << "P1*P2=" << P1 * P2 << std::endl;
 
   }
