@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_UniformFactory_std.cxx
  *  @brief The test file of class Uniform for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -35,7 +32,7 @@ int main(int argc, char *argv[])
 
   try
   {
-    NumericalSample sample(3, 2);
+    Sample sample(3, 2);
     sample[0][0] = 1.0;
     sample[0][1] = 1.5;
     sample[1][0] = 2.0;
@@ -56,6 +53,9 @@ int main(int argc, char *argv[])
     fullprint << "Estimated UserDefined=" << estimatedUserDefined << std::endl;
     estimatedUserDefined = factory.buildAsUserDefined();
     fullprint << "Default UserDefined=" << estimatedUserDefined << std::endl;
+    // For ticket 784
+    estimatedDistribution = factory.build(Sample(2000, Point(1, 0.0)));
+    fullprint << "Estimated distribution=" << estimatedDistribution << std::endl;
   }
   catch (TestFailed & ex)
   {
