@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_UserDefinedSpectralModel_std.cxx
  *  @brief The test file of class UserDefinedSpectralModel
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,35 +14,33 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
 
-NumericalScalar clean(NumericalScalar in)
+Scalar clean(Scalar in)
 {
   // For -0.0 trouble
-  if (fabs(in) < 1.e-6) return 0.0;
+  if (std::abs(in) < 1.e-6) return 0.0;
   return in;
   //return 1.e-6*round(1.e6*in);
 }
 
 HermitianMatrix clean(HermitianMatrix in)
 {
-  UnsignedInteger dim(in.getDimension());
+  UnsignedInteger dim = in.getDimension();
   for(UnsignedInteger i = 0; i < dim; i++)
     for(UnsignedInteger j = 0; j <= i; j++)
     {
-      NumericalScalar realIJ = clean(real(in(i, j)));
-      NumericalScalar imagIJ = clean(imag(in(i, j)));
-      in(i, j) = NumericalComplex(realIJ, imagIJ);
+      Scalar realIJ = clean(real(in(i, j)));
+      Scalar imagIJ = clean(imag(in(i, j)));
+      in(i, j) = Complex(realIJ, imagIJ);
     }
   return in;
 }
@@ -61,12 +58,12 @@ int main(int argc, char *argv[])
     fullprint << "myDefautModel = " << myDefautModel << std::endl;
 
     /* Default dimension parameter to evaluate the model */
-    const UnsignedInteger dimension(2);
+    const UnsignedInteger dimension = 2;
 
     /* Amplitude values */
-    NumericalPoint amplitude(dimension);
+    Point amplitude(dimension);
     /* Scale values */
-    NumericalPoint scale(dimension);
+    Point scale(dimension);
     /* Spatial correclation */
     CorrelationMatrix spatialCorrelation(dimension);
     for (UnsignedInteger index = 0 ; index < dimension; ++index)
@@ -78,9 +75,9 @@ int main(int argc, char *argv[])
     }
 
     /* Sample a CauchyModel */
-    CauchyModel referenceModel(amplitude, scale, spatialCorrelation);
+    CauchyModel referenceModel(scale, amplitude, spatialCorrelation);
 
-    UnsignedInteger size(5);
+    UnsignedInteger size = 5;
     UserDefinedSpectralModel::HermitianMatrixCollection dspCollection(size);
     RegularGrid frequencyGrid(0.0, 2.0 / size, size);
     for (UnsignedInteger i = 0; i < size; ++i)
@@ -94,7 +91,7 @@ int main(int argc, char *argv[])
     RegularGrid samplingGrid(-0.4, 1.0 / 16, 5 * size);
     for (UnsignedInteger i = 0; i < samplingGrid.getN(); ++i)
     {
-      NumericalScalar frequency(samplingGrid.getValue(i));
+      Scalar frequency = samplingGrid.getValue(i);
       fullprint << "frequency=" << clean(frequency) << ", myModel=\n" << clean(myModel(frequency)) << ", referenceModel=\n" << clean(referenceModel(frequency)) << std::endl;
     }
 
