@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_UserDefined_std.cxx
  *  @brief The test file of class UserDefined for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,17 +33,17 @@ int main(int argc, char *argv[])
   try
   {
     // Instanciate one distribution object
-    typedef UserDefined::UserDefinedPairCollection PairCollection;
-    PairCollection collection(4);
-    NumericalPoint point(1);
-    point[0] = 1.0;
-    collection[0] = UserDefinedPair(point, 0.3);
-    point[0] = 2.0;
-    collection[1] = UserDefinedPair(point, 0.1);
-    point[0] = 3.0;
-    collection[2] = UserDefinedPair(point, 0.6);
-    collection[3] = UserDefinedPair(point, 0.6);
-    UserDefined distribution(collection);
+    Sample x(4, 1);
+    x[0][0] = 1.0;
+    x[1][0] = 2.0;
+    x[2][0] = 3.0;
+    x[3][0] = 3.0;
+    Point p(4);
+    p[0] = 0.3;
+    p[1] = 0.1;
+    p[2] = 0.6;
+    p[3] = 0.6;
+    UserDefined distribution(x, p);
     fullprint << "Distribution " << distribution << std::endl;
     std::cout << "Distribution " << distribution << std::endl;
     // Is this distribution elliptical ?
@@ -56,34 +53,36 @@ int main(int argc, char *argv[])
     fullprint << "Continuous = " << (distribution.isContinuous() ? "true" : "false") << std::endl;
 
     // Test for realization of distribution
-    NumericalPoint oneRealization = distribution.getRealization();
+    Point oneRealization = distribution.getRealization();
     fullprint << "oneRealization=" << oneRealization << std::endl;
 
     // Test for sampling
     UnsignedInteger size = 10;
-    NumericalSample oneSample = distribution.getSample( size );
+    Sample oneSample = distribution.getSample( size );
     fullprint << "oneSample=" << oneSample << std::endl;
 
     // Define a point
-    point = NumericalPoint( distribution.getDimension(), 2.0 );
+    Point point(distribution.getDimension(), 2.0);
 
     // Show PDF and CDF of a point
-    NumericalScalar pointPDF = distribution.computePDF( point );
-    NumericalScalar pointCDF = distribution.computeCDF( point );
+    Scalar pointPDF = distribution.computePDF( point );
+    Scalar pointCDF = distribution.computeCDF( point );
     fullprint << "point= " << point
               << " pdf=" << pointPDF
               << " cdf=" << pointCDF
               << std::endl;
 
     // Get 95% quantile
-    NumericalPoint quantile = distribution.computeQuantile( 0.95 );
+    Point quantile = distribution.computeQuantile( 0.95 );
     fullprint << "Quantile=" << quantile << std::endl;
+    fullprint << "entropy=" << distribution.computeEntropy() << std::endl;
+    fullprint << "entropy (MC)=" << -distribution.computeLogPDF(distribution.getSample(1000000)).computeMean()[0] << std::endl;
 
     for (UnsignedInteger i = 0; i < 6; ++i) fullprint << "standard moment n=" << i << ", value=" << distribution.getStandardMoment(i) << std::endl;
-    fullprint << "Standard representative=" << distribution.getStandardRepresentative()->__str__() << std::endl;
+    fullprint << "Standard representative=" << distribution.getStandardRepresentative().__str__() << std::endl;
     // To prevent automatic compaction
     ResourceMap::SetAsUnsignedInteger("UserDefined-SmallSize", 5);
-    NumericalSample sample(40, 3);
+    Sample sample(40, 3);
     for (UnsignedInteger i = 0; i < 4; ++i)
     {
       for (UnsignedInteger j = 0; j < 3; ++j)
@@ -92,9 +91,12 @@ int main(int argc, char *argv[])
       }
     }
     UserDefined multivariateUserDefined(sample);
+    multivariateUserDefined.setName("Unnamed");
     fullprint << "Multivariate UserDefined=" << multivariateUserDefined << std::endl;
     multivariateUserDefined.compactSupport();
     fullprint << "Multivariate UserDefined=" << multivariateUserDefined << std::endl;
+    fullprint << "entropy=" << multivariateUserDefined.computeEntropy() << std::endl;
+    fullprint << "entropy (MC)=" << -multivariateUserDefined.computeLogPDF(multivariateUserDefined.getSample(1000000)).computeMean()[0] << std::endl;
     fullprint << "Marginal 0=" << Distribution(multivariateUserDefined.getMarginal(0)) << std::endl;
     Indices indices(2);
     indices[0] = 2;
