@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_VisualTest_std.cxx
  *  @brief The test file of class VisualTest
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -37,8 +34,8 @@ int main(int argc, char *argv[])
   {
     /* Generate a Normal sample */
     Normal normal(1);
-    UnsignedInteger size(100);
-    NumericalSample sample(normal.getSample(size));
+    UnsignedInteger size = 100;
+    Sample sample(normal.getSample(size));
     Graph sampleCDF(VisualTest::DrawEmpiricalCDF(sample, sample.getMin()[0] - 1.0, sample.getMax()[0] + 1.0));
     fullprint << "sampleCDF = " << sampleCDF << std::endl;
 
@@ -49,8 +46,8 @@ int main(int argc, char *argv[])
   /* Histogram tests */
   {
     Normal normal(1);
-    UnsignedInteger size(100);
-    NumericalSample sample(normal.getSample(size));
+    UnsignedInteger size = 100;
+    Sample sample(normal.getSample(size));
     Graph sampleHist(VisualTest::DrawHistogram(sample, 10));
     fullprint << "sampleHist = " << sampleHist << std::endl;
 
@@ -60,10 +57,10 @@ int main(int argc, char *argv[])
 
   /* QQPlot tests */
   {
-    UnsignedInteger size(100);
+    UnsignedInteger size = 100;
     Normal normal(1);
-    NumericalSample sample(normal.getSample(size));
-    NumericalSample sample2(Gamma(3.0, 4.0, 0.0).getSample(size));
+    Sample sample(normal.getSample(size));
+    Sample sample2(Gamma(3.0, 4.0, 0.0).getSample(size));
     Graph twoSamplesQQPlot(VisualTest::DrawQQplot(sample, sample2, 100));
     fullprint << "twoSamplesQQPlot = " << twoSamplesQQPlot << std::endl;
 
@@ -73,46 +70,46 @@ int main(int argc, char *argv[])
 
   /* HenryLine test */
   {
-    UnsignedInteger size(100);
+    UnsignedInteger size = 100;
     Normal normal(1);
-    NumericalSample sample(normal.getSample(size));
+    Sample sample(normal.getSample(size));
     Graph henryPlot(VisualTest::DrawHenryLine(sample));
     fullprint << "Henry graph = " << henryPlot << std::endl;
   }
 
   /* Clouds tests */
   {
-    UnsignedInteger dimension(2);
+    UnsignedInteger dimension = 2;
     CorrelationMatrix R(dimension);
     R(0, 1) = 0.8;
-    Normal distribution(NumericalPoint(dimension, 3.0), NumericalPoint(dimension, 2.0), R);
-    UnsignedInteger size(100);
-    NumericalSample sample2D(distribution.getSample(size));
-    NumericalSample firstSample(size, 1);
-    NumericalSample secondSample(size, 1);
+    Normal distribution(Point(dimension, 3.0), Point(dimension, 2.0), R);
+    UnsignedInteger size = 100;
+    Sample sample2D(distribution.getSample(size));
+    Sample firstSample(size, 1);
+    Sample secondSample(size, 1);
     for (UnsignedInteger i = 0; i < size; i++)
     {
       firstSample[i][0] = sample2D[i][0];
       secondSample[i][0] = sample2D[i][1];
     }
 
-    Graph sampleSampleClouds(VisualTest::DrawClouds(sample2D, Normal(NumericalPoint(dimension, 2.0), NumericalPoint(dimension, 3.0), R).getSample(size / 2)));
+    Graph sampleSampleClouds(VisualTest::DrawClouds(sample2D, Normal(Point(dimension, 2.0), Point(dimension, 3.0), R).getSample(size / 2)));
     fullprint << "sampleSampleClouds = " << sampleSampleClouds << std::endl;
 
-    Graph sampleDistributionClouds(VisualTest::DrawClouds(sample2D, Normal(NumericalPoint(dimension, 2.5), NumericalPoint(dimension, 1.0), R)));
+    Graph sampleDistributionClouds(VisualTest::DrawClouds(sample2D, Normal(Point(dimension, 2.5), Point(dimension, 1.0), R)));
     fullprint << "sampleDistributionClouds = " << sampleDistributionClouds << std::endl;
   }
 
   /* LinearModel tests */
   {
-    UnsignedInteger dimension(2);
+    UnsignedInteger dimension = 2;
     CorrelationMatrix R(dimension);
     R(0, 1) = 0.8;
-    Normal distribution(NumericalPoint(dimension, 3.0), NumericalPoint(dimension, 2.0), R);
-    UnsignedInteger size(100);
-    NumericalSample sample2D(distribution.getSample(size));
-    NumericalSample firstSample(size, 1);
-    NumericalSample secondSample(size, 1);
+    Normal distribution(Point(dimension, 3.0), Point(dimension, 2.0), R);
+    UnsignedInteger size = 100;
+    Sample sample2D(distribution.getSample(size));
+    Sample firstSample(size, 1);
+    Sample secondSample(size, 1);
     for (UnsignedInteger i = 0; i < size; i++)
     {
       firstSample[i][0] = sample2D[i][0];
@@ -129,19 +126,17 @@ int main(int argc, char *argv[])
 
   /* CobWeb tests */
   {
-    UnsignedInteger size(100);
-    UnsignedInteger inputDimension(6);
-    NumericalSample inputSample(Normal(inputDimension).getSample(size));
+    UnsignedInteger size = 100;
+    UnsignedInteger inputDimension = 6;
+    Sample inputSample(Normal(inputDimension).getSample(size));
     Description inputVar(inputDimension);
     for (UnsignedInteger i = 0; i < inputDimension; ++i) inputVar[i] = (OSS() << "X" << i);
     Description formula(1);
     OSS oss;
     for (UnsignedInteger i = 0; i < inputDimension; ++i) oss << (i > 0 ? "+" : "") << "cos(" << i + 1 << "*" << inputVar[i] << ")";
     formula[0] = oss;
-    Description outputVar(1);
-    outputVar[0] = "y";
-    NumericalMathFunction model(inputVar, outputVar, formula);
-    NumericalSample outputSample(model(inputSample));
+    SymbolicFunction model(inputVar, formula);
+    Sample outputSample(model(inputSample));
     Graph cobwebValue(VisualTest::DrawCobWeb(inputSample, outputSample, 2.5, 3.0, "red", false));
     fullprint << "cobwebValue = " << cobwebValue << std::endl;
     Graph cobwebQuantile(VisualTest::DrawCobWeb(inputSample, outputSample, 0.7, 0.9, "red", false));
@@ -150,12 +145,12 @@ int main(int argc, char *argv[])
 
   /* KendallPlot tests */
   {
-    UnsignedInteger size(100);
+    UnsignedInteger size = 100;
     FrankCopula copula1(1.5);
     GumbelCopula copula2(4.5);
-    NumericalSample sample1(copula1.getSample(size));
+    Sample sample1(copula1.getSample(size));
     sample1.setName("data 1");
-    NumericalSample sample2(copula2.getSample(size));
+    Sample sample2(copula2.getSample(size));
     sample2.setName("data 2");
     Graph kendallPlot1(VisualTest::DrawKendallPlot(sample1, copula2));
     fullprint << "KendallPlot1 = " << kendallPlot1 << std::endl;
