@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_WelchFactory_std.cxx
  *  @brief The test file of class WelchFactory
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author haddad
- *  @date   2011-11-22 12:09:10 +0100 (mar. 22 nov. 2011)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -37,23 +34,23 @@ int main(int argc, char *argv[])
   {
     // Dimension of the input model
     // Size of the TimeGrid
-    UnsignedInteger size(64);
-    UnsignedInteger dimension(1);
+    UnsignedInteger size = 64;
+    UnsignedInteger dimension = 1;
     RegularGrid timeGrid(0.0, 0.1, size);
-    NumericalPoint amplitude(dimension, 2.0);
-    NumericalPoint scale(dimension, 1.0);
-    ExponentialCauchy model(amplitude, scale);
-    SpectralNormalProcess myProcess(model, timeGrid);
+    Point amplitude(dimension, 2.0);
+    Point scale(dimension, 1.0);
+    ExponentialCauchy model(scale, amplitude);
+    SpectralGaussianProcess myProcess(model, timeGrid);
 
     // Create a Process sample
-    UnsignedInteger N(100);
+    UnsignedInteger N = 100;
     ProcessSample sample(myProcess.getSample(N));
 
     // Filtering Windows
     WelchFactory myFactory;
 
     // Build a UserDefinedSpectralModel using the Welch method
-    SpectralModel mySpectralModel(myFactory.build(sample));
+    UserDefinedSpectralModel mySpectralModel(myFactory.buildAsUserDefinedSpectralModel(sample));
 
     // Get the frequency grid of the model
     RegularGrid myFrequencyGrid(mySpectralModel.getFrequencyGrid());
@@ -64,9 +61,9 @@ int main(int argc, char *argv[])
         fullprint << "Spectre " << i << "-" << j << std::endl;
         for (UnsignedInteger k = 0; k < myFrequencyGrid.getN(); ++k)
         {
-          const NumericalScalar frequency(myFrequencyGrid.getStart() + k * myFrequencyGrid.getStep());
-          const NumericalScalar estimatedValue(std::real(mySpectralModel(frequency)(i, j)));
-          const NumericalScalar modelValue(std::real(model.computeSpectralDensity(frequency)(i, j)));
+          const Scalar frequency = myFrequencyGrid.getStart() + k * myFrequencyGrid.getStep();
+          const Scalar estimatedValue = std::real(mySpectralModel(frequency)(i, j));
+          const Scalar modelValue = std::real(model.computeSpectralDensity(frequency)(i, j));
           fullprint << "Frequency =  " <<  frequency ;
           fullprint << ", evaluation = " << estimatedValue << " model = " << modelValue << std::endl;
         }
@@ -76,7 +73,7 @@ int main(int argc, char *argv[])
     TimeSeries timeSeries(myProcess.getRealization());
 
     // Build a UserDefinedSpectralModel using the Welch method
-    SpectralModel mySpectralModel2(myFactory.build(timeSeries));
+    UserDefinedSpectralModel mySpectralModel2(myFactory.buildAsUserDefinedSpectralModel(timeSeries));
 
     // Get the frequency grid of the model
     myFrequencyGrid = mySpectralModel2.getFrequencyGrid();
@@ -87,9 +84,9 @@ int main(int argc, char *argv[])
         fullprint << "Spectre " << i << "-" << j << std::endl;
         for (UnsignedInteger k = 0; k < myFrequencyGrid.getN(); ++k)
         {
-          const NumericalScalar frequency(myFrequencyGrid.getStart() + k * myFrequencyGrid.getStep());
-          const NumericalScalar estimatedValue(std::real(mySpectralModel2(frequency)(i, j)));
-          const NumericalScalar modelValue(std::real(model.computeSpectralDensity(frequency)(i, j)));
+          const Scalar frequency = myFrequencyGrid.getStart() + k * myFrequencyGrid.getStep();
+          const Scalar estimatedValue = std::real(mySpectralModel2(frequency)(i, j));
+          const Scalar modelValue = std::real(model.computeSpectralDensity(frequency)(i, j));
           fullprint << "Frequency =  " <<  frequency ;
           fullprint << ", evaluation = " << estimatedValue << " model = " << modelValue << std::endl;
         }
