@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_WhiteNoise_std.cxx
  *  @brief The test file of class WhiteNoise
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-07-16 10:12:54 +0200 (Mon, 16 Jul 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -36,9 +33,9 @@ int main(int argc, char *argv[])
   try
   {
 
-    const NumericalScalar Tmin(0.0);
-    const NumericalScalar deltaT(0.1);
-    const UnsignedInteger N(11);
+    const Scalar Tmin = 0.0;
+    const Scalar deltaT = 0.1;
+    const UnsignedInteger N = 11;
 
     /* Initialization of the RegularGrid timeGrid1*/
     RegularGrid timeGrid(Tmin, deltaT, N);
