@@ -1,9 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @file  t_Wilks_std.cxx
  *  @brief The test file of class Wilks for standard methods
  *
- *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
+ *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,14 +14,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
- *  @author schueller
- *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
-#include "OT.hxx"
-#include "OTtestcode.hxx"
+#include "openturns/OT.hxx"
+#include "openturns/OTtestcode.hxx"
 
 using namespace OT;
 using namespace OT::Test;
@@ -40,10 +37,10 @@ int main(int argc, char *argv[])
     RandomVector vector(distribution);
     std::cout << "vector=" << vector << std::endl;
     Wilks algo(vector);
-    NumericalPoint alpha(2);
+    Point alpha(2);
     alpha[0] = 0.9;
     alpha[1] = 0.95;
-    NumericalPoint beta(2);
+    Point beta(2);
     beta[0] = 0.9;
     beta[1] = 0.95;
     for (UnsignedInteger a = 0; a < 2; a++)
