@@ -3,18 +3,21 @@ from matplotlib import pyplot as plt
 from openturns.viewer import View
 ot.RandomGenerator.SetSeed(0)
 
-def flooding(X) :
-    Hd = 3.0;     Zb = 55.5
-    L = 5.0e3;     B = 300.0
+
+def flooding(X):
+    Hd = 3.0
+    Zb = 55.5
+    L = 5.0e3
+    B = 300.0
     Zd = Zb + Hd
     Q, Ks, Zv, Zm = X
-    alpha = (Zm - Zv)/L
-    H = (Q/(Ks*B*alpha**0.5))**0.6
+    alpha = (Zm - Zv) / L
+    H = (Q / (Ks * B * alpha**0.5))**0.6
     Zc = H + Zv
     S = Zc - Zd
     return [S]
 
-myFunction = ot.PythonFunction(4, 1, flooding) 
+myFunction = ot.PythonFunction(4, 1, flooding)
 myParam = ot.GumbelAB(1013.0, 558.0)
 Q = ot.ParametrizedDistribution(myParam)
 Q = ot.TruncatedDistribution(Q, 0.0, ot.SpecFunc.MaxScalar)
@@ -23,13 +26,14 @@ Ks = ot.TruncatedDistribution(Ks, 0.0, ot.SpecFunc.MaxScalar)
 Zv = ot.Uniform(49.0, 51.0)
 Zm = ot.Uniform(54.0, 56.0)
 inputX = ot.ComposedDistribution([Q, Ks, Zv, Zm])
-inputX.setDescription(["Q","Ks", "Zv", "Zm"])
+inputX.setDescription(["Q", "Ks", "Zv", "Zm"])
 
 size = 5000
 computeSO = True
 inputDesign = ot.SobolIndicesExperiment(inputX, size, computeSO).generate()
 outputDesign = myFunction(inputDesign)
-sensitivityAnalysis = ot.JansenSensitivityAlgorithm(inputDesign, outputDesign, size)
+sensitivityAnalysis = ot.JansenSensitivityAlgorithm(
+    inputDesign, outputDesign, size)
 
 graph = sensitivityAnalysis.draw()
 
