@@ -6,7 +6,6 @@ Documentation is available online at http://www.openturns.org.
 Available submodules
 --------------------
 common                                --- Utility classes
-wrapper                               --- Wrapping utilities
 typ                                   --- Internal data types
 statistics                            --- Statistical classes
 graph                                 --- Graphical output
@@ -42,11 +41,9 @@ Environment variables
 ---------------------
 OPENTURNS_HOME                        --- Custom installation path
 OPENTURNS_CONFIG_PATH                 --- Path to configuration file
-OPENTURNS_WRAPPER_PATH                --- Path to custom wrappers
 OPENTURNS_LOG_SEVERITY                --- Log severity flag, for example "ALL"
 """
 import sys
-import warnings
 
 # SWIG-related: check if interactive mode
 if not hasattr(sys, 'ps1'):
@@ -62,7 +59,6 @@ if not hasattr(sys, 'ps1'):
             pass
 
 from .common import *
-from .wrapper import *
 from .typ import *
 from .graph import *
 from .geom import *
@@ -90,10 +86,8 @@ from .stattests import *
 from .bayesian import *
 from .uncertainty import *
 
-from .coupling_tools import *
 
-
-def Show(graph, block=False):
+def Show(graph):
     """
     Display a graph pop-up.
 
@@ -104,6 +98,6 @@ def Show(graph, block=False):
     """
     from .viewer import View
     view = View(graph)
-    view.show()
+    view.ShowAll()
 
 __version__ = PlatformInfo.GetVersion()
