@@ -3,7 +3,7 @@
 # @brief Gives functions that help coupling against external code,
 #   .i.e: manipulate template file.
 #
-# Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
+# Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
 #
 # This library is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -15,7 +15,7 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Lesser General Public
+# You should have received a copy of the GNU Lesser General Public License
 # along with this library.  If not, see <http://www.gnu.org/licenses/>.
 #
 #
@@ -98,7 +98,8 @@ def replace(infile, outfile, tokens, values, formats=None, encoding=default_enco
     >>> # display file
     >>> with open('prgm.dat', 'r') as f:
     ...     print(f.read())
-    E=1.4 F=5"""
+    E=1.4 F=5
+    """
     if len(tokens) != len(values):
         raise AssertionError("Error: tokens size is != values size!")
     check_param(tokens, list)
