@@ -92,6 +92,8 @@ class View(object):
 
     add_legend : bool, optional
         Adds a legend if True. Default is True.
+    square_axes : bool, optional
+        Forces the axes to share the same scale if True. Default is False.
     """
 
     @staticmethod
@@ -129,6 +131,7 @@ class View(object):
                  text_kwargs=None,
                  legend_kwargs=None,
                  add_legend=True,
+                 square_axes=False,
                  **kwargs):
 
         # prevent Qt from stopping the interpreter, see matplotlib PR #1905
@@ -220,6 +223,8 @@ class View(object):
             self._ax = [self._fig.add_subplot(111, **axes_kwargs)]
         else:
             self._ax = axes
+        # activate axes only if wanted
+        self._ax[0].axison = graph.getAxes()
 
         has_labels = False
         self._ax[0].grid(b=graph.getGrid())
@@ -249,8 +254,8 @@ class View(object):
                     text_kwargs['color'] = drawable.getColorCode()
 
             # set marker
-            pointStyleDict = {'square': 's', 'circle': 'o', 'triangleup': '2', 'plus': '+', 'times': '+', 'diamond': '+', 'triangledown':
-                              'v', 'star': '*', 'fsquare': 's', 'fcircle': 'o', 'ftriangleup': '2', 'fdiamond': 'D', 'bullet': '.', 'dot': ',', 'none': 'None'}
+            pointStyleDict = {'square': 's', 'circle': 'o', 'triangleup': '^', 'plus': '+', 'times': 'x', 'diamond': 'd', 'triangledown':
+                              'v', 'star': '*', 'fsquare': 's', 'fcircle': 'o', 'ftriangleup': '^', 'fdiamond': 'd', 'bullet': '.', 'dot': ',', 'none': 'None'}
             if 'marker' not in plot_kwargs_default:
                 try:
                     plot_kwargs['marker'] = pointStyleDict[
@@ -345,24 +350,18 @@ class View(object):
 
                 polygonsNumber = drawable.getPalette().getSize()
                 verticesNumber = drawable.getData().getSize() // polygonsNumber
-                colors = drawable.getPalette()
-                colorsRGBA = []
-                for i in range(polygonsNumber):
-                    hex_code = ot.Drawable.ConvertFromName(colors[i])
-                    rgba = ot.Drawable.ConvertToRGBA(hex_code)
-                    colorsRGBA.append(
-                        (rgba[0] / 255.0, rgba[1] / 255.0, rgba[2] / 255.0, rgba[3] / 255.0))
+                colorsRGBA = drawable.getPaletteAsNormalizedRGBA()
                 if 'facecolors' not in polygoncollection_kwargs_default:
                     polygoncollection_kwargs['facecolors'] = colorsRGBA
 
-                if 'edgecolors' not in polygon_kwargs_default:
+                if 'edgecolors' not in polygoncollection_kwargs_default:
                     polygoncollection_kwargs['edgecolors'] = colorsRGBA
                 self._ax[0].add_collection(
                     matplotlib.collections.PolyCollection(np.array(data).reshape((polygonsNumber, verticesNumber, 2)), **polygoncollection_kwargs))
 
             elif drawableKind == 'Pie':
                 pie_kwargs.setdefault(
-                    'labels', list(map(self.ToUnicode, drawable.getLabels())))
+                    'labels', [self.ToUnicode(label) for label in drawable.getLabels()])
                 pie_kwargs.setdefault('colors', drawable.getPalette())
                 self._ax[0].set_aspect('equal')
                 self._ax[0].pie(x, **pie_kwargs)
@@ -392,7 +391,8 @@ class View(object):
                         plt.clabel(contourset, **clabel_kwargs)
                     except KeyError:
                         # https://github.com/matplotlib/matplotlib/issues/9742
-                        warnings.warn('pyplot.clabel likely failed on boundary level')
+                        warnings.warn(
+                            'pyplot.clabel likely failed on boundary level')
                 for i in range(len(contourset.levels)):
                     contourset.collections[i].set_label(
                         '_nolegend_' if i > 0 else drawable.getLegend())
@@ -516,6 +516,13 @@ class View(object):
             legend_kwargs.setdefault('prop', {'size': 10})
 
             self._ax[0].legend(**legend_kwargs)
+        # Make squares look like squares
+        if square_axes:
+            try:
+                self._ax[0].axis('square')
+            except ValueError:
+                warnings.warn('axis square keyword not supported')
+                plt.gca().set_aspect('equal', adjustable='box')
 
     def show(self, **kwargs):
         """
@@ -569,9 +576,9 @@ class View(object):
         plt.close(self._fig)
 
 
-def ToSVGString(graph):
+def ToImageString(graph):
     """
-    Convert as SVG file.
+    Convert as image string.
 
     Parameters
     ----------
@@ -580,7 +587,8 @@ def ToSVGString(graph):
 
     Returns
     -------
-    str: a SVG representation as string
+    image_str : str
+       An image representation as string
     """
     # save interactive mode state
     ision = plt.isinteractive()
@@ -588,15 +596,21 @@ def ToSVGString(graph):
 
     view = View(graph)
     output = io.BytesIO()
-    view.save(output, format='svg')
+    fmt = ot.ResourceMap.Get('View-ImageFormat')
+    view.save(output, format=fmt, dpi=100)
     view.close()
 
     # restore interactive mode state
     if ision:
         plt.ion()
 
-    svgBytes = output.getvalue()
-    return svgBytes.decode('utf-8')
+    image_bytes = output.getvalue()
+    if fmt == 'svg':
+        image_string = image_bytes.decode('utf-8')
+    else:
+        # raw bytes
+        image_string = image_bytes
+    return image_string
 
 
 def PlotDesign(design, bounds, Nx, Ny, figure=None, axes=[], plot_kwargs={}, axes_kwargs={}, text_kwargs={}):
