@@ -1,5 +1,6 @@
 #! /usr/bin/env python
 
+from __future__ import print_function
 from openturns import *
 
 TESTPREAMBLE()
@@ -17,10 +18,10 @@ try:
 
     # Composite process
     process = CompositeProcess(
-        SpatialFunction(NumericalMathFunction("x", "x+2")), whiteNoise)
+        ValueFunction(SymbolicFunction("x", "x+2")), whiteNoise)
     # A realization of the process
     timeSeries = process.getRealization()
-    sample = timeSeries.getSample()
+    sample = timeSeries.getValues()
 
     # Now we build the factory
     factory = BoxCoxFactory()
@@ -28,22 +29,22 @@ try:
     # Creation of the BoxCoxTransform
     myBoxCox = factory.build(timeSeries)
 
-    print "myBoxCox (time-series)=", myBoxCox
-    print "myBoxCox (sample)     =", factory.build(sample)
+    print("myBoxCox (time-series)=", myBoxCox)
+    print("myBoxCox (sample)     =", factory.build(sample))
 
     # Creation of the BoxCoxTransform using shift
-    shift = NumericalPoint(1, 1.0)
+    shift = Point(1, 1.0)
     myBoxCoxShift = factory.build(timeSeries, shift)
 
-    print "myBoxCox with shift (time-series)=", myBoxCoxShift
-    print "myBoxCox with shift (sample)     =", factory.build(sample, shift)
+    print("myBoxCox with shift (time-series)=", myBoxCoxShift)
+    print("myBoxCox with shift (sample)     =", factory.build(sample, shift))
 
     # Creation of the BoxCoxTransform using shift with graph
     graph = Graph()
     myBoxCoxShiftGraph = factory.build(timeSeries, shift, graph)
 
-    print "BoxCox graph (time-series)=", graph
+    print("BoxCox graph (time-series)=", graph)
 
 except:
     import sys
-    print "t_BoxCoxFactory_std.py", sys.exc_type, sys.exc_value
+    print("t_BoxCoxFactory_std.py", sys.exc_info()[0], sys.exc_info()[1])
