@@ -1,10 +1,11 @@
 #! /usr/bin/env python
 
+from __future__ import print_function
 from openturns import *
 from math import *
 
 
-def printNumericalPoint(point, digits):
+def printPoint(point, digits):
     oss = "["
     eps = pow(0.1, digits)
     for i in range(point.getDimension()):
@@ -30,21 +31,19 @@ try:
     inputFunc = Description(2)
     inputFunc[0] = "x0"
     inputFunc[1] = "x1"
-    outputFunc = Description(1)
-    outputFunc[0] = "y0"
-    formulas = Description(outputFunc.getSize())
+    formulas = Description(1)
     formulas[0] = "-(6+x0^2-x1)"
-    print "formulas=", formulas
-    myFunction = NumericalMathFunction(inputFunc, outputFunc, formulas)
+    print("formulas=", formulas)
+    myFunction = SymbolicFunction(inputFunc, formulas)
 
     dim = myFunction.getInputDimension()
     # We create a normal distribution point of dimension 1
-    mean = NumericalPoint(dim, 0.0)
+    mean = Point(dim, 0.0)
     # x0
     mean[0] = 5.0
     # x1
     mean[1] = 2.1
-    sigma = NumericalPoint(dim, 0.0)
+    sigma = Point(dim, 0.0)
     # x0
     sigma[0] = 3.3
     # x1
@@ -72,21 +71,20 @@ try:
 
     # We create a NearestPoint algorithm
     myCobyla = Cobyla()
-    myCobyla.setSpecificParameters(CobylaSpecificParameters())
-    myCobyla.setMaximumIterationsNumber(100)
+    myCobyla.setMaximumEvaluationNumber(200)
     myCobyla.setMaximumAbsoluteError(1.0e-10)
     myCobyla.setMaximumRelativeError(1.0e-10)
     myCobyla.setMaximumResidualError(1.0e-10)
     myCobyla.setMaximumConstraintError(1.0e-10)
-    print "myCobyla=", myCobyla
+    print("myCobyla=", myCobyla)
 
     # We create a FORM algorithm
-    # The first parameter is a NearestPointAlgorithm
+    # The first parameter is an OptimizationAlgorithm
     # The second parameter is an event
     # The third parameter is a starting point for the design point research
     myAlgo = FORM(myCobyla, myEvent, mean)
 
-    print "FORM=", myAlgo
+    print("FORM=", myAlgo)
 
     # Perform the simulation
     myAlgo.run()
@@ -94,40 +92,35 @@ try:
     # Stream out the result
     result = FORMResult(myAlgo.getResult())
     digits = 5
-    print "importance factors=", printNumericalPoint(result.getImportanceFactors(), digits)
+    print("importance factors=", printPoint(
+        result.getImportanceFactors(), digits))
 
     # Graph 1 : Importance Factors graph
     importanceFactorsGraph = result.drawImportanceFactors()
-    importanceFactorsGraph.draw("ImportanceFactorsDrawingFORM", 640, 480)
+    importanceFactorsGraph.draw("ImportanceFactorsDrawingFORM.png")
 
     # Graph 2 : Hasofer Reliability Index Sensitivity Graphs graph
     reliabilityIndexSensitivityGraphs = result.drawHasoferReliabilityIndexSensitivity(
     )
     graph2a = reliabilityIndexSensitivityGraphs[0]
-    graph2a.draw("HasoferReliabilityIndexMarginalSensitivityDrawing", 640, 480)
-    # Check that the correct files have been generated by computing their
-    # checksum
+    graph2a.draw("HasoferReliabilityIndexMarginalSensitivityDrawing.png")
+
     graph2b = reliabilityIndexSensitivityGraphs[1]
-    graph2b.draw("HasoferReliabilityIndexOtherSensitivityDrawing", 640, 480)
-    # Check that the correct files have been generated by computing their
-    # checksum
+    graph2b.draw("HasoferReliabilityIndexOtherSensitivityDrawing.png")
 
     # Graph 3 : FORM Event Probability Sensitivity Graphs graph
     eventProbabilitySensitivityGraphs = result.drawEventProbabilitySensitivity(
     )
     graph3a = eventProbabilitySensitivityGraphs[0]
-    graph3a.draw("EventProbabilityIndexMarginalSensitivityDrawing", 640, 480)
-    # Check that the correct files have been generated by computing their
-    # checksum
+    graph3a.draw("EventProbabilityIndexMarginalSensitivityDrawing.png")
+
     graph3b = eventProbabilitySensitivityGraphs[1]
-    graph3b.draw("EventProbabilityIndexOtherSensitivityDrawing", 640, 480)
-    # Check that the correct files have been generated by computing their
-    # checksum
+    graph3b.draw("EventProbabilityIndexOtherSensitivityDrawing.png")
 
     # Graph 4 : Convergence history
     graph4 = result.getOptimizationResult().drawErrorHistory()
-    graph4.draw("ConvergenceHistory", 640, 480)
+    graph4.draw("ConvergenceHistory.png")
 
 except:
     import sys
-    print "t_FORM_draw.py", sys.exc_type, sys.exc_value
+    print("t_FORM_draw.py", sys.exc_info()[0], sys.exc_info()[1])
