@@ -1,5 +1,6 @@
 #! /usr/bin/env python
 
+from __future__ import print_function
 from openturns import *
 
 from math import *
@@ -7,7 +8,7 @@ from math import *
 TESTPREAMBLE()
 
 
-def printNumericalPoint(point, digits):
+def printPoint(point, digits):
     oss = "["
     eps = pow(0.1, digits)
     for i in range(point.getDimension()):
@@ -26,13 +27,13 @@ def printNumericalPoint(point, digits):
 try:
 
         # We create a numerical math function
-    myFunction = NumericalMathFunction(
-        ["E", "F", "L", "I"], ["d"], ["-F*L^3/(3*E*I)"])
+    myFunction = SymbolicFunction(
+        ["E", "F", "L", "I"], ["-F*L^3/(3*E*I)"])
 
     dim = myFunction.getInputDimension()
 
     # We create a normal distribution point of dimension 1
-    mean = NumericalPoint(dim, 0.0)
+    mean = Point(dim, 0.0)
     # E
     mean[0] = 50.0
     # F
@@ -41,7 +42,7 @@ try:
     mean[2] = 10.0
     # I
     mean[3] = 5.0
-    sigma = NumericalPoint(dim, 1.0)
+    sigma = Point(dim, 1.0)
     R = IdentityMatrix(dim)
     myDistribution = Normal(mean, sigma, R)
 
@@ -56,21 +57,20 @@ try:
 
     # We create a NearestPoint algorithm
     myCobyla = Cobyla()
-    myCobyla.setSpecificParameters(CobylaSpecificParameters())
-    myCobyla.setMaximumIterationsNumber(100)
+    myCobyla.setMaximumEvaluationNumber(400)
     myCobyla.setMaximumAbsoluteError(1.0e-10)
     myCobyla.setMaximumRelativeError(1.0e-10)
     myCobyla.setMaximumResidualError(1.0e-10)
     myCobyla.setMaximumConstraintError(1.0e-10)
-    print "myCobyla=", myCobyla
+    print("myCobyla=", myCobyla)
 
     # We create a FORM algorithm
-    # The first parameter is a NearestPointAlgorithm
+    # The first parameter is an OptimizationAlgorithm
     # The second parameter is an event
     # The third parameter is a starting point for the design point research
     myAlgo = FORM(myCobyla, myEvent, mean)
 
-    print "FORM=", myAlgo
+    print("FORM=", myAlgo)
 
     # Perform the simulation
     myAlgo.run()
@@ -78,17 +78,23 @@ try:
     # Stream out the iresult
     result = myAlgo.getResult()
     digits = 5
-    print "event probability=%.6f" % result.getEventProbability()
-    print "generalized reliability index=%.6f" % result.getGeneralisedReliabilityIndex()
-    print "standard space design point=", printNumericalPoint(result.getStandardSpaceDesignPoint(), digits)
-    print "physical space design point=", printNumericalPoint(result.getPhysicalSpaceDesignPoint(), digits)
+    print("event probability=%.6f" % result.getEventProbability())
+    print("generalized reliability index=%.6f" %
+          result.getGeneralisedReliabilityIndex())
+    print("standard space design point=", printPoint(
+        result.getStandardSpaceDesignPoint(), digits))
+    print("physical space design point=", printPoint(
+        result.getPhysicalSpaceDesignPoint(), digits))
 
     # Is the standard point origin in failure space?
-    print "is standard point origin in failure space? %s" % (result.getIsStandardPointOriginInFailureSpace() and "true" or "false")
+    print("is standard point origin in failure space? %s" %
+          (result.getIsStandardPointOriginInFailureSpace() and "true" or "false"))
 
-    print "importance factors=", printNumericalPoint(result.getImportanceFactors(), digits)
-    print "Hasofer reliability index=%.6f" % result.getHasoferReliabilityIndex()
+    print("importance factors=", printPoint(
+        result.getImportanceFactors(), digits))
+    print("Hasofer reliability index=%.6f" %
+          result.getHasoferReliabilityIndex())
 
 except:
     import sys
-    print "t_FORM_std.py", sys.exc_type, sys.exc_value
+    print("t_FORM_std.py", sys.exc_info()[0], sys.exc_info()[1])
