@@ -1,5 +1,6 @@
 #! /usr/bin/env python
 
+from __future__ import print_function
 from openturns import *
 from math import *
 
@@ -20,10 +21,8 @@ try:
     # Create the Sobol function
     # Reference analytical values
     meanTh = 1.0
-    a = NumericalPoint(dimension)
+    a = Point(dimension)
     inputVariables = Description(dimension)
-    outputVariables = Description(1)
-    outputVariables[0] = "y"
     formula = Description(1)
     formula[0] = "1.0"
     covTh = 1.0
@@ -35,15 +34,15 @@ try:
             " * ((abs(4.0 * xi" + str(i) + " - 2.0) + " + \
             str(a[i]) + ") / (1.0 + " + str(a[i]) + "))"
     covTh = covTh - 1.0
-    model = NumericalMathFunction(inputVariables, outputVariables, formula)
+    model = SymbolicFunction(inputVariables, formula)
 
     # Create the input distribution
-    distribution = ComposedDistribution([Uniform(0.0, 1.0)] * dimension)
+    marginals = [Uniform(0.0, 1.0)] * dimension
+    distribution = ComposedDistribution(marginals)
 
     # Create the orthogonal basis
     enumerateFunction = LinearEnumerateFunction(dimension)
-    productBasis = OrthogonalProductPolynomialFactory(
-        [LegendreFactory()] * dimension, enumerateFunction)
+    productBasis = OrthogonalProductPolynomialFactory(marginals)
 
     # Create the adaptive strategy
     # We can choose amongst several strategies
@@ -89,42 +88,48 @@ try:
 
             # Examine the results
             result = FunctionalChaosResult(algo.getResult())
-            print "###################################"
-            print AdaptiveStrategy(adaptiveStrategy)
-            print ProjectionStrategy(projectionStrategy)
+            print("###################################")
+            print(algo.getAdaptiveStrategy())
+            print(algo.getProjectionStrategy())
             # print "coefficients=", result.getCoefficients()
             residuals = result.getResiduals()
-            print "residuals=", residuals
+            print("residuals=", residuals)
             relativeErrors = result.getRelativeErrors()
-            print "relative errors=", relativeErrors
+            print("relative errors=", relativeErrors)
 
             # Post-process the results
             vector = FunctionalChaosRandomVector(result)
             mean = vector.getMean()[0]
-            print "mean=%.8f" % mean, "absolute error=%.8f" % fabs(mean - meanTh)
+            print("mean=%.8f" % mean, "absolute error=%.8f" %
+                  fabs(mean - meanTh))
             variance = vector.getCovariance()[0, 0]
-            print "variance=%.8f" % variance, "absolute error=%.8f" % fabs(variance - covTh)
+            sensitivity = FunctionalChaosSobolIndices(result)
+            print("variance=%.8f" % variance, "absolute error=%.8f" %
+                  fabs(variance - covTh))
             indices = Indices(1)
             for i in range(dimension):
                 indices[0] = i
-                value = vector.getSobolIndex(i)
-                print "Sobol index", i, "= %.8f" % value, "absolute error=%.8f" % fabs(value - sobol(indices, a) / covTh)
+                value = sensitivity.getSobolIndex(i)
+                print("Sobol index", i, "= %.8f" % value, "absolute error=%.8f" %
+                      fabs(value - sobol(indices, a) / covTh))
             indices = Indices(2)
             k = 0
             for i in range(dimension):
                 indices[0] = i
                 for j in range(i + 1, dimension):
                     indices[1] = j
-                    value = vector.getSobolIndex(indices)
-                    print "Sobol index", indices, "=%.8f" % value, "absolute error=%.8f" % fabs(value - sobol(indices, a) / covTh)
+                    value = sensitivity.getSobolIndex(indices)
+                    print("Sobol index", indices, "=%.8f" % value, "absolute error=%.8f" % fabs(
+                        value - sobol(indices, a) / covTh))
                     k = k + 1
             indices = Indices(3)
             indices[0] = 0
             indices[1] = 1
             indices[2] = 2
-            value = vector.getSobolIndex(indices)
-            print "Sobol index", indices, "=%.8f" % value, "absolute error=%.8f" % fabs(value - sobol(indices, a) / covTh)
+            value = sensitivity.getSobolIndex(indices)
+            print("Sobol index", indices, "=%.8f" % value, "absolute error=%.8f" %
+                  fabs(value - sobol(indices, a) / covTh))
 
 except:
     import sys
-    print "t_FunctionalChaos_gsobol.py", sys.exc_type, sys.exc_value
+    print("t_FunctionalChaos_gsobol.py", sys.exc_info()[0], sys.exc_info()[1])
