@@ -31,13 +31,11 @@ try:
     inputVariables[0] = "xi1"
     inputVariables[1] = "xi2"
     inputVariables[2] = "xi3"
-    outputVariables = Description(1)
-    outputVariables[0] = "y"
     formula = Description(1)
     formula[0] = "sin(xi1) + (" + str(a) + \
         ") * (sin(xi2)) ^ 2 + (" + str(
             b) + ") * xi3^4 * sin(xi1)"
-    model = Function(inputVariables, outputVariables, formula)
+    model = SymbolicFunction(inputVariables, formula)
 
     # Create the input distribution
     distribution = ComposedDistribution([Uniform(-pi, pi)] * dimension)
@@ -111,8 +109,9 @@ try:
             variance = vector.getCovariance()[0, 0]
             print("variance=%.8f" % variance, "absolute error=%.10f" %
                   fabs(variance - covTh))
+            sensitivity = FunctionalChaosSobolIndices(result)
             for i in range(dimension):
-                value = vector.getSobolIndex(i)
+                value = sensitivity.getSobolIndex(i)
                 print("Sobol index", i, "= %.8f" %
                       value, "absolute error=%.10f" % fabs(value - sob_1[i]))
             indices = Indices(2)
@@ -121,7 +120,7 @@ try:
                 indices[0] = i
                 for j in range(i + 1, dimension):
                     indices[1] = j
-                    value = vector.getSobolIndex(indices)
+                    value = sensitivity.getSobolIndex(indices)
                     print("Sobol index", indices, "=%.8f" %
                           value, "absolute error=%.10f" % fabs(value - sob_2[k]))
                     k = k + 1
@@ -129,11 +128,11 @@ try:
             indices[0] = 0
             indices[1] = 1
             indices[2] = 2
-            value = vector.getSobolIndex(indices)
+            value = sensitivity.getSobolIndex(indices)
             print("Sobol index", indices, "=%.8f" %
                   value, "absolute error=%.10f" % fabs(value - sob_3[0]))
             for i in range(dimension):
-                value = vector.getSobolTotalIndex(i)
+                value = sensitivity.getSobolTotalIndex(i)
                 print("Sobol total index", i, "=%.8f" %
                       value, "absolute error=%.10f" % fabs(value - sob_T1[i]))
             indices = Indices(2)
@@ -142,7 +141,7 @@ try:
                 indices[0] = i
                 for j in range(i + 1, dimension):
                     indices[1] = j
-                    value = vector.getSobolIndex(indices)
+                    value = sensitivity.getSobolIndex(indices)
                     print("Sobol total index", indices, "=%.8f" %
                           value, "absolute error=%.10f" % fabs(value - sob_2[k]))
                     k = k + 1
@@ -150,11 +149,11 @@ try:
             indices[0] = 0
             indices[1] = 1
             indices[2] = 2
-            value = vector.getSobolTotalIndex(indices)
+            value = sensitivity.getSobolTotalIndex(indices)
             print("Sobol total index ", indices, "=%.8f" %
                   value, "absolute error=%.10f" % fabs(value - sob_3[0]))
             for i in range(dimension):
-                value = vector.getSobolGroupedIndex(i)
+                value = sensitivity.getSobolGroupedIndex(i)
                 print("Sobol grouped index", i, "=%.8f" %
                       value, "absolute error=%.10f" % fabs(value - sob_T1[i]))
             indices = Indices(2)
@@ -163,7 +162,7 @@ try:
                 indices[0] = i
                 for j in range(i + 1, dimension):
                     indices[1] = j
-                    value = vector.getSobolGroupedIndex(indices)
+                    value = sensitivity.getSobolGroupedIndex(indices)
                     print("Sobol grouped index", indices, "=%.8f" %
                           value, "absolute error=%.10f" % fabs(value - sob_2[k]))
                     k = k + 1
@@ -171,7 +170,7 @@ try:
             indices[0] = 0
             indices[1] = 1
             indices[2] = 2
-            value = vector.getSobolGroupedIndex(indices)
+            value = sensitivity.getSobolGroupedIndex(indices)
             print("Sobol grouped index ", indices, "=%.8f" %
                   value, "absolute error=%.10f" % fabs(value - sob_3[0]))
 
