@@ -1,5 +1,6 @@
 #! /usr/bin/env python
 
+from __future__ import print_function
 from openturns import *
 
 TESTPREAMBLE()
@@ -8,13 +9,13 @@ RandomGenerator.SetSeed(0)
 try:
 
     # We create a numerical math function
-    myFunction = NumericalMathFunction(
-        ["E", "F", "L", "I"], ["d"], ["-F*L^3/(3*E*I)"])
+    myFunction = SymbolicFunction(
+        ["E", "F", "L", "I"], ["-F*L^3/(3*E*I)"])
 
     dim = myFunction.getInputDimension()
 
     # We create a normal distribution point of dimension 1
-    mean = NumericalPoint(dim, 0.0)
+    mean = Point(dim, 0.0)
     # E
     mean[0] = 50.0
     # F
@@ -23,7 +24,7 @@ try:
     mean[2] = 10.0
     # I
     mean[3] = 5.0
-    sigma = NumericalPoint(dim, 1.0)
+    sigma = Point(dim, 1.0)
     R = IdentityMatrix(dim)
     myDistribution = Normal(mean, sigma, R)
 
@@ -42,14 +43,14 @@ try:
     myAlgo.setBlockSize(4)
     myAlgo.setMaximumCoefficientOfVariation(0.1)
 
-    print "LHS=", myAlgo
+    print("LHS=", myAlgo)
 
     # Perform the simulation
     myAlgo.run()
 
     # Stream out the result
-    print "LHS result=", myAlgo.getResult()
+    print("LHS result=", myAlgo.getResult())
 
 except:
     import sys
-    print "t_LHS_std.py", sys.exc_type, sys.exc_value
+    print("t_LHS_std.py", sys.exc_info()[0], sys.exc_info()[1])
