@@ -7,8 +7,8 @@ ot.TESTPREAMBLE()
 ot.PlatformInfo.SetNumericalPrecision(3)
 
 # linear
-levelFunction = ot.Function(
-    ["x1", "x2", "x3", "x4"], ["y1"], ["x1+2*x2-3*x3+4*x4"])
+levelFunction = ot.SymbolicFunction(
+    ["x1", "x2", "x3", "x4"], ["x1+2*x2-3*x3+4*x4"])
 # Add a finite difference gradient to the function
 myGradient = ot.NonCenteredFiniteDifferenceGradient(
     1e-7, levelFunction.getEvaluation())
@@ -26,8 +26,8 @@ print('result=', result)
 
 
 # non-linear
-levelFunction = ot.Function(
-    ["x1", "x2", "x3", "x4"], ["y1"], ["x1*cos(x1)+2*x2*x3-3*x3+4*x3*x4"])
+levelFunction = ot.SymbolicFunction(
+    ["x1", "x2", "x3", "x4"], ["x1*cos(x1)+2*x2*x3-3*x3+4*x3*x4"])
 # Add a finite difference gradient to the function,
 # needs it
 myGradient = ot.NonCenteredFiniteDifferenceGradient(
